from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32F4 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32F401CCFx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CCFx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die423'], 'footprint':'Package_CSP:ST_WLCSP-49_Die423', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CCFx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401C_B-C_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401C_B-C_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401C_B-C_Ux\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401C_B-C_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401C_B-C_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die423'], 'footprint':'Package_CSP:ST_WLCSP-49_Die423', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401C_B-C_Yx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401C_D-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401C_D-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401C_D-E_Ux\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401C_D-E_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401C_D-E_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die433'], 'footprint':'Package_CSP:ST_WLCSP-49_Die433', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401C_D-E_Yx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401R_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401R_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401R_B-C_Tx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401R_D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401R_D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401R_D-E_Tx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401V_B-C_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401V_B-C_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401V_B-C_Hx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401V_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401V_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401V_B-C_Tx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401V_D-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401V_D-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401V_D-E_Hx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401V_D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401V_D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401V_D-E_Tx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F405O_E-G_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F405O_E-G_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-90_Die413'], 'footprint':'Package_CSP:ST_WLCSP-90_Die413', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f405oe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F405O_E-G_Yx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='B10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F405RGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F405RGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f405rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F405RGTx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F405VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F405VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f405vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F405VGTx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F405ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F405ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f405zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F405ZGTx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407I_E-G_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407I_E-G_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407I_E-G_Hx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407I_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407I_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407I_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407V_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407V_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407V_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407Z_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407Z_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407Z_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410C_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410C_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410C_8-B_Tx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410C_8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410C_8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410C_8-B_Ux\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410R_8-B_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410R_8-B_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410R_8-B_Ix\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410R_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410R_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410R_8-B_Tx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410T_8-B_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410T_8-B_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-36_Die458'], 'footprint':'Package_CSP:ST_WLCSP-36_Die458', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410t8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410T_8-B_Yx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411C_C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411C_C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411C_C-E_Ux\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411C_C-E_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411C_C-E_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die431'], 'footprint':'Package_CSP:ST_WLCSP-49_Die431', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411C_C-E_Yx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411R_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411R_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411R_C-E_Tx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411V_C-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411V_C-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411V_C-E_Hx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411V_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411V_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411V_C-E_Tx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412C_E-G_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412C_E-G_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412C_E-G_Ux\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412R_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412R_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412R_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412R_E-G_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412R_E-G_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die441'], 'footprint':'Package_CSP:ST_WLCSP-64_Die441', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412R_E-G_Yx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412R_E-G_YxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412R_E-G_YxP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die441'], 'footprint':'Package_CSP:ST_WLCSP-64_Die441', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412R_E-G_YxP\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412V_E-G_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412V_E-G_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412V_E-G_Hx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412V_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412V_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412V_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412Z_E-G_Jx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412Z_E-G_Jx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412Z_E-G_Jx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412Z_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412Z_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412Z_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413C_G-H_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413C_G-H_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413cg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413C_G-H_Ux\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413M_G-H_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413M_G-H_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_Die463'], 'footprint':'Package_CSP:ST_WLCSP-81_Die463', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413mg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413M_G-H_Yx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413R_G-H_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413R_G-H_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413R_G-H_Tx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413V_G-H_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413V_G-H_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413V_G-H_Hx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413V_G-H_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413V_G-H_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413V_G-H_Tx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413Z_G-H_Jx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413Z_G-H_Jx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413Z_G-H_Jx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413Z_G-H_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413Z_G-H_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413Z_G-H_Tx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F415OGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F415OGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-90_Die413'], 'footprint':'Package_CSP:ST_WLCSP-90_Die413', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f415og.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F415OGYx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='B10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F415RGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F415RGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f415rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F415RGTx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F415VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F415VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f415vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F415VGTx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F415ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F415ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f415zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F415ZGTx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417I_E-G_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417I_E-G_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417I_E-G_Hx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417I_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417I_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417I_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417V_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417V_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417V_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417Z_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417Z_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417Z_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F423CHUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F423CHUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f423ch.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F423CHUx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F423MHYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F423MHYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_Die463'], 'footprint':'Package_CSP:ST_WLCSP-81_Die463', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f423mh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F423MHYx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F423RHTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F423RHTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f423rh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F423RHTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F423VHHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F423VHHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f423vh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F423VHHx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F423VHTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F423VHTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f423vh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F423VHTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F423ZHJx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F423ZHJx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f423zh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F423ZHJx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F423ZHTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F423ZHTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f423zh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F423ZHTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427A_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427A_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427A_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP_1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427I_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427I_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427I_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427I_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427I_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427I_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427V_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427V_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427V_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427Z_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427Z_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427Z_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429A_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429A_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429A_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP_1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429B_E-G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429B_E-G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429be.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429B_E-G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429IITx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429I_E-G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429I_E-G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429I_E-G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429I_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429I_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429I_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429NIHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429N_E-G_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429N_E-G_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ne.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429N_E-G_Hx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429VITx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429V_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429V_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429V_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429ZGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429ZGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die419'], 'footprint':'Package_CSP:ST_WLCSP-143_Die419', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429ZGYx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429ZITx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429ZIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429ZIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die419'], 'footprint':'Package_CSP:ST_WLCSP-143_Die419', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429ZIYx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429Z_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429Z_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429Z_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437AIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437AIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437AIHx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP_1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437I_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437I_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437I_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437I_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437I_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437I_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437V_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437V_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437V_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437Z_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437Z_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437Z_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439AIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439AIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439AIHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP_1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439B_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439B_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439B_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439I_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439I_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439I_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439I_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439I_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439I_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439N_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439N_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439N_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439V_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439V_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439V_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439Z_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439Z_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439Z_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439Z_G-I_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439Z_G-I_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die419'], 'footprint':'Package_CSP:ST_WLCSP-143_Die419', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439Z_G-I_Yx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446M_C-E_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446M_C-E_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_Die421'], 'footprint':'Package_CSP:ST_WLCSP-81_Die421', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446M_C-E_Yx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446R_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446R_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446R_C-E_Tx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446V_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446V_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446V_C-E_Tx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446Z_C-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446Z_C-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446Z_C-E_Hx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446Z_C-E_Jx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446Z_C-E_Jx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446Z_C-E_Jx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446Z_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446Z_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446Z_C-E_Tx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469A_E-G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469A_E-G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ae.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469A_E-G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469A_E-G-I_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469A_E-G-I_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-168_Die434'], 'footprint':'Package_CSP:ST_WLCSP-168_Die434', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ae.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469A_E-G-I_Yx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='F9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='N5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469B_E-G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469B_E-G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469be.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469B_E-G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469IITx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469I_E-G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469I_E-G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469I_E-G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469I_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469I_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469I_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469NIHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469N_E-G_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469N_E-G_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ne.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469N_E-G_Hx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469VITx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469V_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469V_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469V_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469ZITx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='66',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469Z_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469Z_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469Z_E-G_Tx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='66',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479A_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479A_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479A_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479A_G-I_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479A_G-I_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-168_Die434'], 'footprint':'Package_CSP:ST_WLCSP-168_Die434', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479A_G-I_Yx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='F9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='N5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479B_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479B_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479B_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479I_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479I_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479I_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479I_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479I_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479I_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479N_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479N_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479N_G-I_Hx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479V_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479V_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479V_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479Z_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479Z_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479Z_G-I_Tx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='66',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CBUx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401CBYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CBYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die423', 'Package_CSP:ST_WLCSP-49_Die423'], 'footprint':'Package_CSP:ST_WLCSP-49_Die423', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cby6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CBYx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CCUx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401CCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die423', 'Package_CSP:ST_WLCSP-49_Die423', 'Package_CSP:ST_WLCSP-49_Die423'], 'footprint':'Package_CSP:ST_WLCSP-49_Die423', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CCYx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401CDUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CDUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CDUx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401CDYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CDYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die433', 'Package_CSP:ST_WLCSP-49_Die433'], 'footprint':'Package_CSP:ST_WLCSP-49_Die433', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401cd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CDYx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CEUx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401CEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401CEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die433', 'Package_CSP:ST_WLCSP-49_Die433', 'Package_CSP:ST_WLCSP-49_Die433'], 'footprint':'Package_CSP:ST_WLCSP-49_Die433', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401CEYx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401RBTx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401RCTx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401RDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401RDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401RDTx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401RETx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401VBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401VBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401VBHx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401VBTx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401VCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401VCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401VCHx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401VCTx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401VDHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401VDHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401VDHx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401VDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401VDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401VDTx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401VEHx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F401VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F401VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F401', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f401ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F401VETx\n\nArm Cortex-M4 STM32F4 STM32F401', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F405OEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F405OEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-90_Die413', 'Package_CSP:ST_WLCSP-90_Die413'], 'footprint':'Package_CSP:ST_WLCSP-90_Die413', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f405oe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F405OEYx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='B10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F405OGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F405OGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-90_Die413', 'Package_CSP:ST_WLCSP-90_Die413', 'Package_CSP:ST_WLCSP-90_Die413'], 'footprint':'Package_CSP:ST_WLCSP-90_Die413', 'keywords':'Arm Cortex-M4 STM32F4 STM32F405/415', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f405og.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F405OGYx\n\nArm Cortex-M4 STM32F4 STM32F405/415', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='B10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407IEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407IEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407IEHx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407IETx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407IGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407IGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407IGHx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407IGTx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407VETx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407VGTx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407ZETx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F407ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F407ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f407zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F407ZGTx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410C8Tx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410C8Ux\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410CBTx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410CBUx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410R8Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410R8Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410R8Ix\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410R8Tx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410RBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410RBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410RBIx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410RBTx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410T8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410T8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-36_Die458', 'Package_CSP:ST_WLCSP-36_Die458'], 'footprint':'Package_CSP:ST_WLCSP-36_Die458', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410t8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410T8Yx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F410TBYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F410TBYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-36_Die458', 'Package_CSP:ST_WLCSP-36_Die458', 'Package_CSP:ST_WLCSP-36_Die458'], 'footprint':'Package_CSP:ST_WLCSP-36_Die458', 'keywords':'Arm Cortex-M4 STM32F4 STM32F410', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f410tb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F410TBYx\n\nArm Cortex-M4 STM32F4 STM32F410', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411CCUx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411CCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411CCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die431', 'Package_CSP:ST_WLCSP-49_Die431'], 'footprint':'Package_CSP:ST_WLCSP-49_Die431', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411CCYx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411CEUx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411CEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411CEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die431', 'Package_CSP:ST_WLCSP-49_Die431', 'Package_CSP:ST_WLCSP-49_Die431'], 'footprint':'Package_CSP:ST_WLCSP-49_Die431', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411CEYx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411RCTx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411RETx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411VCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411VCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411VCHx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411VCTx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411VEHx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F411VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F411VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F411', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f411ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F411VETx\n\nArm Cortex-M4 STM32F4 STM32F411', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412CEUx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412CGUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412CGUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412cg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412CGUx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412RETx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412REYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412REYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die441', 'Package_CSP:ST_WLCSP-64_Die441'], 'footprint':'Package_CSP:ST_WLCSP-64_Die441', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412REYx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412REYxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412REYxP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die441', 'Package_CSP:ST_WLCSP-64_Die441'], 'footprint':'Package_CSP:ST_WLCSP-64_Die441', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412REYxP\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412RGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412RGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412RGTx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412RGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412RGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die441', 'Package_CSP:ST_WLCSP-64_Die441', 'Package_CSP:ST_WLCSP-64_Die441'], 'footprint':'Package_CSP:ST_WLCSP-64_Die441', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412RGYx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412RGYxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412RGYxP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die441', 'Package_CSP:ST_WLCSP-64_Die441', 'Package_CSP:ST_WLCSP-64_Die441'], 'footprint':'Package_CSP:ST_WLCSP-64_Die441', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412RGYxP\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412VEHx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412VETx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412VGHx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412VGTx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412ZEJx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412ZEJx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412ZEJx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412ZETx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412ZGJx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412ZGJx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412ZGJx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F412ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F412ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F412', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f412zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F412ZGTx\n\nArm Cortex-M4 STM32F4 STM32F412', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413CGUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413CGUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413cg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413CGUx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413CHUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413CHUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413ch.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413CHUx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413MGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413MGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_Die463', 'Package_CSP:ST_WLCSP-81_Die463'], 'footprint':'Package_CSP:ST_WLCSP-81_Die463', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413mg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413MGYx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413MHYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413MHYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_Die463', 'Package_CSP:ST_WLCSP-81_Die463', 'Package_CSP:ST_WLCSP-81_Die463'], 'footprint':'Package_CSP:ST_WLCSP-81_Die463', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413mh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413MHYx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413RGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413RGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413RGTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413RHTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413RHTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413rh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413RHTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413VGHx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413VGTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413VHHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413VHHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413vh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413VHHx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413VHTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413VHTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413vh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413VHTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413ZGJx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413ZGJx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413ZGJx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413ZGTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413ZHJx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413ZHJx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413zh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413ZHJx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F413ZHTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F413ZHTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F413/423', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f413zh.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F413ZHTx\n\nArm Cortex-M4 STM32F4 STM32F413/423', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417IEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417IEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417IEHx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417IETx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417IGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417IGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417IGHx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417IGTx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417VETx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417VGTx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417ZETx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F417ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F417ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F407/417', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f417zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F417ZGTx\n\nArm Cortex-M4 STM32F4 STM32F407/417', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427AGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427AGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427AGHx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP_1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427AIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427AIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427AIHx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP_1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427IGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427IGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427IGHx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427IGTx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427IIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427IIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427IIHx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427IITx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427VGTx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427VITx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427ZGTx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F427ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F427ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f427zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F427ZITx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429AGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429AGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429AGHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP_1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429AIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429AIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429AIHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP_1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429BETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429BETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429be.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429BETx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429BGTx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429BITx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429IEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429IEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429IEHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429IETx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429IGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429IGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429IGHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429IGTx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429IIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429IIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429IIHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429NEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429NEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ne.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429NEHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429NGHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429VETx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429VGTx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429ZETx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F429ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F429ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f429zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F429ZGTx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437IGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437IGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437IGHx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437IGTx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437IIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437IIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437IIHx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437IITx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437VGTx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437VITx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437ZGTx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F437ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F437ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F427/437', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f437zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F437ZITx\n\nArm Cortex-M4 STM32F4 STM32F427/437', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439BGTx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439BITx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439IGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439IGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439IGHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439IGTx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439IIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439IIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439IIHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439IITx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439NGHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439NIHx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439VGTx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439VITx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439ZGTx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439ZGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439ZGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die419', 'Package_CSP:ST_WLCSP-143_Die419'], 'footprint':'Package_CSP:ST_WLCSP-143_Die419', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439ZGYx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439ZITx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F439ZIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F439ZIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die419', 'Package_CSP:ST_WLCSP-143_Die419', 'Package_CSP:ST_WLCSP-143_Die419'], 'footprint':'Package_CSP:ST_WLCSP-143_Die419', 'keywords':'Arm Cortex-M4 STM32F4 STM32F429/439', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f439zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F439ZIYx\n\nArm Cortex-M4 STM32F4 STM32F429/439', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446MCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446MCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_Die421', 'Package_CSP:ST_WLCSP-81_Die421'], 'footprint':'Package_CSP:ST_WLCSP-81_Die421', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446MCYx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446MEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446MEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_Die421', 'Package_CSP:ST_WLCSP-81_Die421', 'Package_CSP:ST_WLCSP-81_Die421'], 'footprint':'Package_CSP:ST_WLCSP-81_Die421', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446MEYx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446RCTx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446RETx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446VCTx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446VETx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446ZCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446ZCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446ZCHx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446ZCJx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446ZCJx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446ZCJx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446ZCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446ZCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446ZCTx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446ZEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446ZEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446ZEHx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446ZEJx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446ZEJx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:UFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446ZEJx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F446ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F446ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F446', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f446ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F446ZETx\n\nArm Cortex-M4 STM32F4 STM32F446', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469AEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469AEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ae.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469AEHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469AEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469AEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434'], 'footprint':'Package_CSP:ST_WLCSP-168_Die434', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ae.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469AEYx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='F9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='N5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469AGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469AGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469AGHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469AGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469AGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434'], 'footprint':'Package_CSP:ST_WLCSP-168_Die434', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469AGYx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='F9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='N5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469AIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469AIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469AIHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469AIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469AIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434'], 'footprint':'Package_CSP:ST_WLCSP-168_Die434', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469AIYx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='F9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='N5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469BETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469BETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469be.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469BETx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469BGTx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469BITx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469IEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469IEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469IEHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469IETx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469IGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469IGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469IGHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469IGTx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469IIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469IIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469IIHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469NEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469NEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ne.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469NEHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469NGHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469VETx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469VGTx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469ZETx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='66',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F469ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F469ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f469zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F469ZGTx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='66',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479AGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479AGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479AGHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479AGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479AGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434'], 'footprint':'Package_CSP:ST_WLCSP-168_Die434', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479AGYx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='F9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='N5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479AIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479AIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479AIHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D13',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP1',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479AIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479AIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434', 'Package_CSP:ST_WLCSP-168_Die434'], 'footprint':'Package_CSP:ST_WLCSP-168_Die434', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479AIYx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='D3',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='F9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='N5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479BGTx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479BITx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479IGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479IGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479IGHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479IGTx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479IIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479IIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479IIHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479IITx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479NGHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479NIHx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479VGTx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479VITx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479ZGTx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='66',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F479ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F479ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F4 STM32F469/479', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f479zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F4.kicad_sym\nSTM32F479ZITx\n\nArm Cortex-M4 STM32F4 STM32F469/479', 'pins':[
            Pin(num='1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VCAP2',func=pin_types.PWROUT,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VCAP1',func=pin_types.PWROUT,unit=1),
            Pin(num='66',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='78',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])