from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32F3 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32F301C8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301C8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die439'], 'footprint':'Package_CSP:ST_WLCSP-49_Die439', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301C8Yx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301C_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301C_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301C_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301K_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301K_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301K_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301K_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301K_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301K_6-8_Ux\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301R_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301R_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301R_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302C8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302C8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die439'], 'footprint':'Package_CSP:ST_WLCSP-49_Die439', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302C8Yx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302C_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302C_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302C_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302C_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302C_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302C_B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302K_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302K_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302K_6-8_Ux\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302R_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302R_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302R_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302R_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302R_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302R_B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302R_D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302R_D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302R_D-E_Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302VCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302VCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_Die422'], 'footprint':'Package_CSP:ST_WLCSP-100_Die422', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302VCYx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302V_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302V_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302V_B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302V_D-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302V_D-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302V_D-E_Hx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302V_D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302V_D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302V_D-E_Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302Z_D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302Z_D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302zd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302Z_D-E_Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303C8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303C8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die438'], 'footprint':'Package_CSP:ST_WLCSP-49_Die438', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303C8Yx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303C_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303C_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303C_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303C_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303C_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303C_B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303K_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303K_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303K_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303K_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303K_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303K_6-8_Ux\n\nArm Cortex-M4 STM32F3 STM32F3x3', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303R_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303R_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303R_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303R_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303R_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303R_B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303R_D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303R_D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303R_D-E_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303VCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303VCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_Die422'], 'footprint':'Package_CSP:ST_WLCSP-100_Die422', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303VCYx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303VEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303VEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_Die446'], 'footprint':'Package_CSP:ST_WLCSP-100_Die446', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303VEYx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303V_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303V_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303V_B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303V_D-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303V_D-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303V_D-E_Hx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303V_D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303V_D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303V_D-E_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303Z_D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303Z_D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303zd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303Z_D-E_Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F318C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F318C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f318c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F318C8Tx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F318C8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F318C8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die439'], 'footprint':'Package_CSP:ST_WLCSP-49_Die439', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f318c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F318C8Yx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='G4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F318K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F318K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f318k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F318K8Ux\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F328C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F328C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f328c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F328C8Tx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334C8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334C8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_Die438'], 'footprint':'Package_CSP:ST_WLCSP-49_Die438', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334C8Yx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334C_4-6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334C_4-6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334C_4-6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334K_4-6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334K_4-6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334K_4-6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334K_4-6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334K_4-6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334K_4-6-8_Ux\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334R_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334R_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334R_6-8_Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F358CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F358CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f358cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F358CCTx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F358RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F358RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f358rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F358RCTx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F358VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F358VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f358vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F358VCTx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373C_8-B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373C_8-B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373C_8-B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373R_8-B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373R_8-B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373R_8-B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373V_8-B-C_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373V_8-B-C_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373V_8-B-C_Hx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373V_8-B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373V_8-B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373V_8-B-C_Tx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F378CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F378CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f378cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F378CCTx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F378RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F378RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f378rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F378RCTx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F378RCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F378RCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-66_Die432'], 'footprint':'Package_CSP:ST_WLCSP-66_Die432', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f378rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F378RCYx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='A1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F378VCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F378VCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f378vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F378VCHx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F378VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F378VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f378vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F378VCTx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F398VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F398VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f398ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F398VETx\n\nArm Cortex-M4 STM32F3 STM32F3x8', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NPOR',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301C6Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301C8Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301K6Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301K6Ux\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301K8Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301K8Ux\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301R6Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F301R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F301R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F301', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f301r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F301R8Tx\n\nArm Cortex-M4 STM32F3 STM32F301', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302C6Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302C8Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302CBTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302CCTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302K6Ux\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302K8Ux\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302R6Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302R8Tx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302RBTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302RCTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302RDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302RDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302RDTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302RETx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302VBTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302VCTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302VDHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302VDHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302VDHx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302VDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302VDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302VDTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302VEHx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302VETx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302ZDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302ZDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302zd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302ZDTx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F302ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F302ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F302', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f302ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F302ZETx\n\nArm Cortex-M4 STM32F3 STM32F302', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303C6Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303C8Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303CBTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303CCTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303K6Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303K6Ux\n\nArm Cortex-M4 STM32F3 STM32F3x3', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303K8Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F3x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303K8Ux\n\nArm Cortex-M4 STM32F3 STM32F3x3', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303R6Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303R8Tx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303RBTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303RCTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303RDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303RDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303RDTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303RETx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303VBTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303VCTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303VDHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303VDHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303VDHx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303VDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303VDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303VDTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303VEHx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303VETx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303ZDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303ZDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303zd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303ZDTx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F303ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F303ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F303', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f303ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F303ZETx\n\nArm Cortex-M4 STM32F3 STM32F303', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334C4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334C4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334C4Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334C6Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334C8Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334K4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334K4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334K4Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334K4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334K4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334K4Ux\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334K6Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334K6Ux\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334K8Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334K8Ux\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334R6Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F334R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F334R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F334', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f334r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F334R8Tx\n\nArm Cortex-M4 STM32F3 STM32F334', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373C8Tx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373CBTx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373CCTx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373R8Tx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373RBTx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373RCTx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDDSD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373V8Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373V8Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373V8Hx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373V8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373V8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373V8Tx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373VBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373VBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373VBHx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373VBTx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373VCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373VCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373VCHx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F373VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F373VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32F3 STM32F373', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f373vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F3.kicad_sym\nSTM32F373VCTx\n\nArm Cortex-M4 STM32F3 STM32F373', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VREFSD-',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VSSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDDSD12',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDDSD3',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VREFSD+',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])