from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_S08 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MC9S08AC128xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC128xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC128xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC128xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC128xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC128xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC128xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC128xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC128xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC128xLKE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC128xLKE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC128xLKE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PTJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTH3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='68',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTH4',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTH5',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC128xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC128xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC128xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC60xFJE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC60xFJE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC60xFJE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ128xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ128xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ128xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ128xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ128xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ128xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ128xLL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ128xLL'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ128xLL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PTJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTL5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTL6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTL7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTG7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTL0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTL1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTL2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTH3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTL3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTH4',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTH5',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTH7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PTL4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PTK0',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PTK1',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PTK2',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PTK3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='PTK4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PTK5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PTK6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PTK7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PTB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ60xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ60xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ60xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08EL32xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08EL32xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08EL32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08EL32xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08EL32xTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08EL32xTL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08EL32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08EL32xTL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08FL16xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08FL16xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08FL16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08FL16xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM16xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM16xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM16xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='18',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM60xGT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM60xGT'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM60xGT\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='22',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM60xLD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM60xLD'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM60xLD\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='21',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM60xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM60xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM60xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='26',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JS16CFK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JS16CFK'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08JS16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JS16CFK\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB0/IRQ/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA4/KBIP4/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='17',name='PTA5/KBIP5/TPMCH1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA6/KBIP6/RxD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA7/KBIP7/TxD',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB2/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTB3/~{BLMS}',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA0/KBIP0/PTMCH0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1/KBIP1/MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA2/KBIP2/MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA3/KBIP3/SPSCK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JS16CWJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JS16CWJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08JS16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JS16CWJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA2/KBIP2/MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA3/KBIP3/SPSCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA4/KBIP4/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='18',name='PTA5/KBIP5/TPMCH1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA6/KBIP6/RxD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA7/KBIP7/TxD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTB0/IRQ/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB2/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB3/~{BLMS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0/KBIP0/PTMCH0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA1/KBIP1/MISO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08LG32J0xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08LG32J0xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MC9S08LG32RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08LG32J0xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTD7/LCD7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCAP2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VLL1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VLL3',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTF7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD6/LCD6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC5/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTD5/LCD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0/LCD21',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC4/LCD20',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC3/LCD19',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC2/LCD18',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC1/LCD17',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTD4/LCD4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC0/LCD16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTE7/LCD15',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTE6/LCD14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTE5/LCD13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTE4/LCD12',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTE3/LCD11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTE2/LCD10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTE1/LCD9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTE0/LCD8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTD3/LCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTD2/LCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTD1/LCD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTD0/LCD0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VCAP1',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08LG32J0xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08LG32J0xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MC9S08LG32RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08LG32J0xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTD7/LCD7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB0/LCD29',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTD1/LCD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTD0/LCD0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VCAP1',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VCAP2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLL1',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VLL3',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD6/LCD6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTI5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTI4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTH7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PTF7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTD5/LCD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTH5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTH4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC5/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTD4/LCD4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTG3/LCD36',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTG2/LCD35',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA0/LCD21',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC4/LCD20',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTC3/LCD19',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTD3/LCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC2/LCD18',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC1/LCD17',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC0/LCD16',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTE7/LCD15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTE6/LCD14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VLL3',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PTG1/LCD34',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG0/LCD33',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTE5/LCD13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTD2/LCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTE4/LCD12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTE3/LCD11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTE2/LCD10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTE1/LCD9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTE0/LCD8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB3/LCD32',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB2/LCD31',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB1/LCD30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08LG32J0xLK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08LG32J0xLK'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:TQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:TQFP-80_14x14mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MC9S08LG32RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08LG32J0xLK\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTD7/LCD7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/LCD39',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5/LCD38',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4/LCD37',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/LCD30',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB0/LCD29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD1/LCD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD0/LCD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCAP1',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VCAP2',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VLL1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PTD6/LCD6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VLL2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VLL3',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTI5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTI4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTI3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTI2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTI1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTI0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTD5/LCD5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTH7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PTF7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTF6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTD4/LCD4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTH5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTH4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTC5/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTD3/LCD3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG3/LCD36',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG2/LCD35',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTA0/LCD21',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTD2/LCD2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC4/LCD20',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC3/LCD19',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2/LCD18',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC1/LCD17',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC0/LCD16',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTE7/LCD15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTE6/LCD14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='68',name='VLL3',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='PTG7/LCD44',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB3/LCD32',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTG6/LCD43',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTG5/LCD42',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTG4/LCD41',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTG1/LCD34',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTG0/LCD33',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTE5/LCD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTE4/LCD12',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTE3/LCD11',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTE2/LCD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTE1/LCD9',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB2/LCD31',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PTE0/LCD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB7/LCD40',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08MP16xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08MP16xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08MP16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08MP16xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTE6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTF0/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08MP16xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08MP16xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08MP16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08MP16xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTE5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTE6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTF0/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08MP16xWL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08MP16xWL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08MP16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08MP16xWL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTF0/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QA4CDNE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QA4CDNE'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QA4RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QA4CDNE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QA4CFQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QA4CFQE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QA4RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QA4CFQE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QA4CPAE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QA4CPAE'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QA4RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QA4CPAE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QB8xGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QB8xGK'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QB8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QB8xGK\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QB8xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QB8xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QB8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QB8xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QB8xWL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QB8xWL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QB8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QB8xWL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QD4xPC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QD4xPC'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QD4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QD4xPC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QD4xSC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QD4xSC'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QD4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QD4xSC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG4xPAE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG4xPAE'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG4xPAE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG8xDNE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG8xDNE'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG8xDNE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG8xDTE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG8xDTE'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG8xDTE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG8xFKE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG8xFKE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG8xFKE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG8xFQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG8xFQE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG8xFQE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG8xPBE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG8xPBE'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG8xPBE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SC4xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SC4xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SC4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SC4xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SE8xRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SE8xRL'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SE8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SE8xRL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SE8xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SE8xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SE8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SE8xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SE8xWL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SE8xWL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SE8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SE8xWL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SF4xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SF4xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SF4RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SF4xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB7/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SF4xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SF4xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SF4RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SF4xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB7/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTA1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG32xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG32xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG32xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG32xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG32xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG32xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG32xTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG32xTL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG32xTL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG8xSC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG8xSC'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG8xSC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH32xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH32xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH32xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH32xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH32xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH32xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH32xTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH32xTL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH32xTL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH32xWL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH32xWL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH32xWL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH8xFK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH8xFK'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH8xFK\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH8xPJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH8xPJ'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH8xPJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH8xSC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH8xSC'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH8xSC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH8xWJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH8xWJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH8xWJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SV16CLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SV16CLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SV16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SV16CLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC16xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC16xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC16xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC16xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC16xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC16xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC16xFJE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC16xFJE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC16xFJE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC32xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC32xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC32xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC32xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC32xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC32xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC32xFJE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC32xFJE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC32xFJE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC32xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC32xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC32xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC32xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC32xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC32xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC48xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC48xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC48xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC48xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC48xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC48xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC48xFJE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC48xFJE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC48xFJE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC48xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC48xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC48xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC48xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC48xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC48xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC60xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC60xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC60xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC60xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC60xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC60xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC60xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC60xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC60xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC60xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC60xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC60xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC8xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC8xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC8xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC8xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC8xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC8xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC8xFJE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC8xFJE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC8xFJE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC96xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC96xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC96xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC96xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC96xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC96xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC96xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC96xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC96xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC96xLKE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC96xLKE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC96xLKE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PTJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTH3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='68',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTH4',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTH5',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AC96xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AC96xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AC96xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW16AE0xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW16AE0xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW16AE0xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW16xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW16xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW16xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW16xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW16xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW16xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW16xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW16xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW16xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW16xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW16xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW16xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW32xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW32xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW32xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW32xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW32xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW32xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW32xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW32xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW32xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW32xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW32xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW32xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW48xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW48xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW48xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW48xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW48xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW48xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW48xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW48xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW48xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW48xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW48xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW48xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW60xFDE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW60xFDE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW60xFDE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW60xFGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW60xFGE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW60xFGE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW60xFUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW60xFUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'Package_QFP:LQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-64_14x14mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW60xFUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW60xPUE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW60xPUE'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AW60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW60xPUE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08AW8AE0xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08AW8AE0xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08AC60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08AW8AE0xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG6/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN16xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN16xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN16xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN16xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN16xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN16xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN32xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN32xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN32xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN32xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN32xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN32xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN32xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN32xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DN60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN32xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN48xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN48xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN48xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN48xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN48xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN48xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN48xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN48xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DN60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN48xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN60xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN60xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN60xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN60xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN60xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN60xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DN60xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DN60xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DN60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DN60xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV16xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV16xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV16xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV16xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV16xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV16xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV32xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV32xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV32xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV32xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV32xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV32xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV32xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV32xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DV60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV32xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV48xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV48xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV48xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV48xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV48xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV48xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV48xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV48xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DV60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV48xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV60xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV60xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV60xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV60xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV60xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV60xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DV60xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DV60xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DV60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DV60xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ16xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ16xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ16xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ16xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ16xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ16xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ32xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ32xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ32xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ32xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ32xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ32xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ32xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ32xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ32xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ48xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ48xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ48xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ48xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ48xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ48xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ48xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ48xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ48xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ60xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ60xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ60xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ60xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ60xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ60xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ96xLF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ96xLF'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ96xLF\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PTF4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ96xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ96xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ96xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08DZ96xLL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08DZ96xLL'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08DZ128.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08DZ96xLL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTG0/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTG1/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PTJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTL5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTL6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTL7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTG4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTG7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTL0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTL1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTL2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTH3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTL3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTH4',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTH5',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTH7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PTL4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PTK0',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PTK1',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PTK2',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PTK3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='PTK4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PTK5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PTK6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PTK7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PTB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08EL16xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08EL16xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08EL32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08EL16xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08EL16xTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08EL16xTL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08EL32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08EL16xTL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08FL8xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08FL8xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08FL16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08FL8xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM16xGT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM16xGT'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM16xGT\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='22',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM16xLD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM16xLD'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM16xLD\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='21',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM32xGT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM32xGT'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM32xGT\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='22',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM32xLD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM32xLD'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM32xLD\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='21',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM32xLH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM32xLH'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM60.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM32xLH\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='26',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM8xGT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM8xGT'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM8xGT\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='22',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM8xLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM8xLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM8xLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='18',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JM8xLD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JM8xLD'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08JM16.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JM8xLD\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IRQ/TPMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='21',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTG4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTG5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JS8CFK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JS8CFK'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm', 'Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08JS16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JS8CFK\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB0/IRQ/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA4/KBIP4/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='17',name='PTA5/KBIP5/TPMCH1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA6/KBIP6/RxD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA7/KBIP7/TxD',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTB2/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTB3/~{BLMS}',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA0/KBIP0/PTMCH0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1/KBIP1/MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA2/KBIP2/MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA3/KBIP3/SPSCK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08JS8CWJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08JS8CWJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08JS16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08JS8CWJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTB4/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA2/KBIP2/MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA3/KBIP3/SPSCK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA4/KBIP4/~{SS}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='USBDN',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB33',func=pin_types.PWROUT,unit=1),
            Pin(num='18',name='PTA5/KBIP5/TPMCH1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA6/KBIP6/RxD',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB5/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA7/KBIP7/TxD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSSOSC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTB0/IRQ/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB2/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB3/~{BLMS}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0/KBIP0/PTMCH0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA1/KBIP1/MISO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QA2CDNE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QA2CDNE'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QA4RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QA2CDNE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QA2CFQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QA2CFQE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm', 'Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QA4RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QA2CFQE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QA2CPAE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QA2CPAE'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QA4RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QA2CPAE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QB4xGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QB4xGK'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm', 'Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_5x5mm_P0.65mm_EP3.6x3.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QB8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QB4xGK\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QB4xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QB4xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QB8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QB4xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QB4xWL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QB4xWL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08QB8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QB4xWL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QD2xPC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QD2xPC'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QD4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QD2xPC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QD2xSC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QD2xSC'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QD4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QD2xSC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG4xDNE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG4xDNE'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG4xDNE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG4xDTE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG4xDTE'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG4xDTE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG4xFKE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG4xFKE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG4xFKE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08QG4xFQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08QG4xFQE'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm', 'Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_4x4mm_P0.8mm_EP2.5x3.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08QG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08QG4xFQE\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SE4xRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SE4xRL'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SE8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SE4xRL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SE4xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SE4xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SE8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SE4xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SE4xWL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SE4xWL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SE8RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SE4xWL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG16xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG16xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG16xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG16xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG16xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG16xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG16xTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG16xTL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG16xTL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG4xSC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG4xSC'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG4xSC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG4xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG4xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG4xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG4xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG4xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG4xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG8xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG8xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG8xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SG8xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SG8xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SG8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SG8xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH16xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH16xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH16xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH16xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH16xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH16xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH16xTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH16xTL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH16xTL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH16xWL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH16xWL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH16xWL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH4xFK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH4xFK'}), 'ref_prefix':'IC', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH4xFK\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH4xPJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH4xPJ'}), 'ref_prefix':'IC', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH4xPJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH4xSC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH4xSC'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH4xSC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH4xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH4xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH4xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH4xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH4xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH4xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH4xWJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH4xWJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH4xWJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH8xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH8xTG'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH8xTG\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SH8xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SH8xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08SH8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SH8xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SL16xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SL16xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08EL32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SL16xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SL16xTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SL16xTL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08EL32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SL16xTL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SL32xTJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SL32xTJ'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08EL32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SL32xTJ\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SL32xTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SL32xTL'}), 'ref_prefix':'IC', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MC9S08EL32.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SL32xTL\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC9S08SV8CLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC9S08SV8CLC'}), 'ref_prefix':'IC', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP S08 Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/reference-manual/MC9S08SV16RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_S08.kicad_sym\nMC9S08SV8CLC\n\nNXP S08 Microcontroller', 'pins':[
            Pin(num='1',name='PTA4/BKGD/MS',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTB7/EXTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTB6/XTAL',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])