from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Diode_Bridge = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ABS2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ABS2'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Diotec_ABS'], 'footprint':'Diode_SMD:Diode_Bridge_Diotec_ABS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/abs2.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nABS2\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B40C1500G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B40C1500G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88501/b40c1500g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB40C1500G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B40C2300-1500A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B40C2300-1500A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB40C2300-1500A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B40C2300-1500B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B40C2300-1500B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB40C2300-1500B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B40C5000-3x00A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B40C5000-3x00A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c500033', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB40C5000-3x00A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B40C800DM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B40C800DM'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88533/800dm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB40C800DM\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B40R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B40R'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40r.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB40R\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU4A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU4A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu4a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU4A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GUO40-08NO1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GUO40-08NO1'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_IXYS_GUFP'], 'footprint':'Diode_THT:Diode_Bridge_IXYS_GUFP', 'keywords':'Three-Phase Bridge Rectifier', 'description':'', 'datasheet':'https://ixapps.ixys.com/DataSheet/GUO40-08NO1.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGUO40-08NO1\n\nThree-Phase Bridge Rectifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU4A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU4A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU4A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MB2S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MB2S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-269AA'], 'footprint':'Package_TO_SOT_SMD:TO-269AA', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88661/mb2s.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMB2S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBL104S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBL104S'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Vishay_MBLS'], 'footprint':'Diode_SMD:Diode_Bridge_Vishay_MBLS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/89959/mbl104s.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMBL104S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDB6S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDB6S'}), 'ref_prefix':'D', 'fplist':['Package_SO:TSSOP-4_4.4x5mm_P4mm'], 'footprint':'Package_SO:TSSOP-4_4.4x5mm_P4mm', 'keywords':'bridge diode rectifier ac dc acdc ac-dc', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MDB8S-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMDB6S\n\nbridge diode rectifier ac dc acdc ac-dc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SC35VB80S-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SC35VB80S-G'}), 'ref_prefix':'U', 'fplist':['Diode_THT:Diode_Bridge_Comchip_SCVB-L'], 'footprint':'Diode_THT:Diode_Bridge_Comchip_SCVB-L', 'keywords':'Three-Phase Bridge Rectifier', 'description':'', 'datasheet':'https://www.comchiptech.com/admin/files/product/SC35VB80S-G%20Thru506369.%20SC35VB160S-G%20RevB.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nSC35VB80S-G\n\nThree-Phase Bridge Rectifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC1005', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC1005'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC1'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC1005\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC6005', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC6005'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC6005\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC8005', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC8005'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93586/kbpc8series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC8005\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ABS10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ABS10'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS'], 'footprint':'Diode_SMD:Diode_Bridge_Diotec_ABS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/abs2.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nABS10\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ABS4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ABS4'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS'], 'footprint':'Diode_SMD:Diode_Bridge_Diotec_ABS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/abs2.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nABS4\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ABS6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ABS6'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS'], 'footprint':'Diode_SMD:Diode_Bridge_Diotec_ABS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/abs2.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nABS6\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ABS8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ABS8'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS'], 'footprint':'Diode_SMD:Diode_Bridge_Diotec_ABS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/abs2.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nABS8\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B125C1500G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B125C1500G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88501/b40c1500g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB125C1500G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B125C2300-1500A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B125C2300-1500A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB125C2300-1500A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B125C2300-1500B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B125C2300-1500B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB125C2300-1500B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B125C3x00-2200A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B125C3x00-2200A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c3700', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB125C3x00-2200A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B125C5000-3x00A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B125C5000-3x00A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c500033', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB125C5000-3x00A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B125C800DM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B125C800DM'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88533/800dm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB125C800DM\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B125R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B125R'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40r.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB125R\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B250C1500G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B250C1500G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88501/b40c1500g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB250C1500G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B250C2300-1500A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B250C2300-1500A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB250C2300-1500A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B250C2300-1500B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B250C2300-1500B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB250C2300-1500B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B250C3x00-2200A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B250C3x00-2200A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c3700', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB250C3x00-2200A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B250C5000-3x00A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B250C5000-3x00A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c500033', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB250C5000-3x00A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B250C800DM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B250C800DM'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88533/800dm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB250C800DM\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B250R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B250R'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40r.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB250R\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B380C1500G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B380C1500G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88501/b40c1500g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB380C1500G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B380C2300-1500A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B380C2300-1500A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB380C2300-1500A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B380C2300-1500B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B380C2300-1500B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB380C2300-1500B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B380C3x00-2200A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B380C3x00-2200A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c3700', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB380C3x00-2200A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B380C5000-3x00A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B380C5000-3x00A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c500033', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB380C5000-3x00A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B380C800DM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B380C800DM'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88533/800dm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB380C800DM\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B380R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B380R'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40r.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB380R\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B40C3x00-2200A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B40C3x00-2200A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c3700', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB40C3x00-2200A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B500C2300-1500A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B500C2300-1500A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB500C2300-1500A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B500C3x00-2200A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B500C3x00-2200A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c3700', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB500C3x00-2200A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B500C5000-3x00A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B500C5000-3x00A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c500033', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB500C5000-3x00A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B500R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B500R'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40r.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB500R\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B700C2300-1500B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B700C2300-1500B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB700C2300-1500B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B80C1500G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B80C1500G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88501/b40c1500g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB80C1500G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B80C2300-1500A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B80C2300-1500A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB80C2300-1500A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B80C2300-1500B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B80C2300-1500B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm'], 'footprint':'Diode_THT:Diode_Bridge_19.0x3.5x10.0mm_P5.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c2300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB80C2300-1500B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B80C3x00-2200A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B80C3x00-2200A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c3700', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB80C3x00-2200A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B80C5000-3x00A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B80C5000-3x00A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm'], 'footprint':'Diode_THT:Diode_Bridge_32.0x5.6x17.0mm_P10.0mm_P7.5mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40c500033', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB80C5000-3x00A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B80C800DM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B80C800DM'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88533/800dm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB80C800DM\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B80R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B80R'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/b40r.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nB80R\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DF005M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DF005M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88571/dfm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDF005M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DF01M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DF01M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88571/dfm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDF01M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DF01S1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DF01S1'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_Diotec_ABS', 'Diode_SMD:Diode_Bridge_OnSemi_SDIP-4L'], 'footprint':'Diode_SMD:Diode_Bridge_Diotec_ABS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/df10s1-d.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDF01S1\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DF02M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DF02M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88571/dfm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDF02M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DF04M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DF04M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88571/dfm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDF04M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DF06M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DF06M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88571/dfm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDF06M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DF08M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DF08M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88571/dfm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDF08M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DF10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DF10M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm'], 'footprint':'Diode_THT:Diode_Bridge_DIP-4_W7.62mm_P5.08mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88571/dfm.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDF10M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DMA40U1800GU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DMA40U1800GU'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP'], 'footprint':'Diode_THT:Diode_Bridge_IXYS_GUFP', 'keywords':'Three-Phase Bridge Rectifier', 'description':'', 'datasheet':'https://ixapps.ixys.com/Datasheet/DMA40U1800GU.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDMA40U1800GU\n\nThree-Phase Bridge Rectifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DNA40U2200GU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DNA40U2200GU'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP'], 'footprint':'Diode_THT:Diode_Bridge_IXYS_GUFP', 'keywords':'Three-Phase Bridge Rectifier', 'description':'', 'datasheet':'https://ixapps.ixys.com/Datasheet/DNA40U2200GU.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nDNA40U2200GU\n\nThree-Phase Bridge Rectifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU4B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU4B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu4a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU4B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU4D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU4D'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu4a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU4D\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU4G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU4G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu4a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU4G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU4J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU4J'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu4a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU4J\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU4K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU4K'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu4a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU4K\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU4M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU4M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu4a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU4M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU6A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU6A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu6a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU6A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU6B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU6B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu6a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU6B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU6D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU6D'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu6a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU6D\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU6G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU6G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu6a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU6G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU6J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU6J'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu6a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU6J\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU6K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU6K'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu6a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU6K\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU6M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU6M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu6a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU6M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU8A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu8a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU8A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU8B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU8B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu8a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU8B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU8D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU8D'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu8a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU8D\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU8G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU8G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu8a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU8G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU8J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU8J'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu8a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU8J\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU8K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU8K'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu8a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU8K\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GBU8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GBU8M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU', 'Diode_THT:Diode_Bridge_Vishay_GBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_GBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/gbu8a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGBU8M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GUO40-12NO1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GUO40-12NO1'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP'], 'footprint':'Diode_THT:Diode_Bridge_IXYS_GUFP', 'keywords':'Three-Phase Bridge Rectifier', 'description':'', 'datasheet':'https://ixapps.ixys.com/DataSheet/GUO40-12NO1.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGUO40-12NO1\n\nThree-Phase Bridge Rectifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GUO40-16NO1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GUO40-16NO1'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP', 'Diode_THT:Diode_Bridge_IXYS_GUFP'], 'footprint':'Diode_THT:Diode_Bridge_IXYS_GUFP', 'keywords':'Three-Phase Bridge Rectifier', 'description':'', 'datasheet':'https://ixapps.ixys.com/DataSheet/GUO40-16NO1.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nGUO40-16NO1\n\nThree-Phase Bridge Rectifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC15005T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC15005T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc15005t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC15005T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC15005W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC15005W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc15005t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC15005W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1501T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1501T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1501t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1501T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1501W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1501W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1501t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1501W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1502T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1502T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1502t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1502T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1502W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1502W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1502t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1502W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1504T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1504T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1504t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1504T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1504W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1504W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1504t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1504W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1506T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1506T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1506t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1506T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1506W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1506W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1506t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1506W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1508T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1508T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1508t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1508T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1508W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1508W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1508t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1508W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1510T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1510T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1510t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1510T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC1510W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC1510W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc1510t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC1510W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC25005T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC25005T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc25005t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC25005T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC25005W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC25005W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc25005t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC25005W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2501T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2501T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2501t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2501T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2501W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2501W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2501t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2501W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2502T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2502T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2502t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2502T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2502W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2502W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2502t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2502W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2504T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2504T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2504t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2504T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2504W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2504W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2504t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2504W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2506T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2506T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2506t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2506T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2506W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2506W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2506t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2506W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2508T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2508T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2508t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2508T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2508W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2508W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2508t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2508W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2510T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2510T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2510t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2510T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC2510W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC2510W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc2510t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC2510W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC35005T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC35005T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc35005t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC35005T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC35005W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC35005W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc35005t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC35005W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3501T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3501T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3501t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3501T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3501W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3501W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3501t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3501W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3502T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3502T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3502t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3502T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3502W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3502W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3502t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3502W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3504T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3504T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3504t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3504T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3504W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3504W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3504t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3504W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3506T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3506T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3506t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3506T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3506W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3506W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3506t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3506W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3508T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3508T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3508t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3508T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3508W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3508W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3508t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3508W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3510T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3510T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3510t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3510T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC3510W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC3510W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc3510t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC3510W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC50005T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC50005T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc50005t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC50005T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC50005W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC50005W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc50005t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC50005W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5001T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5001T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5001t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5001T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5001W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5001W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5001t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5001W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5002T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5002T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5002t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5002T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5002W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5002W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5002t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5002W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5004T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5004T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5004t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5004T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5004W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5004W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5004t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5004W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5006T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5006T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5006t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5006T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5006W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5006W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5006t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5006W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5008T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5008T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5008t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5008T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5008W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5008W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5008t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5008W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5010T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5010T'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', ''], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5010t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5010T\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBPC5010W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBPC5010W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'diode full', 'description':'', 'datasheet':'https://www.diodemodule.com/bridge-rectifier/kbpc/kbpc5010t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBPC5010W\n\ndiode full', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU4B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU4B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU4B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU4D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU4D'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU4D\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU4G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU4G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU4G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU4J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU4J'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU4J\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU4K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU4K'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU4K\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU4M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU4M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU4M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU6A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU6A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU6A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU6B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU6B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU6B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU6D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU6D'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU6D\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU6G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU6G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU6G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU6J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU6J'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU6J\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU6K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU6K'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU6K\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU6M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU6M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU6M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU8A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu8.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU8A\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU8B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU8B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu8.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU8B\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU8D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU8D'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu8.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU8D\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU8G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU8G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu8.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU8G\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU8J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU8J'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu8.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU8J\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU8K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU8K'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu8.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU8K\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KBU8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KBU8M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU', 'Diode_THT:Diode_Bridge_Vishay_KBU'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBU', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88656/kbu8.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nKBU8M\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MB4S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MB4S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA'], 'footprint':'Package_TO_SOT_SMD:TO-269AA', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88661/mb2s.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMB4S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MB6S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MB6S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA'], 'footprint':'Package_TO_SOT_SMD:TO-269AA', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88573/dfs.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMB6S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBL106S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBL106S'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Vishay_MBLS', 'Diode_SMD:Diode_Bridge_Vishay_MBLS'], 'footprint':'Diode_SMD:Diode_Bridge_Vishay_MBLS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/89959/mbl104s.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMBL106S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBL108S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBL108S'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Vishay_MBLS', 'Diode_SMD:Diode_Bridge_Vishay_MBLS', 'Diode_SMD:Diode_Bridge_Vishay_MBLS'], 'footprint':'Diode_SMD:Diode_Bridge_Vishay_MBLS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/89959/mbl104s.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMBL108S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBL110S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBL110S'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Diode_Bridge_Vishay_MBLS', 'Diode_SMD:Diode_Bridge_Vishay_MBLS', 'Diode_SMD:Diode_Bridge_Vishay_MBLS', 'Diode_SMD:Diode_Bridge_Vishay_MBLS'], 'footprint':'Diode_SMD:Diode_Bridge_Vishay_MBLS', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/89959/mbl104s.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMBL110S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDB10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDB10S'}), 'ref_prefix':'D', 'fplist':['Package_SO:TSSOP-4_4.4x5mm_P4mm', 'Package_SO:TSSOP-4_4.4x5mm_P4mm'], 'footprint':'Package_SO:TSSOP-4_4.4x5mm_P4mm', 'keywords':'bridge diode rectifier ac dc acdc ac-dc', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MDB8S-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMDB10S\n\nbridge diode rectifier ac dc acdc ac-dc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MDB8S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MDB8S'}), 'ref_prefix':'D', 'fplist':['Package_SO:TSSOP-4_4.4x5mm_P4mm', 'Package_SO:TSSOP-4_4.4x5mm_P4mm', 'Package_SO:TSSOP-4_4.4x5mm_P4mm'], 'footprint':'Package_SO:TSSOP-4_4.4x5mm_P4mm', 'keywords':'bridge diode rectifier ac dc acdc ac-dc', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MDB8S-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nMDB8S\n\nbridge diode rectifier ac dc acdc ac-dc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RB151', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RB151'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.rectron.com/public/product_datasheets/rb151-rb157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRB151\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RB152', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RB152'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.rectron.com/public/product_datasheets/rb151-rb157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRB152\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RB153', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RB153'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.rectron.com/public/product_datasheets/rb151-rb157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRB153\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RB154', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RB154'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.rectron.com/public/product_datasheets/rb151-rb157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRB154\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RB155', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RB155'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.rectron.com/public/product_datasheets/rb151-rb157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRB155\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RB156', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RB156'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.rectron.com/public/product_datasheets/rb151-rb157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRB156\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RB157', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RB157'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm', 'Diode_THT:Diode_Bridge_Round_D9.0mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.0mm', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'https://www.rectron.com/public/product_datasheets/rb151-rb157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRB157\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RMB2S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RMB2S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA'], 'footprint':'Package_TO_SOT_SMD:TO-269AA', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88705/rmbs.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRMB2S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RMB4S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RMB4S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA', 'Package_TO_SOT_SMD:TO-269AA'], 'footprint':'Package_TO_SOT_SMD:TO-269AA', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/88705/rmbs.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nRMB4S\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SC35VB160S-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SC35VB160S-G'}), 'ref_prefix':'U', 'fplist':['Diode_THT:Diode_Bridge_Comchip_SCVB-L', 'Diode_THT:Diode_Bridge_Comchip_SCVB-L'], 'footprint':'Diode_THT:Diode_Bridge_Comchip_SCVB-L', 'keywords':'Three-Phase Bridge Rectifier', 'description':'', 'datasheet':'https://www.comchiptech.com/admin/files/product/SC35VB80S-G%20Thru506369.%20SC35VB160S-G%20RevB.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nSC35VB160S-G\n\nThree-Phase Bridge Rectifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC101', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC101'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC101\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC102', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC102'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC102\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC104', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC104'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC104\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC106', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC106'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC106\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC108', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC108'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC108\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC110'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'Diode_THT:Diode_Bridge_Vishay_KBPC1'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC1', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC110\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC601', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC601'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC601\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC602', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC602'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC602\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC604', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC604'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC604\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC606', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC606'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC606\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC608', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC608'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC608\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC610', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC610'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93585/vs-kbpc1series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC610\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC801', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC801'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93586/kbpc8series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC801\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC802', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC802'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93586/kbpc8series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC802\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC804', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC804'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93586/kbpc8series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC804\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC806', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC806'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93586/kbpc8series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC806\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC808', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC808'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93586/kbpc8series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC808\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-KBPC810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-KBPC810'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'Diode_THT:Diode_Bridge_Vishay_KBPC6'], 'footprint':'Diode_THT:Diode_Bridge_Vishay_KBPC6', 'keywords':'rectifier acdc', 'description':'', 'datasheet':'http://www.vishay.com/docs/93586/kbpc8series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nVS-KBPC810\n\nrectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W005G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W005G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'Bridge Rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88769/woo5g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nW005G\n\nBridge Rectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W01G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W01G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'Bridge Rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88769/woo5g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nW01G\n\nBridge Rectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W02G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W02G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'Bridge Rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88769/woo5g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nW02G\n\nBridge Rectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W04G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W04G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'Bridge Rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88769/woo5g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nW04G\n\nBridge Rectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W06G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W06G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'Bridge Rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88769/woo5g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nW06G\n\nBridge Rectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W08G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W08G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'Bridge Rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88769/woo5g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nW08G\n\nBridge Rectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W10G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W10G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', '', 'Diode_THT:Diode_Bridge_GeneSiC_KBPC_W', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm', 'Diode_THT:Diode_Bridge_Round_D9.8mm'], 'footprint':'Diode_THT:Diode_Bridge_Round_D9.8mm', 'keywords':'Bridge Rectifier acdc', 'description':'', 'datasheet':'https://www.vishay.com/docs/88769/woo5g.pdf', 'search_text':'/usr/share/kicad/symbols/Diode_Bridge.kicad_sym\nW10G\n\nBridge Rectifier acdc', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])