from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

_74xx = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'74469', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74469'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'counter', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74469', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74469\n\ncounter', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='UD',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CBO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='CBI',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='D6',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74ALVC164245', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74ALVC164245'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'transceiver', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74ALVC164245.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74ALVC164245\n\ntransceiver', 'pins':[
            Pin(num='1',name='1DIR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1B6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='1B7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='2B0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='2B1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='2B2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='2B3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='V_{CC(B)}',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2B4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='1B0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='2B5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2B6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='2B7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='2DIR',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='2A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='2A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2A5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='1B1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='2A4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='V_{CC(A)}',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='2A3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='2A2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2A1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='2A0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='1A7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='1A6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='1A5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='1A4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='V_{CC(A)}',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1A3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='1A2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1A1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='1A0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1B2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='1B3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='V_{CC(B)}',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='1B4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='1B5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CB3Q16210DGG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CB3Q16210DGG'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cb3q16210.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CB3Q16210DGG\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTLV16212', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTLV16212'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'bus', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbtlv16212.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBTLV16212\n\nbus', 'pins':[
            Pin(num='10',name='4A2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='5A1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='5A2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='6A1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='6A2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='7A1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='7A2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='8A1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='8A2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='9A1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='9A2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='10A1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='10A2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='11A1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='11A2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='12A1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='12A2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='12B2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='1A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='12B1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='11B2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='11B1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='10B2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='10B1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='9B2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='9B1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='8B2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='8B1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='2A1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='7B2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='7B1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='6B2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='6B1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='5B2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='5B1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='4B2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='4B1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='3B2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='2A2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='3B1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='2B2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='2B1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='1B2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='1B1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='3A1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='3A2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='4A1',func=pin_types.BIDIR,unit=1),
            Pin(num='1',name='S0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTLV3257', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTLV3257'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'mux demux low-voltage', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74cbtlv3257.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBTLV3257\n\nmux demux low-voltage', 'pins':[
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=4),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=4),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=4),
            Pin(num='1',name='S',func=pin_types.INPUT,unit=5),
            Pin(num='15',name='~{OE}',func=pin_types.INPUT,unit=5),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '11', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '12', '14']},{'label': 'uE', 'num': 5, 'pin_nums': ['1', '16', '8', '15']}] }),
        Part(**{ 'name':'74CBTLV3861', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTLV3861'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'bus', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74cbtlv3861', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBTLV3861\n\nbus', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='A8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC137', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC137'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc237.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC137\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Y5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Y4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{Y3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{Y2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Y1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Y0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Y7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{Y6}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC138', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC138'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc238.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC138\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Y5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Y4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{Y3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{Y2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Y1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Y0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{E0}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Y7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{Y6}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC14'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCMOS not inverter', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74HC14', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC14\n\nHCMOS not inverter', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74HC164', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC164'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'8-bit shift register', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT164.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC164\n\n8-bit shift register', 'pins':[
            Pin(num='1',name='DSA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DSB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{MR}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC237', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC237'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc237.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC237\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC238', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC238'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd74hc238.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC238\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC240'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCMOS BUFFER 3State inv', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT240.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC240\n\nHCMOS BUFFER 3State inv', 'pins':[
            Pin(num='1',name='1OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='2A0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='2OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2Y3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC244', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC244'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCMOS BUFFER 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT244.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC244\n\nHCMOS BUFFER 3State', 'pins':[
            Pin(num='1',name='1OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='2A0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='2OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2Y3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC4024', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC4024'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'binary counter', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC4024.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC4024\n\nbinary counter', 'pins':[
            Pin(num='1',name='~{CP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='Q2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC4051', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC4051'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCMOS Multiplexer Demultiplexer Analog', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc4051.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC4051\n\nHCMOS Multiplexer Demultiplexer Analog', 'pins':[
            Pin(num='1',name='A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='A0',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='S2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC4060', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC4060'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'binary counter oscillator', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/m74hc4060.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC4060\n\nbinary counter oscillator', 'pins':[
            Pin(num='1',name='Q12',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Î¦0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{Î¦1}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q9',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q8',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q10',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q13',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q14',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{Î¦0}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC590', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC590'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCMOS Counter 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC590.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC590\n\nHCMOS Counter 3State', 'pins':[
            Pin(num='1',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{MRC}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CPC',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CPR',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RCO}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC594', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC594'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCMOS SR', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74hc594.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC594\n\nHCMOS SR', 'pins':[
            Pin(num='1',name='QB',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{RCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='QD',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='QE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='QF',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='QG',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='QH',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC595', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC595'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCMOS SR 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74hc595.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC595\n\nHCMOS SR 3State', 'pins':[
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC596', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC596'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'HCMOS SR OpenCollector', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT595.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC596\n\nHCMOS SR OpenCollector', 'pins':[
            Pin(num='1',name='QB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='QD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='QE',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='QF',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='QG',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='QH',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC7014', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC7014'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'Hex non-inverting Schmitt buffer', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC7014.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC7014\n\nHex non-inverting Schmitt buffer', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '12']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LCX07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LCX07'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'CMOS hex buffer', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/74lcx07.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LCX07\n\nCMOS hex buffer', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS00'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL nand 2-input', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74ls00', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS00\n\nTTL nand 2-input', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS01'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL nand 2-input open collector', 'description':'', 'datasheet':'http://www.nteinc.com/specs/7400to7499/pdf/nte74LS01.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS01\n\nTTL nand 2-input open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS02'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nor2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74ls02', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS02\n\nTTL Nor2', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS03', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS03'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand2 OpenColl', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS03', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS03\n\nTTL Nand2 OpenColl', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '11', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS04'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL not inv', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS04', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS04\n\nTTL not inv', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS05'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL not inv OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS05', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS05\n\nTTL not inv OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS08'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL and2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS08', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS08\n\nTTL and2', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS09', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS09'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL and2 OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS09', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS09\n\nTTL and2 OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '10', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS10'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand3', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS10', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS10\n\nTTL Nand3', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=4),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['13', '2', '1', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '9', '11', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS107', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS107'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL JK', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS107', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS107\n\nTTL JK', 'pins':[
            Pin(num='1',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='8',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '13', '3', '2', '1', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '9', '6', '10', '8', '11']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS109', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS109'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL JK', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS109', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS109\n\nTTL JK', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{K}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~{K}',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '4', '2', '7', '1', '5', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '13', '11', '9', '12', '14', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74LS11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS11'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL And3', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS11', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS11\n\nTTL And3', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=4),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '12', '13', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '6', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '9', '10', '11']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS112', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS112'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL JK', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS112', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS112\n\nTTL JK', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '6', '4', '1', '15', '3', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '14', '13', '12', '11', '7', '9']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74LS113', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS113'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL JK', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS113', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS113\n\nTTL JK', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '6', '4', '1', '3', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '8', '13', '10', '9', '12']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS114', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS114'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL JK', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS114', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS114\n\nTTL JK', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '13', '6', '4', '1', '2', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '8', '12', '9', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS12'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand3 OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS12', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS12\n\nTTL Nand3 OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=4),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '2', '1', '13']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '4', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '11', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS121', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS121'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'monostable', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74121', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS121\n\nmonostable', 'pins':[
            Pin(num='1',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Cext',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='R/Cext',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Rint',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS122', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS122'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL monostable', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS122', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS122\n\nTTL monostable', 'pins':[
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Cext',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='R/Cext',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Clr',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Rint',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS123'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL monostable', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS123', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS123\n\nTTL monostable', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Cext',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='RCext',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Clr',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Clr',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='Cext',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='RCext',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='A',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '14', '4', '13', '15', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '11', '12', '6', '9', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74LS125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS125'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL buffer 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS125', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS125\n\nTTL buffer 3State', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '12', '11']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS126'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Buffer 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS126', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS126\n\nTTL Buffer 3State', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '10', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS13'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS13', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS13\n\nTTL Nand4', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '2', '4', '1', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '13', '9', '12', '8']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS132', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS132'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS132', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS132\n\nTTL Nand2', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '11', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS133', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS133'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand13', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS133', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS133\n\nTTL Nand13', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=2),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '11', '3', '4', '5', '13', '2', '9', '12', '14', '6', '7', '10', '15']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '16']}] }),
        Part(**{ 'name':'74LS136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL XOR2 OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn54ls136.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS136\n\nTTL XOR2 OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '10', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS137', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS137'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD8 DECOD', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS137', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS137\n\nTTL DECOD8 DECOD', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{GL}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS138', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS138'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD DECOD8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS138', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS138\n\nTTL DECOD DECOD8', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='O4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='O3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='O2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='O1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='O0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O7',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='O6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS139', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS139'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD4', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls139a.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS139\n\nTTL DECOD4', 'pins':[
            Pin(num='1',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='O0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='O2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='O3',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='O2',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='O1',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='O0',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='A1',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='A0',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='E',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='O3',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1', '4', '2', '7', '5', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '14', '9', '10', '13', '15', '11']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74LS145', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS145'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD10 OpenColl', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS145', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS145\n\nTTL DECOD10 OpenColl', 'pins':[
            Pin(num='1',name='Q0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='Q8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='Q9',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='Q2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='Q3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='Q4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='Q5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='Q6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q7',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS147', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS147'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ENCOD', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS147', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS147\n\nTTL ENCOD', 'pins':[
            Pin(num='1',name='E4',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='E9',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='E3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='S3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='E5',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E6',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='E7',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='E8',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='S1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='S0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS148', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS148'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ENCOD', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS148', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS148\n\nTTL ENCOD', 'pins':[
            Pin(num='1',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GS',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='EO',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='S1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='S0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS15'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL And3', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS15', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS15\n\nTTL And3', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=4),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '13', '12', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '4', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '11', '9', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS151', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS151'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS151', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS151\n\nTTL MUX8', 'pins':[
            Pin(num='1',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Z',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Z}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='S2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS153', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS153'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Mux4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS153', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS153\n\nTTL Mux4', 'pins':[
            Pin(num='1',name='Ea',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Eb',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Za',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Zb',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS154', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS154'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD16 DECOD', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS154', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS154\n\nTTL DECOD16 DECOD', 'pins':[
            Pin(num='1',name='S0',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='S9',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='S10',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='S11',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='S12',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='S13',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='S14',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='S15',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='E0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='S3',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='S4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='S5',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='S6',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='S7',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='S8',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS155', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS155'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD8 DECOD4 DEMUX4 DEMUX8 DEMUX DECOD', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS155', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS155\n\nTTL DECOD8 DECOD4 DEMUX4 DEMUX8 DEMUX DECOD', 'pins':[
            Pin(num='1',name='Ea1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Eb1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Eb2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Ea2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q3a',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q2a',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q1a',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q0a',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q0b',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS157', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS157'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS157', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS157\n\nTTL MUX MUX2', 'pins':[
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Zd',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Za',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Zb',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Zc',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS158', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS158'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Mux MUX2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS158', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS158\n\nTTL Mux MUX2', 'pins':[
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Zc',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Za',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Zb',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Zd',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS161', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS161'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS161', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS161\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{PE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS165', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS165'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL SR SR8', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74ls165a.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS165\n\nTTL SR SR8', 'pins':[
            Pin(num='1',name='~{PL}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Q7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q7',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS166', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS166'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL SR SR8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS166', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS166\n\nTTL SR SR8', 'pins':[
            Pin(num='1',name='Ds',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Qh',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='H',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Clk',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Clr',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS168', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS168'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS168', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS168\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='U/~{D}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{TC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{CEP}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{PE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS170', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS170'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Register OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS170', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS170\n\nTTL Register OpenCol', 'pins':[
            Pin(num='1',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='~{Er}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{Ew}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Wb',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Wa',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Rb',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Ra',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS173', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS173'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG REG4 3State DFF', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS173', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS173\n\nTTL REG REG4 3State DFF', 'pins':[
            Pin(num='1',name='Oe1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Mr',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Oe2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='E1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS174', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS174'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG REG6 DFF', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS174', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS174\n\nTTL REG REG6 DFF', 'pins':[
            Pin(num='1',name='~{Mr}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Cp',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS175', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS175'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG REG4 DFF', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS175', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS175\n\nTTL REG REG4 DFF', 'pins':[
            Pin(num='1',name='~{Mr}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Cp',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS181', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS181'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ALU ARITH', 'description':'', 'datasheet':'74xx/74F181.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS181\n\nTTL ALU ARITH', 'pins':[
            Pin(num='1',name='B0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='F1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='F2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='F3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A=B',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='X',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Cn+4',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='S3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Cn',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='F0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS182', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS182'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ALU ARITH', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS182', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS182\n\nTTL ALU ARITH', 'pins':[
            Pin(num='1',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='G',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Cn+y',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Cn+x',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Cn',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='G0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='G3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='P',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Cn+z',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS190', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS190'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS190', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS190\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Pl',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Tc',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Rc',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Ce',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D/U',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS192', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS192'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls193.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS192\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='QA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='QC',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='QD',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS194', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS194'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL RS SR4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS194', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS194\n\nTTL RS SR4', 'pins':[
            Pin(num='1',name='Mr',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Dsr',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Dsl',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='S0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS195', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS195'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL SR SR4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS195', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS195\n\nTTL SR SR4', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{K}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{PE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS196', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS196'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS196', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS196\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='Pl',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Mr',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Cp1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Cp0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS20'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS20', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS20\n\nTTL Nand4', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '5', '2', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '8', '13', '9', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS21', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS21'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL And4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS21', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS21\n\nTTL And4', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '6', '4', '1', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '8', '9', '12', '13']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS221', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS221'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Monostable', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS221', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS221\n\nTTL Monostable', 'pins':[
            Pin(num='1',name='~{A}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Cext',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='RCext',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='~{CLR}',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='Cext',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='RCext',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='~{A}',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['13', '2', '1', '14', '3', '15', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '12', '7', '5', '10', '9', '11']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74LS240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS240'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls240.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS240\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O3a',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='O2a',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='O1a',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='O0a',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='O3b',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O2b',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O1b',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O0b',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS240_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS240_Split'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls240.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS240_Split\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~',func=pin_types.TRISTATE,unit=3),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='~',func=pin_types.TRISTATE,unit=4),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='19',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='9',name='~',func=pin_types.TRISTATE,unit=5),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='7',name='~',func=pin_types.TRISTATE,unit=6),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=7),
            Pin(num='5',name='~',func=pin_types.TRISTATE,unit=7),
            Pin(num='17',name='~',func=pin_types.INPUT,unit=8),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=8),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=9)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '18']},{'label': 'uB', 'num': 2, 'pin_nums': ['16', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '19', '9']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '7']},{'label': 'uG', 'num': 7, 'pin_nums': ['5', '15']},{'label': 'uH', 'num': 8, 'pin_nums': ['17', '3']},{'label': 'uI', 'num': 9, 'pin_nums': ['20', '10']}] }),
        Part(**{ 'name':'74LS241', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS241'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls241.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS241\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O3a',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='O2a',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='O1a',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='O0a',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='O3b',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O2b',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O1b',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O0b',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS241_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS241_Split'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls241.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS241_Split\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~',func=pin_types.TRISTATE,unit=3),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='~',func=pin_types.TRISTATE,unit=4),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='19',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='9',name='~',func=pin_types.TRISTATE,unit=5),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='7',name='~',func=pin_types.TRISTATE,unit=6),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=7),
            Pin(num='5',name='~',func=pin_types.TRISTATE,unit=7),
            Pin(num='17',name='~',func=pin_types.INPUT,unit=8),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=8),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=9)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '18']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '16']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['19', '11', '9']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['5', '15']},{'label': 'uH', 'num': 8, 'pin_nums': ['17', '3']},{'label': 'uI', 'num': 9, 'pin_nums': ['10', '20']}] }),
        Part(**{ 'name':'74LS242', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS242'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'bus 3state', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS242', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS242\n\nbus 3state', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='B2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS243'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Buffer 3State BUS BIDI', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS243', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS243\n\nTTL Buffer 3State BUS BIDI', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='B2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS244', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS244'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls244.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS244\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O3a',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='O2a',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='O1a',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='O0a',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='O3b',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O2b',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O1b',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O0b',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS244_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS244_Split'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls241.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS244_Split\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~',func=pin_types.TRISTATE,unit=3),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='~',func=pin_types.TRISTATE,unit=4),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='19',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='9',name='~',func=pin_types.TRISTATE,unit=5),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='7',name='~',func=pin_types.TRISTATE,unit=6),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=7),
            Pin(num='5',name='~',func=pin_types.TRISTATE,unit=7),
            Pin(num='17',name='~',func=pin_types.INPUT,unit=8),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=8),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=9),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=9)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['18', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['16', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '19', '9']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '7']},{'label': 'uG', 'num': 7, 'pin_nums': ['15', '5']},{'label': 'uH', 'num': 8, 'pin_nums': ['17', '3']},{'label': 'uI', 'num': 9, 'pin_nums': ['20', '10']}] }),
        Part(**{ 'name':'74LS245', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS245'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL BUS 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS245', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS245\n\nTTL BUS 3State', 'pins':[
            Pin(num='1',name='A->B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS247', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS247'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS247', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS247\n\nTTL DECOD', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Lt',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Rbo',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Rbi',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS248', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS248'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS248', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS248\n\nTTL DECOD', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}/~{RBO}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS251', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS251'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX8 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS251', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS251\n\nTTL MUX MUX8 3State', 'pins':[
            Pin(num='1',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='~{Y}',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='S2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS253', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS253'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX4 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS253', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS253\n\nTTL MUX MUX4 3State', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Za',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Zb',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'latch', 'description':'', 'datasheet':'https://alfter.us/wp-content/uploads/2022/12/74LS256.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS256\n\nlatch', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q_{1b}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q_{2b}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q_{3b}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Db',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CL}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Da',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q_{0a}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q_{1a}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q_{2a}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q_{3a}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q_{0b}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS257', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS257'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS257', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS257\n\nTTL MUX MUX2', 'pins':[
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Zc',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Za',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Zb',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Zd',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS258', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS258'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS258', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS258\n\nTTL MUX MUX2', 'pins':[
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Zc',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Za',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Zb',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Zd',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS259', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS259'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG DFF', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS259', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS259\n\nTTL REG DFF', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Clr',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS26', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS26'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand2 OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS26', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS26\n\nTTL Nand2 OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '8', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '12', '11']},{'label': 'uE', 'num': 5, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS27', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS27'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nor3', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS27', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS27\n\nTTL Nor3', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=4),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '12', '2', '13']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '3', '5', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '11', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS273', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS273'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DFF DFF8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS273', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS273\n\nTTL DFF DFF8', 'pins':[
            Pin(num='1',name='~{Mr}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS279', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS279'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL latch set reset srs flip flop flipflop rs-flipflop', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/sn54ls279a', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS279\n\nTTL latch set reset srs flip flop flipflop rs-flipflop', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~{R}',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~{S}',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='~{S}',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=3),
            Pin(num='13',name='Q',func=pin_types.OUTPUT,unit=4),
            Pin(num='14',name='~{R}',func=pin_types.INPUT,unit=4),
            Pin(num='15',name='~{S}',func=pin_types.INPUT,unit=4),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '4', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '11', '12', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '13', '15']},{'label': 'uE', 'num': 5, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74LS280', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS280'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ALU Arith', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS280', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS280\n\nTTL ALU Arith', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='H',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Even',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Odd',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS283', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS283'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ADD Arith ALU', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS283', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS283\n\nTTL ADD Arith ALU', 'pins':[
            Pin(num='1',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='S4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='B4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='S3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='C0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='C4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS290', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS290'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS290', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS290\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='Ms1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Cp0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Cp1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Mr1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Mr2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Ms2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS295', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS295'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'register', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS295', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS295\n\nregister', 'pins':[
            Pin(num='1',name='Ds',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Pe',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Cp',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS298', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS298'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS298', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS298\n\nTTL MUX MUX2', 'pins':[
            Pin(num='1',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='I0c',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS299', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS299'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG SR SR8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS299', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS299\n\nTTL REG SR SR8', 'pins':[
            Pin(num='1',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Ds0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='IO3',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='IO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='IO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='Ds7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OE1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OE2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='IO4',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='IO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='IO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Mr',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS30'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nand8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS30', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS30\n\nTTL Nand8', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=2),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '12', '8', '2', '5', '1', '3', '11', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS32'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Or2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS32', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS32\n\nTTL Or2', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS322', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS322'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'register', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS322', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS322\n\nregister', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Clk',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qh',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='H/Qh',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='F/Qf',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='D/Qd',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B/Qb',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S/P',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A/Qa',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='C/Qc',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='E/Qe',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='G/Qg',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Clr',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS323'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG SR SR8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS323', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS323\n\nTTL REG SR SR8', 'pins':[
            Pin(num='1',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DS0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='IO3',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='IO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='IO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='DS7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OE1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OE2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='IO4',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='IO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='IO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS33'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Nor2 OpenColl', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS33', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS33\n\nTTL Nor2 OpenColl', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '10', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS348', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS348'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ENCOD Arith', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS348', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS348\n\nTTL ENCOD Arith', 'pins':[
            Pin(num='1',name='4',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GS',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='E0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='5',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='6',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='7',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A0',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS352', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS352'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Mux MUX4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS352', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS352\n\nTTL Mux MUX4', 'pins':[
            Pin(num='1',name='Ea',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Eb',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Za',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Zb',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS353', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS353'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS353', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS353\n\nTTL MUX MUX2', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Za',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Zb',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS365', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS365'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Buffer BUS 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS365', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS365\n\nTTL Buffer BUS 3State', 'pins':[
            Pin(num='1',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O3',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='O4',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS366', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS366'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Buffer BUS 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS366', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS366\n\nTTL Buffer BUS 3State', 'pins':[
            Pin(num='1',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O3',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='O4',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS367', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS367'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Buffer BUS 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS367', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS367\n\nTTL Buffer BUS 3State', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='O5b',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='O6b',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O1a',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O2a',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O3a',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='O4a',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS368', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS368'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL Buffer BUS 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS368', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS368\n\nTTL Buffer BUS 3State', 'pins':[
            Pin(num='1',name='OEa',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='O5b',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='O6b',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OEb',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O1a',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O2a',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O3a',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='O4a',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS373'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG DFF DFF8 LATCH', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS373', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS373\n\nTTL REG DFF DFF8 LATCH', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS374', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS374'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DFF DFF8 REG 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS374', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS374\n\nTTL DFF DFF8 REG 3State', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS375', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS375'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DFF DFF4 Latch', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS375', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS375\n\nTTL DFF DFF4 Latch', 'pins':[
            Pin(num='1',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='E23',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E01',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS377', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS377'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG DFF DFF8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS377', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS377\n\nTTL REG DFF DFF8', 'pins':[
            Pin(num='1',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS378', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS378'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG DFF DFF6', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS378', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS378\n\nTTL REG DFF DFF6', 'pins':[
            Pin(num='1',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='C',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS379', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS379'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG DFF DFF4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS379', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS379\n\nTTL REG DFF DFF4', 'pins':[
            Pin(num='1',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS385', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS385'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ADD Arith ALU', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS385', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS385\n\nTTL ADD Arith ALU', 'pins':[
            Pin(num='1',name='Clk',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Clr',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='3S',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='3S/A',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='3B',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='3A',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='4A',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='4B',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='4S/A',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='4S',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='1S',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='1S/A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='1B',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2B',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='2S/A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2S',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS386', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS386'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL XOR2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS386', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS386\n\nTTL XOR2', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '10', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS390', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS390'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS390', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS390\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='~{CP0}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CP1}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='~{CP1}',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='Q0',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='MR',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{CP0}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '4', '6', '1', '2', '5', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '9', '15', '12', '13', '10', '11']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74LS393', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS393'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'74xx\\74LS393.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS393\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='Q0',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='MR',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='CP',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '3', '5', '1', '4', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '10', '13', '9', '11', '8']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS395', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS395'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL SR SR4 REG 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS395', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS395\n\nTTL SR SR4 REG 3State', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CP}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name="Q'3",func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Ds',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='LD/~{SH}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{OE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS398', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS398'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX2 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS398', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS398\n\nTTL MUX MUX2 3State', 'pins':[
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{Qc}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{Qd}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Qa}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{Qb}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Qb',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS399', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS399'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL MUX MUX2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS399', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS399\n\nTTL MUX MUX2', 'pins':[
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS42', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS42'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD DECOD10', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS42', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS42\n\nTTL DECOD DECOD10', 'pins':[
            Pin(num='1',name='0',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='8',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='9',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='3',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='5',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='6',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='7',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS47', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS47'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD DECOD7 OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS47', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS47\n\nTTL DECOD DECOD7 OpenCol', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LT',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RBI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS48', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS48'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD DECOD7', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS48', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS48\n\nTTL DECOD DECOD7', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LT',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RBI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS49', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS49'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD DECOD7 OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74ls47', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS49\n\nTTL DECOD DECOD7 OpenCol', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='e',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='c',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS51', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS51'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ANDNOR', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls51.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS51\n\nTTL ANDNOR', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['10', '11', '1', '8', '9', '13', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '2', '6', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS54', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS54'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ANDNOR', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS54', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS54\n\nTTL ANDNOR', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=2),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['9', '1', '10', '2', '5', '8', '13', '3', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS540', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS540'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'BUFFER BUS TTL 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS540', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS540\n\nBUFFER BUS TTL 3State', 'pins':[
            Pin(num='1',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Y7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Y6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Y5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Y4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS541', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS541'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL BUFFER 3State BUS', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS541', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS541\n\nTTL BUFFER 3State BUS', 'pins':[
            Pin(num='1',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Y7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Y6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Y5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Y4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS55', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS55'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ANDNOR', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS55', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS55\n\nTTL ANDNOR', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=2),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '2', '11', '12', '10', '3', '8', '13', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS573', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS573'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DFF DFF8 LATCH 3State', 'description':'', 'datasheet':'74xx/74hc573.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS573\n\nTTL DFF DFF8 LATCH 3State', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Load',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='D7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS574', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS574'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL REG DFF DFF8 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS574', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS574\n\nTTL REG DFF DFF8 3State', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='D7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS629', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS629'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'VCO', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS629', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS629\n\nVCO', 'pins':[
            Pin(num='15',name='OSC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='FC',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='RNG',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CX1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CX2',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='1',name='FC',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='Y',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='EN',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='CX2',func=pin_types.PASSIVE,unit=2),
            Pin(num='13',name='CX1',func=pin_types.PASSIVE,unit=2),
            Pin(num='14',name='RNG',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='OSC',func=pin_types.PASSIVE,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '6', '15', '4', '2', '7', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '13', '8', '1', '12', '14', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '9']}] }),
        Part(**{ 'name':'74LS688', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS688'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD Arith', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS688', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS688\n\nTTL DECOD Arith', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='R4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='R5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='R6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='R7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='P=R',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='R0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='R3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS73', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS73'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL JK JKFF', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS73', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS73\n\nTTL JK JKFF', 'pins':[
            Pin(num='10',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='1',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='2',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '8', '10', '5', '9', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '14', '2', '1', '3', '12']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '11']}] }),
        Part(**{ 'name':'74LS74', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS74'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DFF', 'description':'', 'datasheet':'74xx/74hc_hct74.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS74\n\nTTL DFF', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '3', '5', '4', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '11', '8', '12', '10', '13']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS75'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DFF Latch', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS75', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS75\n\nTTL DFF Latch', 'pins':[
            Pin(num='1',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='E01',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='E23',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS76', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS76'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL JK JKFF', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS76', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS76\n\nTTL JK JKFF', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['15', '3', '16', '2', '14', '4', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '6', '10', '8', '12', '11', '9']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '13']}] }),
        Part(**{ 'name':'74LS77', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS77'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DFF Latch', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS77', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS77\n\nTTL DFF Latch', 'pins':[
            Pin(num='1',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='E01',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E23',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS78', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS78'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL JK JKFF', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS78', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS78\n\nTTL JK JKFF', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '5', '2', '13', '14', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '6', '8', '10', '5', '9', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['11', '4']}] }),
        Part(**{ 'name':'74LS83', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS83'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL ADD ARITH ALU', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS83', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS83\n\nTTL ADD ARITH ALU', 'pins':[
            Pin(num='1',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='C0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='C4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='S4',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='B4',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='S1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS85', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS85'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL COMP ARITH', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS85', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS85\n\nTTL COMP ARITH', 'pins':[
            Pin(num='1',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Ia<b',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Ia=b',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Ia>b',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Oa>b',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Oa=b',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Oa<b',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='B0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS86'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL XOR2', 'description':'', 'datasheet':'74xx/74ls86.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS86\n\nTTL XOR2', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '12', '11']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS90', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS90'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS90', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS90\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='CP1..3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CP0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R0(1)',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R0(2)',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='R9(1)',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R9(2)',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS91', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS91'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL SR SR8', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS91', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS91\n\nTTL SR SR8', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Qh',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Qh}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS92', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS92'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS92', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS92\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='CP1..3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CP0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='R0(1)',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R0(2)',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS93', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS93'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS93', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS93\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='CP1..3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CP0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R0(1)',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R0(2)',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS95', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS95'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL SR SR4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS95', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS95\n\nTTL SR SR4', 'pins':[
            Pin(num='1',name='Ds',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Mode',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Cp2.Lshift',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Cp1.Rshift',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LV14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LV14'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL not inv', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LV14', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LV14\n\nTTL not inv', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='3.3V',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '12']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LV8154', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LV8154'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'counter binary', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lv8154.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LV8154\n\ncounter binary', 'pins':[
            Pin(num='1',name='CKLA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{CCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y6',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CLKB',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{GAL}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{GAU}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{GBL}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{GBU}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{RCOA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{CLKBEN}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74VHC9164FT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74VHC9164FT'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'shift register universal serial parallel', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=15655&prodName=74VHC9164FT', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74VHC9164FT\n\nshift register universal serial parallel', 'pins':[
            Pin(num='1',name='P/S_CONT',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q/D5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='Q/D6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='Q/D7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='Q/D8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name="Q8'",func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q8C',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{CLR_LOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q/D1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='Q/D2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='Q/D3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q/D4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CD74HC4067M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CD74HC4067M'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm'], 'footprint':'Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm', 'keywords':'multiplexer demultiplexer mux demux', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc4067.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nCD74HC4067M\n\nmultiplexer demultiplexer mux demux', 'pins':[
            Pin(num='1',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='S3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='I15',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='I14',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='I13',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='I12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='I7',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='I11',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='I10',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='I9',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='I8',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='I6',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I5',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='I4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='I2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='I1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='I0',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CD74HC4067SM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CD74HC4067SM'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'multiplexer demultiplexer mux demux', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc4067.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nCD74HC4067SM\n\nmultiplexer demultiplexer mux demux', 'pins':[
            Pin(num='1',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='S3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='I15',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='I14',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='I13',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='I12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='I7',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='I11',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='I10',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='I9',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='I8',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='I6',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I5',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='I4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='I2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='I1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='I0',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC74LCX16245DT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC74LCX16245DT'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'transceiver', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/mc74lcx16245-d.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nMC74LCX16245DT\n\ntransceiver', 'pins':[
            Pin(num='1',name='T/~{R}1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='B8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='B10',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='B11',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='B12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='B0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='B13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='B14',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='B15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='T/~{R}2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{OE2}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='A14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='A13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='A12',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='A11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='A10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='A9',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='A8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='A7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='A6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='A5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='A0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='~{OE1}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='B5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MM74C923', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MM74C923'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'encoder', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/snMM74C923', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nMM74C923\n\nencoder', 'pins':[
            Pin(num='1',name='Y1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='X2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='X1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DA',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='XOE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='E',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='D',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='C',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='A',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='Y2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Y3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Y4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OSC',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='KBM',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='X4',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='X3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74AVC16827DGGR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74AVC16827DGGR'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-56_6.1x14mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-56_6.1x14mm_P0.5mm', 'keywords':'Buffer Driver 3-State', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74avc16827.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nSN74AVC16827DGGR\n\nBuffer Driver 3-State', 'pins':[
            Pin(num='1',name='1OE1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='1Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1Y8',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='1Y9',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='1Y10',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='2Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='2Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='2Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='1Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='2Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='2Y6',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='2Y8',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2Y9',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='2Y10',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='2OE1',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='2OE2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='1Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='2A10',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='2A9',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='2A7',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='2A6',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='2A5',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='2A4',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='1A10',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='1A9',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='1A8',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='1A7',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1A6',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='1A5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='1A4',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='1OE2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='1Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='1Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='1Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74CB3Q3384ADBQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74CB3Q3384ADBQ'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'low voltage high bandwidth', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cb3q3384a.pdf?ts=1634790233466', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nSN74CB3Q3384ADBQ\n\nlow voltage high bandwidth', 'pins':[
            Pin(num='1',name='~{1OE}',func=pin_types.INPUT),
            Pin(num='10',name='1B5',func=pin_types.TRISTATE),
            Pin(num='11',name='1A5',func=pin_types.TRISTATE),
            Pin(num='12',name='GND',func=pin_types.PWRIN),
            Pin(num='13',name='~{2OE}',func=pin_types.INPUT),
            Pin(num='14',name='2A1',func=pin_types.TRISTATE),
            Pin(num='15',name='2B1',func=pin_types.TRISTATE),
            Pin(num='16',name='2B2',func=pin_types.TRISTATE),
            Pin(num='17',name='2A2',func=pin_types.TRISTATE),
            Pin(num='18',name='2A3',func=pin_types.TRISTATE),
            Pin(num='19',name='2B3',func=pin_types.TRISTATE),
            Pin(num='2',name='1B1',func=pin_types.TRISTATE),
            Pin(num='20',name='2B4',func=pin_types.TRISTATE),
            Pin(num='21',name='2A4',func=pin_types.TRISTATE),
            Pin(num='22',name='2A5',func=pin_types.TRISTATE),
            Pin(num='23',name='2B5',func=pin_types.TRISTATE),
            Pin(num='24',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='1A1',func=pin_types.TRISTATE),
            Pin(num='4',name='1A2',func=pin_types.TRISTATE),
            Pin(num='5',name='1B2',func=pin_types.TRISTATE),
            Pin(num='6',name='1B3',func=pin_types.TRISTATE),
            Pin(num='7',name='1A3',func=pin_types.TRISTATE),
            Pin(num='8',name='1A4',func=pin_types.TRISTATE),
            Pin(num='9',name='1B4',func=pin_types.TRISTATE)], 'unit_defs':[] }),
        Part(**{ 'name':'7400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7400'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL nand 2-input', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn7400', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n7400\n\nTTL nand 2-input', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'7402', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7402'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL Nor2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn7402', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n7402\n\nTTL Nor2', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '12', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74AHC04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC04'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'AHCMOS not inv', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT04.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHC04\n\nAHCMOS not inv', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74AHC240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC240'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'AHCMOS BUFFER 3State inv', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn54ahc240.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHC240\n\nAHCMOS BUFFER 3State inv', 'pins':[
            Pin(num='1',name='1OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='2A0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='2OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2Y3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC244', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC244'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'AHCMOS BUFFER 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT244.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHC244\n\nAHCMOS BUFFER 3State', 'pins':[
            Pin(num='1',name='1OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='2A0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='2OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2Y3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC273', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC273'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'AHCMOS DFF DFF8', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT273.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHC273\n\nAHCMOS DFF DFF8', 'pins':[
            Pin(num='1',name='~{Mr}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC373'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'AHCMOS REG DFF DFF8 LATCH', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC373.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHC373\n\nAHCMOS REG DFF DFF8 LATCH', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC374', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC374'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'AHCMOS DFF DFF8 REG 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT374.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHC374\n\nAHCMOS DFF DFF8 REG 3State', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC541', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC541'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL BUFFER 3State BUS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74ahc541.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHC541\n\nTTL BUFFER 3State BUS', 'pins':[
            Pin(num='1',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Y7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Y6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Y5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Y4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC595', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC595'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'AHCMOS SR 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT595.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHC595\n\nAHCMOS SR 3State', 'pins':[
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT04'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'AHCTMOS not inv', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT04.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT04\n\nAHCTMOS not inv', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '12']},{'label': 'uG', 'num': 7, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74AHCT123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT123'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL monostable, multivibrator', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74ahct123a', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT123\n\nTTL monostable, multivibrator', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Cext',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='RCext',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Clr',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Clr',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='Cext',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='RCext',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='A',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '15', '1', '14', '2', '13', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '11', '6', '12', '9', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74AHCT125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT125'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'buffer 3State', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74ahct125.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT125\n\nbuffer 3State', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74AHCT240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT240'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'AHCTMOS BUFFER 3State inv', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHCT240.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT240\n\nAHCTMOS BUFFER 3State inv', 'pins':[
            Pin(num='1',name='1OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='2A0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='2OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2Y3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT244', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT244'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'AHCTMOS BUFFER 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT244.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT244\n\nAHCTMOS BUFFER 3State', 'pins':[
            Pin(num='1',name='1OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='2A0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='2OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2Y3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT273', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT273'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'AHCTMOS DFF DFF8', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT273.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT273\n\nAHCTMOS DFF DFF8', 'pins':[
            Pin(num='1',name='~{Mr}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT373'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'AHCTMOS REG DFF DFF8 LATCH', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74ahct373.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT373\n\nAHCTMOS REG DFF DFF8 LATCH', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT374', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT374'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'AHCTMOS DFF DFF8 REG 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT374.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT374\n\nAHCTMOS DFF DFF8 REG 3State', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT541', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT541'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL BUFFER 3State BUS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74ahct541.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT541\n\nTTL BUFFER 3State BUS', 'pins':[
            Pin(num='1',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Y7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Y6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Y5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Y4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT595', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT595'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'AHCTMOS SR 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT595.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74AHCT595\n\nAHCTMOS SR 3State', 'pins':[
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CB3Q16210DGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CB3Q16210DGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cb3q16210.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CB3Q16210DGV\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CB3Q16210DL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CB3Q16210DL'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cb3q16210.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CB3Q16210DL\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CB3T16210DGG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CB3T16210DGG'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cb3t16210.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CB3T16210DGG\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CB3T16210DGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CB3T16210DGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cb3t16210.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CB3T16210DGV\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBT16210CDGG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBT16210CDGG'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbt16210c.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBT16210CDGG\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBT16210CDGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBT16210CDGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbt16210c.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBT16210CDGV\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBT16210CDL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBT16210CDL'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbt16210c.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBT16210CDL\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBT3861', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBT3861'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'bus', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbt3861.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBT3861\n\nbus', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='A8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTD16210DGG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTD16210DGG'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbtd16210.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBTD16210DGG\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTD16210DGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTD16210DGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbtd16210.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBTD16210DGV\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTD16210DL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTD16210DL'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_4.4x9.7mm_P0.4mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'bus transmission gates fet switch bidirectional', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbtd16210.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBTD16210DL\n\nbus transmission gates fet switch bidirectional', 'pins':[
            Pin(num='10',name='1A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='1A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='2A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='2A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='2A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='2A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='1A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='2A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='2A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2A8',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='2A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='2A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='2B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='2B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='2B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='2B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='2B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='2B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='2B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='2B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='1B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='1B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='1B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='1B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='1A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='1B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='1B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='1B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='1B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='1A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='1A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='1A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTD3861', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTD3861'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'bus', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cbtd3861.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74CBTD3861\n\nbus', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='A9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='A10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='B10',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='B9',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='B8',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='B7',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='B6',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='B5',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='B4',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='B3',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='B1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='A8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC00'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'HCMOS nand 2-input', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74hc00', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC00\n\nHCMOS nand 2-input', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '11', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74HC02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC02'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'HCMOS Nor2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74hc02', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC02\n\nHCMOS Nor2', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '9', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '11', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74HC04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC04'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCMOS not inv', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT04.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC04\n\nHCMOS not inv', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74HC123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC123'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL monostable, multivibrator', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT123.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC123\n\nTTL monostable, multivibrator', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Cext',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='RCext',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Clr',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Clr',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='Cext',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='RCext',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='A',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['13', '3', '14', '4', '15', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '9', '6', '10', '7', '11', '12']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'74HC165', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC165'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'8 bit shift register parallel load cmos', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT165.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC165\n\n8 bit shift register parallel load cmos', 'pins':[
            Pin(num='1',name='~{PL}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Q7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q7',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC173', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC173'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL REG REG4 3State DFF', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd74hc173.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC173\n\nTTL REG REG4 3State DFF', 'pins':[
            Pin(num='1',name='Oe1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Mr',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Oe2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='E1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC192', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC192'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd74hc192.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC192\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='QA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='QC',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='QD',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC193', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC193'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT193.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC193\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='QA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='QC',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='QD',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC245', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC245'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'HCMOS BUS 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74HC245', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC245\n\nHCMOS BUS 3State', 'pins':[
            Pin(num='1',name='A->B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC273', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC273'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCMOS DFF DFF8', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT273.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC273\n\nHCMOS DFF DFF8', 'pins':[
            Pin(num='1',name='~{Mr}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC373'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCMOS REG DFF DFF8 LATCH', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd54hc373.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC373\n\nHCMOS REG DFF DFF8 LATCH', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC374', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC374'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCMOS DFF DFF8 REG 3State', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd74hct374.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC374\n\nHCMOS DFF DFF8 REG 3State', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC590A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC590A'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'HCMOS Counter 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74hc590a.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC590A\n\nHCMOS Counter 3State', 'pins':[
            Pin(num='1',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{MRC}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CPC',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CPR',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RCO}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC688', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC688'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'HCMOS DECOD Arith', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd54hc688.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC688\n\nHCMOS DECOD Arith', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='R4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='R5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='R6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='R7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='P=R',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='R0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='R3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC74', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC74'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL DFF', 'description':'', 'datasheet':'74xx/74hc_hct74.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC74\n\nTTL DFF', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '6', '1', '5', '3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '13', '9', '11', '12', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74HC85', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC85'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL COMP ARITH', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT85.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC85\n\nTTL COMP ARITH', 'pins':[
            Pin(num='1',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Ia<b',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Ia=b',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Ia>b',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Oa>b',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Oa=b',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Oa<b',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='B0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC86'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL XOR2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74HC86', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HC86\n\nTTL XOR2', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '5', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '10', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74HCT00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT00'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCTMOS nand 2-input', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74hct00', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT00\n\nHCTMOS nand 2-input', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '13', '11']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74HCT02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT02'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCTMOS Nor2', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74hct02', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT02\n\nHCTMOS Nor2', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '11', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74HCT04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT04'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'HCTMOS not inv', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT04.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT04\n\nHCTMOS not inv', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '12']},{'label': 'uG', 'num': 7, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74HCT123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT123'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'TTL monostable, multivibrator', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT123.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT123\n\nTTL monostable, multivibrator', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Cext',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='RCext',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Clr',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Clr',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='Cext',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='RCext',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='A',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['13', '14', '1', '3', '15', '4', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '12', '9', '6', '10', '7', '11']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '16']}] }),
        Part(**{ 'name':'74HCT137', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT137'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc237.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT137\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Y5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Y4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{Y3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{Y2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Y1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Y0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Y7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{Y6}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT138', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT138'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc238.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT138\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Y5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Y4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{Y3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{Y2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Y1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Y0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{E0}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Y7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{Y6}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT164', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT164'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'8-bit shift register', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT164.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT164\n\n8-bit shift register', 'pins':[
            Pin(num='1',name='DSA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DSB',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{MR}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT193', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT193'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT193.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT193\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='QA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='QC',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='QD',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT173', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT173'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL REG REG4 3State DFF', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd74hc173.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT173\n\nTTL REG REG4 3State DFF', 'pins':[
            Pin(num='1',name='Oe1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Mr',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Oe2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='E1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT237', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT237'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hc237.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT237\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT238', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT238'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd74hc238.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT238\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT240'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCTMOS BUFFER 3State inv', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT240.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT240\n\nHCTMOS BUFFER 3State inv', 'pins':[
            Pin(num='1',name='1OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='2A0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='2OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2Y3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT244', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT244'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCTMOS BUFFER 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT244.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT244\n\nHCTMOS BUFFER 3State', 'pins':[
            Pin(num='1',name='1OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='2A3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='2A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='2A1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='2A0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='2OE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='1A3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='2Y3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT273', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT273'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'HCTMOS DFF DFF8', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT273.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT273\n\nHCTMOS DFF DFF8', 'pins':[
            Pin(num='1',name='~{Mr}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT373'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'HCTMOS REG DFF DFF8 LATCH', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74hct373.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT373\n\nHCTMOS REG DFF DFF8 LATCH', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT374', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT374'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'HCTMOS DFF DFF8 REG 3State', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd74hct374.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT374\n\nHCTMOS DFF DFF8 REG 3State', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT4051', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT4051'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL Multiplexer Demultiplexer Analog', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd74hct4051.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT4051\n\nTTL Multiplexer Demultiplexer Analog', 'pins':[
            Pin(num='1',name='A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='A0',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A7',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='S2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT541', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT541'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'TTL BUFFER 3State BUS', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74HCT541', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT541\n\nTTL BUFFER 3State BUS', 'pins':[
            Pin(num='1',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Y7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Y6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Y5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Y4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='G2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT574', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT574'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL REG DFF DFF8 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74HCT574', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT574\n\nTTL REG DFF DFF8 3State', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='D7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT595', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT595'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'HCTMOS SR 3State', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT595.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT595\n\nHCTMOS SR 3State', 'pins':[
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT596', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT596'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'HCTMOS SR OpenCollector', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT595.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT596\n\nHCTMOS SR OpenCollector', 'pins':[
            Pin(num='1',name='QB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='QD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='QE',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='QF',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='QG',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='QH',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT688', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT688'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'HCTMOS DECOD Arith', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd54hc688.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT688\n\nHCTMOS DECOD Arith', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='R4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='R5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='R6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='R7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='P=R',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='R0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='R3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HCT74', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT74'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL DFF', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT74.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT74\n\nTTL DFF', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{S}',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~{R}',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '6', '2', '5', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '12', '13', '10', '8', '11']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74HCT85', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HCT85'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL COMP ARITH', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74HC_HCT85.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74HCT85\n\nTTL COMP ARITH', 'pins':[
            Pin(num='1',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Ia<b',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Ia=b',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Ia>b',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Oa>b',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Oa=b',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Oa<b',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='B0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS06'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL not inv OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS06', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS06\n\nTTL not inv OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['9', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS06N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS06N'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL not inv OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS06N', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS06N\n\nTTL not inv OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS07'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL hex buffer OpenCol', 'description':'', 'datasheet':'www.ti.com/lit/ds/symlink/sn74ls07.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS07\n\nTTL hex buffer OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['9', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS14'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL not inverter', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS14', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS14\n\nTTL not inverter', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS156', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS156'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL DECOD8 DECOD4 DEMUX4 DEMUX8 OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS156', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS156\n\nTTL DECOD8 DECOD4 DEMUX4 DEMUX8 OpenCol', 'pins':[
            Pin(num='1',name='Ea1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Eb1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Eb2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Ea2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q3a',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q2a',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q1a',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q0a',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q0b',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS160'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS160', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS160\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{PE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS162', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS162'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS162', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS162\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{PE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS163', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS163'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS163', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS163\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{PE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS169', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS169'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS169', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS169\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='U/~{D}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{TC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{CEP}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{PE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS191', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS191'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS191', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS191\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Pl',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Tc',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Rc',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Ce',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D/U',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS193', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS193'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls193.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS193\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='QA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='QC',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='QD',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS197', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS197'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS197', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS197\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='Pl',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Mr',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Cp1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Cp0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS22', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS22'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL Nand4 OpenColl', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS22', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS22\n\nTTL Nand4 OpenColl', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '2', '6', '1', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '13', '8', '9', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS246', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS246'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL DECOD', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS246', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS246\n\nTTL DECOD', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Lt',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Rbo',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Rbi',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS249', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS249'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL DECOD OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS249', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS249\n\nTTL DECOD OpenCol', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}/~{RBO}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS28'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'TTL Nor2 Buffer', 'description':'', 'datasheet':'http://eeshop.unl.edu/pdf/74ls28.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS28\n\nTTL Nor2 Buffer', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '11', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS293', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS293'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS293', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS293\n\nTTL CNT CNT4', 'pins':[
            Pin(num='1',name='Ms1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Cp0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Cp1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Mr1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Mr2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Ms2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS37', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS37'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'TTL nand 2-input buffer', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74ls37', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS37\n\nTTL nand 2-input buffer', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '10', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS38'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL Nand2 OpenCol Buffer', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS38', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS38\n\nTTL Nand2 OpenCol Buffer', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '11', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'74LS40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS40'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL Nand4', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS40', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS40\n\nTTL Nand4', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=3),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '2', '6', '4', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '8', '9', '10', '12']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'74LS46', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS46'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL DECOD DECOD7 OpenCol', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS46', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS46\n\nTTL DECOD DECOD7 OpenCol', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LT',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RBI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS590', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS590'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL Counter 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74ls590', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS590\n\nTTL Counter 3State', 'pins':[
            Pin(num='1',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{MRC}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CPC',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CPR',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RCO}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS595', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS595'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'TTL SR 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74ls595', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS595\n\nTTL SR 3State', 'pins':[
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS596', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS596'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'HCMOS SR OpenCollector', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74ls596', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS596\n\nHCMOS SR OpenCollector', 'pins':[
            Pin(num='1',name='QB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~{SRCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='QD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='QE',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='QF',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='QG',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='QH',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name="QH'",func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS670', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS670'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL Register 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LS670', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LS670\n\nTTL Register 3State', 'pins':[
            Pin(num='1',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='~{Er}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{Ew}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Wb',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Wa',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Rb',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Ra',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC125'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL buffer 3State', 'description':'', 'datasheet':'http://www.ti.com/lit/gpn/sn74LVC125', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\n74LVC125\n\nTTL buffer 3State', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '10', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '11', '12']},{'label': 'uE', 'num': 5, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'CD74AC238', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CD74AC238'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd74ac238.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nCD74AC238\n\ndemux', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74ALVC164245DGG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74ALVC164245DGG'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'transceiver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74alvc164245.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nSN74ALVC164245DGG\n\ntransceiver', 'pins':[
            Pin(num='1',name='1DIR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1B6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='1B7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='2B0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='2B1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='2B2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='2B3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='V_{CC(B)}',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2B4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='1B0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='2B5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2B6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='2B7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='2DIR',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='2A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='2A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2A5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='1B1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='2A4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='V_{CC(A)}',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='2A3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='2A2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2A1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='2A0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='1A7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='1A6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='1A5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='1A4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='V_{CC(A)}',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1A3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='1A2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1A1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='1A0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1B2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='1B3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='V_{CC(B)}',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='1B4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='1B5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74ALVC164245DL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74ALVC164245DL'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:SSOP-48_7.5x15.9mm_P0.635mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'transceiver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74alvc164245.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nSN74ALVC164245DL\n\ntransceiver', 'pins':[
            Pin(num='1',name='1DIR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='1B6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='1B7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='2B0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='2B1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='2B2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='2B3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='V_{CC(B)}',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='2B4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='1B0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='2B5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='2B6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='2B7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='2DIR',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='2~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='2A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='2A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='2A5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='1B1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='2A4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='V_{CC(A)}',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='2A3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='2A2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='2A1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='2A0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='1A7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='1A6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='1A5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='1A4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='V_{CC(A)}',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='1A3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='1A2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='1A1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='1A0',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='1~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1B2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='1B3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='V_{CC(B)}',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='1B4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='1B5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74CB3Q3384APW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74CB3Q3384APW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'low voltage high bandwidth', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74cb3q3384a.pdf?ts=1634790233466', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nSN74CB3Q3384APW\n\nlow voltage high bandwidth', 'pins':[
            Pin(num='1',name='~{1OE}',func=pin_types.INPUT),
            Pin(num='10',name='1B5',func=pin_types.TRISTATE),
            Pin(num='11',name='1A5',func=pin_types.TRISTATE),
            Pin(num='12',name='GND',func=pin_types.PWRIN),
            Pin(num='13',name='~{2OE}',func=pin_types.INPUT),
            Pin(num='14',name='2A1',func=pin_types.TRISTATE),
            Pin(num='15',name='2B1',func=pin_types.TRISTATE),
            Pin(num='16',name='2B2',func=pin_types.TRISTATE),
            Pin(num='17',name='2A2',func=pin_types.TRISTATE),
            Pin(num='18',name='2A3',func=pin_types.TRISTATE),
            Pin(num='19',name='2B3',func=pin_types.TRISTATE),
            Pin(num='2',name='1B1',func=pin_types.TRISTATE),
            Pin(num='20',name='2B4',func=pin_types.TRISTATE),
            Pin(num='21',name='2A4',func=pin_types.TRISTATE),
            Pin(num='22',name='2A5',func=pin_types.TRISTATE),
            Pin(num='23',name='2B5',func=pin_types.TRISTATE),
            Pin(num='24',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='1A1',func=pin_types.TRISTATE),
            Pin(num='4',name='1A2',func=pin_types.TRISTATE),
            Pin(num='5',name='1B2',func=pin_types.TRISTATE),
            Pin(num='6',name='1B3',func=pin_types.TRISTATE),
            Pin(num='7',name='1A3',func=pin_types.TRISTATE),
            Pin(num='8',name='1A4',func=pin_types.TRISTATE),
            Pin(num='9',name='1B4',func=pin_types.TRISTATE)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LS07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LS07'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'TTL hex buffer OpenCol', 'description':'', 'datasheet':'www.ti.com/lit/ds/symlink/sn74ls07.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nSN74LS07\n\nTTL hex buffer OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['7', '14']}] }),
        Part(**{ 'name':'SN74LS07N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LS07N'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'TTL hex buffer OpenCol', 'description':'', 'datasheet':'www.ti.com/lit/ds/symlink/sn74ls07.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nSN74LS07N\n\nTTL hex buffer OpenCol', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=7),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '12']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']}] }),
        Part(**{ 'name':'SN74LV4T125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LV4T125'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'3State CMOS shifter translator', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lv4t125.pdf', 'search_text':'/usr/share/kicad/symbols/74xx.kicad_sym\nSN74LV4T125\n\n3State CMOS shifter translator', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=5),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '13', '11']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '7']}] })])