from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

FPGA_Xilinx_Artix7 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'XC7A100T-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A100T-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A100T-CSG324\n\nFPGA', 'pins':[
            Pin(num='A11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A18',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L18',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A8',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A9',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B10',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B8',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B9',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C10',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C11',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C9',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D10',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D9',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='K5',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N4',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_25_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='B1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B3',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C4',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D4',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='D7',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D8',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F5',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F6',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='G6',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='TCK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E11',name='TDI_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E12',name='TMS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E13',name='TDO_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E9',name='CCLK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J10',name='VP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J9',name='VREFN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K10',name='VREFP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K9',name='VN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L10',name='DXP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L9',name='DXN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P10',name='DONE_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P11',name='M2_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P12',name='M0_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P13',name='M1_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P7',name='INIT_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='CFGBVS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='VCCO_0',func=pin_types.PWRIN,unit=4),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='VCCBATT_0',func=pin_types.PWRIN,unit=5),
            Pin(num='F10',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G11',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H10',name='VCCADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H9',name='GNDADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V3',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E16', 'J15', 'R12', 'R13', 'R15', 'R16', 'E15', 'F18', 'J14', 'R17', 'C16', 'E17', 'A13', 'R18', 'G13', 'T10', 'A18', 'H17', 'T11', 'C14', 'J17', 'J18', 'T12', 'J13', 'C15', 'K13', 'T13', 'D18', 'H18', 'K14', 'F13', 'T14', 'K15', 'K16', 'T15', 'A15', 'A14', 'C13', 'K17', 'T16', 'C17', 'K18', 'D16', 'T18', 'L13', 'D17', 'L14', 'T9', 'L15', 'U11', 'B11', 'L16', 'B13', 'U12', 'H16', 'L17', 'L18', 'U13', 'D15', 'C12', 'M13', 'A17', 'U14', 'B17', 'G18', 'M14', 'U15', 'M16', 'F14', 'H15', 'U16', 'H14', 'M17', 'E18', 'B14', 'M18', 'U17', 'B16', 'F16', 'N13', 'A11', 'B18', 'U18', 'N14', 'B12', 'D14', 'N15', 'V10', 'A16', 'N16', 'V11', 'N17', 'V12', 'P14', 'D12', 'P15', 'V14', 'G17', 'P16', 'V15', 'D13', 'F15', 'P17', 'V16', 'P18', 'G14', 'R11', 'V17', 'R10', 'G16', 'V18', 'G15']},{'label': 'uB', 'num': 2, 'pin_nums': ['M6', 'L3', 'C9', 'A10', 'P3', 'R6', 'T6', 'U7', 'V7', 'C11', 'L1', 'A8', 'D10', 'L4', 'N1', 'P4', 'R7', 'M4', 'T5', 'T8', 'U8', 'V8', 'L5', 'A9', 'D9', 'N2', 'P5', 'R8', 'U1', 'U9', 'V9', 'U6', 'K3', 'B10', 'L6', 'N3', 'P6', 'T1', 'U2', 'V1', 'K4', 'B8', 'M1', 'N4', 'R1', 'T2', 'U3', 'V2', 'B9', 'K5', 'M2', 'N5', 'R2', 'T3', 'U4', 'V4', 'K6', 'C10', 'M3', 'N6', 'R3', 'T4', 'U5', 'V5', 'R5', 'P2', 'V6']},{'label': 'uC', 'num': 3, 'pin_nums': ['A6', 'D3', 'C1', 'H1', 'F5', 'J4', 'A7', 'C2', 'D4', 'E5', 'F6', 'H2', 'J5', 'B1', 'C3', 'D5', 'E6', 'G1', 'H4', 'K1', 'B2', 'C4', 'D6', 'E7', 'G2', 'H5', 'K2', 'A1', 'B3', 'C5', 'D7', 'F1', 'G3', 'H6', 'A3', 'B4', 'C6', 'D8', 'F2', 'G4', 'J1', 'A4', 'B6', 'C7', 'E1', 'E3', 'F3', 'G5', 'J2', 'A5', 'B7', 'D2', 'E2', 'F4', 'G6', 'J3']},{'label': 'uD', 'num': 4, 'pin_nums': ['P11', 'E9', 'P12', 'J10', 'P13', 'J9', 'K10', 'P7', 'P8', 'E10', 'K9', 'P10', 'E11', 'L10', 'P9', 'L9', 'R9', 'E12', 'E13']},{'label': 'uE', 'num': 5, 'pin_nums': ['N11', 'H10', 'K7', 'M11', 'J11', 'R4', 'A2', 'E4', 'F9', 'H11', 'J12', 'K8', 'M12', 'N12', 'T17', 'E8', 'B15', 'G10', 'H12', 'J16', 'L11', 'M15', 'N18', 'T7', 'B5', 'F10', 'G11', 'H13', 'J6', 'L12', 'M5', 'N7', 'U10', 'F11', 'C18', 'G12', 'H3', 'J7', 'L2', 'M7', 'N8', 'V13', 'C8', 'F12', 'G7', 'H7', 'J8', 'L7', 'M8', 'N9', 'V3', 'D1', 'F17', 'G8', 'H8', 'K11', 'L8', 'M9', 'P1', 'A12', 'F7', 'D11', 'F8', 'G9', 'H9', 'K12', 'M10', 'N10', 'R14', 'E14']}] }),
        Part(**{ 'name':'XC7A100T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A100T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A100T-FGG484\n\nFPGA', 'pins':[
            Pin(num='AA10',name='IO_L9P_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='IO_L9N_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='IO_L3P_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='IO_L5N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='IO_L4P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='IO_L1N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA17',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='IO_L8P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='IO_L8N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='IO_L7P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='IO_L7N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='IO_L3N_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='IO_L4N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='IO_L2P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='IO_L2N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L15P_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L15N_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L17P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='IO_L14P_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L17N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L10P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L13P_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L13N_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L14N_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='IO_L10N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='IO_L12P_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='IO_L12N_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='W14',name='IO_L6P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO_L16P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO_L16N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y11',name='IO_L11P_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='IO_L11N_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='IO_L5P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='IO_L6N_T0_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='IO_L1P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='IO_0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='Y21',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A16',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='A18',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A20',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A21',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B13',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B14',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B15',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B16',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B20',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B21',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B22',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C13',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C14',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C18',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C20',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C21',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='C22',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D17',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='D19',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D21',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D22',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='E16',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E19',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E21',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E22',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO_0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F21',name='IO_25_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='G13',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H17',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J14',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J22',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K19',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K21',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='L18',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='N22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA7',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AA8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AB5',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J1',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J4',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='M5',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='N2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='T3',name='IO_0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T6',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U7',name='IO_25_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='V7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W3',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W5',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W9',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y9',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B7',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C4',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='D10',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='D6',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='MGTRREF_216',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='R13',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='T12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='T13',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U10',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U12',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U13',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='CFGBVS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='V12',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E12',name='VCCBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K10',name='VCCADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K9',name='GNDADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['P18', 'V15', 'P19', 'AA14', 'V16', 'P20', 'V17', 'P21', 'AA11', 'V18', 'P22', 'AA13', 'V19', 'AA15', 'R14', 'V20', 'AA16', 'R15', 'V22', 'AA17', 'R16', 'AA18', 'W10', 'AA19', 'R17', 'W11', 'AA20', 'R18', 'AA21', 'W12', 'AA9', 'R19', 'W13', 'AB10', 'R21', 'W14', 'AB11', 'R22', 'W15', 'AA10', 'AB12', 'T14', 'W16', 'P17', 'AB13', 'T15', 'W17', 'AB14', 'T16', 'W19', 'AB15', 'T18', 'W20', 'AB16', 'T19', 'W21', 'AB17', 'T20', 'W22', 'AB18', 'T21', 'Y10', 'AB20', 'T22', 'Y11', 'AB21', 'U15', 'Y12', 'AB22', 'U16', 'Y13', 'M14', 'U17', 'Y14', 'N13', 'U18', 'Y16', 'N14', 'U19', 'Y17', 'N15', 'U20', 'Y18', 'N17', 'U21', 'Y19', 'P14', 'U22', 'Y20', 'V10', 'P15', 'Y21', 'P16', 'V13', 'Y22', 'V14']},{'label': 'uB', 'num': 2, 'pin_nums': ['A13', 'D19', 'H14', 'L19', 'A14', 'H15', 'D20', 'L20', 'A15', 'D21', 'H16', 'L21', 'A16', 'H17', 'D22', 'M13', 'A17', 'E13', 'H18', 'M15', 'A18', 'E14', 'H19', 'M16', 'A19', 'E15', 'H20', 'M17', 'A20', 'E16', 'H22', 'M18', 'A21', 'E17', 'J13', 'M20', 'B13', 'E18', 'J14', 'M21', 'B14', 'E19', 'J15', 'M22', 'B15', 'E21', 'J16', 'N18', 'B16', 'E22', 'J17', 'N19', 'B17', 'F13', 'J19', 'N20', 'B18', 'F14', 'J20', 'N21', 'B20', 'F15', 'J21', 'N22', 'B21', 'F16', 'J22', 'B22', 'F18', 'K13', 'C13', 'F19', 'K14', 'C14', 'F20', 'K16', 'C15', 'F21', 'K17', 'C17', 'F22', 'K18', 'C18', 'G13', 'K19', 'H13', 'C19', 'G15', 'K20', 'C20', 'G16', 'K21', 'C21', 'G17', 'K22', 'C22', 'G18', 'L13', 'D14', 'G19', 'L14', 'D15', 'G20', 'L15', 'D16', 'G21', 'L16', 'D17', 'G22', 'L17', 'D18', 'L18']},{'label': 'uC', 'num': 3, 'pin_nums': ['AB8', 'T4', 'Y9', 'B1', 'K6', 'T5', 'B2', 'L1', 'T6', 'C1', 'L3', 'U1', 'C2', 'L4', 'U2', 'D1', 'L5', 'U3', 'D2', 'L6', 'U5', 'E1', 'M1', 'U6', 'E2', 'M2', 'U7', 'E3', 'M3', 'V2', 'F1', 'M4', 'V3', 'F2', 'M5', 'V4', 'F3', 'M6', 'V5', 'F4', 'N1', 'V6', 'G1', 'N2', 'V7', 'G2', 'N3', 'V8', 'G3', 'N4', 'V9', 'A1', 'G4', 'N5', 'W1', 'AA1', 'H2', 'P1', 'W2', 'AA3', 'H3', 'P2', 'W3', 'AA4', 'H4', 'P4', 'W4', 'AA5', 'H5', 'P5', 'W5', 'AA6', 'H6', 'P6', 'W6', 'AA7', 'J1', 'R1', 'W7', 'AA8', 'J2', 'R2', 'W9', 'AB1', 'J3', 'R3', 'Y1', 'AB2', 'J4', 'R4', 'Y2', 'AB3', 'J5', 'R5', 'Y3', 'AB4', 'J6', 'R6', 'Y4', 'AB5', 'K1', 'T1', 'Y6', 'AB6', 'K2', 'K4', 'T2', 'Y7', 'AB7', 'K3', 'T3', 'Y8']},{'label': 'uD', 'num': 4, 'pin_nums': ['D9', 'B8', 'C11', 'E10', 'A10', 'E6', 'A4', 'C5', 'A6', 'C7', 'F10', 'A8', 'C9', 'F6', 'B10', 'D11', 'B4', 'D5', 'B6', 'D7']},{'label': 'uE', 'num': 5, 'pin_nums': ['B11', 'B7', 'C4', 'D10', 'E8', 'F8', 'B5', 'B9', 'C8', 'D6', 'F7', 'F9']},{'label': 'uF', 'num': 6, 'pin_nums': ['U11', 'M9', 'N10', 'U12', 'U13', 'F12', 'N12', 'G11', 'N9', 'U8', 'U9', 'L10', 'R13', 'T12', 'L12', 'V12', 'L9', 'T13', 'M10', 'U10']},{'label': 'uG', 'num': 7, 'pin_nums': ['G7', 'V1', 'G8', 'AA22', 'M19', 'V11', 'AB19', 'G9', 'M7', 'V21', 'AB9', 'H1', 'M8', 'W18', 'B12', 'H10', 'N11', 'W8', 'B19', 'H11', 'N16', 'Y15', 'B3', 'H12', 'N6', 'Y5', 'C10', 'H21', 'N7', 'C12', 'H7', 'N8', 'C16', 'H8', 'P10', 'C3', 'H9', 'P11', 'C6', 'J10', 'P12', 'D12', 'J11', 'P13', 'D13', 'J12', 'P3', 'D3', 'J18', 'P7', 'D4', 'J7', 'P8', 'D8', 'J8', 'P9', 'E11', 'J9', 'R10', 'E12', 'K10', 'R11', 'E20', 'K11', 'R12', 'E4', 'K12', 'R20', 'E5', 'K15', 'R7', 'E7', 'K5', 'R8', 'A11', 'E9', 'K7', 'R9', 'A12', 'F11', 'K8', 'T10', 'A2', 'F17', 'K9', 'T11', 'A22', 'F5', 'L11', 'T17', 'A3', 'G10', 'L2', 'T7', 'A5', 'G12', 'L22', 'T8', 'A7', 'G14', 'L7', 'T9', 'A9', 'G5', 'L8', 'M12', 'U14', 'AA12', 'G6', 'M11', 'U4', 'AA2']}] }),
        Part(**{ 'name':'XC7A100T-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A100T-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A100T-FGG676\n\nFPGA', 'pins':[
            Pin(num='AA21',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AA22',name='IO_L8P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L8N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L7P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L5N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L9P_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB25',name='IO_L7N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L3P_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L9N_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AC26',name='IO_L3N_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD22',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AE19',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AF26',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='T14',name='IO_L20P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L20N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L21P_T3_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L21N_T3_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L17P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L15P_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T26',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='IO_L23P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L22P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L22N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_25_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L17N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L15N_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L13P_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L12P_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='U24',name='IO_0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L1P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L1N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L23N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L24P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L24N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L19P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L18P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V21',name='IO_L13N_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L12N_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L10P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L6P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L2P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='W18',name='IO_L19N_T3_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L18N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L16P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L14P_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='IO_L10N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W24',name='IO_L6N_T0_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L4P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L2N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L16N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L14N_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L11P_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='IO_L11N_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y25',name='IO_L5P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y26',name='IO_L4N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='D25',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='D26',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E23',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E25',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E26',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F23',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F24',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F25',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F26',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G23',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G24',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G25',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G26',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H21',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H23',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H24',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H26',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J18',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J23',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J24',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J25',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J26',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K15',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K21',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K23',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K24',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='K25',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=2),
            Pin(num='K26',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='L22',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L23',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L24',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L25',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='M19',name='IO_0_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M24',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M25',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M26',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N14',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='N16',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N22',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N23',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N24',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N25',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='N26',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P14',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P16',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P19',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P20',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P22',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='P23',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R14',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R18',name='IO_25_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R19',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='R20',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R25',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A21',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='A22',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='AC5',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='AD2',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='B17',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B18',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='B19',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C26',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D18',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D22',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D23',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E16',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E19',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='E20',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E21',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E22',name='IO_25_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F15',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F16',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='F17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F18',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F19',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F20',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G15',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G16',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G17',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G19',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H14',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H15',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H16',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H17',name='IO_0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='W7',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='Y4',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='A1',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='A2',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A3',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A5',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B5',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C2',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='D1',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D2',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='D3',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D4',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D6',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E1',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E3',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E5',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F3',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F5',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F8',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G1',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G2',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G3',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='G4',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G5',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G6',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G7',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G8',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G9',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H1',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='H2',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='H3',name='IO_25_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H6',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H7',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H8',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H9',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J7',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='IO_0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K3',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='K5',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K6',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K7',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K8',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='L1',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='L2',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L7',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L8',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='M1',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M2',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M4',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M7',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M8',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='N1',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N2',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N3',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='N6',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N7',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N8',name='IO_0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P1',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P2',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P4',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R1',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R2',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R3',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R5',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T2',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T3',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T4',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='T7',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U1',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U2',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U4',name='IO_25_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U5',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A13',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A7',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A9',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='AA11',name='MGTREFCLK1P_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='MGTREFCLK0P_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='MGTREFCLK1N_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AB13',name='MGTREFCLK0N_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC10',name='MGTPTXP0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC12',name='MGTPRXP0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC14',name='MGTPRXP2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='MGTPTXP2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='MGTPTXN0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD12',name='MGTPRXN0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD14',name='MGTPRXN2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='MGTPTXN2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE11',name='MGTPRXP3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='MGTPRXP1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='MGTPTXP3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE9',name='MGTPTXP1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF11',name='MGTPRXN3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='MGTPRXN1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='MGTPTXN3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF9',name='MGTPTXN1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='B11',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B7',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B9',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C10',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C14',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C8',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D8',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A15',name='MGTRREF_216',func=pin_types.PWRIN,unit=6),
            Pin(num='AA10',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AA12',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC11',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC13',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC9',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AD15',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AD7',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE10',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE12',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE14',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE8',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AF15',name='MGTRREF_213',func=pin_types.PWRIN,unit=6),
            Pin(num='B10',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B12',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B14',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B8',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='C15',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='C7',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D11',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D13',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D9',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='F10',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='F12',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='AB15',name='CFGBVS_0',func=pin_types.BIDIR,unit=7),
            Pin(num='AB7',name='M0_0',func=pin_types.BIDIR,unit=7),
            Pin(num='AE16',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='TDI_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='TMS_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H12',name='TCK_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='CCLK_0',func=pin_types.BIDIR,unit=7),
            Pin(num='J10',name='TDO_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='VREFN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N12',name='VP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='VN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='VREFP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='R11',name='DXN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='R12',name='DXP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='V11',name='INIT_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W10',name='DONE_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W11',name='VCCO_0',func=pin_types.PWRIN,unit=7),
            Pin(num='W9',name='M2_0',func=pin_types.BIDIR,unit=7),
            Pin(num='Y14',name='VCCO_0',func=pin_types.PWRIN,unit=7),
            Pin(num='Y9',name='M1_0',func=pin_types.BIDIR,unit=7),
            Pin(num='A10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G14',name='VCCBATT_0',func=pin_types.PWRIN,unit=8),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='GNDADC_0',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='VCCADC_0',func=pin_types.PWRIN,unit=8),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='N20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='R24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['T19', 'V16', 'V24', 'U20', 'AA21', 'W24', 'Y25', 'AE19', 'T20', 'U21', 'V17', 'V26', 'W25', 'Y26', 'AA23', 'AA25', 'AF26', 'T26', 'U22', 'V18', 'W17', 'W26', 'AB18', 'T14', 'U14', 'U23', 'V19', 'W18', 'Y20', 'AB24', 'T15', 'U15', 'U24', 'V20', 'W19', 'Y21', 'AA24', 'AB25', 'AA22', 'T16', 'U16', 'U25', 'AB26', 'V21', 'W20', 'Y22', 'AC24', 'T17', 'U17', 'U26', 'V22', 'W21', 'Y23', 'AC25', 'AD22', 'T18', 'U19', 'V14', 'AC26', 'V23', 'W23', 'Y24']},{'label': 'uB', 'num': 2, 'pin_nums': ['G24', 'K24', 'T24', 'N21', 'K25', 'G25', 'T25', 'N22', 'G26', 'K26', 'N23', 'L14', 'H18', 'N24', 'L15', 'H19', 'N25', 'H20', 'L17', 'N26', 'H21', 'L18', 'P14', 'H22', 'L19', 'P15', 'H23', 'L20', 'P16', 'H24', 'L21', 'P18', 'H26', 'L22', 'P19', 'J14', 'L23', 'P20', 'J15', 'L24', 'P21', 'J16', 'L25', 'P22', 'J17', 'M14', 'P23', 'J18', 'M15', 'P24', 'J19', 'M16', 'P25', 'J20', 'M17', 'P26', 'D25', 'J21', 'M18', 'R14', 'D26', 'J23', 'M19', 'R15', 'E23', 'J24', 'M20', 'R16', 'E25', 'J25', 'M21', 'R17', 'E26', 'J26', 'M22', 'R18', 'F22', 'K14', 'M24', 'R19', 'F23', 'K15', 'M25', 'R20', 'F24', 'K16', 'M26', 'R21', 'F25', 'K17', 'N14', 'R22', 'K23', 'F26', 'K18', 'N15', 'R23', 'G20', 'K20', 'N16', 'R25', 'G21', 'K21', 'N17', 'R26', 'G22', 'K22', 'N18', 'T22', 'G23', 'N19', 'T23']},{'label': 'uC', 'num': 3, 'pin_nums': ['A22', 'C17', 'B18', 'D24', 'F15', 'G17', 'Y4', 'A23', 'B19', 'C18', 'D16', 'E16', 'F16', 'G19', 'A24', 'B20', 'C19', 'D18', 'E17', 'F17', 'H14', 'A17', 'A25', 'B21', 'C21', 'D19', 'E18', 'F18', 'H15', 'A18', 'AA1', 'B22', 'C22', 'D20', 'E19', 'F19', 'H16', 'A19', 'AC5', 'B24', 'C23', 'D21', 'E20', 'F20', 'H17', 'A20', 'AD2', 'B25', 'C24', 'C26', 'D22', 'E21', 'G15', 'U3', 'A21', 'B17', 'B26', 'C25', 'D23', 'E22', 'G16', 'W7']},{'label': 'uD', 'num': 4, 'pin_nums': ['K8', 'F8', 'R3', 'A1', 'L1', 'G1', 'R5', 'A2', 'G2', 'L2', 'R6', 'A3', 'L3', 'G3', 'R7', 'A4', 'G4', 'L4', 'R8', 'A5', 'G5', 'L5', 'T2', 'B1', 'G6', 'L7', 'T3', 'B2', 'L8', 'G7', 'T4', 'B4', 'G8', 'M1', 'T5', 'B5', 'G9', 'M2', 'T6', 'C1', 'H1', 'M4', 'T7', 'C2', 'M5', 'H2', 'T8', 'K7', 'C3', 'H3', 'M6', 'U1', 'C4', 'H4', 'M7', 'U2', 'C5', 'H6', 'M8', 'U4', 'D1', 'H7', 'N1', 'U5', 'D2', 'H8', 'N2', 'U6', 'D3', 'H9', 'N3', 'D4', 'J1', 'N4', 'D5', 'J3', 'N5', 'D6', 'J4', 'N6', 'E1', 'J5', 'N7', 'E2', 'J6', 'N8', 'E3', 'J7', 'P1', 'E5', 'J8', 'P2', 'E6', 'K1', 'P3', 'F2', 'K2', 'P4', 'F3', 'K3', 'P5', 'F4', 'K4', 'P6', 'F5', 'K5', 'P8', 'F6', 'K6', 'R1', 'F7', 'R2']},{'label': 'uE', 'num': 5, 'pin_nums': ['F11', 'AD14', 'C14', 'AB11', 'AF7', 'AB13', 'AD8', 'AF9', 'C8', 'F13', 'A11', 'AC10', 'AE11', 'B11', 'D10', 'A13', 'AC12', 'AE13', 'B13', 'D12', 'A7', 'AC14', 'AE7', 'B7', 'D14', 'A9', 'AC8', 'AE9', 'B9', 'D8', 'AA11', 'AD10', 'AF11', 'C10', 'E11', 'AA13', 'AD12', 'AF13', 'C12', 'E13']},{'label': 'uF', 'num': 6, 'pin_nums': ['B10', 'D9', 'F10', 'AD15', 'B12', 'AD7', 'B14', 'F12', 'A15', 'AE10', 'B8', 'AA10', 'AE12', 'C15', 'AA12', 'AE14', 'C7', 'AC11', 'AE8', 'D11', 'AC13', 'AF15', 'D13', 'AC9']},{'label': 'uG', 'num': 7, 'pin_nums': ['R12', 'H12', 'V11', 'H13', 'J10', 'W10', 'AB15', 'N11', 'W11', 'AB7', 'N12', 'W9', 'AE16', 'P11', 'Y14', 'H10', 'P12', 'Y9', 'H11', 'R11']},{'label': 'uH', 'num': 8, 'pin_nums': ['T21', 'E24', 'AD6', 'T9', 'L13', 'E4', 'AD9', 'L16', 'U10', 'AE15', 'E7', 'L26', 'U11', 'E8', 'AE24', 'L6', 'U12', 'AE4', 'E9', 'L9', 'U13', 'AE6', 'F1', 'M10', 'U18', 'AF1', 'F14', 'M11', 'U8', 'A10', 'AF10', 'F21', 'M12', 'U9', 'A12', 'AF12', 'F9', 'M13', 'V10', 'A14', 'AF14', 'G10', 'M23', 'V12', 'A16', 'AF16', 'G11', 'M3', 'V13', 'A26', 'AF21', 'G12', 'M9', 'V15', 'A6', 'AF6', 'G13', 'N10', 'V25', 'A8', 'AF8', 'G14', 'N13', 'V5', 'AA14', 'B15', 'G18', 'N20', 'W12', 'AA16', 'B16', 'H25', 'N9', 'W13', 'AA26', 'B23', 'H5', 'P10', 'W2', 'AA6', 'B3', 'J11', 'P13', 'W22', 'AA9', 'B6', 'J12', 'P17', 'Y10', 'AB10', 'C11', 'J13', 'P7', 'Y11', 'AB12', 'C13', 'J2', 'P9', 'Y12', 'AB14', 'C16', 'J22', 'R10', 'Y13', 'AB23', 'C20', 'J9', 'R13', 'Y19', 'AB3', 'C6', 'K10', 'R24', 'AB8', 'C9', 'K11', 'R4', 'AB9', 'D15', 'K12', 'R9', 'AC15', 'D17', 'K13', 'T1', 'AC20', 'D7', 'K19', 'T10', 'E15', 'AC7', 'E10', 'K9', 'T11', 'AD11', 'E12', 'L10', 'T12', 'AD13', 'E14', 'L11', 'T13', 'AD16', 'L12']}] }),
        Part(**{ 'name':'XC7A100T-FTG256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A100T-FTG256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A100T-FTG256\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='E15',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H16',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A5',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A6',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='A7',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='B4',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B5',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B6',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B7',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C6',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C7',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D6',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='F2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_25_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M4',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='CFGBVS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='CCLK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H10',name='DONE_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='VREFN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='VP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J7',name='VN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='VREFP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='INIT_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='DXN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='DXP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='VCCO_0',func=pin_types.PWRIN,unit=3),
            Pin(num='L7',name='TCK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M10',name='M1_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M11',name='M2_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='TMS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M9',name='M0_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='TDI_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N8',name='TDO_0',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='VCCBATT_0',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GNDADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['D13', 'P9', 'K12', 'D14', 'R10', 'K13', 'D15', 'K15', 'R11', 'D16', 'R12', 'K16', 'A13', 'D8', 'L12', 'R13', 'D11', 'D9', 'L13', 'R14', 'E11', 'L14', 'R15', 'A14', 'E12', 'R16', 'L15', 'A12', 'E13', 'L16', 'R5', 'E14', 'M12', 'R6', 'E15', 'M13', 'R7', 'E16', 'M14', 'R8', 'F12', 'M15', 'T10', 'A15', 'F13', 'M16', 'T11', 'A16', 'F14', 'A8', 'M6', 'T12', 'A9', 'F15', 'N10', 'T13', 'B10', 'G11', 'B11', 'N11', 'T14', 'B12', 'G12', 'N12', 'T15', 'B13', 'G14', 'N13', 'T5', 'B14', 'G15', 'T7', 'B15', 'N14', 'B16', 'G16', 'N16', 'T8', 'B9', 'H11', 'N6', 'T9', 'A10', 'C10', 'H12', 'N9', 'C11', 'H13', 'P10', 'C12', 'H14', 'P11', 'C13', 'H15', 'P13', 'C14', 'H16', 'P14', 'C16', 'J12', 'P15', 'C8', 'J13', 'P16', 'C9', 'J14', 'P6', 'D10', 'J15', 'P7', 'J16', 'P8']},{'label': 'uB', 'num': 2, 'pin_nums': ['H2', 'R3', 'B5', 'H3', 'R4', 'B6', 'H4', 'T1', 'B7', 'H5', 'T2', 'C1', 'J1', 'T3', 'C2', 'J2', 'T4', 'C3', 'J3', 'C4', 'J4', 'C6', 'J5', 'C7', 'K1', 'D1', 'K2', 'D3', 'K3', 'D4', 'K5', 'D5', 'L2', 'D6', 'L3', 'D7', 'L4', 'E1', 'L5', 'E2', 'M1', 'E3', 'M2', 'E4', 'M3', 'E5', 'M4', 'E6', 'M5', 'F1', 'N1', 'A2', 'F2', 'N2', 'A3', 'F3', 'N3', 'A4', 'F4', 'N4', 'A5', 'F5', 'P1', 'A6', 'G1', 'P3', 'A7', 'G2', 'P4', 'B1', 'G4', 'P5', 'B2', 'B4', 'G5', 'R1', 'B3', 'H1', 'R2']},{'label': 'uC', 'num': 3, 'pin_nums': ['L6', 'N8', 'H10', 'L7', 'H7', 'H8', 'L9', 'J7', 'M10', 'J8', 'M11', 'E8', 'K8', 'K10', 'M7', 'M9', 'E7', 'K7', 'N7']},{'label': 'uD', 'num': 4, 'pin_nums': ['D2', 'F8', 'K14', 'G9', 'E10', 'F9', 'H6', 'K4', 'N15', 'A1', 'E9', 'G10', 'H9', 'K6', 'N5', 'A11', 'F10', 'G13', 'J10', 'K9', 'P12', 'B8', 'F11', 'G3', 'J11', 'L1', 'P2', 'C15', 'F16', 'G6', 'J6', 'L10', 'R9', 'C5', 'F6', 'G7', 'J9', 'L11', 'M8', 'T16', 'D12', 'F7', 'G8', 'K11', 'L8', 'T6']}] }),
        Part(**{ 'name':'XC7A15T-CPG236', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A15T-CPG236'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A15T-CPG236\n\nFPGA', 'pins':[
            Pin(num='A14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R18',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='J1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='K1',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='K2',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='L1',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N1',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='P1',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R2',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A2',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C1',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C7',name='MGTRREF_216',func=pin_types.PWRIN,unit=4),
            Pin(num='E1',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='F3',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='DXP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A12',name='VP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A13',name='VREFN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B11',name='DXN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B12',name='VREFP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='VN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='C11',name='CCLK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='C8',name='TCK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='M2_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='INIT_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U12',name='DONE_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='CFGBVS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V12',name='M0_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='W10',name='TDI_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='M1_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W8',name='TDO_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W9',name='TMS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GNDADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='C13',name='VCCADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C9',name='VCCBATT_0',func=pin_types.PWRIN,unit=6),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['U14', 'W17', 'V15', 'B18', 'D19', 'G19', 'K17', 'M17', 'B19', 'P19', 'U15', 'V16', 'A17', 'W18', 'H17', 'K18', 'M18', 'E18', 'C14', 'R17', 'U16', 'V17', 'W19', 'C15', 'E19', 'H19', 'K19', 'M19', 'R18', 'U17', 'V19', 'C16', 'F17', 'J17', 'L12', 'N17', 'R19', 'U18', 'W13', 'A15', 'G18', 'D18', 'A16', 'K13', 'C17', 'F18', 'J18', 'L13', 'M12', 'N18', 'P18', 'T17', 'A18', 'U19', 'W14', 'C18', 'A14', 'G13', 'J19', 'L17', 'N19', 'T18', 'V13', 'B15', 'W15', 'D17', 'G17', 'K12', 'L18', 'B16', 'P17', 'U13', 'V14', 'W16', 'B17']},{'label': 'uB', 'num': 2, 'pin_nums': ['M8', 'R1', 'J1', 'L1', 'U3', 'V4', 'W5', 'J2', 'L2', 'N1', 'R2', 'V5', 'W6', 'U4', 'J3', 'L3', 'N2', 'R3', 'U5', 'V6', 'W4', 'W7', 'G2', 'J7', 'L7', 'N3', 'T1', 'U7', 'V7', 'G3', 'K1', 'M1', 'N7', 'T2', 'U8', 'V8', 'H1', 'K2', 'M2', 'N8', 'T3', 'V1', 'W2', 'H2', 'K3', 'M3', 'P1', 'U1', 'V2', 'W3', 'H3', 'K7', 'M7', 'P3', 'V3', 'U2']},{'label': 'uC', 'num': 3, 'pin_nums': ['B4', 'A6', 'B10', 'A2', 'B8', 'D2', 'A8', 'A10', 'A4', 'D1', 'B2', 'B6']},{'label': 'uD', 'num': 4, 'pin_nums': ['F3', 'E1', 'G9', 'B1', 'C5', 'C7', 'C1', 'E2', 'G7', 'H9']},{'label': 'uE', 'num': 5, 'pin_nums': ['C11', 'V12', 'V9', 'C8', 'A11', 'G12', 'W10', 'A12', 'U10', 'W11', 'A13', 'U11', 'W8', 'B11', 'U12', 'W9', 'B12', 'V10', 'B13', 'V11']},{'label': 'uF', 'num': 6, 'pin_nums': ['B7', 'F2', 'H13', 'C4', 'J8', 'M10', 'N9', 'A3', 'B9', 'C6', 'G1', 'H18', 'J9', 'M11', 'P2', 'A5', 'C10', 'C9', 'G10', 'H7', 'K8', 'M13', 'T19', 'A7', 'C12', 'D3', 'G11', 'H8', 'L10', 'M9', 'U6', 'A9', 'C13', 'E17', 'G8', 'J10', 'L11', 'N10', 'U9', 'B14', 'C19', 'E3', 'H10', 'J11', 'L19', 'N11', 'V18', 'B3', 'C2', 'F1', 'H11', 'J12', 'L8', 'N12', 'W1', 'A1', 'B5', 'C3', 'F19', 'H12', 'J13', 'L9', 'N13', 'W12', 'A19']}] }),
        Part(**{ 'name':'XC7A15T-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A15T-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A15T-CSG324\n\nFPGA', 'pins':[
            Pin(num='A11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A18',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L18',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A8',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A9',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B10',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B8',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B9',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C10',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C11',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C9',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D10',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D9',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='K5',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N4',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_25_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='B1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B3',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C4',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D4',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='D7',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D8',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F5',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F6',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='G6',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='TCK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E11',name='TDI_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E12',name='TMS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E13',name='TDO_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E9',name='CCLK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J10',name='VP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J9',name='VREFN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K10',name='VREFP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K9',name='VN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L10',name='DXP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L9',name='DXN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P10',name='DONE_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P11',name='M2_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P12',name='M0_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P13',name='M1_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P7',name='INIT_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='CFGBVS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='VCCO_0',func=pin_types.PWRIN,unit=4),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='VCCBATT_0',func=pin_types.PWRIN,unit=5),
            Pin(num='F10',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G11',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H10',name='VCCADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H9',name='GNDADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V3',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['D13', 'K14', 'R17', 'D14', 'R18', 'K15', 'D15', 'K16', 'T10', 'D16', 'T11', 'K17', 'D17', 'K18', 'T12', 'D18', 'L13', 'T13', 'E15', 'L14', 'T14', 'E16', 'T15', 'L15', 'E17', 'L16', 'T16', 'A14', 'E18', 'L17', 'T18', 'F13', 'L18', 'T9', 'F14', 'M13', 'U11', 'F15', 'M14', 'U12', 'F16', 'M16', 'U13', 'F18', 'M17', 'U14', 'A13', 'G13', 'M18', 'U15', 'A11', 'G14', 'A15', 'N13', 'U16', 'A16', 'G15', 'N14', 'U17', 'A17', 'G16', 'N15', 'U18', 'A18', 'G17', 'N16', 'V10', 'B11', 'G18', 'B12', 'N17', 'V11', 'B13', 'H14', 'P14', 'V12', 'B14', 'H15', 'B16', 'P15', 'V14', 'B17', 'H16', 'P16', 'V15', 'B18', 'H17', 'P17', 'V16', 'C12', 'H18', 'P18', 'V17', 'C13', 'J13', 'R10', 'V18', 'C14', 'J14', 'R11', 'C15', 'J15', 'R12', 'C16', 'J17', 'R13', 'C17', 'J18', 'R15', 'D12', 'K13', 'R16']},{'label': 'uB', 'num': 2, 'pin_nums': ['K4', 'N4', 'R1', 'M1', 'T2', 'U3', 'V2', 'B9', 'K5', 'M2', 'N5', 'R2', 'T3', 'U4', 'V4', 'C10', 'K6', 'M3', 'N6', 'R3', 'T4', 'U5', 'V5', 'C11', 'L1', 'M4', 'P2', 'R5', 'T5', 'U6', 'V6', 'A10', 'C9', 'L3', 'M6', 'P3', 'R6', 'T6', 'U7', 'V7', 'A8', 'D10', 'L4', 'N1', 'P4', 'R7', 'T8', 'U8', 'V8', 'A9', 'D9', 'L5', 'N2', 'P5', 'R8', 'U1', 'U9', 'V9', 'B10', 'K3', 'L6', 'N3', 'P6', 'T1', 'U2', 'V1', 'B8']},{'label': 'uC', 'num': 3, 'pin_nums': ['A3', 'B4', 'F2', 'C6', 'D8', 'G4', 'J1', 'C7', 'E1', 'F3', 'G5', 'J2', 'B6', 'A4', 'A5', 'B7', 'D2', 'E2', 'F4', 'G6', 'J3', 'C1', 'A6', 'D3', 'E3', 'F5', 'H1', 'J4', 'B3', 'A7', 'C2', 'D4', 'D7', 'E5', 'F1', 'F6', 'H2', 'G3', 'J5', 'H6', 'B1', 'C3', 'D5', 'E6', 'G1', 'H4', 'K1', 'B2', 'C4', 'D6', 'E7', 'G2', 'H5', 'K2', 'A1', 'C5']},{'label': 'uD', 'num': 4, 'pin_nums': ['P8', 'E11', 'P9', 'L10', 'E12', 'L9', 'R9', 'E13', 'P10', 'E9', 'P11', 'J10', 'P12', 'J9', 'P13', 'K10', 'E10', 'P7', 'K9']},{'label': 'uE', 'num': 5, 'pin_nums': ['J8', 'H7', 'G7', 'C8', 'F12', 'L7', 'M8', 'N9', 'V3', 'D1', 'F17', 'G8', 'H8', 'P1', 'K11', 'L8', 'M9', 'D11', 'F7', 'G9', 'H9', 'K12', 'M10', 'N10', 'R14', 'A12', 'E14', 'F8', 'H10', 'J11', 'K7', 'M11', 'N11', 'R4', 'A2', 'E4', 'F9', 'H11', 'J12', 'K8', 'M12', 'N12', 'T17', 'B15', 'E8', 'G10', 'H12', 'J16', 'L11', 'M15', 'N18', 'T7', 'B5', 'F10', 'G11', 'H13', 'J6', 'L12', 'M5', 'N7', 'U10', 'V13', 'C18', 'F11', 'G12', 'H3', 'N8', 'J7', 'L2', 'M7']}] }),
        Part(**{ 'name':'XC7A15T-CSG325', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A15T-CSG325'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A15T-CSG325\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='E15',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H16',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M4',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R5',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_25_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='A6',name='MGTRREF_216',func=pin_types.PWRIN,unit=4),
            Pin(num='B4',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='C1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='E1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='F3',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='F5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='E12',name='CFGBVS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='CCLK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='DONE_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='M2_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='TCK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K10',name='VP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='VREFN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='VREFP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='VN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='DXP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='DXN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='P10',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R10',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='R11',name='M1_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R12',name='M0_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='TMS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='INIT_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T8',name='TDO_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='TDI_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='VCCBATT_0',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G10',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GNDADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A13', 'L18', 'A15', 'M14', 'E14', 'U17', 'A16', 'E15', 'M15', 'A17', 'U18', 'A9', 'E16', 'M16', 'U8', 'B10', 'E17', 'M17', 'B11', 'U9', 'B12', 'E18', 'N14', 'A10', 'V11', 'B13', 'F14', 'N16', 'V12', 'B14', 'F15', 'N17', 'V13', 'B15', 'F17', 'N18', 'A12', 'V14', 'B16', 'F18', 'P14', 'V15', 'B17', 'G14', 'P15', 'V16', 'B9', 'G15', 'P16', 'V17', 'C10', 'G16', 'P17', 'V9', 'C11', 'G17', 'P18', 'C12', 'G18', 'R13', 'C13', 'H14', 'R14', 'C14', 'H15', 'R15', 'C16', 'H16', 'R16', 'C17', 'H17', 'R17', 'C18', 'H18', 'R18', 'C8', 'J14', 'T11', 'C9', 'J15', 'T12', 'D10', 'J16', 'T13', 'D11', 'J18', 'T14', 'D13', 'K15', 'T15', 'D14', 'K16', 'T17', 'D15', 'K17', 'T18', 'D16', 'A14', 'K18', 'U10', 'D17', 'L14', 'U11', 'D18', 'L15', 'U12', 'D8', 'L16', 'U14', 'U16', 'D9', 'L17', 'U15', 'E13']},{'label': 'uB', 'num': 2, 'pin_nums': ['K1', 'L5', 'P5', 'N1', 'R6', 'U1', 'V4', 'L6', 'N2', 'P6', 'R7', 'K2', 'U2', 'V5', 'P7', 'T1', 'K3', 'M1', 'N3', 'U4', 'V6', 'K5', 'M2', 'N4', 'R1', 'T2', 'U5', 'V7', 'K6', 'M3', 'N6', 'R2', 'T3', 'U6', 'V8', 'L2', 'M4', 'J4', 'P1', 'R3', 'T4', 'U7', 'J6', 'J5', 'L3', 'M5', 'P3', 'M6', 'R4', 'T5', 'V2', 'P4', 'R5', 'T7', 'L4', 'V3']},{'label': 'uC', 'num': 3, 'pin_nums': ['B1', 'H1', 'D5', 'B2', 'D6', 'H2', 'B5', 'E3', 'B6', 'E4', 'C3', 'F1', 'C4', 'F2', 'A3', 'D1', 'G3', 'A4', 'D2', 'G4']},{'label': 'uD', 'num': 4, 'pin_nums': ['C5', 'E5', 'F5', 'B4', 'A2', 'C1', 'A6', 'E1', 'F3', 'G2']},{'label': 'uE', 'num': 5, 'pin_nums': ['F13', 'P10', 'R10', 'F8', 'K10', 'R11', 'K9', 'R12', 'R8', 'E10', 'L10', 'F12', 'M9', 'E12', 'L9', 'T10', 'E8', 'M10', 'T8', 'T9']},{'label': 'uF', 'num': 6, 'pin_nums': ['G9', 'L12', 'V18', 'B7', 'H10', 'L13', 'B8', 'H11', 'L7', 'C15', 'H12', 'L8', 'C2', 'H13', 'M11', 'C6', 'H3', 'M12', 'C7', 'H4', 'M13', 'D12', 'H5', 'M18', 'D3', 'H6', 'M7', 'D4', 'H7', 'M8', 'D7', 'H8', 'N10', 'E11', 'H9', 'N11', 'E2', 'J1', 'N12', 'E6', 'J10', 'N13', 'E7', 'J11', 'N15', 'E9', 'J12', 'N5', 'F10', 'J13', 'N7', 'F11', 'J17', 'N8', 'F16', 'J2', 'N9', 'F4', 'J3', 'P11', 'F6', 'J7', 'P12', 'F7', 'J8', 'P13', 'F9', 'J9', 'P2', 'G1', 'K11', 'P8', 'G10', 'K12', 'P9', 'A1', 'G11', 'K13', 'R9', 'A11', 'G12', 'K14', 'T16', 'A18', 'G13', 'K4', 'T6', 'A5', 'G5', 'K7', 'U13', 'A7', 'G6', 'K8', 'U3', 'A8', 'B3', 'G7', 'L1', 'V1', 'B18', 'G8', 'L11', 'V10']}] }),
        Part(**{ 'name':'XC7A15T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A15T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A15T-FGG484\n\nFPGA', 'pins':[
            Pin(num='AA17',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='W17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y18',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='Y21',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A16',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='A18',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A20',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A21',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B13',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B14',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B15',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B16',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B20',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B21',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B22',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C13',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C14',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C18',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C20',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C21',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='C22',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D17',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='D19',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D21',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D22',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='E16',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E19',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E21',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E22',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO_0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F21',name='IO_25_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='G13',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H17',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J14',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J22',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K19',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K21',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='L18',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='N22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA7',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AA8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AB5',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J1',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J4',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='M5',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='N2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='T3',name='IO_0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T6',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U7',name='IO_25_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='V7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W3',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W5',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W9',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y9',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B7',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C4',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='D10',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='D6',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='MGTRREF_216',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='R13',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='T12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='T13',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U10',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U12',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U13',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='CFGBVS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='V12',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E12',name='VCCBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K10',name='VCCADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K9',name='GNDADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['N14', 'T22', 'R18', 'V17', 'W20', 'Y22', 'N15', 'AA19', 'P20', 'R19', 'U17', 'V18', 'W21', 'AA21', 'N17', 'P21', 'R21', 'U18', 'V19', 'W22', 'AB14', 'P14', 'P22', 'R22', 'U19', 'V20', 'Y10', 'AB18', 'P15', 'R14', 'T18', 'U20', 'V22', 'AA20', 'AB20', 'Y18', 'AA18', 'P16', 'AB21', 'R15', 'T19', 'U21', 'W13', 'Y19', 'AB22', 'P17', 'P19', 'R16', 'T20', 'U22', 'M14', 'W17', 'Y20', 'AA17', 'P18', 'N13', 'R17', 'T21', 'V16', 'W19', 'Y21']},{'label': 'uB', 'num': 2, 'pin_nums': ['G15', 'C19', 'K20', 'C20', 'G16', 'K21', 'C21', 'G17', 'K22', 'G18', 'C22', 'L13', 'D14', 'G19', 'L14', 'G20', 'D15', 'L15', 'D16', 'G21', 'L16', 'G22', 'D17', 'L17', 'D18', 'H13', 'L18', 'A13', 'D19', 'H14', 'L19', 'A14', 'D20', 'H15', 'L20', 'A15', 'D21', 'H16', 'L21', 'G13', 'A16', 'D22', 'H17', 'M13', 'A17', 'E13', 'H18', 'M15', 'A18', 'E14', 'H19', 'M16', 'A19', 'E15', 'H20', 'M17', 'A20', 'E16', 'H22', 'M18', 'A21', 'E17', 'J13', 'M20', 'B13', 'E18', 'J14', 'M21', 'B14', 'E19', 'J15', 'M22', 'B15', 'E21', 'J16', 'N18', 'B16', 'E22', 'J17', 'N19', 'B17', 'F13', 'J19', 'N20', 'B18', 'F14', 'J20', 'N21', 'B20', 'F15', 'J21', 'N22', 'B21', 'F16', 'J22', 'B22', 'F18', 'K13', 'C13', 'F19', 'K14', 'C14', 'F20', 'K16', 'C15', 'F21', 'K17', 'C17', 'F22', 'K18', 'C18', 'K19']},{'label': 'uC', 'num': 3, 'pin_nums': ['AA7', 'J1', 'R1', 'W7', 'AA8', 'R2', 'J2', 'W9', 'AB1', 'J3', 'R3', 'Y1', 'AB2', 'R4', 'J4', 'Y2', 'AB3', 'J5', 'R5', 'Y3', 'AB4', 'J6', 'R6', 'Y4', 'AB5', 'K1', 'T1', 'Y6', 'AB6', 'T2', 'K2', 'Y7', 'AB7', 'K3', 'T3', 'Y8', 'AB8', 'K4', 'T4', 'Y9', 'B1', 'K6', 'T5', 'B2', 'L1', 'T6', 'C1', 'L3', 'U1', 'C2', 'L4', 'U2', 'D1', 'L5', 'U3', 'D2', 'L6', 'U5', 'E1', 'M1', 'U6', 'E2', 'M2', 'U7', 'E3', 'M3', 'V2', 'F1', 'M4', 'V3', 'F2', 'M5', 'V4', 'F3', 'M6', 'V5', 'F4', 'N1', 'V6', 'P6', 'G1', 'N2', 'V7', 'G2', 'N3', 'V8', 'G3', 'N4', 'V9', 'A1', 'G4', 'N5', 'W1', 'AA1', 'H2', 'P1', 'W2', 'AA3', 'H3', 'P2', 'W3', 'AA4', 'H4', 'P4', 'W4', 'AA5', 'H5', 'P5', 'W5', 'AA6', 'H6', 'W6']},{'label': 'uD', 'num': 4, 'pin_nums': ['B4', 'D5', 'B6', 'D7', 'B8', 'D9', 'A10', 'C11', 'E10', 'A4', 'C5', 'E6', 'A6', 'C7', 'F10', 'A8', 'C9', 'F6', 'B10', 'D11']},{'label': 'uE', 'num': 5, 'pin_nums': ['D6', 'B9', 'C8', 'B5', 'F7', 'F9', 'B7', 'B11', 'C4', 'D10', 'E8', 'F8']},{'label': 'uF', 'num': 6, 'pin_nums': ['M10', 'U10', 'U11', 'M9', 'N10', 'U12', 'F12', 'N12', 'U13', 'U8', 'G11', 'N9', 'T13', 'L10', 'R13', 'U9', 'T12', 'V12', 'L12', 'L9']},{'label': 'uG', 'num': 7, 'pin_nums': ['E9', 'A11', 'K7', 'R9', 'A12', 'F11', 'T10', 'K8', 'A2', 'F17', 'K9', 'T11', 'A22', 'F5', 'T17', 'L11', 'A3', 'G10', 'L2', 'T7', 'A5', 'G12', 'L22', 'T8', 'A7', 'G14', 'L7', 'T9', 'A9', 'G5', 'U14', 'L8', 'AA12', 'G6', 'M11', 'U4', 'AA2', 'G7', 'M12', 'V1', 'AA22', 'G8', 'M19', 'V11', 'AB19', 'G9', 'M7', 'V21', 'AB9', 'H1', 'M8', 'W18', 'B12', 'H10', 'N11', 'W8', 'B19', 'H11', 'N16', 'Y15', 'B3', 'H12', 'N6', 'Y5', 'C10', 'H21', 'N7', 'C12', 'H7', 'N8', 'C16', 'H8', 'P10', 'C3', 'H9', 'P11', 'C6', 'J10', 'P12', 'D12', 'J11', 'P13', 'D13', 'J12', 'P3', 'D3', 'J18', 'P7', 'D4', 'J7', 'P8', 'D8', 'J8', 'P9', 'E11', 'J9', 'R10', 'E12', 'K10', 'R11', 'E20', 'K11', 'R12', 'E4', 'K12', 'R20', 'E5', 'K15', 'R7', 'E7', 'K5', 'R8']}] }),
        Part(**{ 'name':'XC7A15T-FTG256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A15T-FTG256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A15T-FTG256\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='E15',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H16',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A5',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A6',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='A7',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='B4',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B5',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B6',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B7',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C6',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C7',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D6',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='F2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_25_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M4',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='CFGBVS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='CCLK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H10',name='DONE_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='VREFN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='VP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J7',name='VN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='VREFP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='INIT_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='DXN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='DXP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='VCCO_0',func=pin_types.PWRIN,unit=3),
            Pin(num='L7',name='TCK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M10',name='M1_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M11',name='M2_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='TMS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M9',name='M0_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='TDI_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N8',name='TDO_0',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='VCCBATT_0',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GNDADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E14', 'M12', 'R6', 'A12', 'E15', 'R7', 'A14', 'M13', 'E16', 'M14', 'R8', 'A13', 'F12', 'T10', 'M15', 'A15', 'F13', 'A16', 'M16', 'T11', 'A8', 'F14', 'M6', 'T12', 'A9', 'F15', 'N10', 'T13', 'B10', 'B11', 'G11', 'T14', 'N11', 'B12', 'G12', 'N12', 'T15', 'B13', 'G14', 'B14', 'N13', 'T5', 'B15', 'G15', 'N14', 'T7', 'B16', 'G16', 'N16', 'T8', 'B9', 'H11', 'N6', 'T9', 'C10', 'H12', 'N9', 'C11', 'H13', 'P10', 'C12', 'H14', 'P11', 'C13', 'H15', 'P13', 'C14', 'H16', 'P14', 'C16', 'J12', 'P15', 'C8', 'J13', 'P16', 'C9', 'J14', 'P6', 'D10', 'J15', 'P7', 'D11', 'J16', 'P8', 'D13', 'K12', 'P9', 'D14', 'K13', 'R10', 'D15', 'K15', 'R11', 'D16', 'K16', 'R12', 'D8', 'L12', 'R13', 'D9', 'L13', 'R14', 'E11', 'L14', 'R15', 'E12', 'L15', 'A10', 'R16', 'E13', 'L16', 'R5']},{'label': 'uB', 'num': 2, 'pin_nums': ['K1', 'D1', 'K2', 'D3', 'K3', 'D4', 'K5', 'D5', 'L2', 'D6', 'L3', 'D7', 'L4', 'E1', 'L5', 'E2', 'M1', 'E3', 'M2', 'E4', 'M3', 'E5', 'M4', 'E6', 'M5', 'F1', 'N1', 'A2', 'F2', 'N2', 'A3', 'F3', 'N3', 'A4', 'F4', 'N4', 'A5', 'F5', 'P1', 'A6', 'G1', 'P3', 'A7', 'G2', 'P4', 'B1', 'G4', 'P5', 'B2', 'G5', 'R1', 'B3', 'H1', 'R2', 'B4', 'H2', 'R3', 'B5', 'H3', 'R4', 'B6', 'H4', 'T1', 'B7', 'H5', 'T2', 'C1', 'J1', 'T3', 'C2', 'J2', 'T4', 'C3', 'J3', 'C4', 'J4', 'C6', 'J5', 'C7']},{'label': 'uC', 'num': 3, 'pin_nums': ['N8', 'L7', 'H7', 'L9', 'H8', 'J7', 'M10', 'M11', 'J8', 'K10', 'M7', 'E7', 'K7', 'M9', 'E8', 'K8', 'N7', 'H10', 'L6']},{'label': 'uD', 'num': 4, 'pin_nums': ['K6', 'G10', 'H9', 'A1', 'E9', 'N5', 'J10', 'K9', 'E10', 'P12', 'A11', 'G13', 'F10', 'F9', 'K4', 'B8', 'F11', 'G3', 'J11', 'L1', 'N15', 'P2', 'C15', 'F16', 'G6', 'J6', 'L10', 'R9', 'C5', 'F6', 'G7', 'J9', 'L11', 'T16', 'F7', 'D12', 'G8', 'K11', 'L8', 'T6', 'D2', 'F8', 'G9', 'K14', 'M8', 'H6']}] }),
        Part(**{ 'name':'XC7A200T-FBG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A200T-FBG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A200T-FBG484\n\nFPGA', 'pins':[
            Pin(num='AA10',name='IO_L9P_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='IO_L9N_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='IO_L3P_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='IO_L5N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='IO_L4P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='IO_L1N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA17',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='IO_L8P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='IO_L8N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='IO_L7P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='IO_L7N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='IO_L3N_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='IO_L4N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='IO_L2P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='IO_L2N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L15P_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L15N_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L17P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='IO_L14P_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L17N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L10P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L13P_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L13N_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L14N_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='IO_L10N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='IO_L12P_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='IO_L12N_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='W14',name='IO_L6P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO_L16P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO_L16N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y11',name='IO_L11P_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='IO_L11N_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='IO_L5P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='IO_L6N_T0_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='IO_L1P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='IO_0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='Y21',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A16',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='A18',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A20',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A21',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B13',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B14',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B15',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B16',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B20',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B21',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B22',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C13',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C14',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C18',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C20',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C21',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='C22',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D17',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='D19',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D21',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D22',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='E16',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E19',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E21',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E22',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO_0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F21',name='IO_25_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='G13',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H17',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J14',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J22',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K19',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K21',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='L18',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='N22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA7',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AA8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AB5',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J1',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J4',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='M5',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='N2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='T3',name='IO_0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T6',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U7',name='IO_25_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='V7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W3',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W5',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W9',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y9',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B7',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C4',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='D10',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='D6',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='MGTRREF_216',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='R13',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='T12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='T13',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U10',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U12',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U13',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='CFGBVS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='V12',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E12',name='VCCBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K10',name='VCCADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K9',name='GNDADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['N14', 'AA13', 'U19', 'Y17', 'N15', 'Y18', 'U20', 'N17', 'U21', 'Y19', 'P14', 'Y20', 'U22', 'P15', 'V10', 'Y21', 'P16', 'V13', 'Y22', 'AA11', 'AA14', 'P17', 'V14', 'P18', 'V15', 'P19', 'V16', 'P20', 'V17', 'P21', 'V18', 'P22', 'V19', 'AA15', 'R14', 'V20', 'AA16', 'R15', 'AA17', 'V22', 'AA18', 'R16', 'W10', 'AA19', 'R17', 'W11', 'AA20', 'AA21', 'R18', 'W12', 'AA9', 'R19', 'W13', 'AB10', 'R21', 'W14', 'AB11', 'R22', 'W15', 'AB12', 'T14', 'W16', 'AB13', 'T15', 'W17', 'AA10', 'AB14', 'T16', 'W19', 'AB15', 'T18', 'W20', 'AB16', 'T19', 'W21', 'AB17', 'T20', 'W22', 'AB18', 'T21', 'Y10', 'AB20', 'T22', 'Y11', 'AB21', 'U15', 'Y12', 'AB22', 'U16', 'Y13', 'M14', 'U17', 'Y14', 'N13', 'U18', 'Y16']},{'label': 'uB', 'num': 2, 'pin_nums': ['G17', 'G18', 'C22', 'L13', 'D14', 'G19', 'L14', 'D15', 'G20', 'L15', 'D16', 'G21', 'L16', 'D17', 'G22', 'L17', 'D18', 'H13', 'L18', 'A13', 'D19', 'H14', 'L19', 'A14', 'D20', 'H15', 'L20', 'A15', 'D21', 'H16', 'L21', 'A16', 'D22', 'H17', 'M13', 'A17', 'E13', 'H18', 'M15', 'A18', 'E14', 'H19', 'M16', 'A19', 'E15', 'H20', 'M17', 'A20', 'E16', 'H22', 'M18', 'A21', 'E17', 'J13', 'M20', 'B13', 'E18', 'J14', 'M21', 'B14', 'E19', 'J15', 'M22', 'B15', 'E21', 'J16', 'N18', 'B16', 'E22', 'J17', 'N19', 'B17', 'F13', 'J19', 'N20', 'B18', 'F14', 'J20', 'N21', 'B20', 'F15', 'J21', 'N22', 'B21', 'F16', 'J22', 'B22', 'F18', 'K13', 'C13', 'F19', 'K14', 'C14', 'F20', 'K16', 'C15', 'F21', 'K17', 'C17', 'F22', 'K18', 'C18', 'G13', 'K19', 'C19', 'G15', 'K20', 'K22', 'C20', 'G16', 'K21', 'C21']},{'label': 'uC', 'num': 3, 'pin_nums': ['AB2', 'R4', 'J4', 'Y2', 'AB3', 'R5', 'J5', 'Y3', 'AB4', 'J6', 'R6', 'Y4', 'AB5', 'T1', 'K1', 'Y6', 'AB6', 'K2', 'T2', 'Y7', 'AB7', 'K3', 'T3', 'Y8', 'AB8', 'K4', 'T4', 'Y9', 'B1', 'T5', 'K6', 'B2', 'L1', 'T6', 'C1', 'L3', 'U1', 'C2', 'L4', 'U2', 'D1', 'L5', 'U3', 'D2', 'L6', 'U5', 'E1', 'M1', 'U6', 'J3', 'E2', 'M2', 'U7', 'E3', 'M3', 'V2', 'F1', 'M4', 'V3', 'F2', 'M5', 'V4', 'F3', 'M6', 'V5', 'F4', 'N1', 'V6', 'R3', 'G1', 'N2', 'V7', 'G2', 'N3', 'V8', 'G3', 'N4', 'V9', 'A1', 'G4', 'N5', 'W1', 'AA1', 'H2', 'P1', 'W2', 'AA3', 'H3', 'P2', 'W3', 'AA4', 'H4', 'P4', 'W4', 'AA5', 'H5', 'P5', 'W5', 'AA6', 'H6', 'P6', 'W6', 'AA7', 'J1', 'R1', 'W7', 'AA8', 'J2', 'R2', 'W9', 'AB1', 'Y1']},{'label': 'uD', 'num': 4, 'pin_nums': ['C11', 'A10', 'E10', 'C5', 'A4', 'E6', 'A6', 'C7', 'F10', 'A8', 'C9', 'F6', 'B10', 'D11', 'B4', 'D5', 'B6', 'D7', 'B8', 'D9']},{'label': 'uE', 'num': 5, 'pin_nums': ['B11', 'B7', 'C4', 'D10', 'E8', 'C8', 'D6', 'F7', 'F8', 'F9', 'B5', 'B9']},{'label': 'uF', 'num': 6, 'pin_nums': ['N10', 'U12', 'F12', 'U13', 'N12', 'G11', 'N9', 'U8', 'L10', 'R13', 'U9', 'L12', 'T12', 'V12', 'L9', 'T13', 'M10', 'U10', 'M9', 'U11']},{'label': 'uG', 'num': 7, 'pin_nums': ['A22', 'F5', 'T17', 'L11', 'G10', 'A3', 'T7', 'L2', 'A5', 'G12', 'L22', 'T8', 'G14', 'A7', 'T9', 'L7', 'G5', 'A9', 'L8', 'U14', 'AA12', 'G6', 'M11', 'U4', 'AA2', 'G7', 'M12', 'V1', 'AA22', 'G8', 'V11', 'M19', 'AB19', 'G9', 'M7', 'V21', 'AB9', 'H1', 'M8', 'W18', 'B12', 'H10', 'N11', 'W8', 'B19', 'H11', 'N16', 'Y15', 'B3', 'H12', 'N6', 'Y5', 'C10', 'H21', 'N7', 'C12', 'H7', 'N8', 'C16', 'H8', 'P10', 'C3', 'H9', 'P11', 'C6', 'J10', 'P12', 'D12', 'J11', 'P13', 'D13', 'J12', 'P3', 'D3', 'J18', 'P7', 'D4', 'J7', 'P8', 'D8', 'J8', 'P9', 'E11', 'J9', 'R10', 'E12', 'K10', 'R11', 'E20', 'K11', 'R12', 'E4', 'K12', 'R20', 'E5', 'K15', 'R7', 'E7', 'K5', 'R8', 'F17', 'A11', 'E9', 'K7', 'R9', 'A12', 'F11', 'K8', 'T10', 'A2', 'K9', 'T11']}] }),
        Part(**{ 'name':'XC7A200T-FBG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A200T-FBG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A200T-FBG676\n\nFPGA', 'pins':[
            Pin(num='AA15',name='IO_L23N_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA17',name='IO_L19P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA18',name='IO_L17N_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='IO_L13P_T2_MRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='IO_L12P_T1_MRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AA22',name='IO_L8P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L8N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L7P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L5N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='IO_L22P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='IO_L19N_T3_VREF_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AB19',name='IO_L13N_T2_MRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L12N_T1_MRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L11P_T1_SRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AB24',name='IO_L9P_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB25',name='IO_L7N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L3P_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='IO_L22N_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='IO_L20P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC18',name='IO_L15P_T2_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='IO_L14P_T2_SRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC21',name='IO_L11N_T1_SRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='IO_L2P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='IO_L2N_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L9N_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AC26',name='IO_L3N_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD17',name='IO_L20N_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD18',name='IO_L15N_T2_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD19',name='IO_L14N_T2_SRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD20',name='IO_L10P_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD21',name='IO_L7P_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD22',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AD23',name='IO_L6P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L6N_T0_VREF_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='IO_L4P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD26',name='IO_L4N_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE17',name='IO_L18P_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE18',name='IO_L16P_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE19',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AE20',name='IO_L10N_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE21',name='IO_L7N_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE22',name='IO_L9P_T1_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE23',name='IO_L5P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L1P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L1N_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF17',name='IO_L18N_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF18',name='IO_L16N_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF19',name='IO_L8P_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF20',name='IO_L8N_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF22',name='IO_L9N_T1_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF23',name='IO_L5N_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF24',name='IO_L3P_T0_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF25',name='IO_L3N_T0_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF26',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='T14',name='IO_L20P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L20N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L21P_T3_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L21N_T3_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L17P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L15P_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T26',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='IO_L23P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L22P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L22N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_25_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L17N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L15N_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L13P_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L12P_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='U24',name='IO_0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L1P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L1N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L23N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L24P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L24N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L19P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L18P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V21',name='IO_L13N_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L12N_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L10P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L6P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L2P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='IO_L24P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO_L24N_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO_25_12',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='W18',name='IO_L19N_T3_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L18N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L16P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L14P_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='IO_L10N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W24',name='IO_L6N_T0_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L4P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L2N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='IO_L23P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='IO_L21P_T3_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='IO_L21N_T3_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='IO_L17P_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L16N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L14N_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L11P_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='IO_L11N_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y25',name='IO_L5P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y26',name='IO_L4N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='D25',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='D26',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E23',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E25',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E26',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F23',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F24',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F25',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F26',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G23',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G24',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G25',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G26',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H21',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H23',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H24',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H26',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J18',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J23',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J24',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J25',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J26',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K15',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K21',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K23',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K24',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='K25',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=2),
            Pin(num='K26',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='L22',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L23',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L24',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L25',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='M19',name='IO_0_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M24',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M25',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M26',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N14',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='N16',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N22',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N23',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N24',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N25',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='N26',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P14',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P16',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P19',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P20',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P22',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='P23',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R14',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R18',name='IO_25_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R19',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='R20',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R25',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A21',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='A22',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='AA2',name='IO_L12N_T1_MRCC_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L12P_T1_MRCC_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AA4',name='IO_L13P_T2_MRCC_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L22P_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AA7',name='IO_L19N_T3_VREF_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AA8',name='IO_L23N_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L7P_T1_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L11P_T1_SRCC_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='IO_L13N_T2_MRCC_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AB5',name='IO_L22N_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L24P_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AC1',name='IO_L7N_T1_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AC2',name='IO_L11N_T1_SRCC_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AC3',name='IO_L14P_T2_SRCC_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AC4',name='IO_L18P_T2_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AC5',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='AC6',name='IO_L24N_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AD1',name='IO_L9P_T1_DQS_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AD2',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='AD3',name='IO_L14N_T2_SRCC_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AD4',name='IO_L18N_T2_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AD5',name='IO_L15P_T2_DQS_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AE1',name='IO_L9N_T1_DQS_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AE2',name='IO_L10P_T1_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AE3',name='IO_L16P_T2_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AE5',name='IO_L15N_T2_DQS_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AF2',name='IO_L10N_T1_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AF3',name='IO_L16N_T2_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AF4',name='IO_L17N_T2_33',func=pin_types.BIDIR,unit=3),
            Pin(num='AF5',name='IO_L17P_T2_33',func=pin_types.BIDIR,unit=3),
            Pin(num='B17',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B18',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='B19',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C26',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D18',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D22',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D23',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E16',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E19',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='E20',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E21',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E22',name='IO_25_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F15',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F16',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='F17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F18',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F19',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F20',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G15',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G16',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G17',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G19',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H14',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H15',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H16',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H17',name='IO_0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='U7',name='IO_L6P_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='V1',name='IO_L1P_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L3N_T0_DQS_33',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L3P_T0_DQS_33',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='IO_L4P_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='V7',name='IO_L6N_T0_VREF_33',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L21P_T3_DQS_33',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_25_33',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L1N_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='W3',name='IO_L5P_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='W4',name='IO_L2N_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='W5',name='IO_L2P_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L4N_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='W8',name='IO_L21N_T3_DQS_33',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L8N_T1_33',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L8P_T1_33',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L5N_T0_33',func=pin_types.BIDIR,unit=3),
            Pin(num='Y4',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='Y5',name='IO_L20N_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L20P_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L19P_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L23P_T3_33',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='A2',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A3',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A5',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B5',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C2',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='D1',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D2',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='D3',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D4',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D6',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E1',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E3',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E5',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F3',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F5',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F8',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G1',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G2',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G3',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='G4',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G5',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G6',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G7',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G8',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G9',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H1',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='H2',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='H3',name='IO_25_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H6',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H7',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H8',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H9',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J7',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='IO_0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K3',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='K5',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K6',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K7',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K8',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='L1',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='L2',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L7',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L8',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='M1',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M2',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M4',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M7',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M8',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='N1',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N2',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N3',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='N6',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N7',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N8',name='IO_0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P1',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P2',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P4',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R1',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R2',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R3',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R5',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T2',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T3',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T4',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='T7',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U1',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U2',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U4',name='IO_25_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U5',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A13',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A7',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A9',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='AA11',name='MGTREFCLK1P_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='MGTREFCLK0P_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='MGTREFCLK1N_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AB13',name='MGTREFCLK0N_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC10',name='MGTPTXP0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC12',name='MGTPRXP0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC14',name='MGTPRXP2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='MGTPTXP2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='MGTPTXN0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD12',name='MGTPRXN0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD14',name='MGTPRXN2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='MGTPTXN2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE11',name='MGTPRXP3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='MGTPRXP1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='MGTPTXP3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE9',name='MGTPTXP1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF11',name='MGTPRXN3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='MGTPRXN1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='MGTPTXN3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF9',name='MGTPTXN1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='B11',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B7',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B9',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C10',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C14',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C8',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D8',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A15',name='MGTRREF_216',func=pin_types.PWRIN,unit=6),
            Pin(num='AA10',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AA12',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC11',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC13',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC9',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AD15',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AD7',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE10',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE12',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE14',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE8',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AF15',name='MGTRREF_213',func=pin_types.PWRIN,unit=6),
            Pin(num='B10',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B12',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B14',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B8',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='C15',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='C7',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D11',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D13',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D9',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='F10',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='F12',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='AB15',name='CFGBVS_0',func=pin_types.BIDIR,unit=7),
            Pin(num='AB7',name='M0_0',func=pin_types.BIDIR,unit=7),
            Pin(num='AE16',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='TDI_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='TMS_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H12',name='TCK_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='CCLK_0',func=pin_types.BIDIR,unit=7),
            Pin(num='J10',name='TDO_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='VREFN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N12',name='VP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='VN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='VREFP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='R11',name='DXN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='R12',name='DXP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='V11',name='INIT_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W10',name='DONE_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W11',name='VCCO_0',func=pin_types.PWRIN,unit=7),
            Pin(num='W9',name='M2_0',func=pin_types.BIDIR,unit=7),
            Pin(num='Y14',name='VCCO_0',func=pin_types.PWRIN,unit=7),
            Pin(num='Y9',name='M1_0',func=pin_types.BIDIR,unit=7),
            Pin(num='A10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G14',name='VCCBATT_0',func=pin_types.PWRIN,unit=8),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='GNDADC_0',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='VCCADC_0',func=pin_types.PWRIN,unit=8),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='N20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='R24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AD25', 'Y16', 'U19', 'AA20', 'AD26', 'Y17', 'U20', 'AA21', 'AA22', 'AE17', 'U21', 'Y18', 'AA23', 'AE18', 'Y20', 'U22', 'AA24', 'AE19', 'AA25', 'U23', 'Y21', 'AD24', 'AB16', 'AE20', 'U24', 'Y22', 'AB17', 'AE21', 'AA15', 'AB18', 'U25', 'Y23', 'AB19', 'AE22', 'Y24', 'U26', 'AB20', 'AE23', 'V14', 'Y25', 'AB21', 'AE25', 'V16', 'Y26', 'AB22', 'AE26', 'V17', 'AB24', 'AF17', 'V18', 'AB25', 'AF18', 'V19', 'AB26', 'AF19', 'V20', 'AC16', 'AF20', 'V21', 'AC17', 'AF22', 'V22', 'AC18', 'AF23', 'V23', 'AC19', 'AF24', 'V24', 'AC21', 'AF25', 'V26', 'AF26', 'AC22', 'W14', 'AC23', 'T14', 'W15', 'AC24', 'T15', 'W16', 'AC25', 'T16', 'W17', 'AC26', 'T17', 'W18', 'AD17', 'T18', 'W19', 'AD18', 'T19', 'W20', 'AD19', 'T20', 'W21', 'AA18', 'AA17', 'AD20', 'T26', 'W23', 'AD21', 'U14', 'AA19', 'W24', 'AD22', 'U15', 'W25', 'AD23', 'U16', 'W26', 'U17', 'Y15']},{'label': 'uB', 'num': 2, 'pin_nums': ['L19', 'P15', 'H23', 'L20', 'P16', 'H24', 'L21', 'P18', 'H26', 'L22', 'P19', 'J14', 'L23', 'P20', 'J15', 'L24', 'P21', 'J16', 'L25', 'P22', 'J17', 'M14', 'P23', 'J18', 'M15', 'P24', 'J19', 'M16', 'P25', 'J20', 'M17', 'P26', 'D25', 'J21', 'M18', 'R14', 'D26', 'J23', 'M19', 'R15', 'E23', 'J24', 'M20', 'R16', 'E25', 'J25', 'M21', 'R17', 'E26', 'J26', 'M22', 'R18', 'F22', 'K14', 'M24', 'R19', 'F23', 'K15', 'M25', 'R20', 'F24', 'K16', 'M26', 'R21', 'F25', 'K17', 'N14', 'R22', 'F26', 'K18', 'N15', 'R23', 'G20', 'K20', 'N16', 'R25', 'G21', 'K21', 'N17', 'R26', 'G22', 'K22', 'N18', 'T22', 'G23', 'K23', 'N19', 'T23', 'G24', 'K24', 'N21', 'T24', 'G25', 'K25', 'N22', 'T25', 'G26', 'K26', 'N23', 'H18', 'L14', 'N24', 'H19', 'L15', 'N25', 'H20', 'H22', 'L17', 'N26', 'H21', 'L18', 'P14']},{'label': 'uC', 'num': 3, 'pin_nums': ['E18', 'A22', 'E19', 'AF3', 'W6', 'A23', 'AF4', 'E20', 'W7', 'A24', 'AF5', 'E21', 'W8', 'A25', 'B17', 'E22', 'Y1', 'AA1', 'B18', 'F15', 'Y2', 'AA2', 'B19', 'F16', 'Y3', 'AA3', 'B20', 'F17', 'Y4', 'AA4', 'B21', 'F18', 'Y5', 'AA5', 'B22', 'F19', 'Y6', 'AA7', 'B24', 'F20', 'Y7', 'AA8', 'B25', 'G15', 'Y8', 'AB1', 'B26', 'G16', 'AB2', 'C17', 'G17', 'AB4', 'C18', 'G19', 'AB5', 'C19', 'H14', 'AB6', 'C21', 'H15', 'AC1', 'C22', 'H16', 'AC2', 'C23', 'H17', 'AC3', 'C24', 'U3', 'AC4', 'C25', 'U7', 'AC5', 'C26', 'V1', 'AC6', 'D16', 'V2', 'A21', 'AD1', 'D18', 'V3', 'AD2', 'D19', 'V4', 'AD3', 'D20', 'V6', 'AD4', 'D21', 'V7', 'AD5', 'D22', 'V8', 'A17', 'AE1', 'D23', 'V9', 'A18', 'AE2', 'D24', 'W1', 'A19', 'AE3', 'E16', 'W3', 'W5', 'A20', 'AE5', 'E17', 'W4', 'AF2']},{'label': 'uD', 'num': 4, 'pin_nums': ['E1', 'N7', 'J5', 'E2', 'N8', 'J6', 'E3', 'J7', 'P1', 'E5', 'P2', 'J8', 'E6', 'K1', 'P3', 'J4', 'F2', 'P4', 'K2', 'F3', 'K3', 'P5', 'F4', 'P6', 'K4', 'F5', 'K5', 'P8', 'F6', 'K6', 'R1', 'F7', 'K7', 'R2', 'F8', 'K8', 'R3', 'A1', 'G1', 'L1', 'R5', 'A2', 'G2', 'L2', 'R6', 'A3', 'G3', 'L3', 'R7', 'A4', 'G4', 'R8', 'L4', 'A5', 'G5', 'L5', 'T2', 'B1', 'G6', 'L7', 'T3', 'B2', 'G7', 'L8', 'T4', 'B4', 'G8', 'M1', 'T5', 'B5', 'G9', 'M2', 'T6', 'C1', 'H1', 'M4', 'T7', 'C2', 'H2', 'M5', 'T8', 'H3', 'C3', 'M6', 'U1', 'C4', 'H4', 'M7', 'U2', 'C5', 'H6', 'M8', 'U4', 'D1', 'H7', 'N1', 'U5', 'D2', 'H8', 'N2', 'U6', 'D3', 'H9', 'N3', 'D4', 'J1', 'N4', 'D5', 'J3', 'N5', 'D6', 'N6']},{'label': 'uE', 'num': 5, 'pin_nums': ['AE9', 'D8', 'AC8', 'B9', 'AA11', 'AD10', 'AF11', 'C10', 'E11', 'AA13', 'AD12', 'AF13', 'C12', 'E13', 'AB11', 'AD14', 'AF7', 'C14', 'F11', 'AB13', 'AD8', 'AF9', 'C8', 'F13', 'A11', 'AC10', 'AE11', 'B11', 'D10', 'A13', 'A9', 'AC12', 'AE13', 'B13', 'D12', 'A7', 'AC14', 'AE7', 'B7', 'D14']},{'label': 'uF', 'num': 6, 'pin_nums': ['AE8', 'AC11', 'D11', 'AF15', 'D13', 'AC13', 'AC9', 'B10', 'D9', 'AD15', 'B12', 'F10', 'F12', 'AD7', 'B14', 'A15', 'AE10', 'B8', 'AA12', 'AA10', 'AE12', 'C15', 'C7', 'AE14']},{'label': 'uG', 'num': 7, 'pin_nums': ['Y14', 'P11', 'Y9', 'H10', 'P12', 'H11', 'R11', 'H12', 'R12', 'H13', 'V11', 'J10', 'W10', 'AB15', 'AE16', 'N11', 'W11', 'AB7', 'N12', 'W9']},{'label': 'uH', 'num': 8, 'pin_nums': ['Y12', 'AB14', 'J22', 'C16', 'R10', 'Y13', 'AB23', 'J9', 'C20', 'R13', 'Y19', 'AB3', 'C6', 'K10', 'R24', 'AB8', 'K11', 'C9', 'R4', 'AB9', 'D15', 'K12', 'R9', 'AC15', 'D17', 'K13', 'T1', 'AC20', 'D7', 'K19', 'T10', 'AC7', 'K9', 'E10', 'T11', 'AD11', 'E12', 'L10', 'T12', 'AD13', 'E14', 'L11', 'T13', 'AD16', 'E15', 'L12', 'T21', 'AD6', 'E24', 'L13', 'T9', 'AD9', 'E4', 'L16', 'U10', 'AE15', 'E7', 'L26', 'U11', 'AE24', 'E8', 'L6', 'U12', 'AE4', 'L9', 'E9', 'U13', 'AE6', 'F1', 'M10', 'AB12', 'U18', 'AF1', 'F14', 'M11', 'U8', 'A10', 'AF10', 'F21', 'M12', 'U9', 'A12', 'AF12', 'F9', 'M13', 'V10', 'A14', 'AF14', 'G10', 'M23', 'V12', 'A16', 'AF16', 'G11', 'M3', 'V13', 'A26', 'AF21', 'G12', 'M9', 'V15', 'AF6', 'A6', 'G13', 'N10', 'V25', 'J2', 'A8', 'AF8', 'G14', 'N13', 'V5', 'AA14', 'B15', 'G18', 'N20', 'W12', 'AA16', 'B16', 'H25', 'N9', 'W13', 'AA26', 'B23', 'H5', 'P10', 'W2', 'AA6', 'B3', 'J11', 'P13', 'W22', 'AA9', 'B6', 'J12', 'P17', 'Y10', 'AB10', 'C11', 'J13', 'P7', 'Y11', 'C13', 'P9']}] }),
        Part(**{ 'name':'XC7A200T-FFG1156', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A200T-FFG1156'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A200T-FFG1156\n\nFPGA', 'pins':[
            Pin(num='AC24',name='IO_L22P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AC26',name='IO_L16P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC27',name='IO_L16N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD23',name='IO_0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD24',name='IO_L22N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD25',name='IO_L24P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD26',name='IO_L15P_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD28',name='IO_L9P_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD29',name='IO_L9N_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD30',name='IO_L8P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD31',name='IO_L7P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD32',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AD33',name='IO_L2P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD34',name='IO_L2N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE23',name='IO_L20P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE25',name='IO_L24N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE26',name='IO_L15N_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE27',name='IO_L18P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE28',name='IO_L14P_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE29',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AE30',name='IO_L8N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE31',name='IO_L7N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE32',name='IO_L6P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AE33',name='IO_L4P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF23',name='IO_L20N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF24',name='IO_25_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF25',name='IO_L23P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF26',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AF27',name='IO_L18N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF28',name='IO_L14N_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF29',name='IO_L11P_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF30',name='IO_L11N_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF32',name='IO_L6N_T0_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF33',name='IO_L4N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AF34',name='IO_L1P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG24',name='IO_L21P_T3_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG25',name='IO_L23N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG26',name='IO_L19P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG27',name='IO_L17P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG29',name='IO_L12P_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG30',name='IO_L12N_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG31',name='IO_L10P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG32',name='IO_L5P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AG33',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AG34',name='IO_L1N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH24',name='IO_L21N_T3_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH26',name='IO_L19N_T3_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH27',name='IO_L17N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH28',name='IO_L13P_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH29',name='IO_L13N_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH30',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AH31',name='IO_L10N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH32',name='IO_L5N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH33',name='IO_L3P_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AH34',name='IO_L3N_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ24',name='IO_0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ25',name='IO_L19P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ26',name='IO_L20P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ27',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AJ28',name='IO_L14P_T2_SRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ29',name='IO_L11P_T1_SRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ30',name='IO_L9P_T1_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ31',name='IO_L7P_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ33',name='IO_L2P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AJ34',name='IO_L2N_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK25',name='IO_L19N_T3_VREF_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK26',name='IO_L20N_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK27',name='IO_L18P_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK28',name='IO_L14N_T2_SRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK30',name='IO_L11N_T1_SRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK31',name='IO_L9N_T1_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK32',name='IO_L7N_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK33',name='IO_L4P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AK34',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AL24',name='IO_25_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AL25',name='IO_L23P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AL27',name='IO_L18N_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AL28',name='IO_L13P_T2_MRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AL29',name='IO_L13N_T2_MRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AL30',name='IO_L12P_T1_MRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AL31',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AL32',name='IO_L6P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AL33',name='IO_L4N_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AL34',name='IO_L1P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AM25',name='IO_L23N_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AM26',name='IO_L21P_T3_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AM27',name='IO_L22P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AM28',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AM29',name='IO_L16P_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AM30',name='IO_L12N_T1_MRCC_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AM31',name='IO_L8P_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AM32',name='IO_L6N_T0_VREF_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AM34',name='IO_L1N_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AN25',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AN26',name='IO_L21N_T3_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AN27',name='IO_L22N_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AN28',name='IO_L17P_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AN29',name='IO_L16N_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AN31',name='IO_L10P_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AN32',name='IO_L8N_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AN33',name='IO_L5P_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AN34',name='IO_L3P_T0_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AP25',name='IO_L24P_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AP26',name='IO_L24N_T3_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AP28',name='IO_L17N_T2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AP29',name='IO_L15P_T2_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AP30',name='IO_L15N_T2_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AP31',name='IO_L10N_T1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AP32',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AP33',name='IO_L5N_T0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AP34',name='IO_L3N_T0_DQS_12',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AA25',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AA27',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AA28',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AA29',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AA30',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AA31',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='AA32',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AA33',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AA34',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB24',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB25',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB26',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB27',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB28',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='AB29',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB30',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB31',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB32',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AB34',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AC28',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AC29',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AC31',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AC32',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AC33',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='AC34',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M27',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M28',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='M29',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M30',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M31',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M32',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M34',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N24',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N25',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='N26',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N27',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N28',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N29',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N31',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N32',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N33',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N34',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P28',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P29',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P30',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P31',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P32',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='P33',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='P34',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='R25',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='R27',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='R28',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='R29',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='R30',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='R31',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='R32',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='R33',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T26',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='T27',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T28',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T29',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T30',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T32',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T33',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='T34',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U24',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U25',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U26',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U27',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U29',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U30',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U31',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U32',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='U33',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='U34',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='V24',name='IO_0_14',func=pin_types.BIDIR,unit=2),
            Pin(num='V26',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=2),
            Pin(num='V27',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=2),
            Pin(num='V28',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=2),
            Pin(num='V29',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=2),
            Pin(num='V30',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='V31',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=2),
            Pin(num='V32',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=2),
            Pin(num='V33',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=2),
            Pin(num='V34',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W24',name='IO_25_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W25',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W26',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W27',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='W28',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W29',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W30',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W31',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W33',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=2),
            Pin(num='W34',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y24',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='Y25',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y26',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y27',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y28',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y30',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y31',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y32',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y33',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y34',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='A31',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='B28',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='C25',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='D32',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='E29',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='F26',name='VCCO_17',func=pin_types.PWRIN,unit=3),
            Pin(num='G24',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G25',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G26',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G27',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G29',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G30',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G31',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G32',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G33',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='G34',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H24',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H26',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H27',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H28',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H29',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H30',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='H31',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H32',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H33',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H34',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J23',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J24',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J25',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J26',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J27',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='J28',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J29',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J30',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J31',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J33',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='J34',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K23',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K24',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='K25',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K26',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K27',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K28',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K30',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K31',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K32',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K33',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='K34',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='L23',name='IO_0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L24',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L25',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L27',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L28',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L29',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L30',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L31',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='L32',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L33',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='L34',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='M24',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='M25',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='M26',name='IO_25_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AC11',name='IO_0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD1',name='IO_L2P_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD10',name='IO_L24P_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD11',name='IO_L22P_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD3',name='IO_L10P_T1_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD4',name='IO_L8N_T1_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD5',name='IO_L8P_T1_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD6',name='IO_L13P_T2_MRCC_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD7',name='VCCO_33',func=pin_types.PWRIN,unit=4),
            Pin(num='AD8',name='IO_L15N_T2_DQS_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AD9',name='IO_L15P_T2_DQS_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE1',name='IO_L2N_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE10',name='IO_L24N_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE11',name='IO_L22N_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE2',name='IO_L4P_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE3',name='IO_L10N_T1_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE4',name='VCCO_33',func=pin_types.PWRIN,unit=4),
            Pin(num='AE5',name='IO_L12P_T1_MRCC_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE6',name='IO_L13N_T2_MRCC_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE7',name='IO_L16N_T2_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AE8',name='IO_L16P_T2_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF1',name='VCCO_33',func=pin_types.PWRIN,unit=4),
            Pin(num='AF10',name='IO_25_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF11',name='VCCO_33',func=pin_types.PWRIN,unit=4),
            Pin(num='AF12',name='IO_L20P_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF2',name='IO_L4N_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF3',name='IO_L5P_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF4',name='IO_L7P_T1_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF5',name='IO_L12N_T1_MRCC_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF7',name='IO_L14P_T2_SRCC_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF8',name='IO_L18N_T2_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AF9',name='IO_L18P_T2_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG1',name='IO_L1P_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG10',name='IO_L21P_T3_DQS_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG11',name='IO_L23P_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG12',name='IO_L20N_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG2',name='IO_L5N_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG4',name='IO_L7N_T1_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG5',name='IO_L11N_T1_SRCC_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG6',name='IO_L11P_T1_SRCC_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG7',name='IO_L14N_T2_SRCC_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AG8',name='VCCO_33',func=pin_types.PWRIN,unit=4),
            Pin(num='AG9',name='IO_L21N_T3_DQS_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH1',name='IO_L1N_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH11',name='IO_L23N_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH2',name='IO_L3P_T0_DQS_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH3',name='IO_L6P_T0_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH4',name='IO_L9P_T1_DQS_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH5',name='VCCO_33',func=pin_types.PWRIN,unit=4),
            Pin(num='AH6',name='IO_L17N_T2_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH7',name='IO_L17P_T2_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH8',name='IO_L19N_T3_VREF_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AH9',name='IO_L19P_T3_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ1',name='IO_L3N_T0_DQS_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ10',name='IO_L19P_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ11',name='IO_L23P_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ2',name='VCCO_32',func=pin_types.PWRIN,unit=4),
            Pin(num='AJ3',name='IO_L6N_T0_VREF_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ4',name='IO_L9N_T1_DQS_33',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ5',name='IO_L8P_T1_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ6',name='IO_L12P_T1_MRCC_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ8',name='IO_L15P_T2_DQS_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AJ9',name='IO_0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK1',name='IO_L2N_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK10',name='IO_L19N_T3_VREF_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK11',name='IO_L23N_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK2',name='IO_L2P_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK3',name='IO_L6P_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK5',name='IO_L8N_T1_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK6',name='IO_L12N_T1_MRCC_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK7',name='IO_L13P_T2_MRCC_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK8',name='IO_L15N_T2_DQS_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AK9',name='VCCO_32',func=pin_types.PWRIN,unit=4),
            Pin(num='AL10',name='IO_L24P_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AL2',name='IO_L4P_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AL3',name='IO_L6N_T0_VREF_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AL4',name='IO_L10P_T1_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AL5',name='IO_L11P_T1_SRCC_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AL6',name='VCCO_32',func=pin_types.PWRIN,unit=4),
            Pin(num='AL7',name='IO_L13N_T2_MRCC_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AL8',name='IO_25_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AL9',name='IO_L21P_T3_DQS_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM1',name='IO_L4N_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM10',name='IO_L24N_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM11',name='IO_L22P_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM2',name='IO_L3P_T0_DQS_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM3',name='VCCO_32',func=pin_types.PWRIN,unit=4),
            Pin(num='AM4',name='IO_L10N_T1_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM5',name='IO_L11N_T1_SRCC_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM6',name='IO_L14N_T2_SRCC_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM7',name='IO_L14P_T2_SRCC_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AM9',name='IO_L21N_T3_DQS_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN1',name='IO_L1P_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN10',name='VCCO_32',func=pin_types.PWRIN,unit=4),
            Pin(num='AN11',name='IO_L22N_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN2',name='IO_L3N_T0_DQS_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN3',name='IO_L5P_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN4',name='IO_L7P_T1_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN6',name='IO_L17N_T2_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN7',name='IO_L17P_T2_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN8',name='IO_L16P_T2_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AN9',name='IO_L18P_T2_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP1',name='IO_L1N_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP10',name='IO_L20N_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP11',name='IO_L20P_T3_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP3',name='IO_L5N_T0_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP4',name='IO_L7N_T1_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP5',name='IO_L9N_T1_DQS_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP6',name='IO_L9P_T1_DQS_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP7',name='VCCO_32',func=pin_types.PWRIN,unit=4),
            Pin(num='AP8',name='IO_L16N_T2_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AP9',name='IO_L18N_T2_32',func=pin_types.BIDIR,unit=4),
            Pin(num='AA10',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AA2',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AA3',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AA4',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AA5',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AA6',name='VCCO_34',func=pin_types.PWRIN,unit=5),
            Pin(num='AA7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AA8',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AA9',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB1',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB10',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='IO_25_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB3',name='VCCO_34',func=pin_types.PWRIN,unit=5),
            Pin(num='AB4',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB5',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB6',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB7',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AB9',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AC1',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AC10',name='VCCO_34',func=pin_types.PWRIN,unit=5),
            Pin(num='AC2',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AC3',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AC4',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AC6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AC7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='AC9',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=5),
            Pin(num='M1',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=5),
            Pin(num='M11',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=5),
            Pin(num='M3',name='VCCO_35',func=pin_types.PWRIN,unit=5),
            Pin(num='M4',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=5),
            Pin(num='M5',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=5),
            Pin(num='M6',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=5),
            Pin(num='M7',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=5),
            Pin(num='N1',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=5),
            Pin(num='N10',name='VCCO_35',func=pin_types.PWRIN,unit=5),
            Pin(num='N2',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=5),
            Pin(num='N3',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=5),
            Pin(num='N4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=5),
            Pin(num='N6',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=5),
            Pin(num='N7',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=5),
            Pin(num='N8',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=5),
            Pin(num='N9',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=5),
            Pin(num='P1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=5),
            Pin(num='P10',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='P3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=5),
            Pin(num='P4',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=5),
            Pin(num='P5',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=5),
            Pin(num='P6',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=5),
            Pin(num='P7',name='VCCO_35',func=pin_types.PWRIN,unit=5),
            Pin(num='P8',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=5),
            Pin(num='P9',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R10',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R11',name='IO_0_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R2',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R3',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R4',name='VCCO_35',func=pin_types.PWRIN,unit=5),
            Pin(num='R5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R6',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R7',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='T1',name='VCCO_35',func=pin_types.PWRIN,unit=5),
            Pin(num='T10',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=5),
            Pin(num='T2',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=5),
            Pin(num='T3',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=5),
            Pin(num='T4',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=5),
            Pin(num='T5',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=5),
            Pin(num='T7',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='T8',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U1',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U10',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='IO_25_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U2',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U6',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U7',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='U8',name='VCCO_35',func=pin_types.PWRIN,unit=5),
            Pin(num='U9',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=5),
            Pin(num='V1',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=5),
            Pin(num='V2',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=5),
            Pin(num='V3',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=5),
            Pin(num='V4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=5),
            Pin(num='V5',name='VCCO_34',func=pin_types.PWRIN,unit=5),
            Pin(num='V6',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='V7',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='V8',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='W1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=5),
            Pin(num='W10',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='W2',name='VCCO_34',func=pin_types.PWRIN,unit=5),
            Pin(num='W3',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=5),
            Pin(num='W4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=5),
            Pin(num='W5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=5),
            Pin(num='W6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='W8',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=5),
            Pin(num='W9',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y10',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y11',name='IO_0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y5',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y6',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y7',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y8',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=5),
            Pin(num='Y9',name='VCCO_34',func=pin_types.PWRIN,unit=5),
            Pin(num='A6',name='VCCO_37',func=pin_types.PWRIN,unit=6),
            Pin(num='B3',name='VCCO_37',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='VCCO_37',func=pin_types.PWRIN,unit=6),
            Pin(num='D7',name='VCCO_37',func=pin_types.PWRIN,unit=6),
            Pin(num='E4',name='VCCO_37',func=pin_types.PWRIN,unit=6),
            Pin(num='F1',name='VCCO_36',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCO_37',func=pin_types.PWRIN,unit=6),
            Pin(num='F2',name='IO_L15N_T2_DQS_36',func=pin_types.BIDIR,unit=6),
            Pin(num='F3',name='IO_L15P_T2_DQS_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G1',name='IO_L22N_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G10',name='IO_L2P_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G11',name='IO_L4N_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G2',name='IO_L20N_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G4',name='IO_L13N_T2_MRCC_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G5',name='IO_L13P_T2_MRCC_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G6',name='IO_L10N_T1_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G7',name='IO_L10P_T1_36',func=pin_types.BIDIR,unit=6),
            Pin(num='G8',name='VCCO_36',func=pin_types.PWRIN,unit=6),
            Pin(num='G9',name='IO_L2N_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H1',name='IO_L22P_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H11',name='IO_L4P_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H12',name='IO_0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H2',name='IO_L20P_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H3',name='IO_L17N_T2_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H4',name='IO_L17P_T2_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H5',name='VCCO_36',func=pin_types.PWRIN,unit=6),
            Pin(num='H6',name='IO_L12N_T1_MRCC_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H7',name='IO_L12P_T1_MRCC_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H8',name='IO_L8N_T1_36',func=pin_types.BIDIR,unit=6),
            Pin(num='H9',name='IO_L8P_T1_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J1',name='IO_L21N_T3_DQS_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J10',name='IO_L6N_T0_VREF_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J11',name='IO_L3N_T0_DQS_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J12',name='VCCO_36',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='VCCO_36',func=pin_types.PWRIN,unit=6),
            Pin(num='J3',name='IO_L18N_T2_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J4',name='IO_L18P_T2_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J5',name='IO_L14N_T2_SRCC_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J6',name='IO_L14P_T2_SRCC_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J8',name='IO_L7N_T1_36',func=pin_types.BIDIR,unit=6),
            Pin(num='J9',name='IO_L7P_T1_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K1',name='IO_L21P_T3_DQS_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K10',name='IO_L6P_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K11',name='IO_L3P_T0_DQS_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K12',name='IO_L1N_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K2',name='IO_L24N_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K3',name='IO_L24P_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K5',name='IO_L16N_T2_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K6',name='IO_L11N_T1_SRCC_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K7',name='IO_L11P_T1_SRCC_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K8',name='IO_L9N_T1_DQS_36',func=pin_types.BIDIR,unit=6),
            Pin(num='K9',name='VCCO_36',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='IO_L5P_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='IO_L1P_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='L2',name='IO_L23N_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='L3',name='IO_L19N_T3_VREF_36',func=pin_types.BIDIR,unit=6),
            Pin(num='L4',name='IO_L19P_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='L5',name='IO_L16P_T2_36',func=pin_types.BIDIR,unit=6),
            Pin(num='L6',name='VCCO_36',func=pin_types.PWRIN,unit=6),
            Pin(num='L7',name='IO_25_36',func=pin_types.BIDIR,unit=6),
            Pin(num='L8',name='IO_L9P_T1_DQS_36',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='IO_L5N_T0_36',func=pin_types.BIDIR,unit=6),
            Pin(num='M2',name='IO_L23P_T3_36',func=pin_types.BIDIR,unit=6),
            Pin(num='A13',name='MGTPTXN0_116',func=pin_types.BIDIR,unit=7),
            Pin(num='A15',name='MGTPTXN2_116',func=pin_types.BIDIR,unit=7),
            Pin(num='A17',name='MGTPTXN3_116',func=pin_types.BIDIR,unit=7),
            Pin(num='AG14',name='MGTREFCLK0P_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AG16',name='MGTREFCLK1P_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AH14',name='MGTREFCLK0N_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AH16',name='MGTREFCLK1N_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ13',name='MGTPRXP3_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ15',name='MGTPRXP2_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AJ17',name='MGTPRXP0_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AK13',name='MGTPRXN3_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AK15',name='MGTPRXN2_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AK17',name='MGTPRXN0_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AL14',name='MGTPTXP2_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AL16',name='MGTPRXP1_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AM14',name='MGTPTXN2_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AM16',name='MGTPRXN1_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AN13',name='MGTPTXP3_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AN15',name='MGTPTXP1_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AN17',name='MGTPTXP0_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AP13',name='MGTPTXN3_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AP15',name='MGTPTXN1_113',func=pin_types.BIDIR,unit=7),
            Pin(num='AP17',name='MGTPTXN0_113',func=pin_types.BIDIR,unit=7),
            Pin(num='B13',name='MGTPTXP0_116',func=pin_types.BIDIR,unit=7),
            Pin(num='B15',name='MGTPTXP2_116',func=pin_types.BIDIR,unit=7),
            Pin(num='B17',name='MGTPTXP3_116',func=pin_types.BIDIR,unit=7),
            Pin(num='C14',name='MGTPTXN1_116',func=pin_types.BIDIR,unit=7),
            Pin(num='C16',name='MGTPRXN2_116',func=pin_types.BIDIR,unit=7),
            Pin(num='D14',name='MGTPTXP1_116',func=pin_types.BIDIR,unit=7),
            Pin(num='D16',name='MGTPRXP2_116',func=pin_types.BIDIR,unit=7),
            Pin(num='E13',name='MGTPRXN0_116',func=pin_types.BIDIR,unit=7),
            Pin(num='E15',name='MGTPRXN1_116',func=pin_types.BIDIR,unit=7),
            Pin(num='E17',name='MGTPRXN3_116',func=pin_types.BIDIR,unit=7),
            Pin(num='F13',name='MGTPRXP0_116',func=pin_types.BIDIR,unit=7),
            Pin(num='F15',name='MGTPRXP1_116',func=pin_types.BIDIR,unit=7),
            Pin(num='F17',name='MGTPRXP3_116',func=pin_types.BIDIR,unit=7),
            Pin(num='G14',name='MGTREFCLK1N_116',func=pin_types.BIDIR,unit=7),
            Pin(num='G16',name='MGTREFCLK0N_116',func=pin_types.BIDIR,unit=7),
            Pin(num='H14',name='MGTREFCLK1P_116',func=pin_types.BIDIR,unit=7),
            Pin(num='H16',name='MGTREFCLK0P_116',func=pin_types.BIDIR,unit=7),
            Pin(num='A19',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=8),
            Pin(num='A21',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=8),
            Pin(num='A23',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=8),
            Pin(num='AG18',name='MGTREFCLK1P_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AG20',name='MGTREFCLK0P_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AH18',name='MGTREFCLK1N_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AH20',name='MGTREFCLK0N_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ19',name='MGTPRXP1_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AJ21',name='MGTPRXP3_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AK19',name='MGTPRXN1_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AK21',name='MGTPRXN3_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AL18',name='MGTPRXP0_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AL20',name='MGTPRXP2_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AL22',name='MGTPTXP2_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AM18',name='MGTPRXN0_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AM20',name='MGTPRXN2_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AM22',name='MGTPTXN2_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AN19',name='MGTPTXP0_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AN21',name='MGTPTXP1_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AN23',name='MGTPTXP3_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AP19',name='MGTPTXN0_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AP21',name='MGTPTXN1_213',func=pin_types.BIDIR,unit=8),
            Pin(num='AP23',name='MGTPTXN3_213',func=pin_types.BIDIR,unit=8),
            Pin(num='B19',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=8),
            Pin(num='B21',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=8),
            Pin(num='B23',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=8),
            Pin(num='C18',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=8),
            Pin(num='C20',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=8),
            Pin(num='C22',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=8),
            Pin(num='D18',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=8),
            Pin(num='D20',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=8),
            Pin(num='D22',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=8),
            Pin(num='E19',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=8),
            Pin(num='E21',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=8),
            Pin(num='F19',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=8),
            Pin(num='F21',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=8),
            Pin(num='G18',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=8),
            Pin(num='G20',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=8),
            Pin(num='H18',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=8),
            Pin(num='H20',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=8),
            Pin(num='AG15',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AG17',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AG19',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AG21',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AH22',name='MGTRREF_213',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ14',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ16',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ18',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ20',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AJ22',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AL13',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AL15',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AL17',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AL19',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AL21',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AN14',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AN16',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AN18',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AN20',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='AN22',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=9),
            Pin(num='B14',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='B16',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='B18',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='B20',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='B22',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='D13',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='D15',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='D17',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='D19',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='D21',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='F14',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='F16',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='F18',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='F20',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='F22',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='G22',name='MGTRREF_216',func=pin_types.PWRIN,unit=9),
            Pin(num='H15',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='H17',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='H19',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='H21',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=9),
            Pin(num='AD13',name='TDO_0',func=pin_types.BIDIR,unit=10),
            Pin(num='AE12',name='TCK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='AE13',name='TMS_0',func=pin_types.BIDIR,unit=10),
            Pin(num='AE14',name='TDI_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K21',name='M2_0',func=pin_types.BIDIR,unit=10),
            Pin(num='K22',name='M1_0',func=pin_types.BIDIR,unit=10),
            Pin(num='L13',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='L22',name='M0_0',func=pin_types.BIDIR,unit=10),
            Pin(num='M12',name='CFGBVS_0',func=pin_types.BIDIR,unit=10),
            Pin(num='N11',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='P11',name='DONE_0',func=pin_types.BIDIR,unit=10),
            Pin(num='T11',name='VCCO_0',func=pin_types.PWRIN,unit=10),
            Pin(num='U17',name='VREFN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='U18',name='VP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V11',name='INIT_B_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V17',name='VN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='V18',name='VREFP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W11',name='CCLK_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W17',name='DXN_0',func=pin_types.BIDIR,unit=10),
            Pin(num='W18',name='DXP_0',func=pin_types.BIDIR,unit=10),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='AA13',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='AA15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AA17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AA19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AA21',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='AA23',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='AB12',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='AB14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AB16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AB18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AB20',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='AB22',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='AC13',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='AC15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AC17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AC19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AC21',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='AC23',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='AD12',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='AD14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AD16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AD18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AD20',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AD22',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AE15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AE17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AE19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='AE21',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B33',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C30',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='D27',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E24',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E34',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F31',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G28',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='H25',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J32',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K13',name='VCCBATT_0',func=pin_types.PWRIN,unit=11),
            Pin(num='K14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K20',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='K29',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='L21',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M20',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='M21',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M22',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='M23',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M33',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N13',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N14',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='N20',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N21',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='N22',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N23',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='N30',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P12',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P15',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P17',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='P20',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='P22',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='R13',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='R15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R17',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='R21',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='R23',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='T12',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='T14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='T17',name='GNDADC_0',func=pin_types.PWRIN,unit=11),
            Pin(num='T18',name='VCCADC_0',func=pin_types.PWRIN,unit=11),
            Pin(num='T20',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='T22',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U13',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='U15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='U21',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='U23',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='V12',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='V14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='V20',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='V22',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='W13',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='W15',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='W19',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='W21',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='W23',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='Y12',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='Y14',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='Y16',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='Y18',name='VCCINT',func=pin_types.PWRIN,unit=11),
            Pin(num='Y20',name='VCCBRAM',func=pin_types.PWRIN,unit=11),
            Pin(num='Y22',name='VCCAUX',func=pin_types.PWRIN,unit=11),
            Pin(num='AA1',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AA11',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AA14',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AA16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AA18',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AA20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AB13',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AB15',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AB17',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AB21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AB23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AB33',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AC12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AC14',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AC16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AC18',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AC20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AC22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AC30',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AC5',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AD15',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AD17',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AD19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AD2',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AD21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AD27',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AE16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AE18',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AE20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AE22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AE24',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AE34',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AE9',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF13',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF15',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF17',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF18',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF31',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AG13',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AG22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AG23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AG28',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AG3',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH10',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH13',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH15',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH17',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AH25',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AJ12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AJ23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AJ32',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AJ7',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK14',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK18',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK24',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK29',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AK4',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AL1',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AL11',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AL12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AL23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AL26',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM13',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM15',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM17',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM24',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM33',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AM8',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AN12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AN24',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AN30',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AN5',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP14',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP18',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP2',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP24',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='AP27',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='P19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='P21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='P23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='P27',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R24',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R34',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='T13',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='T15',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='T19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='T23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='T31',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='U16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='U20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='U22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='U28',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='V15',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='V19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='V23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='W14',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='W20',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='W22',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='W32',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='Y13',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='Y17',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='Y21',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='Y23',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='Y29',name='GND',func=pin_types.PWRIN,unit=12),
            Pin(num='Y4',name='GND',func=pin_types.PWRIN,unit=12)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AE23', 'AH26', 'AP34', 'AL29', 'AH27', 'AE25', 'AL30', 'AE26', 'AH28', 'AL31', 'AH29', 'AE27', 'AL32', 'AH30', 'AE28', 'AL33', 'AE29', 'AH31', 'AL34', 'AE30', 'AH32', 'AM25', 'AE31', 'AH33', 'AM26', 'AE32', 'AH34', 'AM27', 'AE33', 'AJ24', 'AM28', 'AF23', 'AJ25', 'AM29', 'AF24', 'AJ26', 'AM30', 'AF25', 'AJ27', 'AM31', 'AF26', 'AJ28', 'AM32', 'AJ29', 'AF27', 'AC26', 'AM34', 'AF28', 'AJ30', 'AN25', 'AF29', 'AJ31', 'AN26', 'AF30', 'AJ33', 'AN27', 'AC27', 'AF32', 'AJ34', 'AC25', 'AN28', 'AF33', 'AK25', 'AN29', 'AF34', 'AK26', 'AN31', 'AG24', 'AK27', 'AN32', 'AK28', 'AG25', 'AN33', 'AK30', 'AG26', 'AD23', 'AN34', 'AG27', 'AK31', 'AD24', 'AP25', 'AD25', 'AG29', 'AK32', 'AP26', 'AD26', 'AG30', 'AK33', 'AP28', 'AD28', 'AD29', 'AG31', 'AK34', 'AP29', 'AD30', 'AL24', 'AG32', 'AP30', 'AC24', 'AD31', 'AG33', 'AL25', 'AD32', 'AP31', 'AL28', 'AD33', 'AG34', 'AL27', 'AP32', 'AD34', 'AH24', 'AP33']},{'label': 'uB', 'num': 2, 'pin_nums': ['T24', 'W26', 'T25', 'M32', 'W27', 'AA24', 'M34', 'T26', 'W28', 'AA25', 'N24', 'T27', 'W29', 'AA27', 'N25', 'T28', 'W30', 'AA28', 'N26', 'T29', 'W31', 'AA29', 'N27', 'T30', 'W33', 'AA30', 'N28', 'T32', 'W34', 'AA31', 'N29', 'T33', 'Y24', 'AA32', 'N31', 'T34', 'Y25', 'AA33', 'N32', 'U24', 'Y26', 'AA34', 'N33', 'U25', 'Y27', 'AB24', 'N34', 'U26', 'Y28', 'AB25', 'P24', 'U27', 'Y30', 'AB26', 'P25', 'U29', 'Y31', 'AB27', 'P26', 'U30', 'Y32', 'AB28', 'P28', 'U31', 'Y33', 'AB29', 'P29', 'U32', 'Y34', 'AB30', 'P30', 'U33', 'AB31', 'P31', 'U34', 'AB32', 'P32', 'V24', 'AB34', 'P33', 'V26', 'AC28', 'P34', 'V27', 'AC29', 'R25', 'V28', 'AC31', 'R26', 'V29', 'AC32', 'R27', 'V30', 'AC33', 'R28', 'V31', 'AC34', 'R29', 'V32', 'M27', 'R30', 'V33', 'M28', 'R31', 'V34', 'M29', 'M31', 'R32', 'W24', 'M30', 'R33', 'W25']},{'label': 'uC', 'num': 3, 'pin_nums': ['L29', 'M26', 'G32', 'J26', 'G24', 'G33', 'H31', 'J27', 'K23', 'K24', 'K32', 'K33', 'L30', 'G34', 'H32', 'J28', 'K25', 'K34', 'G25', 'L31', 'A31', 'G26', 'H24', 'H33', 'J29', 'K26', 'L23', 'L32', 'H26', 'B28', 'G27', 'H34', 'J30', 'K27', 'L24', 'L33', 'C25', 'G29', 'H27', 'J23', 'J31', 'K28', 'L25', 'L34', 'G30', 'D32', 'H28', 'J24', 'J33', 'K30', 'L27', 'M24', 'F26', 'E29', 'G31', 'H29', 'J25', 'J34', 'K31', 'L28', 'M25', 'H30']},{'label': 'uD', 'num': 4, 'pin_nums': ['AE3', 'AH4', 'AL7', 'AP9', 'AE4', 'AL8', 'AH5', 'AE5', 'AH6', 'AL9', 'AE6', 'AM1', 'AH7', 'AE7', 'AH8', 'AM10', 'AE8', 'AH9', 'AM11', 'AF1', 'AJ1', 'AM2', 'AF10', 'AM3', 'AJ10', 'AF11', 'AJ11', 'AM4', 'AF12', 'AJ2', 'AM5', 'AF2', 'AJ3', 'AM6', 'AF3', 'AJ4', 'AM7', 'AF4', 'AJ5', 'AM9', 'AF5', 'AJ6', 'AN1', 'AF7', 'AJ8', 'AN10', 'AF8', 'AJ9', 'AN11', 'AF9', 'AK1', 'AN2', 'AC11', 'AG1', 'AK10', 'AN3', 'AD1', 'AG10', 'AK11', 'AN4', 'AD10', 'AG11', 'AK2', 'AN6', 'AD11', 'AG12', 'AK3', 'AN7', 'AD3', 'AG2', 'AK5', 'AN8', 'AD4', 'AG4', 'AK6', 'AN9', 'AD5', 'AG5', 'AK7', 'AP1', 'AD6', 'AG6', 'AK8', 'AP10', 'AL6', 'AD7', 'AG7', 'AK9', 'AP11', 'AD8', 'AG8', 'AL10', 'AP3', 'AD9', 'AG9', 'AL2', 'AP4', 'AE1', 'AH1', 'AL3', 'AP5', 'AE10', 'AH11', 'AL4', 'AP6', 'AE11', 'AH2', 'AL5', 'AP7', 'AE2', 'AH3', 'AP8']},{'label': 'uE', 'num': 5, 'pin_nums': ['M11', 'W10', 'M3', 'R7', 'W2', 'AA10', 'M4', 'R8', 'W3', 'AA2', 'M5', 'T1', 'W4', 'AA3', 'M6', 'T10', 'W5', 'AA4', 'M7', 'T2', 'W6', 'AA5', 'M9', 'T3', 'W8', 'AA6', 'N1', 'T4', 'W9', 'AA7', 'N10', 'T5', 'Y1', 'AA8', 'N2', 'T7', 'Y10', 'AA9', 'N3', 'T8', 'Y11', 'AB1', 'N4', 'T9', 'Y2', 'AB10', 'N6', 'U1', 'Y3', 'AB11', 'N7', 'U10', 'Y5', 'AB2', 'N8', 'U11', 'Y6', 'AB3', 'N9', 'U2', 'Y7', 'AB4', 'P1', 'U4', 'Y8', 'AB5', 'P10', 'U5', 'Y9', 'AB6', 'P3', 'U6', 'AB7', 'P4', 'U7', 'AB9', 'P5', 'U8', 'AC1', 'P6', 'U9', 'AC10', 'P7', 'V1', 'AC2', 'P8', 'V2', 'AC3', 'P9', 'V3', 'AC4', 'R1', 'V4', 'AC6', 'R10', 'V5', 'AC7', 'R11', 'V6', 'AC8', 'R2', 'V7', 'AC9', 'R3', 'V8', 'M1', 'R4', 'R6', 'V9', 'M10', 'R5', 'W1']},{'label': 'uF', 'num': 6, 'pin_nums': ['L12', 'H12', 'J5', 'K2', 'H9', 'L9', 'F11', 'G5', 'H2', 'J1', 'J6', 'K3', 'L2', 'M2', 'F2', 'G6', 'H3', 'J10', 'J8', 'K5', 'L3', 'A6', 'F3', 'G7', 'H4', 'J11', 'J9', 'K6', 'L4', 'G1', 'B3', 'G8', 'H5', 'J12', 'K1', 'K7', 'L5', 'C10', 'G10', 'F1', 'G9', 'H6', 'J2', 'K10', 'K8', 'L6', 'D7', 'G11', 'H1', 'H7', 'J3', 'K11', 'K9', 'L7', 'G2', 'E4', 'H11', 'H8', 'J4', 'K12', 'L10', 'L8', 'G4']},{'label': 'uG', 'num': 7, 'pin_nums': ['AH16', 'AL16', 'AP17', 'H14', 'E13', 'AJ13', 'B13', 'E15', 'H16', 'AM14', 'A13', 'AJ15', 'AM16', 'B15', 'E17', 'A15', 'AJ17', 'B17', 'AN13', 'F13', 'A17', 'AK13', 'AN15', 'C14', 'F15', 'AG14', 'AK15', 'AN17', 'C16', 'F17', 'AP15', 'AG16', 'AK17', 'AP13', 'D14', 'G14', 'G16', 'AH14', 'AL14', 'D16']},{'label': 'uH', 'num': 8, 'pin_nums': ['AH18', 'AP21', 'AH20', 'AP23', 'AM18', 'D18', 'D20', 'G20', 'H18', 'AJ19', 'AM20', 'B19', 'D22', 'H20', 'A19', 'AJ21', 'AM22', 'B21', 'E19', 'AK19', 'AN19', 'A21', 'B23', 'E21', 'A23', 'AK21', 'AN21', 'C18', 'F19', 'AL18', 'AG18', 'AN23', 'C20', 'F21', 'AG20', 'AL20', 'AP19', 'C22', 'G18', 'AL22']},{'label': 'uI', 'num': 9, 'pin_nums': ['H17', 'AL19', 'D21', 'AJ14', 'B16', 'AJ16', 'AL21', 'B18', 'F14', 'H19', 'AJ18', 'AN14', 'B20', 'F16', 'H21', 'AG15', 'AJ20', 'AN16', 'B22', 'F18', 'AG17', 'AJ22', 'AN18', 'D13', 'F20', 'AG19', 'AL13', 'AN20', 'D15', 'F22', 'AG21', 'AL15', 'AN22', 'D17', 'G22', 'AH22', 'AL17', 'B14', 'D19', 'H15']},{'label': 'uJ', 'num': 10, 'pin_nums': ['K22', 'U18', 'V11', 'L13', 'L22', 'V17', 'AD13', 'M12', 'V18', 'AE12', 'N11', 'W11', 'AE13', 'P11', 'W17', 'AE14', 'T11', 'W18', 'K21', 'U17']},{'label': 'uK', 'num': 11, 'pin_nums': ['K13', 'T12', 'AD22', 'A11', 'E9', 'K14', 'M8', 'T14', 'AE15', 'A12', 'F12', 'K15', 'N12', 'T16', 'A14', 'AE17', 'F23', 'K16', 'N13', 'T17', 'A16', 'AE19', 'F31', 'K17', 'N14', 'T18', 'A18', 'AE21', 'F6', 'K18', 'N15', 'T20', 'A20', 'B12', 'G12', 'K19', 'N16', 'T22', 'A22', 'B24', 'G13', 'K20', 'N17', 'U13', 'B33', 'A24', 'G15', 'K29', 'N18', 'U15', 'A26', 'B8', 'G17', 'K4', 'N19', 'U19', 'AA13', 'C12', 'G19', 'L1', 'N20', 'U21', 'AA15', 'C13', 'G21', 'L11', 'N21', 'U23', 'AA17', 'C15', 'G23', 'L14', 'N22', 'V12', 'AA19', 'C17', 'G28', 'L15', 'N23', 'V14', 'AA21', 'C19', 'G3', 'L16', 'N30', 'V16', 'AA23', 'C21', 'H10', 'L17', 'N5', 'V20', 'C23', 'AB12', 'H13', 'L18', 'P12', 'V22', 'AB14', 'C24', 'H22', 'L19', 'P13', 'W13', 'AB16', 'C30', 'H23', 'L20', 'P14', 'W15', 'AB18', 'C5', 'H25', 'L21', 'P15', 'W19', 'AB20', 'D12', 'J13', 'L26', 'P16', 'W21', 'AB22', 'D2', 'J14', 'M13', 'P17', 'W23', 'AC13', 'D23', 'J15', 'M14', 'P18', 'Y12', 'AC15', 'D27', 'J16', 'M15', 'P2', 'Y14', 'AC17', 'E12', 'J17', 'M16', 'P20', 'Y16', 'AC19', 'E14', 'J18', 'M17', 'P22', 'Y18', 'AC21', 'E16', 'J19', 'M18', 'AD20', 'R13', 'Y20', 'AC23', 'E18', 'J20', 'M19', 'R15', 'Y22', 'AD12', 'E20', 'J21', 'M20', 'R17', 'AD14', 'E22', 'J22', 'M21', 'R19', 'AD16', 'E23', 'J32', 'M22', 'M33', 'R21', 'AD18', 'E24', 'J7', 'M23', 'R23', 'A1', 'E34']},{'label': 'uL', 'num': 12, 'pin_nums': ['AP16', 'AE34', 'AA16', 'AP18', 'AK12', 'U3', 'AE9', 'AA18', 'AK14', 'AP2', 'V10', 'AA20', 'AF13', 'AK16', 'AP20', 'V13', 'AF14', 'AA22', 'AK18', 'AP22', 'V15', 'AA26', 'AF15', 'AK20', 'AP24', 'V19', 'AB13', 'AF16', 'AK22', 'AP27', 'V21', 'AB15', 'AF17', 'AK23', 'P19', 'V23', 'AB17', 'AF18', 'AK24', 'P21', 'AE24', 'V25', 'AB19', 'AF19', 'AK29', 'P23', 'W12', 'AB21', 'AF20', 'AK4', 'P27', 'W14', 'AB23', 'AF21', 'AL1', 'R12', 'W16', 'AB33', 'AF22', 'AL11', 'R14', 'W20', 'AB8', 'AF31', 'AL12', 'R16', 'W22', 'AC12', 'AF6', 'AL23', 'R18', 'W32', 'AC14', 'AG13', 'AL26', 'R20', 'W7', 'AG22', 'AC16', 'AM12', 'R22', 'Y13', 'AC18', 'AG23', 'AM13', 'R24', 'Y15', 'AC20', 'AG28', 'AM15', 'R34', 'Y17', 'AC22', 'AG3', 'AM17', 'R9', 'Y19', 'AC30', 'AH10', 'AM19', 'T13', 'Y21', 'AC5', 'AH12', 'AM21', 'T15', 'Y23', 'AD15', 'AH13', 'AM23', 'T19', 'Y29', 'AD17', 'AH15', 'AM24', 'T21', 'Y4', 'AD19', 'AH17', 'AM33', 'T23', 'AD2', 'AH19', 'AM8', 'T31', 'AD21', 'AH21', 'AN12', 'T6', 'AD27', 'AH23', 'AN24', 'U12', 'AE16', 'AH25', 'AN30', 'U14', 'AA1', 'AE18', 'AJ12', 'AN5', 'U16', 'AA11', 'AE20', 'AJ23', 'AP12', 'U20', 'U28', 'AA12', 'AE22', 'AJ32', 'AP14', 'U22', 'AA14', 'AJ7']}] }),
        Part(**{ 'name':'XC7A200T-SBG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A200T-SBG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A200T-SBG484\n\nFPGA', 'pins':[
            Pin(num='AA10',name='IO_L9P_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='IO_L9N_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='IO_L3P_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='IO_L5N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='IO_L4P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='IO_L1N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA17',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='IO_L8P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='IO_L8N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='IO_L7P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='IO_L7N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='IO_L3N_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='IO_L4N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='IO_L2P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='IO_L2N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L15P_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L15N_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L17P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='IO_L14P_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L17N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L10P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L13P_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L13N_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L14N_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='IO_L10N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='IO_L12P_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='IO_L12N_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='W14',name='IO_L6P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO_L16P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO_L16N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y11',name='IO_L11P_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='IO_L11N_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='IO_L5P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='IO_L6N_T0_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='IO_L1P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='IO_0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='Y21',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A16',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='A18',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A20',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A21',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B13',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B14',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B15',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B16',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B20',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B21',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B22',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C13',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C14',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C18',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C20',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C21',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='C22',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D17',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='D19',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D21',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D22',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='E16',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E19',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E21',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E22',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO_0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F21',name='IO_25_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='G13',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H17',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J14',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J22',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K19',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K21',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='L18',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='N22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA7',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AA8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AB5',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J1',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J4',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='M5',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='N2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='T3',name='IO_0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T6',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U7',name='IO_25_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='V7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W3',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W5',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W9',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y9',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B7',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C4',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='D10',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='D6',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='MGTRREF_216',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='R13',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='T12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='T13',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U10',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U12',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U13',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='CFGBVS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='V12',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E12',name='VCCBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K10',name='VCCADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K9',name='GNDADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['T19', 'T20', 'AB17', 'W22', 'AB18', 'T21', 'Y10', 'AB20', 'T22', 'Y11', 'AB21', 'U15', 'Y12', 'AB22', 'U16', 'Y13', 'M14', 'U17', 'Y14', 'AA10', 'N13', 'U18', 'Y16', 'N14', 'U19', 'Y17', 'N15', 'U20', 'Y18', 'N17', 'U21', 'Y19', 'P14', 'U22', 'Y20', 'P15', 'V10', 'Y21', 'P16', 'V13', 'Y22', 'P17', 'V14', 'P18', 'V15', 'P19', 'V16', 'P20', 'V17', 'AA14', 'P21', 'V18', 'P22', 'V19', 'R14', 'V20', 'AA11', 'AA13', 'R15', 'V22', 'AA15', 'R16', 'W10', 'AA16', 'AA17', 'R17', 'W11', 'AA18', 'R18', 'W12', 'AA19', 'R19', 'AA20', 'W13', 'AA21', 'R21', 'W14', 'AA9', 'R22', 'W15', 'AB10', 'AB11', 'T14', 'W16', 'AB12', 'T15', 'W17', 'AB13', 'T16', 'W19', 'AB14', 'W21', 'AB15', 'T18', 'W20', 'AB16']},{'label': 'uB', 'num': 2, 'pin_nums': ['C13', 'K14', 'F19', 'C14', 'K16', 'F20', 'C15', 'F21', 'K17', 'C17', 'K18', 'F22', 'C18', 'G13', 'K19', 'C19', 'K20', 'G15', 'C20', 'G16', 'K21', 'C21', 'K22', 'G17', 'C22', 'G18', 'L13', 'D14', 'G19', 'L14', 'D15', 'G20', 'L15', 'D16', 'G21', 'L16', 'D17', 'G22', 'L17', 'D18', 'H13', 'L18', 'A13', 'D19', 'H14', 'L19', 'A14', 'D20', 'H15', 'L20', 'A15', 'D21', 'H16', 'L21', 'A16', 'D22', 'H17', 'M13', 'A17', 'E13', 'H18', 'M15', 'A18', 'E14', 'H19', 'M16', 'A19', 'E15', 'H20', 'M17', 'A20', 'E16', 'H22', 'M18', 'A21', 'E17', 'J13', 'M20', 'B13', 'E18', 'J14', 'M21', 'B14', 'E19', 'J15', 'M22', 'B15', 'E21', 'J16', 'N18', 'B16', 'E22', 'J17', 'N19', 'B22', 'B17', 'F13', 'J19', 'N20', 'B18', 'F14', 'J20', 'N21', 'B20', 'F15', 'J21', 'N22', 'B21', 'F16', 'J22', 'F18', 'K13']},{'label': 'uC', 'num': 3, 'pin_nums': ['H2', 'P1', 'W2', 'AA3', 'H3', 'W3', 'P2', 'AA4', 'H4', 'P4', 'W4', 'AA5', 'H5', 'W5', 'P5', 'AA6', 'H6', 'P6', 'W6', 'AA7', 'J1', 'R1', 'W7', 'AA8', 'J2', 'R2', 'W9', 'AB1', 'J3', 'Y1', 'R3', 'AB2', 'J4', 'R4', 'Y2', 'AB3', 'J5', 'R5', 'Y3', 'AB4', 'J6', 'R6', 'Y4', 'AB5', 'K1', 'T1', 'Y6', 'AB6', 'K2', 'T2', 'Y7', 'AB7', 'K3', 'T3', 'Y8', 'AB8', 'K4', 'T4', 'Y9', 'B1', 'K6', 'T5', 'B2', 'L1', 'T6', 'C1', 'L3', 'U1', 'C2', 'L4', 'U2', 'D1', 'L5', 'U3', 'D2', 'L6', 'U5', 'E1', 'M1', 'U6', 'E2', 'M2', 'U7', 'E3', 'M3', 'V2', 'F1', 'M4', 'V3', 'F2', 'M5', 'V4', 'F3', 'M6', 'V5', 'F4', 'N1', 'V6', 'G1', 'N2', 'V7', 'G2', 'N3', 'V8', 'AA1', 'G3', 'N4', 'V9', 'A1', 'G4', 'N5', 'W1']},{'label': 'uD', 'num': 4, 'pin_nums': ['A4', 'C5', 'E6', 'C7', 'A6', 'F10', 'A8', 'C9', 'F6', 'B10', 'D11', 'B4', 'D5', 'B6', 'D7', 'A10', 'D9', 'B8', 'E10', 'C11']},{'label': 'uE', 'num': 5, 'pin_nums': ['E8', 'B11', 'B7', 'C4', 'D10', 'F8', 'B5', 'B9', 'C8', 'D6', 'F7', 'F9']},{'label': 'uF', 'num': 6, 'pin_nums': ['U13', 'F12', 'N12', 'U8', 'G11', 'N9', 'L10', 'R13', 'U9', 'V12', 'L12', 'T12', 'U12', 'L9', 'T13', 'U10', 'M10', 'M9', 'U11', 'N10']},{'label': 'uG', 'num': 7, 'pin_nums': ['K10', 'R11', 'E20', 'K11', 'R12', 'E4', 'K12', 'R20', 'E5', 'K15', 'R7', 'E7', 'K5', 'R8', 'A11', 'E9', 'K7', 'R9', 'A12', 'F11', 'K8', 'T10', 'A2', 'F17', 'K9', 'T11', 'A22', 'F5', 'L11', 'T17', 'A3', 'G10', 'L2', 'T7', 'A5', 'G12', 'L22', 'T8', 'A7', 'G14', 'L7', 'T9', 'A9', 'G5', 'L8', 'U14', 'AA12', 'G6', 'M11', 'U4', 'AA2', 'G7', 'M12', 'V1', 'AA22', 'G8', 'M19', 'V11', 'AB19', 'G9', 'M7', 'V21', 'AB9', 'H1', 'M8', 'W18', 'B12', 'H10', 'N11', 'W8', 'B19', 'H11', 'N16', 'Y15', 'B3', 'H12', 'N6', 'Y5', 'C10', 'H21', 'N7', 'C12', 'H7', 'N8', 'C16', 'H8', 'P10', 'C3', 'H9', 'P11', 'C6', 'J10', 'P12', 'D12', 'J11', 'P13', 'D13', 'J12', 'P3', 'D3', 'J18', 'P7', 'D4', 'J7', 'P8', 'D8', 'E12', 'J8', 'P9', 'E11', 'J9', 'R10']}] }),
        Part(**{ 'name':'XC7A35T-CPG236', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A35T-CPG236'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A35T-CPG236\n\nFPGA', 'pins':[
            Pin(num='A14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R18',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='J1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='K1',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='K2',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='L1',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N1',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='P1',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R2',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A2',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C1',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C7',name='MGTRREF_216',func=pin_types.PWRIN,unit=4),
            Pin(num='E1',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='F3',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='DXP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A12',name='VP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A13',name='VREFN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B11',name='DXN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B12',name='VREFP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='VN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='C11',name='CCLK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='C8',name='TCK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='M2_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='INIT_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U12',name='DONE_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='CFGBVS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V12',name='M0_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='W10',name='TDI_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='M1_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W8',name='TDO_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W9',name='TMS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GNDADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='C13',name='VCCADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C9',name='VCCBATT_0',func=pin_types.PWRIN,unit=6),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C18', 'G13', 'N19', 'A18', 'L17', 'T18', 'V13', 'W15', 'D17', 'G17', 'B15', 'K12', 'L18', 'P17', 'U13', 'V14', 'W16', 'B16', 'D18', 'G18', 'K13', 'M12', 'P18', 'U14', 'V15', 'W17', 'A17', 'B17', 'D19', 'G19', 'A15', 'K17', 'M17', 'P19', 'B18', 'U15', 'V16', 'W18', 'B19', 'E18', 'H17', 'K18', 'M18', 'R17', 'U16', 'V17', 'W19', 'C14', 'E19', 'H19', 'K19', 'M19', 'R18', 'U17', 'C15', 'V19', 'F17', 'J17', 'C16', 'J19', 'L12', 'N17', 'A14', 'R19', 'U18', 'W13', 'C17', 'F18', 'J18', 'L13', 'N18', 'T17', 'U19', 'W14', 'A16']},{'label': 'uB', 'num': 2, 'pin_nums': ['H2', 'K3', 'U1', 'M3', 'P1', 'V2', 'W3', 'K2', 'H3', 'K7', 'W4', 'P3', 'U2', 'M7', 'V3', 'M2', 'J1', 'L1', 'M8', 'R1', 'U3', 'V4', 'W5', 'J2', 'L2', 'N1', 'R2', 'U4', 'V5', 'W6', 'J3', 'L3', 'N2', 'R3', 'U5', 'V6', 'W7', 'J7', 'G2', 'L7', 'T3', 'N3', 'T1', 'U7', 'V1', 'V7', 'W2', 'G3', 'K1', 'M1', 'N7', 'T2', 'U8', 'V8', 'H1', 'N8']},{'label': 'uC', 'num': 3, 'pin_nums': ['A10', 'A4', 'A8', 'B2', 'B6', 'D1', 'A2', 'A6', 'B10', 'B4', 'B8', 'D2']},{'label': 'uD', 'num': 4, 'pin_nums': ['G9', 'B1', 'C5', 'F3', 'E1', 'C7', 'C1', 'E2', 'G7', 'H9']},{'label': 'uE', 'num': 5, 'pin_nums': ['B12', 'V10', 'V11', 'B13', 'V12', 'C11', 'U12', 'C8', 'V9', 'A11', 'W10', 'G12', 'A12', 'U10', 'W11', 'A13', 'U11', 'W8', 'B11', 'W9']},{'label': 'uF', 'num': 6, 'pin_nums': ['H11', 'C2', 'B3', 'F1', 'J12', 'L8', 'N12', 'W1', 'A1', 'B5', 'C3', 'F19', 'N13', 'W12', 'H12', 'J13', 'L9', 'A19', 'B7', 'C4', 'F2', 'H13', 'J8', 'M10', 'N9', 'A3', 'B9', 'C6', 'G1', 'H18', 'J9', 'M11', 'P2', 'A5', 'C10', 'C9', 'G10', 'H7', 'K8', 'M13', 'T19', 'A7', 'C12', 'D3', 'G11', 'H8', 'L10', 'M9', 'U6', 'A9', 'C13', 'E17', 'G8', 'J10', 'L11', 'N10', 'U9', 'V18', 'B14', 'C19', 'E3', 'H10', 'N11', 'J11', 'L19']}] }),
        Part(**{ 'name':'XC7A35T-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A35T-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A35T-CSG324\n\nFPGA', 'pins':[
            Pin(num='A11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A18',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L18',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A8',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A9',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B10',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B8',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B9',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C10',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C11',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C9',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D10',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D9',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='K5',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N4',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_25_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='B1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B3',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C4',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D4',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='D7',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D8',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F5',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F6',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='G6',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='TCK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E11',name='TDI_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E12',name='TMS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E13',name='TDO_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E9',name='CCLK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J10',name='VP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J9',name='VREFN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K10',name='VREFP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K9',name='VN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L10',name='DXP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L9',name='DXN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P10',name='DONE_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P11',name='M2_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P12',name='M0_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P13',name='M1_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P7',name='INIT_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='CFGBVS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='VCCO_0',func=pin_types.PWRIN,unit=4),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='VCCBATT_0',func=pin_types.PWRIN,unit=5),
            Pin(num='F10',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G11',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H10',name='VCCADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H9',name='GNDADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V3',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['F18', 'M17', 'U14', 'M18', 'G13', 'U15', 'A15', 'A14', 'G14', 'N13', 'U16', 'A16', 'N14', 'G15', 'U17', 'A17', 'G16', 'N15', 'U18', 'A18', 'G17', 'N16', 'B11', 'V10', 'B12', 'G18', 'N17', 'V11', 'B13', 'H14', 'P14', 'V12', 'B14', 'B16', 'H15', 'P15', 'V14', 'B17', 'H16', 'P16', 'V15', 'B18', 'H17', 'P17', 'V16', 'C12', 'H18', 'P18', 'V17', 'C13', 'J13', 'R10', 'V18', 'C14', 'J14', 'R11', 'C15', 'J15', 'R12', 'A11', 'C16', 'J17', 'R13', 'C17', 'J18', 'R15', 'D12', 'K13', 'R16', 'D13', 'K14', 'R17', 'D14', 'K15', 'R18', 'D15', 'K16', 'T10', 'M16', 'D16', 'K17', 'T11', 'D17', 'K18', 'T12', 'D18', 'L13', 'T13', 'E15', 'L14', 'T14', 'E16', 'L15', 'T15', 'E17', 'L16', 'T16', 'E18', 'L17', 'T18', 'F13', 'L18', 'T9', 'F14', 'M13', 'U11', 'A13', 'F15', 'M14', 'U12', 'F16', 'U13']},{'label': 'uB', 'num': 2, 'pin_nums': ['N2', 'A9', 'D9', 'P5', 'L5', 'R8', 'U9', 'V9', 'B10', 'K3', 'L6', 'N3', 'P6', 'T1', 'U2', 'V1', 'B8', 'K4', 'M1', 'N4', 'R1', 'T2', 'U3', 'V2', 'B9', 'K5', 'M2', 'N5', 'R2', 'T3', 'U4', 'V4', 'C10', 'K6', 'M3', 'N6', 'R3', 'T4', 'U5', 'V5', 'C11', 'L1', 'M4', 'P2', 'R5', 'T5', 'U6', 'V6', 'A10', 'C9', 'L3', 'M6', 'P3', 'R6', 'T6', 'U1', 'U7', 'V7', 'A8', 'D10', 'L4', 'N1', 'P4', 'R7', 'T8', 'U8', 'V8']},{'label': 'uC', 'num': 3, 'pin_nums': ['B2', 'D6', 'G2', 'C4', 'E7', 'H5', 'K2', 'A1', 'C5', 'D7', 'F1', 'B3', 'G3', 'H6', 'D8', 'A3', 'B4', 'C6', 'F2', 'G4', 'J1', 'H4', 'A4', 'B6', 'C7', 'E1', 'F3', 'G5', 'J2', 'A5', 'B7', 'D2', 'E2', 'F4', 'G6', 'J3', 'A6', 'C1', 'D3', 'E3', 'F5', 'H1', 'J4', 'A7', 'C2', 'D4', 'E5', 'C3', 'F6', 'H2', 'J5', 'D5', 'B1', 'E6', 'G1', 'K1']},{'label': 'uD', 'num': 4, 'pin_nums': ['J9', 'P13', 'P7', 'K10', 'E10', 'K9', 'P8', 'E11', 'L10', 'P9', 'E12', 'L9', 'R9', 'E13', 'P10', 'E9', 'P11', 'J10', 'P12']},{'label': 'uE', 'num': 5, 'pin_nums': ['L11', 'G11', 'B5', 'F10', 'H13', 'J6', 'L12', 'M5', 'N18', 'N7', 'T7', 'U10', 'C18', 'F11', 'G12', 'H3', 'L2', 'J7', 'M7', 'N8', 'V13', 'C8', 'F12', 'G7', 'H7', 'J8', 'L7', 'M8', 'N9', 'V3', 'D1', 'F17', 'G8', 'H8', 'K11', 'L8', 'M9', 'P1', 'D11', 'F7', 'G9', 'H9', 'K12', 'M10', 'N10', 'R14', 'A12', 'E14', 'F8', 'H10', 'J11', 'K7', 'M11', 'N11', 'R4', 'A2', 'E4', 'F9', 'H11', 'J12', 'K8', 'M12', 'N12', 'T17', 'B15', 'E8', 'G10', 'H12', 'M15', 'J16']}] }),
        Part(**{ 'name':'XC7A35T-CSG325', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A35T-CSG325'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A35T-CSG325\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='E15',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H16',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M4',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R5',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_25_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='A6',name='MGTRREF_216',func=pin_types.PWRIN,unit=4),
            Pin(num='B4',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='C1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='E1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='F3',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='F5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='E12',name='CFGBVS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='CCLK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='DONE_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='M2_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='TCK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K10',name='VP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='VREFN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='VREFP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='VN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='DXP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='DXN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='P10',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R10',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='R11',name='M1_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R12',name='M0_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='TMS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='INIT_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T8',name='TDO_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='TDI_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='VCCBATT_0',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G10',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GNDADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G18', 'C13', 'H14', 'R14', 'C14', 'H15', 'R15', 'C16', 'H16', 'R16', 'C17', 'H17', 'R17', 'C18', 'H18', 'R18', 'C8', 'J14', 'T11', 'C9', 'J15', 'T12', 'D10', 'J16', 'T13', 'D11', 'J18', 'T14', 'D13', 'K15', 'T15', 'D14', 'K16', 'T17', 'D15', 'K17', 'T18', 'A14', 'D16', 'K18', 'U10', 'D17', 'L14', 'U11', 'D18', 'L15', 'U12', 'D8', 'L16', 'U14', 'D9', 'L17', 'U15', 'A12', 'A13', 'E13', 'L18', 'U16', 'A15', 'E14', 'M14', 'U17', 'A16', 'E15', 'M15', 'A17', 'U18', 'A9', 'E16', 'M16', 'U8', 'B10', 'E17', 'M17', 'B11', 'U9', 'B12', 'E18', 'N14', 'V11', 'A10', 'B13', 'F14', 'N16', 'V12', 'B14', 'F15', 'N17', 'V13', 'B15', 'F17', 'N18', 'V14', 'B16', 'F18', 'P14', 'V15', 'B17', 'G14', 'P15', 'V16', 'B9', 'G15', 'P16', 'V17', 'C10', 'G16', 'P17', 'R13', 'V9', 'C11', 'G17', 'P18', 'C12']},{'label': 'uB', 'num': 2, 'pin_nums': ['M5', 'L3', 'P3', 'J5', 'R4', 'T5', 'V2', 'T4', 'L4', 'M6', 'J6', 'P4', 'V3', 'T7', 'R5', 'L5', 'N1', 'P5', 'K1', 'R6', 'U1', 'V4', 'L2', 'M4', 'K2', 'L6', 'N2', 'P1', 'P6', 'R3', 'R7', 'U2', 'V5', 'M1', 'K3', 'N3', 'P7', 'T1', 'U4', 'V6', 'K5', 'M2', 'N4', 'R1', 'T2', 'U5', 'V7', 'M3', 'K6', 'N6', 'R2', 'T3', 'U6', 'V8', 'J4', 'U7']},{'label': 'uC', 'num': 3, 'pin_nums': ['A3', 'G3', 'D1', 'A4', 'D2', 'G4', 'B1', 'D5', 'H1', 'B2', 'D6', 'H2', 'B5', 'E3', 'B6', 'E4', 'C3', 'F1', 'C4', 'F2']},{'label': 'uD', 'num': 4, 'pin_nums': ['A2', 'C5', 'E5', 'F5', 'B4', 'A6', 'C1', 'E1', 'F3', 'G2']},{'label': 'uE', 'num': 5, 'pin_nums': ['E8', 'M10', 'T8', 'F12', 'T9', 'M9', 'L9', 'F13', 'P10', 'F8', 'R10', 'K10', 'R11', 'K9', 'R12', 'E10', 'L10', 'R8', 'E12', 'T10']},{'label': 'uF', 'num': 6, 'pin_nums': ['E7', 'J11', 'N15', 'E9', 'N5', 'J12', 'F10', 'J13', 'N7', 'F11', 'N8', 'J17', 'F16', 'J2', 'N9', 'F4', 'J3', 'P11', 'F6', 'J7', 'P12', 'F7', 'P13', 'J8', 'F9', 'J9', 'P2', 'G1', 'K11', 'P8', 'G10', 'K12', 'P9', 'A1', 'G11', 'K13', 'R9', 'A11', 'G12', 'K14', 'T16', 'A18', 'G13', 'K4', 'T6', 'A5', 'G5', 'K7', 'U13', 'A7', 'G6', 'K8', 'U3', 'A8', 'G7', 'L1', 'V1', 'B18', 'G8', 'L11', 'V10', 'B3', 'G9', 'L12', 'V18', 'B7', 'H10', 'L13', 'B8', 'H11', 'L7', 'C15', 'H12', 'L8', 'C2', 'H13', 'M11', 'C6', 'H3', 'M12', 'C7', 'H4', 'M13', 'D12', 'H5', 'M18', 'D3', 'H6', 'M7', 'D4', 'H7', 'M8', 'D7', 'H8', 'N10', 'E11', 'H9', 'N11', 'E2', 'J1', 'N12', 'E6', 'J10', 'N13']}] }),
        Part(**{ 'name':'XC7A35T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A35T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A35T-FGG484\n\nFPGA', 'pins':[
            Pin(num='AA17',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='W17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y18',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='Y21',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A16',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='A18',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A20',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A21',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B13',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B14',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B15',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B16',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B20',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B21',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B22',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C13',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C14',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C18',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C20',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C21',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='C22',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D17',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='D19',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D21',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D22',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='E16',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E19',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E21',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E22',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO_0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F21',name='IO_25_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='G13',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H17',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J14',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J22',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K19',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K21',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='L18',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='N22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA7',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AA8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AB5',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J1',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J4',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='M5',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='N2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='T3',name='IO_0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T6',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U7',name='IO_25_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='V7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W3',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W5',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W9',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y9',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B7',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C4',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='D10',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='D6',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='MGTRREF_216',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='R13',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='T12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='T13',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U10',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U12',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U13',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='CFGBVS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='V12',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E12',name='VCCBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K10',name='VCCADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K9',name='GNDADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AA19', 'AB22', 'P16', 'P17', 'R16', 'T20', 'U22', 'W17', 'Y20', 'R15', 'M14', 'U21', 'AA20', 'W13', 'P18', 'R17', 'T21', 'V16', 'N13', 'W19', 'Y19', 'Y21', 'N14', 'P19', 'R18', 'T22', 'AA18', 'V17', 'W20', 'Y22', 'N15', 'P20', 'R19', 'U17', 'V18', 'W21', 'AA21', 'N17', 'P21', 'R21', 'U18', 'V19', 'W22', 'P14', 'AB14', 'P22', 'R22', 'U19', 'V20', 'Y10', 'AB18', 'P15', 'R14', 'T18', 'U20', 'V22', 'Y18', 'AB20', 'AA17', 'T19', 'AB21']},{'label': 'uB', 'num': 2, 'pin_nums': ['E13', 'M15', 'E14', 'A18', 'H19', 'M16', 'A19', 'E15', 'H20', 'M17', 'A20', 'E16', 'H22', 'M18', 'A21', 'E17', 'J13', 'M20', 'B13', 'E18', 'J14', 'M21', 'B14', 'E19', 'J15', 'M22', 'B15', 'E21', 'J16', 'N18', 'B16', 'E22', 'J17', 'N19', 'B17', 'F13', 'J19', 'N20', 'B18', 'F14', 'J20', 'N21', 'B20', 'F15', 'J21', 'N22', 'B21', 'F16', 'J22', 'B22', 'F18', 'K13', 'C13', 'F19', 'K14', 'C14', 'F20', 'K16', 'C15', 'F21', 'K17', 'C17', 'F22', 'K18', 'C18', 'G13', 'K19', 'C19', 'G15', 'K20', 'C20', 'G16', 'K21', 'C21', 'G17', 'K22', 'C22', 'G18', 'L13', 'D14', 'G19', 'L14', 'D15', 'G20', 'L15', 'D16', 'G21', 'L16', 'D17', 'G22', 'L17', 'D18', 'H13', 'L18', 'A13', 'D19', 'H14', 'L19', 'A14', 'D20', 'H15', 'L20', 'A15', 'D21', 'H16', 'H18', 'L21', 'A16', 'D22', 'H17', 'M13', 'A17']},{'label': 'uC', 'num': 3, 'pin_nums': ['L5', 'D1', 'U3', 'L6', 'D2', 'U5', 'E1', 'M1', 'U6', 'M2', 'E2', 'U7', 'E3', 'M3', 'V2', 'M4', 'F1', 'V3', 'F2', 'M5', 'V4', 'F3', 'M6', 'V5', 'F4', 'N1', 'V6', 'G1', 'N2', 'V7', 'G2', 'N3', 'V8', 'G3', 'N4', 'V9', 'A1', 'G4', 'N5', 'W1', 'AA1', 'H2', 'P1', 'W2', 'AA3', 'H3', 'P2', 'W3', 'AA4', 'H4', 'P4', 'W4', 'AA5', 'H5', 'P5', 'W5', 'AA6', 'H6', 'P6', 'W6', 'AA7', 'J1', 'R1', 'W7', 'AA8', 'J2', 'R2', 'W9', 'AB1', 'J3', 'R3', 'Y1', 'AB2', 'J4', 'R4', 'Y2', 'AB3', 'J5', 'R5', 'Y3', 'AB4', 'J6', 'R6', 'Y4', 'AB5', 'K1', 'T1', 'Y6', 'AB6', 'K2', 'T2', 'Y7', 'L4', 'AB7', 'K3', 'T3', 'Y8', 'AB8', 'K4', 'T4', 'Y9', 'B1', 'K6', 'T5', 'B2', 'L1', 'T6', 'C1', 'L3', 'U1', 'C2', 'U2']},{'label': 'uD', 'num': 4, 'pin_nums': ['F6', 'A8', 'C9', 'B10', 'D11', 'B4', 'D5', 'B6', 'D7', 'B8', 'D9', 'A10', 'C11', 'E10', 'A4', 'C5', 'E6', 'A6', 'C7', 'F10']},{'label': 'uE', 'num': 5, 'pin_nums': ['B9', 'D6', 'F7', 'C8', 'B5', 'F9', 'B11', 'C4', 'B7', 'E8', 'F8', 'D10']},{'label': 'uF', 'num': 6, 'pin_nums': ['U9', 'R13', 'T12', 'V12', 'L12', 'L9', 'T13', 'M10', 'U10', 'M9', 'U11', 'N10', 'U12', 'F12', 'L10', 'N12', 'U13', 'G11', 'N9', 'U8']},{'label': 'uG', 'num': 7, 'pin_nums': ['B19', 'N16', 'H11', 'Y15', 'B3', 'N6', 'H12', 'Y5', 'C10', 'H21', 'N7', 'C12', 'N8', 'H7', 'C16', 'H8', 'P10', 'B12', 'C3', 'H9', 'P11', 'C6', 'J10', 'P12', 'D12', 'P13', 'J11', 'N11', 'D13', 'J12', 'P3', 'D3', 'J18', 'P7', 'D4', 'J7', 'P8', 'D8', 'J8', 'P9', 'E11', 'J9', 'R10', 'E12', 'K10', 'R11', 'E20', 'K11', 'R12', 'E4', 'R20', 'K12', 'E5', 'K15', 'R7', 'E7', 'K5', 'R8', 'A11', 'E9', 'K7', 'R9', 'A12', 'F11', 'K8', 'T10', 'A2', 'F17', 'K9', 'T11', 'A22', 'F5', 'L11', 'T17', 'A3', 'G10', 'L2', 'T7', 'G12', 'A5', 'L22', 'T8', 'A7', 'G14', 'L7', 'T9', 'A9', 'G5', 'L8', 'U14', 'AA12', 'G6', 'M11', 'U4', 'AA2', 'G7', 'M12', 'V1', 'AA22', 'G8', 'M19', 'V11', 'AB19', 'G9', 'M7', 'V21', 'AB9', 'H1', 'M8', 'W18', 'H10', 'W8']}] }),
        Part(**{ 'name':'XC7A35T-FTG256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A35T-FTG256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A35T-FTG256\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='E15',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H16',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A5',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A6',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='A7',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='B4',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B5',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B6',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B7',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C6',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C7',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D6',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='F2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_25_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M4',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='CFGBVS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='CCLK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H10',name='DONE_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='VREFN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='VP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J7',name='VN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='VREFP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='INIT_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='DXN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='DXP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='VCCO_0',func=pin_types.PWRIN,unit=3),
            Pin(num='L7',name='TCK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M10',name='M1_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M11',name='M2_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='TMS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M9',name='M0_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='TDI_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N8',name='TDO_0',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='VCCBATT_0',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GNDADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C11', 'P10', 'H13', 'C12', 'P11', 'H14', 'C13', 'H15', 'P13', 'C14', 'P14', 'H16', 'C16', 'J12', 'P15', 'C8', 'P16', 'J13', 'C9', 'J14', 'P6', 'D10', 'P7', 'J15', 'D11', 'J16', 'P8', 'D13', 'K12', 'P9', 'D14', 'K13', 'R10', 'D15', 'K15', 'R11', 'D16', 'K16', 'R12', 'D8', 'L12', 'R13', 'H12', 'D9', 'L13', 'R14', 'E11', 'L14', 'R15', 'E12', 'L15', 'R16', 'A12', 'E13', 'L16', 'R5', 'E14', 'M12', 'R6', 'E15', 'M13', 'R7', 'A14', 'E16', 'M14', 'R8', 'A13', 'F12', 'A15', 'M15', 'T10', 'F13', 'A16', 'M16', 'T11', 'A8', 'F14', 'M6', 'T12', 'A9', 'F15', 'N10', 'T13', 'B10', 'B11', 'G11', 'N11', 'T14', 'B12', 'G12', 'N12', 'T15', 'B13', 'G14', 'A10', 'B14', 'N13', 'T5', 'B15', 'G15', 'N14', 'T7', 'B16', 'G16', 'N16', 'T8', 'B9', 'H11', 'N6', 'T9', 'C10', 'N9']},{'label': 'uB', 'num': 2, 'pin_nums': ['F2', 'A2', 'N2', 'F3', 'A3', 'N3', 'A4', 'F4', 'N4', 'A5', 'F5', 'P1', 'A6', 'G1', 'P3', 'A7', 'G2', 'P4', 'B1', 'G4', 'P5', 'B2', 'G5', 'R1', 'B3', 'H1', 'R2', 'B4', 'H2', 'R3', 'B5', 'H3', 'R4', 'B6', 'H4', 'T1', 'B7', 'H5', 'T2', 'C1', 'J1', 'T3', 'C2', 'J2', 'T4', 'C3', 'J3', 'C4', 'J4', 'C6', 'J5', 'C7', 'K1', 'D1', 'K2', 'D3', 'K3', 'D4', 'K5', 'D5', 'L2', 'D6', 'L3', 'D7', 'L4', 'E1', 'L5', 'E2', 'M1', 'E3', 'M2', 'E4', 'M3', 'E5', 'M4', 'E6', 'M5', 'F1', 'N1']},{'label': 'uC', 'num': 3, 'pin_nums': ['N7', 'E8', 'K8', 'H10', 'N8', 'L6', 'H7', 'L7', 'H8', 'L9', 'J7', 'M10', 'E7', 'M11', 'K7', 'J8', 'K10', 'M7', 'M9']},{'label': 'uD', 'num': 4, 'pin_nums': ['D12', 'G8', 'F7', 'T6', 'L8', 'D2', 'F8', 'G9', 'K14', 'M8', 'E10', 'F9', 'H6', 'K4', 'N15', 'A1', 'E9', 'G10', 'H9', 'K6', 'N5', 'A11', 'F10', 'G13', 'J10', 'K9', 'P12', 'B8', 'F11', 'G3', 'J11', 'L1', 'P2', 'C15', 'F16', 'G6', 'J6', 'K11', 'L10', 'R9', 'C5', 'F6', 'G7', 'J9', 'L11', 'T16']}] }),
        Part(**{ 'name':'XC7A50T-CPG236', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A50T-CPG236'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A50T-CPG236\n\nFPGA', 'pins':[
            Pin(num='A14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='F18',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='VCCO_16',func=pin_types.PWRIN,unit=1),
            Pin(num='G17',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J19',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='K17',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N19',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R18',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G3',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='J1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='K1',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='K2',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='L1',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='M8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N1',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='P1',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R2',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A2',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A8',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B8',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C1',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C7',name='MGTRREF_216',func=pin_types.PWRIN,unit=4),
            Pin(num='E1',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='E2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='F3',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='DXP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A12',name='VP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A13',name='VREFN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B11',name='DXN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B12',name='VREFP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='VN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='C11',name='CCLK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='C8',name='TCK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='G12',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='M2_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U11',name='INIT_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='U12',name='DONE_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V10',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V11',name='CFGBVS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V12',name='M0_0',func=pin_types.BIDIR,unit=5),
            Pin(num='V9',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='W10',name='TDI_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W11',name='M1_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W8',name='TDO_0',func=pin_types.BIDIR,unit=5),
            Pin(num='W9',name='TMS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C12',name='GNDADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='C13',name='VCCADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='C19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C9',name='VCCBATT_0',func=pin_types.PWRIN,unit=6),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T19',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B16', 'P17', 'W16', 'U13', 'V14', 'A14', 'B17', 'D18', 'G18', 'K13', 'M12', 'P18', 'U14', 'V15', 'W17', 'B18', 'G19', 'K17', 'D19', 'B19', 'M17', 'P19', 'U15', 'A17', 'V16', 'W18', 'C14', 'E18', 'H17', 'K18', 'M18', 'R17', 'U16', 'V17', 'W19', 'C15', 'E19', 'H19', 'K19', 'M19', 'R18', 'U17', 'V19', 'D17', 'C16', 'F17', 'J17', 'K12', 'L12', 'L18', 'N17', 'R19', 'A15', 'U18', 'W13', 'A16', 'C17', 'F18', 'J18', 'L13', 'N18', 'T17', 'U19', 'W14', 'A18', 'C18', 'G13', 'J19', 'L17', 'N19', 'T18', 'V13', 'W15', 'B15', 'G17']},{'label': 'uB', 'num': 2, 'pin_nums': ['K7', 'H3', 'M7', 'U2', 'P3', 'V3', 'W4', 'J1', 'L1', 'M8', 'U3', 'V4', 'W5', 'R1', 'J2', 'N1', 'L2', 'R2', 'U4', 'V5', 'W6', 'J3', 'L3', 'N2', 'R3', 'U5', 'V6', 'W7', 'U1', 'G2', 'J7', 'L7', 'N3', 'T1', 'U7', 'V7', 'W3', 'G3', 'K1', 'M1', 'N7', 'T2', 'U8', 'V8', 'H1', 'K2', 'M2', 'N8', 'T3', 'V1', 'W2', 'H2', 'K3', 'M3', 'P1', 'V2']},{'label': 'uC', 'num': 3, 'pin_nums': ['A2', 'A6', 'B10', 'B4', 'B8', 'A4', 'A8', 'A10', 'B2', 'B6', 'D1', 'D2']},{'label': 'uD', 'num': 4, 'pin_nums': ['C1', 'C7', 'E2', 'G7', 'H9', 'E1', 'B1', 'C5', 'F3', 'G9']},{'label': 'uE', 'num': 5, 'pin_nums': ['B13', 'V11', 'C11', 'V12', 'C8', 'V9', 'A11', 'G12', 'W10', 'A12', 'U10', 'W11', 'A13', 'U11', 'W8', 'B11', 'U12', 'W9', 'B12', 'V10']},{'label': 'uF', 'num': 6, 'pin_nums': ['F19', 'A1', 'C3', 'H12', 'B5', 'J13', 'L9', 'W12', 'A19', 'B7', 'C4', 'F2', 'H13', 'J8', 'M10', 'N9', 'A3', 'B9', 'C6', 'G1', 'H18', 'J9', 'M11', 'P2', 'A5', 'C10', 'C9', 'G10', 'H7', 'K8', 'M13', 'T19', 'A7', 'C12', 'D3', 'G11', 'H8', 'L10', 'M9', 'U6', 'A9', 'C13', 'E17', 'G8', 'J10', 'L11', 'N10', 'U9', 'B14', 'C19', 'E3', 'H10', 'J11', 'L19', 'N11', 'N13', 'V18', 'B3', 'C2', 'F1', 'H11', 'J12', 'L8', 'N12', 'W1']}] }),
        Part(**{ 'name':'XC7A50T-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A50T-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A50T-CSG324\n\nFPGA', 'pins':[
            Pin(num='A11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A18',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L18',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A8',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A9',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B10',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B8',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B9',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C10',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C11',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C9',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D10',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D9',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='K5',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N4',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_25_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='B1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B3',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C4',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D4',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='D7',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D8',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F5',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F6',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='G6',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='TCK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E11',name='TDI_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E12',name='TMS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E13',name='TDO_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E9',name='CCLK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J10',name='VP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J9',name='VREFN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K10',name='VREFP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K9',name='VN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L10',name='DXP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L9',name='DXN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P10',name='DONE_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P11',name='M2_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P12',name='M0_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P13',name='M1_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P7',name='INIT_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='CFGBVS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='VCCO_0',func=pin_types.PWRIN,unit=4),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='VCCBATT_0',func=pin_types.PWRIN,unit=5),
            Pin(num='F10',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G11',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H10',name='VCCADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H9',name='GNDADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V3',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B17', 'P16', 'V15', 'B18', 'H17', 'P17', 'V16', 'C12', 'H18', 'P18', 'V17', 'C13', 'J13', 'R10', 'V18', 'C14', 'J14', 'R11', 'C15', 'J15', 'R12', 'A11', 'C16', 'J17', 'R13', 'C17', 'J18', 'R15', 'D12', 'K13', 'R16', 'D13', 'K14', 'R17', 'D14', 'K15', 'R18', 'D15', 'K16', 'T10', 'D16', 'K17', 'T11', 'D17', 'K18', 'T12', 'D18', 'L13', 'T13', 'E15', 'L14', 'T14', 'E16', 'L15', 'T15', 'E17', 'L16', 'T16', 'E18', 'L17', 'T18', 'F13', 'L18', 'T9', 'F14', 'M13', 'U11', 'A13', 'F15', 'M14', 'U12', 'F16', 'M16', 'U13', 'F18', 'M17', 'U14', 'G13', 'M18', 'U15', 'A15', 'G14', 'A14', 'N13', 'U16', 'A16', 'G15', 'N14', 'U17', 'A17', 'G16', 'N15', 'U18', 'A18', 'G17', 'N16', 'V10', 'B11', 'G18', 'B12', 'N17', 'V11', 'B13', 'H14', 'H16', 'P14', 'V12', 'B14', 'H15', 'B16', 'P15', 'V14']},{'label': 'uB', 'num': 2, 'pin_nums': ['P6', 'T1', 'K4', 'B8', 'M1', 'N4', 'R1', 'T2', 'U2', 'U3', 'V1', 'V2', 'N5', 'R2', 'T3', 'B9', 'K5', 'M2', 'U4', 'V4', 'C10', 'K6', 'M3', 'N6', 'R3', 'T4', 'U5', 'V5', 'C11', 'L1', 'M4', 'P2', 'R5', 'T5', 'U6', 'V6', 'L3', 'A10', 'C9', 'M6', 'P3', 'R6', 'T6', 'U7', 'V7', 'D10', 'L4', 'A8', 'N1', 'P4', 'R7', 'T8', 'U8', 'V8', 'L5', 'A9', 'D9', 'N2', 'P5', 'L6', 'R8', 'U1', 'U9', 'V9', 'B10', 'K3', 'N3']},{'label': 'uC', 'num': 3, 'pin_nums': ['B3', 'D7', 'A1', 'C5', 'F1', 'G3', 'H6', 'A3', 'B4', 'C6', 'D8', 'F2', 'G4', 'J1', 'A4', 'B6', 'C7', 'E1', 'F3', 'G5', 'J2', 'A5', 'B7', 'D2', 'E2', 'F4', 'G6', 'J3', 'A6', 'C1', 'D3', 'E3', 'F5', 'H1', 'J4', 'A7', 'C2', 'D4', 'E5', 'F6', 'H2', 'J5', 'B1', 'C3', 'D5', 'E6', 'G1', 'H4', 'K1', 'B2', 'C4', 'D6', 'E7', 'G2', 'H5', 'K2']},{'label': 'uD', 'num': 4, 'pin_nums': ['E10', 'P8', 'K9', 'P7', 'E11', 'L10', 'P9', 'R9', 'E12', 'L9', 'E13', 'P10', 'E9', 'P11', 'J10', 'P12', 'J9', 'P13', 'K10']},{'label': 'uE', 'num': 5, 'pin_nums': ['J7', 'C18', 'G12', 'H3', 'F11', 'M7', 'N8', 'V13', 'C8', 'F12', 'G7', 'H7', 'J8', 'L7', 'M8', 'N9', 'V3', 'D1', 'F17', 'G8', 'H8', 'K11', 'L8', 'M9', 'P1', 'D11', 'F7', 'G9', 'H9', 'K12', 'M10', 'N10', 'R14', 'A12', 'E14', 'F8', 'H10', 'J11', 'K7', 'M11', 'N11', 'R4', 'A2', 'E4', 'F9', 'H11', 'J12', 'K8', 'M12', 'N12', 'T17', 'B15', 'E8', 'G10', 'H12', 'J16', 'L11', 'L2', 'M15', 'N18', 'T7', 'B5', 'F10', 'G11', 'H13', 'J6', 'L12', 'M5', 'N7', 'U10']}] }),
        Part(**{ 'name':'XC7A50T-CSG325', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A50T-CSG325'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A50T-CSG325\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='E15',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H16',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P18',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='J6',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M4',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R5',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_25_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B5',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='C4',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='E4',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=3),
            Pin(num='A2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='A6',name='MGTRREF_216',func=pin_types.PWRIN,unit=4),
            Pin(num='B4',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='C1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='E1',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='E5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='F3',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='F5',name='MGTAVCC',func=pin_types.PWRIN,unit=4),
            Pin(num='G2',name='MGTAVTT',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='E12',name='CFGBVS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='E8',name='CCLK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F12',name='DONE_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='M2_0',func=pin_types.BIDIR,unit=5),
            Pin(num='F8',name='TCK_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K10',name='VP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='K9',name='VREFN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L10',name='VREFP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='L9',name='VN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M10',name='DXP_0',func=pin_types.BIDIR,unit=5),
            Pin(num='M9',name='DXN_0',func=pin_types.BIDIR,unit=5),
            Pin(num='P10',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R10',name='VCCO_0',func=pin_types.PWRIN,unit=5),
            Pin(num='R11',name='M1_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R12',name='M0_0',func=pin_types.BIDIR,unit=5),
            Pin(num='R8',name='TMS_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T10',name='INIT_B_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T8',name='TDO_0',func=pin_types.BIDIR,unit=5),
            Pin(num='T9',name='TDI_0',func=pin_types.BIDIR,unit=5),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E11',name='VCCBATT_0',func=pin_types.PWRIN,unit=6),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G10',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='G8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H11',name='VCCBRAM',func=pin_types.PWRIN,unit=6),
            Pin(num='H12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J10',name='VCCADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='J9',name='GNDADC_0',func=pin_types.PWRIN,unit=6),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='K8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='M7',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N7',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='N8',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P13',name='VCCAUX',func=pin_types.PWRIN,unit=6),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P8',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=6),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U13',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='U3',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=6),
            Pin(num='V18',name='GND',func=pin_types.PWRIN,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['K15', 'D13', 'T15', 'D14', 'K16', 'T17', 'D15', 'K17', 'T18', 'A14', 'K18', 'D16', 'U10', 'D17', 'L14', 'U11', 'L15', 'D18', 'U12', 'D8', 'L16', 'U14', 'L17', 'D9', 'U15', 'A12', 'A13', 'E13', 'L18', 'U16', 'A15', 'E14', 'M14', 'U17', 'A16', 'E15', 'M15', 'A17', 'U18', 'A9', 'E16', 'M16', 'U8', 'B10', 'E17', 'M17', 'B11', 'U9', 'N14', 'B12', 'E18', 'V11', 'A10', 'B13', 'F14', 'N16', 'V12', 'B14', 'F15', 'N17', 'V13', 'B15', 'F17', 'N18', 'V14', 'B16', 'F18', 'P14', 'V15', 'B17', 'G14', 'P15', 'V16', 'B9', 'G15', 'P16', 'V17', 'C10', 'G16', 'P17', 'V9', 'C11', 'G17', 'P18', 'J18', 'C12', 'G18', 'R13', 'C13', 'H14', 'R14', 'C14', 'H15', 'R15', 'C16', 'H16', 'R16', 'C17', 'H17', 'R17', 'C18', 'H18', 'R18', 'C8', 'J14', 'T11', 'C9', 'J15', 'T12', 'D10', 'J16', 'T13', 'D11', 'T14']},{'label': 'uB', 'num': 2, 'pin_nums': ['P4', 'L4', 'R5', 'J6', 'M6', 'T7', 'V3', 'K1', 'L5', 'N1', 'P5', 'V4', 'R6', 'U1', 'R7', 'K2', 'L6', 'N2', 'P6', 'U2', 'V5', 'K3', 'M1', 'N3', 'P7', 'T1', 'U4', 'V6', 'K5', 'M2', 'N4', 'R1', 'T2', 'U5', 'V7', 'K6', 'M3', 'N6', 'R2', 'T3', 'U6', 'V8', 'J4', 'L2', 'M4', 'P1', 'R3', 'T4', 'U7', 'J5', 'L3', 'M5', 'P3', 'V2', 'R4', 'T5']},{'label': 'uC', 'num': 3, 'pin_nums': ['G4', 'B1', 'H1', 'D5', 'H2', 'B2', 'D6', 'B5', 'E3', 'B6', 'E4', 'C3', 'F1', 'F2', 'C4', 'A3', 'D1', 'G3', 'A4', 'D2']},{'label': 'uD', 'num': 4, 'pin_nums': ['A6', 'E1', 'F3', 'G2', 'C1', 'A2', 'B4', 'C5', 'E5', 'F5']},{'label': 'uE', 'num': 5, 'pin_nums': ['F12', 'M9', 'T9', 'F13', 'P10', 'F8', 'R10', 'K10', 'R11', 'K9', 'R12', 'E10', 'L10', 'R8', 'E12', 'L9', 'T10', 'E8', 'M10', 'T8']},{'label': 'uF', 'num': 6, 'pin_nums': ['G1', 'P8', 'G10', 'P9', 'K12', 'A1', 'G11', 'K13', 'R9', 'A11', 'G12', 'K14', 'T16', 'A18', 'G13', 'K4', 'T6', 'A5', 'G5', 'K7', 'U13', 'A7', 'G6', 'K8', 'U3', 'A8', 'G7', 'L1', 'V1', 'B18', 'G8', 'L11', 'V10', 'B3', 'G9', 'L12', 'V18', 'B7', 'H10', 'L13', 'B8', 'H11', 'L7', 'C15', 'H12', 'L8', 'C2', 'H13', 'M11', 'C6', 'H3', 'M12', 'C7', 'H4', 'M13', 'D12', 'H5', 'M18', 'D3', 'H6', 'M7', 'D4', 'H7', 'M8', 'D7', 'H8', 'N10', 'E11', 'H9', 'N11', 'E2', 'J1', 'N12', 'E6', 'J10', 'N13', 'E7', 'J11', 'N15', 'E9', 'J12', 'N5', 'F10', 'J13', 'N7', 'F11', 'J17', 'N8', 'F16', 'J2', 'N9', 'F4', 'J3', 'P11', 'F6', 'J7', 'P12', 'F7', 'J8', 'K11', 'P13', 'F9', 'J9', 'P2']}] }),
        Part(**{ 'name':'XC7A50T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A50T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A50T-FGG484\n\nFPGA', 'pins':[
            Pin(num='AA17',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AB18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='W17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y18',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='Y21',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A16',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='A18',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A20',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A21',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B13',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B14',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B15',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B16',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B20',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B21',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B22',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C13',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C14',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C18',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C20',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C21',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='C22',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D17',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='D19',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D21',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D22',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='E16',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E19',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E21',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E22',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO_0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F21',name='IO_25_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='G13',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H17',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J14',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J22',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K19',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K21',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='L18',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='N22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA7',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AA8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AB5',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J1',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J4',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='M5',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='N2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='T3',name='IO_0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T6',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U7',name='IO_25_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='V7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W3',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W5',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W9',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y9',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B7',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C4',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='D10',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='D6',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='MGTRREF_216',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='R13',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='T12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='T13',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U10',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U12',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U13',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='CFGBVS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='V12',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E12',name='VCCBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K10',name='VCCADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K9',name='GNDADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['T21', 'R17', 'AA17', 'P18', 'N13', 'V16', 'W19', 'Y21', 'N14', 'P19', 'R18', 'T22', 'V17', 'W20', 'Y22', 'AA19', 'R19', 'N15', 'P20', 'U17', 'V18', 'W21', 'AA21', 'N17', 'P21', 'R21', 'U18', 'V19', 'W22', 'AB14', 'P14', 'P22', 'R22', 'U19', 'V20', 'Y10', 'AB18', 'P15', 'R14', 'T18', 'U20', 'AA20', 'AB20', 'V22', 'Y18', 'AA18', 'AB21', 'P16', 'R15', 'T19', 'U21', 'W13', 'Y19', 'AB22', 'P17', 'R16', 'T20', 'U22', 'M14', 'W17', 'Y20']},{'label': 'uB', 'num': 2, 'pin_nums': ['N20', 'F14', 'B18', 'N21', 'J20', 'F15', 'B20', 'J21', 'N22', 'B21', 'F16', 'J22', 'F18', 'B22', 'K13', 'C13', 'F19', 'K14', 'C14', 'F20', 'K16', 'C15', 'F21', 'K17', 'C17', 'F22', 'K18', 'C18', 'G13', 'K19', 'C19', 'G15', 'K20', 'C20', 'G16', 'K21', 'C21', 'G17', 'K22', 'C22', 'G18', 'L13', 'D14', 'G19', 'L14', 'D15', 'G20', 'L15', 'D16', 'G21', 'L16', 'D17', 'G22', 'L17', 'D18', 'H13', 'L18', 'F13', 'A13', 'D19', 'H14', 'L19', 'A14', 'D20', 'H15', 'L20', 'A15', 'D21', 'H16', 'L21', 'A16', 'D22', 'H17', 'M13', 'A17', 'E13', 'H18', 'M15', 'A18', 'E14', 'H19', 'M16', 'A19', 'E15', 'H20', 'M17', 'A20', 'E16', 'H22', 'M18', 'A21', 'E17', 'J13', 'M20', 'B13', 'E18', 'J14', 'M21', 'B14', 'E19', 'J15', 'M22', 'B15', 'E21', 'J16', 'N18', 'B16', 'E22', 'J17', 'N19', 'B17', 'J19']},{'label': 'uC', 'num': 3, 'pin_nums': ['G1', 'N2', 'V7', 'N3', 'G2', 'V8', 'G3', 'N4', 'V9', 'A1', 'N5', 'G4', 'W1', 'AA1', 'H2', 'P1', 'W2', 'AA3', 'H3', 'P2', 'W3', 'AA4', 'H4', 'P4', 'W4', 'AA5', 'H5', 'P5', 'W5', 'AA6', 'H6', 'P6', 'W6', 'AA7', 'J1', 'R1', 'W7', 'AA8', 'J2', 'R2', 'W9', 'AB1', 'J3', 'R3', 'Y1', 'AB2', 'J4', 'R4', 'Y2', 'AB3', 'J5', 'R5', 'Y3', 'AB4', 'J6', 'R6', 'Y4', 'AB5', 'K1', 'T1', 'Y6', 'AB6', 'K2', 'T2', 'Y7', 'AB7', 'K3', 'T3', 'Y8', 'AB8', 'K4', 'T4', 'Y9', 'B1', 'K6', 'T5', 'B2', 'L1', 'T6', 'C1', 'L3', 'U1', 'C2', 'L4', 'U2', 'D1', 'L5', 'U3', 'D2', 'L6', 'U5', 'E1', 'M1', 'U6', 'E2', 'M2', 'U7', 'N1', 'E3', 'M3', 'V2', 'F1', 'M4', 'V3', 'F2', 'M5', 'V4', 'F3', 'M6', 'V5', 'F4', 'V6']},{'label': 'uD', 'num': 4, 'pin_nums': ['B10', 'D11', 'D5', 'B4', 'B6', 'D7', 'B8', 'D9', 'A10', 'C11', 'E10', 'A4', 'C5', 'E6', 'A6', 'C7', 'F10', 'A8', 'C9', 'F6']},{'label': 'uE', 'num': 5, 'pin_nums': ['D10', 'E8', 'C4', 'B11', 'B7', 'F8', 'B9', 'B5', 'C8', 'D6', 'F7', 'F9']},{'label': 'uF', 'num': 6, 'pin_nums': ['V12', 'L9', 'T13', 'M10', 'U10', 'M9', 'U11', 'T12', 'N10', 'U12', 'F12', 'N12', 'U13', 'G11', 'N9', 'U8', 'R13', 'L10', 'U9', 'L12']},{'label': 'uG', 'num': 7, 'pin_nums': ['D3', 'J18', 'P7', 'D4', 'P8', 'J7', 'D8', 'J8', 'P9', 'E11', 'R10', 'J9', 'E12', 'K10', 'R11', 'E20', 'K11', 'R12', 'E4', 'K12', 'R20', 'E5', 'R7', 'K15', 'E7', 'K5', 'R8', 'A11', 'E9', 'K7', 'R9', 'A12', 'F11', 'K8', 'T10', 'A2', 'F17', 'K9', 'T11', 'A22', 'F5', 'L11', 'T17', 'A3', 'G10', 'L2', 'T7', 'A5', 'G12', 'L22', 'T8', 'A7', 'G14', 'L7', 'T9', 'A9', 'G5', 'L8', 'U14', 'AA12', 'G6', 'M11', 'U4', 'AA2', 'G7', 'M12', 'V1', 'AA22', 'G8', 'M19', 'V11', 'AB19', 'G9', 'M7', 'V21', 'AB9', 'H1', 'M8', 'W18', 'B12', 'H10', 'N11', 'W8', 'B19', 'H11', 'N16', 'Y15', 'B3', 'H12', 'N6', 'Y5', 'C10', 'H21', 'N7', 'C12', 'H7', 'N8', 'C16', 'H8', 'P10', 'C3', 'H9', 'P11', 'C6', 'J10', 'P12', 'D12', 'J11', 'P13', 'D13', 'J12', 'P3']}] }),
        Part(**{ 'name':'XC7A50T-FTG256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A50T-FTG256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A50T-FTG256\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='E15',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H16',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A5',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A6',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='A7',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='B4',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B5',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B6',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B7',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C6',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C7',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D6',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='F2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_25_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M4',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='CFGBVS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='CCLK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H10',name='DONE_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='VREFN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='VP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J7',name='VN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='VREFP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='INIT_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='DXN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='DXP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='VCCO_0',func=pin_types.PWRIN,unit=3),
            Pin(num='L7',name='TCK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M10',name='M1_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M11',name='M2_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='TMS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M9',name='M0_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='TDI_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N8',name='TDO_0',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='VCCBATT_0',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GNDADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['D13', 'K12', 'P9', 'D14', 'R10', 'K13', 'D15', 'K15', 'R11', 'D16', 'R12', 'K16', 'D8', 'L12', 'R13', 'D9', 'L13', 'R14', 'E11', 'L14', 'R15', 'E12', 'R16', 'L15', 'A12', 'E13', 'L16', 'R5', 'E14', 'M12', 'R6', 'E15', 'M13', 'R7', 'A14', 'E16', 'M14', 'R8', 'A13', 'F12', 'A15', 'M15', 'T10', 'F13', 'A16', 'M16', 'T11', 'A8', 'F14', 'M6', 'T12', 'A9', 'F15', 'N10', 'T13', 'B10', 'B11', 'G11', 'N11', 'T14', 'B12', 'G12', 'N12', 'T15', 'B13', 'G14', 'A10', 'B14', 'N13', 'T5', 'B15', 'G15', 'N14', 'T7', 'B16', 'G16', 'N16', 'T8', 'B9', 'H11', 'N6', 'T9', 'C10', 'H12', 'N9', 'C11', 'H13', 'P10', 'C12', 'H14', 'P11', 'C13', 'H15', 'P13', 'C14', 'H16', 'P14', 'C16', 'J12', 'P15', 'C8', 'J13', 'P16', 'C9', 'J14', 'P6', 'D10', 'J15', 'P7', 'D11', 'J16', 'P8']},{'label': 'uB', 'num': 2, 'pin_nums': ['H2', 'H3', 'B5', 'R4', 'B6', 'H4', 'T1', 'B7', 'H5', 'T2', 'C1', 'J1', 'T3', 'C2', 'J2', 'T4', 'C3', 'J3', 'C4', 'J4', 'C6', 'J5', 'C7', 'K1', 'D1', 'K2', 'D3', 'K3', 'D4', 'K5', 'D5', 'L2', 'D6', 'L3', 'D7', 'L4', 'E1', 'L5', 'E2', 'M1', 'E3', 'M2', 'E4', 'M3', 'E5', 'M4', 'E6', 'M5', 'F1', 'N1', 'A2', 'F2', 'N2', 'A3', 'F3', 'N3', 'A4', 'F4', 'N4', 'A5', 'F5', 'P1', 'A6', 'G1', 'P3', 'A7', 'G2', 'P4', 'B1', 'G4', 'P5', 'B2', 'G5', 'R1', 'R3', 'B3', 'H1', 'R2', 'B4']},{'label': 'uC', 'num': 3, 'pin_nums': ['H10', 'N8', 'L6', 'L7', 'H7', 'K8', 'H8', 'L9', 'N7', 'J7', 'M10', 'J8', 'M11', 'K10', 'M7', 'E7', 'K7', 'M9', 'E8']},{'label': 'uD', 'num': 4, 'pin_nums': ['K4', 'H6', 'E10', 'F9', 'N15', 'G10', 'H9', 'K6', 'E9', 'N5', 'A1', 'A11', 'F10', 'G13', 'J10', 'P12', 'K9', 'F11', 'G3', 'B8', 'J11', 'L1', 'P2', 'D2', 'G9', 'C15', 'F16', 'G6', 'J6', 'K14', 'L10', 'M8', 'R9', 'F6', 'C5', 'G7', 'J9', 'L11', 'T16', 'D12', 'F7', 'G8', 'K11', 'L8', 'T6', 'F8']}] }),
        Part(**{ 'name':'XC7A75T-CSG324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A75T-CSG324'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A75T-CSG324\n\nFPGA', 'pins':[
            Pin(num='A11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A18',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='D17',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='G16',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G18',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='K15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='L18',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P17',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U12',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U13',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U16',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V11',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A8',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A9',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B10',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B8',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B9',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C10',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C11',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C9',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D10',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D9',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='K5',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='N4',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='R1',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T3',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_25_34',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V2',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A3',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A4',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A5',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A6',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='A7',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='B1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B3',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B4',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B6',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B7',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C2',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C4',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C5',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C6',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C7',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D3',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D4',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D5',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='D7',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D8',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E5',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E6',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E7',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F5',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F6',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G5',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='G6',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H1',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J4',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E10',name='TCK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E11',name='TDI_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E12',name='TMS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E13',name='TDO_0',func=pin_types.BIDIR,unit=4),
            Pin(num='E9',name='CCLK_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J10',name='VP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='J9',name='VREFN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K10',name='VREFP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='K9',name='VN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L10',name='DXP_0',func=pin_types.BIDIR,unit=4),
            Pin(num='L9',name='DXN_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P10',name='DONE_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P11',name='M2_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P12',name='M0_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P13',name='M1_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P7',name='INIT_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='CFGBVS_0',func=pin_types.BIDIR,unit=4),
            Pin(num='P9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=4),
            Pin(num='R9',name='VCCO_0',func=pin_types.PWRIN,unit=4),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='D11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='VCCBATT_0',func=pin_types.PWRIN,unit=5),
            Pin(num='F10',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G11',name='VCCBRAM',func=pin_types.PWRIN,unit=5),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H10',name='VCCADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='H13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='H9',name='GNDADC_0',func=pin_types.PWRIN,unit=5),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J16',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J6',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=5),
            Pin(num='M15',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M5',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N11',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N12',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='N9',name='VCCINT',func=pin_types.PWRIN,unit=5),
            Pin(num='P1',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R14',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=5),
            Pin(num='V3',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C15', 'R12', 'J15', 'C16', 'R13', 'J17', 'C17', 'J18', 'R15', 'D12', 'R16', 'K13', 'D13', 'K14', 'R17', 'D14', 'R18', 'K15', 'J14', 'D15', 'K16', 'T10', 'D16', 'T11', 'K17', 'D17', 'K18', 'T12', 'D18', 'L13', 'T13', 'E15', 'L14', 'T14', 'E16', 'L15', 'T15', 'E17', 'L16', 'T16', 'E18', 'L17', 'T18', 'F13', 'L18', 'T9', 'F14', 'M13', 'U11', 'F15', 'M14', 'U12', 'A15', 'F16', 'M16', 'U13', 'F18', 'M17', 'U14', 'G13', 'M18', 'U15', 'A13', 'A14', 'G14', 'N13', 'U16', 'A16', 'G15', 'N14', 'U17', 'A17', 'G16', 'A18', 'N15', 'U18', 'B11', 'G17', 'N16', 'V10', 'B12', 'G18', 'B13', 'N17', 'V11', 'B14', 'H14', 'P14', 'V12', 'B16', 'H15', 'P15', 'V14', 'B17', 'H16', 'P16', 'V15', 'B18', 'H17', 'P17', 'V16', 'C12', 'H18', 'P18', 'V17', 'C13', 'J13', 'R10', 'V18', 'A11', 'C14', 'R11']},{'label': 'uB', 'num': 2, 'pin_nums': ['M6', 'L3', 'P3', 'A10', 'C9', 'R6', 'T6', 'U7', 'V7', 'A8', 'D10', 'L4', 'N1', 'P4', 'R7', 'T8', 'U8', 'V8', 'A9', 'D9', 'L5', 'N2', 'P5', 'R8', 'U1', 'U9', 'V9', 'B10', 'K3', 'L6', 'N3', 'P6', 'T1', 'U2', 'V1', 'B8', 'K4', 'M1', 'N4', 'R1', 'T2', 'U3', 'V2', 'B9', 'K5', 'M2', 'N5', 'R2', 'T3', 'U4', 'V4', 'C10', 'K6', 'M3', 'N6', 'R3', 'T4', 'U5', 'V5', 'C11', 'L1', 'M4', 'P2', 'R5', 'T5', 'U6', 'V6']},{'label': 'uC', 'num': 3, 'pin_nums': ['E5', 'C2', 'F6', 'A7', 'D4', 'H2', 'J5', 'E6', 'G1', 'H4', 'K1', 'C3', 'B1', 'D5', 'C4', 'B2', 'D6', 'E7', 'G2', 'H5', 'K2', 'A1', 'B3', 'C5', 'D7', 'F1', 'G3', 'H6', 'C6', 'A3', 'B4', 'D8', 'F2', 'G4', 'J1', 'A6', 'B6', 'C7', 'A4', 'D3', 'E1', 'E3', 'F3', 'G5', 'F5', 'J2', 'H1', 'A5', 'B7', 'D2', 'E2', 'F4', 'G6', 'J3', 'J4', 'C1']},{'label': 'uD', 'num': 4, 'pin_nums': ['P11', 'J10', 'P12', 'J9', 'P13', 'K10', 'P7', 'E10', 'K9', 'P8', 'E11', 'L10', 'P9', 'E12', 'E9', 'L9', 'R9', 'E13', 'P10']},{'label': 'uE', 'num': 5, 'pin_nums': ['A2', 'E4', 'J12', 'F9', 'H11', 'K8', 'M12', 'N12', 'T17', 'E14', 'E8', 'G10', 'H12', 'J16', 'T7', 'N18', 'B15', 'L11', 'M15', 'B5', 'F10', 'G11', 'H13', 'F8', 'J6', 'L12', 'M5', 'H10', 'N7', 'U10', 'J11', 'C18', 'F11', 'G12', 'H3', 'J7', 'K7', 'L2', 'M11', 'M7', 'N8', 'V13', 'C8', 'F12', 'G7', 'H7', 'J8', 'L7', 'M8', 'N9', 'V3', 'D1', 'F17', 'G8', 'H8', 'K11', 'L8', 'M9', 'P1', 'D11', 'F7', 'G9', 'H9', 'K12', 'M10', 'N10', 'R14', 'N11', 'A12', 'R4']}] }),
        Part(**{ 'name':'XC7A75T-FGG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A75T-FGG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A75T-FGG484\n\nFPGA', 'pins':[
            Pin(num='AA10',name='IO_L9P_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='IO_L9N_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA13',name='IO_L3P_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA14',name='IO_L5N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA15',name='IO_L4P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA16',name='IO_L1N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA17',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AA18',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA19',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA21',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AA9',name='IO_L8P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB10',name='IO_L8N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB11',name='IO_L7P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB12',name='IO_L7N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB13',name='IO_L3N_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB14',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AB15',name='IO_L4N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB16',name='IO_L2P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB17',name='IO_L2N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB20',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB21',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='AB22',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N17',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P19',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R22',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L15P_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L15N_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='IO_L17P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U15',name='IO_L14P_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L17N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='U20',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='IO_L10P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='IO_L13P_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L13N_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO_L14N_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V17',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='IO_L10N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='IO_L12P_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='IO_L12N_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='W14',name='IO_L6P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO_L16P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO_L16N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='W22',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y11',name='IO_L11P_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='IO_L11N_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='IO_L5P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='IO_L6N_T0_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='IO_L1P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='IO_0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='Y21',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A14',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A15',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A16',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='A18',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A19',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A20',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='A21',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B13',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B14',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='B15',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B16',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B20',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B21',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='B22',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C13',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C14',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C17',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C18',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C20',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='C21',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='C22',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D17',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='D19',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D21',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='D22',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='E16',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E19',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E21',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='E22',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO_0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F21',name='IO_25_16',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='VCCO_16',func=pin_types.PWRIN,unit=2),
            Pin(num='G13',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H17',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J14',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J22',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K19',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K21',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='L18',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='N22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA4',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA6',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AA7',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AA8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB4',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='AB5',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB6',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB7',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='AB8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='B1',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='B2',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='C1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D1',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='D2',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E1',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E2',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='E3',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F1',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F2',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='F3',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='F4',name='IO_0_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G1',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='G4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H5',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='H6',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J1',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J2',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J3',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='J4',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J5',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='J6',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K1',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K2',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K4',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='K6',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L3',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='IO_25_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M1',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M2',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M3',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M4',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='M5',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='M6',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N1',name='VCCO_35',func=pin_types.PWRIN,unit=3),
            Pin(num='N2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N3',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N4',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='N5',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P4',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P5',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=3),
            Pin(num='P6',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R1',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=3),
            Pin(num='R2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R4',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='R5',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T1',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T2',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='T3',name='IO_0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T4',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T5',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='T6',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U1',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U5',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U6',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='U7',name='IO_25_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V2',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V3',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V4',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V5',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V6',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='V7',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V8',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='V9',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W1',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W2',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W3',name='VCCO_34',func=pin_types.PWRIN,unit=3),
            Pin(num='W4',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W5',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W6',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W7',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=3),
            Pin(num='W9',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y1',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y2',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y3',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y4',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y6',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y7',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y8',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='Y9',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=3),
            Pin(num='A10',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A6',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='A8',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B10',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B6',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B8',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C11',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C7',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='C9',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D11',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D7',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='D9',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E10',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F10',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=4),
            Pin(num='B11',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B5',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B7',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='B9',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C4',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='C8',name='MGTAVTT',func=pin_types.PWRIN,unit=5),
            Pin(num='D10',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='D6',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='E8',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F7',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F8',name='MGTRREF_216',func=pin_types.PWRIN,unit=5),
            Pin(num='F9',name='MGTAVCC',func=pin_types.PWRIN,unit=5),
            Pin(num='F12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='G11',name='DONE_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L10',name='VP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L12',name='CCLK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='L9',name='VREFN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M10',name='VREFP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='M9',name='VN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N10',name='DXP_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N12',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='N9',name='DXN_0',func=pin_types.BIDIR,unit=6),
            Pin(num='R13',name='TDI_0',func=pin_types.BIDIR,unit=6),
            Pin(num='T12',name='VCCO_0',func=pin_types.PWRIN,unit=6),
            Pin(num='T13',name='TMS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U10',name='M1_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U11',name='M0_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U12',name='INIT_B_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U13',name='TDO_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U8',name='CFGBVS_0',func=pin_types.BIDIR,unit=6),
            Pin(num='U9',name='M2_0',func=pin_types.BIDIR,unit=6),
            Pin(num='V12',name='TCK_0',func=pin_types.BIDIR,unit=6),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AA22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='D8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E12',name='VCCBATT_0',func=pin_types.PWRIN,unit=7),
            Pin(num='E20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='H21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='J8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K10',name='VCCADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='K15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K5',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='K9',name='GNDADC_0',func=pin_types.PWRIN,unit=7),
            Pin(num='L11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='L2',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L22',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='M19',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N11',name='VCCBRAM',func=pin_types.PWRIN,unit=7),
            Pin(num='N16',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N6',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='N8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P12',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P3',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='P8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R11',name='VCCAUX',func=pin_types.PWRIN,unit=7),
            Pin(num='R12',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R20',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R7',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='R8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='R9',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T17',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T7',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='T8',name='VCCINT',func=pin_types.PWRIN,unit=7),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U14',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='U4',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V1',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V11',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='V21',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W18',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='W8',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y15',name='GND',func=pin_types.PWRIN,unit=7),
            Pin(num='Y5',name='GND',func=pin_types.PWRIN,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['V15', 'P19', 'V16', 'P20', 'V17', 'P21', 'V18', 'AA11', 'AA13', 'P22', 'V19', 'AA15', 'R14', 'V20', 'AA16', 'R15', 'V22', 'AA17', 'AA18', 'R16', 'W10', 'AA19', 'R17', 'W11', 'AA20', 'AA21', 'R18', 'W12', 'AA9', 'R19', 'W13', 'AB10', 'R21', 'W14', 'AB11', 'R22', 'W15', 'AA10', 'AB12', 'T14', 'W16', 'AB13', 'T15', 'W17', 'AB14', 'T16', 'W19', 'AB15', 'T18', 'W20', 'AB16', 'T19', 'W21', 'AB17', 'T20', 'W22', 'AB18', 'T21', 'Y10', 'AB20', 'T22', 'Y11', 'AB21', 'U15', 'Y12', 'AB22', 'U16', 'Y13', 'M14', 'U17', 'Y14', 'N13', 'U18', 'Y16', 'N14', 'U19', 'Y17', 'N15', 'U20', 'Y18', 'N17', 'U21', 'Y19', 'P14', 'U22', 'Y20', 'P15', 'V10', 'Y21', 'P16', 'P18', 'V13', 'Y22', 'P17', 'AA14', 'V14']},{'label': 'uB', 'num': 2, 'pin_nums': ['L19', 'D20', 'A14', 'H15', 'L20', 'D21', 'A15', 'H16', 'L21', 'A16', 'D22', 'H17', 'M13', 'E13', 'A17', 'H18', 'M15', 'A18', 'E14', 'H19', 'M16', 'A19', 'E15', 'H20', 'M17', 'A20', 'E16', 'H22', 'M18', 'E17', 'A21', 'J13', 'M20', 'B13', 'E18', 'J14', 'M21', 'B14', 'E19', 'J15', 'M22', 'B15', 'E21', 'J16', 'N18', 'B16', 'E22', 'J17', 'N19', 'D19', 'B17', 'F13', 'J19', 'N20', 'B18', 'F14', 'J20', 'N21', 'B20', 'F15', 'J21', 'N22', 'B21', 'F16', 'J22', 'B22', 'F18', 'K13', 'C13', 'F19', 'K14', 'C14', 'F20', 'K16', 'F21', 'C15', 'K17', 'C17', 'F22', 'K18', 'C18', 'G13', 'K19', 'C19', 'G15', 'K20', 'C20', 'G16', 'K21', 'C21', 'G17', 'K22', 'C22', 'G18', 'L13', 'D14', 'G19', 'L14', 'G20', 'D15', 'L15', 'D16', 'G21', 'L16', 'D17', 'G22', 'L17', 'D18', 'H13', 'L18', 'A13', 'H14']},{'label': 'uC', 'num': 3, 'pin_nums': ['B1', 'K6', 'T5', 'L1', 'B2', 'T6', 'C1', 'L3', 'U1', 'L4', 'C2', 'U2', 'D1', 'L5', 'U3', 'D2', 'L6', 'U5', 'E1', 'M1', 'U6', 'E2', 'M2', 'U7', 'E3', 'M3', 'V2', 'F1', 'M4', 'V3', 'F2', 'M5', 'V4', 'F3', 'M6', 'V5', 'F4', 'N1', 'V6', 'G1', 'N2', 'V7', 'G2', 'N3', 'V8', 'G3', 'N4', 'V9', 'A1', 'G4', 'N5', 'W1', 'AA1', 'H2', 'P1', 'W2', 'AA3', 'H3', 'P2', 'W3', 'AA4', 'H4', 'P4', 'W4', 'AA5', 'H5', 'P5', 'W5', 'K4', 'AA6', 'H6', 'P6', 'W6', 'AA7', 'J1', 'R1', 'W7', 'AA8', 'J2', 'R2', 'W9', 'AB1', 'J3', 'R3', 'Y1', 'AB2', 'J4', 'R4', 'Y2', 'AB3', 'J5', 'R5', 'Y3', 'AB4', 'J6', 'R6', 'Y4', 'AB5', 'K1', 'T1', 'Y6', 'AB6', 'K2', 'T2', 'Y7', 'AB7', 'K3', 'T3', 'Y8', 'AB8', 'T4', 'Y9']},{'label': 'uD', 'num': 4, 'pin_nums': ['B8', 'D9', 'C11', 'A10', 'E10', 'A4', 'C5', 'E6', 'A6', 'C7', 'F10', 'A8', 'C9', 'F6', 'B10', 'D11', 'B4', 'D5', 'B6', 'D7']},{'label': 'uE', 'num': 5, 'pin_nums': ['D6', 'C8', 'F7', 'B9', 'B5', 'F9', 'C4', 'B11', 'B7', 'D10', 'E8', 'F8']},{'label': 'uF', 'num': 6, 'pin_nums': ['M9', 'U11', 'N10', 'U12', 'F12', 'N12', 'U13', 'G11', 'N9', 'U8', 'L10', 'R13', 'U9', 'L12', 'T12', 'V12', 'L9', 'T13', 'M10', 'U10']},{'label': 'uG', 'num': 7, 'pin_nums': ['AA22', 'G8', 'M19', 'V11', 'AB19', 'M7', 'G9', 'V21', 'AB9', 'H1', 'M8', 'W18', 'M12', 'B12', 'N11', 'H10', 'W8', 'B19', 'H11', 'N16', 'Y15', 'B3', 'H12', 'N6', 'Y5', 'C10', 'H21', 'N7', 'C12', 'H7', 'N8', 'C16', 'H8', 'P10', 'C3', 'H9', 'P11', 'C6', 'J10', 'P12', 'D12', 'J11', 'P13', 'D13', 'J12', 'P3', 'D3', 'J18', 'P7', 'D4', 'J7', 'P8', 'D8', 'J8', 'P9', 'E11', 'J9', 'R10', 'E12', 'K10', 'R11', 'E20', 'K11', 'R12', 'E4', 'K12', 'R20', 'E5', 'K15', 'R7', 'E7', 'K5', 'R8', 'A11', 'E9', 'K7', 'R9', 'A12', 'F11', 'K8', 'T10', 'A2', 'F17', 'K9', 'T11', 'A22', 'F5', 'L11', 'T17', 'A3', 'G10', 'L2', 'T7', 'A5', 'G12', 'L22', 'T8', 'A7', 'G14', 'L7', 'T9', 'A9', 'G5', 'L8', 'U14', 'AA12', 'G6', 'M11', 'U4', 'AA2', 'G7', 'V1']}] }),
        Part(**{ 'name':'XC7A75T-FGG676', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A75T-FGG676'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A75T-FGG676\n\nFPGA', 'pins':[
            Pin(num='AA21',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AA22',name='IO_L8P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO_L8N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO_L7P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IO_L5N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB18',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AB24',name='IO_L9P_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB25',name='IO_L7N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='IO_L3P_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC24',name='IO_L9N_T1_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='AC26',name='IO_L3N_T0_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD22',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AE19',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='AF26',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='T14',name='IO_L20P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L20N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='T17',name='IO_L21P_T3_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO_L21N_T3_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO_L17P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L15P_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='T26',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='U14',name='IO_L23P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO_L22P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO_L22N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='IO_25_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO_L17N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L15N_T2_DQS_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U21',name='IO_L13P_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L12P_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='U24',name='IO_0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO_L1P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='IO_L1N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V14',name='IO_L23N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO_L24P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO_L24N_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO_L19P_T3_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L18P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='V21',name='IO_L13N_T2_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L12N_T1_MRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO_L10P_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='IO_L6P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO_L2P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='VCCO_12',func=pin_types.PWRIN,unit=1),
            Pin(num='W18',name='IO_L19N_T3_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO_L18N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L16P_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='IO_L14P_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W23',name='IO_L10N_T1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W24',name='IO_L6N_T0_VREF_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO_L4P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='IO_L2N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO_L16N_T2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L14N_T2_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L11P_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='IO_L11N_T1_SRCC_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='VCCO_13',func=pin_types.PWRIN,unit=1),
            Pin(num='Y25',name='IO_L5P_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='Y26',name='IO_L4N_T0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='D25',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=2),
            Pin(num='D26',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E23',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E25',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=2),
            Pin(num='E26',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F23',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F24',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F25',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='F26',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G20',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G21',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G23',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='G24',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G25',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=2),
            Pin(num='G26',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H19',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='H21',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H23',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H24',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=2),
            Pin(num='H26',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='J18',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J19',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J23',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J24',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J25',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=2),
            Pin(num='J26',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='K15',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K21',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K22',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K23',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=2),
            Pin(num='K24',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='K25',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=2),
            Pin(num='K26',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_25_15',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='L22',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L23',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L24',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=2),
            Pin(num='L25',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='VCCO_15',func=pin_types.PWRIN,unit=2),
            Pin(num='M19',name='IO_0_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M21',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M24',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M25',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=2),
            Pin(num='M26',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N14',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='N16',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N22',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N23',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N24',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='N25',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='N26',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P14',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P16',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P19',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P20',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P22',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='P23',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P24',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P25',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=2),
            Pin(num='P26',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R14',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R18',name='IO_25_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R19',name='VCCO_14',func=pin_types.PWRIN,unit=2),
            Pin(num='R20',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R23',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R25',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=2),
            Pin(num='R26',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T23',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T24',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=2),
            Pin(num='T25',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=2),
            Pin(num='A17',name='IO_L9P_T1_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A18',name='IO_L9N_T1_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A19',name='IO_L10N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A20',name='IO_L15N_T2_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A21',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='A22',name='IO_L17N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A23',name='IO_L21P_T3_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A24',name='IO_L21N_T3_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='A25',name='IO_L20N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='AA1',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='AC5',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='AD2',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='B17',name='IO_L7N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B18',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='B19',name='IO_L10P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B20',name='IO_L15P_T2_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B21',name='IO_L16N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B22',name='IO_L17P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B24',name='IO_L23N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B25',name='IO_L20P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='B26',name='IO_L22N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C17',name='IO_L7P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C18',name='IO_L12N_T1_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C19',name='IO_L13N_T2_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C21',name='IO_L16P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C22',name='IO_L19P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C23',name='IO_L19N_T3_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C24',name='IO_L23P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='C25',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='C26',name='IO_L22P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D16',name='IO_L8N_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D18',name='IO_L12P_T1_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D19',name='IO_L13P_T2_MRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D20',name='IO_L14N_T2_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D21',name='IO_L18N_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D22',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='D23',name='IO_L24P_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='D24',name='IO_L24N_T3_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E16',name='IO_L8P_T1_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E17',name='IO_L11P_T1_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E18',name='IO_L11N_T1_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E19',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='E20',name='IO_L14P_T2_SRCC_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E21',name='IO_L18P_T2_16',func=pin_types.BIDIR,unit=3),
            Pin(num='E22',name='IO_25_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F15',name='IO_L4N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F16',name='VCCO_16',func=pin_types.PWRIN,unit=3),
            Pin(num='F17',name='IO_L2N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F18',name='IO_L3P_T0_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F19',name='IO_L3N_T0_DQS_16',func=pin_types.BIDIR,unit=3),
            Pin(num='F20',name='IO_L5N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G15',name='IO_L4P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G16',name='IO_L6N_T0_VREF_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G17',name='IO_L2P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='G19',name='IO_L5P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H14',name='IO_L1P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H15',name='IO_L1N_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H16',name='IO_L6P_T0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='H17',name='IO_0_16',func=pin_types.BIDIR,unit=3),
            Pin(num='U3',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='W7',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='Y4',name='VCCO_33',func=pin_types.PWRIN,unit=3),
            Pin(num='A1',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='A2',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A3',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A4',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='A5',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B1',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B2',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B4',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='B5',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C1',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C2',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C3',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C4',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='C5',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='D1',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D2',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='D3',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D4',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='D6',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E1',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E2',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E3',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E5',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='E6',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F2',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F3',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F4',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F5',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F6',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='F8',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G1',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G2',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G3',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='G4',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G5',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G6',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G7',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G8',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='G9',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H1',name='IO_L10N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='H2',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='H3',name='IO_25_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H4',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H6',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H7',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H8',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='H9',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='J3',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='J4',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J5',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J6',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='J7',name='VCCO_35',func=pin_types.PWRIN,unit=4),
            Pin(num='J8',name='IO_0_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K1',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K3',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K4',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='K5',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='K6',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K7',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='K8',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=4),
            Pin(num='L1',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='L2',name='IO_L11N_T1_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L4',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L5',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L7',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='L8',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=4),
            Pin(num='M1',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M2',name='IO_L11P_T1_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M4',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M5',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M6',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M7',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='M8',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='N1',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N2',name='IO_L12N_T1_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N3',name='IO_L12P_T1_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N4',name='IO_L14N_T2_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N5',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='N6',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N7',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='N8',name='IO_0_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P1',name='IO_L15N_T2_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P2',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='P3',name='IO_L13N_T2_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P4',name='IO_L14P_T2_SRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P5',name='IO_L19N_T3_VREF_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P6',name='IO_L19P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='P8',name='IO_L22N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R1',name='IO_L15P_T2_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R2',name='IO_L17N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R3',name='IO_L13P_T2_MRCC_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R5',name='IO_L20N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R6',name='IO_L23N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R7',name='IO_L23P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='R8',name='IO_L22P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T2',name='IO_L17P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T3',name='IO_L16N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T4',name='IO_L16P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T5',name='IO_L20P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T6',name='VCCO_34',func=pin_types.PWRIN,unit=4),
            Pin(num='T7',name='IO_L24N_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='T8',name='IO_L24P_T3_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U1',name='IO_L18N_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U2',name='IO_L18P_T2_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U4',name='IO_25_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U5',name='IO_L21N_T3_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='U6',name='IO_L21P_T3_DQS_34',func=pin_types.BIDIR,unit=4),
            Pin(num='A11',name='MGTPRXN0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A13',name='MGTPRXN2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A7',name='MGTPTXN0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A9',name='MGTPTXN2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='AA11',name='MGTREFCLK1P_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AA13',name='MGTREFCLK0P_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AB11',name='MGTREFCLK1N_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AB13',name='MGTREFCLK0N_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC10',name='MGTPTXP0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC12',name='MGTPRXP0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC14',name='MGTPRXP2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AC8',name='MGTPTXP2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD10',name='MGTPTXN0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD12',name='MGTPRXN0_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD14',name='MGTPRXN2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AD8',name='MGTPTXN2_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE11',name='MGTPRXP3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE13',name='MGTPRXP1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE7',name='MGTPTXP3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AE9',name='MGTPTXP1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF11',name='MGTPRXN3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF13',name='MGTPRXN1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF7',name='MGTPTXN3_213',func=pin_types.BIDIR,unit=5),
            Pin(num='AF9',name='MGTPTXN1_213',func=pin_types.BIDIR,unit=5),
            Pin(num='B11',name='MGTPRXP0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B13',name='MGTPRXP2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B7',name='MGTPTXP0_216',func=pin_types.BIDIR,unit=5),
            Pin(num='B9',name='MGTPTXP2_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C10',name='MGTPTXN3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C12',name='MGTPRXN3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C14',name='MGTPRXN1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='C8',name='MGTPTXN1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D10',name='MGTPTXP3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D12',name='MGTPRXP3_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D14',name='MGTPRXP1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='D8',name='MGTPTXP1_216',func=pin_types.BIDIR,unit=5),
            Pin(num='E11',name='MGTREFCLK0N_216',func=pin_types.BIDIR,unit=5),
            Pin(num='E13',name='MGTREFCLK1N_216',func=pin_types.BIDIR,unit=5),
            Pin(num='F11',name='MGTREFCLK0P_216',func=pin_types.BIDIR,unit=5),
            Pin(num='F13',name='MGTREFCLK1P_216',func=pin_types.BIDIR,unit=5),
            Pin(num='A15',name='MGTRREF_216',func=pin_types.PWRIN,unit=6),
            Pin(num='AA10',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AA12',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC11',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC13',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AC9',name='MGTAVCC_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AD15',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AD7',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE10',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE12',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE14',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AE8',name='MGTAVTT_G10',func=pin_types.PWRIN,unit=6),
            Pin(num='AF15',name='MGTRREF_213',func=pin_types.PWRIN,unit=6),
            Pin(num='B10',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B12',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B14',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='B8',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='C15',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='C7',name='MGTAVTT_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D11',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D13',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='D9',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='F10',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='F12',name='MGTAVCC_G11',func=pin_types.PWRIN,unit=6),
            Pin(num='AB15',name='CFGBVS_0',func=pin_types.BIDIR,unit=7),
            Pin(num='AB7',name='M0_0',func=pin_types.BIDIR,unit=7),
            Pin(num='AE16',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H10',name='TDI_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H11',name='TMS_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H12',name='TCK_0',func=pin_types.BIDIR,unit=7),
            Pin(num='H13',name='CCLK_0',func=pin_types.BIDIR,unit=7),
            Pin(num='J10',name='TDO_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N11',name='VREFN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='N12',name='VP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P11',name='VN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='P12',name='VREFP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='R11',name='DXN_0',func=pin_types.BIDIR,unit=7),
            Pin(num='R12',name='DXP_0',func=pin_types.BIDIR,unit=7),
            Pin(num='V11',name='INIT_B_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W10',name='DONE_0',func=pin_types.BIDIR,unit=7),
            Pin(num='W11',name='VCCO_0',func=pin_types.PWRIN,unit=7),
            Pin(num='W9',name='M2_0',func=pin_types.BIDIR,unit=7),
            Pin(num='Y14',name='VCCO_0',func=pin_types.PWRIN,unit=7),
            Pin(num='Y9',name='M1_0',func=pin_types.BIDIR,unit=7),
            Pin(num='A10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AB9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AC7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AD9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AE6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='AF8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='C9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F14',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='F9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='G14',name='VCCBATT_0',func=pin_types.PWRIN,unit=8),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='J9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='K13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K19',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='K9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L13',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='L16',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L26',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L6',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='L9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='M10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='M11',name='GNDADC_0',func=pin_types.PWRIN,unit=8),
            Pin(num='M12',name='VCCADC_0',func=pin_types.PWRIN,unit=8),
            Pin(num='M13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M23',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M3',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='M9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='N20',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='N9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='P10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='P13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P17',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P7',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='P9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='R24',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R4',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='R9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='T1',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='T13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T21',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='T9',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U11',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='U18',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U8',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='U9',name='VCCAUX',func=pin_types.PWRIN,unit=8),
            Pin(num='V10',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V12',name='VCCINT',func=pin_types.PWRIN,unit=8),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V15',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V25',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='V5',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W13',name='VCCBRAM',func=pin_types.PWRIN,unit=8),
            Pin(num='W2',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='W22',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y10',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y11',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y12',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y13',name='GND',func=pin_types.PWRIN,unit=8),
            Pin(num='Y19',name='GND',func=pin_types.PWRIN,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['AE19', 'V17', 'AA21', 'T20', 'U21', 'V26', 'W25', 'Y26', 'AA23', 'AF26', 'T26', 'U22', 'V18', 'W26', 'AA25', 'W17', 'T14', 'U14', 'U23', 'V19', 'AB18', 'W18', 'Y20', 'AB24', 'T15', 'U15', 'U24', 'V20', 'W19', 'Y21', 'AA24', 'AB25', 'T16', 'U16', 'U25', 'V21', 'AA22', 'W20', 'Y22', 'Y25', 'AB26', 'AC24', 'T17', 'U17', 'U26', 'V22', 'W21', 'Y23', 'AC25', 'T18', 'U19', 'V14', 'V23', 'W23', 'Y24', 'AC26', 'AD22', 'T19', 'U20', 'V16', 'V24', 'W24']},{'label': 'uB', 'num': 2, 'pin_nums': ['N21', 'G25', 'N22', 'K25', 'T25', 'G26', 'K26', 'N23', 'H18', 'L14', 'N24', 'H19', 'L15', 'N25', 'H20', 'L17', 'N26', 'H21', 'L18', 'P14', 'H22', 'L19', 'P15', 'H23', 'L20', 'P16', 'H24', 'L21', 'P18', 'H26', 'L22', 'P19', 'J14', 'L23', 'P20', 'J15', 'L24', 'P21', 'J16', 'L25', 'P22', 'J17', 'M14', 'P23', 'J18', 'M15', 'P24', 'K24', 'J19', 'M16', 'P25', 'J20', 'M17', 'P26', 'D25', 'J21', 'M18', 'R14', 'D26', 'J23', 'M19', 'R15', 'E23', 'J24', 'M20', 'R16', 'E25', 'J25', 'M21', 'R17', 'E26', 'J26', 'M22', 'R18', 'F22', 'K14', 'M24', 'R19', 'F23', 'K15', 'M25', 'R20', 'F24', 'K16', 'M26', 'R21', 'F25', 'K17', 'N14', 'R22', 'F26', 'K18', 'N15', 'R23', 'G20', 'K20', 'N16', 'R25', 'G21', 'K21', 'N17', 'R26', 'G22', 'K22', 'N18', 'T22', 'T24', 'G23', 'K23', 'N19', 'T23', 'G24']},{'label': 'uC', 'num': 3, 'pin_nums': ['A23', 'C18', 'D16', 'B19', 'E16', 'F16', 'G19', 'B20', 'C19', 'D18', 'E17', 'F17', 'A24', 'H14', 'A17', 'A25', 'B21', 'C21', 'D19', 'E18', 'F18', 'H15', 'G16', 'AA1', 'B22', 'A18', 'C22', 'D20', 'E19', 'F19', 'H16', 'A19', 'AC5', 'B24', 'C23', 'D21', 'E20', 'F20', 'H17', 'AD2', 'A20', 'B25', 'C24', 'D22', 'E21', 'G15', 'U3', 'A22', 'B18', 'W7', 'A21', 'B17', 'B26', 'C17', 'C25', 'C26', 'D23', 'E22', 'D24', 'F15', 'G17', 'Y4']},{'label': 'uD', 'num': 4, 'pin_nums': ['F8', 'R3', 'A1', 'G1', 'L1', 'R5', 'A2', 'G2', 'L2', 'R6', 'A3', 'G3', 'L3', 'R7', 'A4', 'G4', 'L4', 'R8', 'A5', 'G5', 'L5', 'T2', 'B1', 'G6', 'L7', 'T3', 'B2', 'G7', 'L8', 'T4', 'B4', 'G8', 'M1', 'T5', 'B5', 'G9', 'M2', 'T6', 'C1', 'H1', 'M4', 'T7', 'C2', 'H2', 'M5', 'T8', 'C3', 'H3', 'M6', 'U1', 'C4', 'H4', 'M7', 'U2', 'C5', 'H6', 'M8', 'U4', 'D1', 'H7', 'N1', 'U5', 'D2', 'H8', 'N2', 'U6', 'D3', 'H9', 'N3', 'D4', 'J1', 'N4', 'D5', 'J3', 'N5', 'D6', 'J4', 'N6', 'E1', 'J5', 'N7', 'E2', 'J6', 'N8', 'E3', 'J7', 'P1', 'E5', 'J8', 'P2', 'E6', 'K1', 'P3', 'F2', 'K2', 'P4', 'F3', 'K3', 'P5', 'F4', 'K4', 'P6', 'F5', 'K5', 'P8', 'F6', 'K6', 'K8', 'R1', 'F7', 'K7', 'R2']},{'label': 'uE', 'num': 5, 'pin_nums': ['AB13', 'C8', 'F13', 'AD8', 'AF9', 'AF7', 'A11', 'AC10', 'C14', 'D10', 'AE11', 'B11', 'AD14', 'A13', 'AC12', 'AE13', 'B13', 'D12', 'A7', 'AC14', 'AE7', 'B7', 'D14', 'A9', 'AC8', 'AE9', 'B9', 'D8', 'AA11', 'AD10', 'AF11', 'C10', 'E11', 'AA13', 'AD12', 'AF13', 'C12', 'E13', 'AB11', 'F11']},{'label': 'uF', 'num': 6, 'pin_nums': ['F10', 'AD15', 'B12', 'AD7', 'B14', 'F12', 'A15', 'AE10', 'B8', 'AA10', 'AE12', 'C15', 'AA12', 'AE14', 'C7', 'AC11', 'AE8', 'D11', 'AC13', 'AF15', 'D13', 'AC9', 'B10', 'D9']},{'label': 'uG', 'num': 7, 'pin_nums': ['H13', 'V11', 'J10', 'H12', 'W10', 'AB15', 'N11', 'W11', 'AB7', 'N12', 'W9', 'AE16', 'P11', 'Y14', 'H10', 'P12', 'Y9', 'H11', 'R11', 'R12']},{'label': 'uH', 'num': 8, 'pin_nums': ['AD6', 'L13', 'T9', 'AD9', 'E4', 'L16', 'U10', 'AE15', 'E7', 'L26', 'U11', 'AE24', 'E8', 'L6', 'U12', 'AE4', 'E9', 'L9', 'U13', 'AE6', 'F1', 'M10', 'U18', 'AF1', 'F14', 'M11', 'U8', 'A10', 'AF10', 'F21', 'M12', 'U9', 'A12', 'AF12', 'F9', 'M13', 'V10', 'A14', 'AF14', 'G10', 'M23', 'V12', 'A16', 'AF16', 'G11', 'M3', 'V13', 'A26', 'AF21', 'G12', 'M9', 'V15', 'A6', 'AF6', 'G13', 'N10', 'V25', 'A8', 'AF8', 'G14', 'N13', 'V5', 'AA14', 'B15', 'G18', 'N20', 'W12', 'AA16', 'B16', 'H25', 'N9', 'W13', 'AA26', 'B23', 'H5', 'P10', 'W2', 'AA6', 'B3', 'J11', 'P13', 'W22', 'AA9', 'B6', 'J12', 'P17', 'Y10', 'AB10', 'C11', 'J13', 'P7', 'Y11', 'AB12', 'C13', 'J2', 'P9', 'Y12', 'AB14', 'C16', 'J22', 'R10', 'Y13', 'AB23', 'C20', 'J9', 'R13', 'Y19', 'AB3', 'C6', 'K10', 'R24', 'AB8', 'C9', 'K11', 'R4', 'AB9', 'D15', 'K12', 'R9', 'AC15', 'D17', 'K13', 'T1', 'AC20', 'D7', 'K19', 'T10', 'AC7', 'E10', 'K9', 'T11', 'AD11', 'E12', 'L10', 'T12', 'AD13', 'E14', 'E24', 'L11', 'T13', 'AD16', 'E15', 'L12', 'T21']}] }),
        Part(**{ 'name':'XC7A75T-FTG256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC7A75T-FTG256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx_Artix7.kicad_sym\nXC7A75T-FTG256\n\nFPGA', 'pins':[
            Pin(num='A10',name='IO_L3N_T0_DQS_AD1N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L5N_T0_AD9N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L7P_T1_AD2P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L7N_T1_AD2N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L9N_T1_DQS_AD3N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='IO_L2P_T0_AD8P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L2N_T0_AD8N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO_L4P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO_L4N_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO_L5P_T0_AD9P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L8N_T1_AD10N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L9P_T1_DQS_AD3P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO_L10N_T1_AD11N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L3P_T0_DQS_AD1P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='IO_L11P_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L11N_T1_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L12N_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L8P_T1_AD10P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L10P_T1_AD11P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L1P_T0_AD0P_15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L1N_T0_AD0N_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L14N_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO_L12P_T1_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L15P_T2_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L15N_T2_DQS_ADV_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L17N_T2_A25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L6P_T0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L6N_T0_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L14P_T2_SRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L13P_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L13N_T2_MRCC_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='E15',name='IO_L18N_T2_A23_15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO_L17P_T2_A26_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO_L16P_T2_A28_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO_L16N_T2_A27_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L21N_T3_DQS_A18_15',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L18P_T2_A24_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO_25_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='IO_L19N_T3_A21_VREF_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L21P_T3_DQS_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO_L24N_T3_RS0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L22N_T3_A16_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L19P_T3_A22_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L20P_T3_A20_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L20N_T3_A19_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L24P_T3_RS1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='H16',name='IO_L22P_T3_A17_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VCCO_15',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO_L1P_T0_D00_MOSI_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L1N_T0_D01_DIN_14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO_L23P_T3_FOE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L23N_T3_FWE_B_15',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO_0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO_L5P_T0_D06_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L2P_T0_D02_14',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L2N_T0_D03_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO_L6P_T0_FCS_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO_L5N_T0_D07_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L4P_T0_D04_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO_L3P_T0_DQS_PUDC_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='IO_L6N_T0_D08_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='IO_L4N_T0_D05_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L3N_T0_DQS_EMCCLK_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L7P_T1_D09_14',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='IO_L19P_T3_A10_D26_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='IO_L13P_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO_L13N_T2_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L11P_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L12P_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L7N_T1_D10_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='IO_L19N_T3_A09_D25_VREF_14',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='IO_L18P_T2_A12_D28_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='IO_L14P_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='IO_L14N_T2_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L11N_T1_SRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO_L12N_T1_MRCC_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO_L8P_T1_D11_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L8N_T1_D12_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='IO_25_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='P8',name='IO_L20P_T3_A08_D24_14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='IO_L18N_T2_A11_D27_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO_L17P_T2_A14_D30_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO_L17N_T2_A13_D29_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO_L15P_T2_DQS_RDWR_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO_L16P_T2_CSI_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='IO_L9P_T1_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='IO_L9N_T1_DQS_D13_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='IO_L23P_T3_A03_D19_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IO_L24P_T3_A01_D17_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='IO_L24N_T3_A00_D16_14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='IO_L20N_T3_A07_D23_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='IO_L22N_T3_A04_D20_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='VCCO_14',func=pin_types.PWRIN,unit=1),
            Pin(num='T12',name='IO_L15N_T2_DQS_DOUT_CSO_B_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L16N_T2_A15_D31_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L10P_T1_D14_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='IO_L10N_T1_D15_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO_L23N_T3_A02_D18_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='IO_L21P_T3_DQS_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='IO_L21N_T3_DQS_A06_D22_14',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L22P_T3_A05_D21_14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L8N_T1_AD14N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A3',name='IO_L4N_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A4',name='IO_L3N_T0_DQS_AD5N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A5',name='IO_L3P_T0_DQS_AD5P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='A6',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='A7',name='IO_L1N_T0_AD4N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L9N_T1_DQS_AD7N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B2',name='IO_L8P_T1_AD14P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B3',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='B4',name='IO_L4P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B5',name='IO_L2N_T0_AD12N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B6',name='IO_L2P_T0_AD12P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='B7',name='IO_L1P_T0_AD4P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L9P_T1_DQS_AD7P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='IO_L7N_T1_AD6N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C3',name='IO_L7P_T1_AD6P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C4',name='IO_L12N_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C6',name='IO_L5N_T0_AD13N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='C7',name='IO_L5P_T0_AD13P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D1',name='IO_L10N_T1_AD15N_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D3',name='IO_L11N_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D4',name='IO_L12P_T1_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D5',name='IO_L6N_T0_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D6',name='IO_L6P_T0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='D7',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E1',name='IO_L15N_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E2',name='IO_L10P_T1_AD15P_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L11P_T1_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='E5',name='IO_L13N_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='E6',name='IO_0_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='F2',name='IO_L15P_T2_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L14N_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='IO_L14P_T2_SRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='F5',name='IO_L13P_T2_MRCC_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G1',name='IO_L17N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='IO_L17P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G4',name='IO_L16N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='G5',name='IO_L16P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L20N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L20P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L21N_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H4',name='IO_L18N_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L18P_T2_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L22N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J2',name='VCCO_35',func=pin_types.PWRIN,unit=2),
            Pin(num='J3',name='IO_L21P_T3_DQS_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L19N_T3_VREF_35',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='IO_L19P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L22P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L24N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L24P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_25_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='IO_L23N_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L3',name='IO_L23P_T3_35',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L1P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='L5',name='IO_0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M1',name='IO_L2N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L2P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='M4',name='IO_L1N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L6P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L4P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N2',name='IO_L3N_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L3P_T0_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L6N_T0_VREF_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P1',name='IO_L4N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L5N_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L5P_T0_34',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L10P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L7N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='IO_L7P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R3',name='IO_L8P_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T1',name='VCCO_34',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO_L8N_T1_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='IO_L9N_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='T4',name='IO_L9P_T1_DQS_34',func=pin_types.BIDIR,unit=2),
            Pin(num='E7',name='CFGBVS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='E8',name='CCLK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H10',name='DONE_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H7',name='VREFN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='H8',name='VP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J7',name='VN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='J8',name='VREFP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K10',name='INIT_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K7',name='DXN_0',func=pin_types.BIDIR,unit=3),
            Pin(num='K8',name='DXP_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L6',name='VCCO_0',func=pin_types.PWRIN,unit=3),
            Pin(num='L7',name='TCK_0',func=pin_types.BIDIR,unit=3),
            Pin(num='L9',name='PROGRAM_B_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M10',name='M1_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M11',name='M2_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M7',name='TMS_0',func=pin_types.BIDIR,unit=3),
            Pin(num='M9',name='M0_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N7',name='TDI_0',func=pin_types.BIDIR,unit=3),
            Pin(num='N8',name='TDO_0',func=pin_types.BIDIR,unit=3),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='B8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='E10',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='E9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F10',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F11',name='VCCBRAM',func=pin_types.PWRIN,unit=4),
            Pin(num='F16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='F8',name='VCCBATT_0',func=pin_types.PWRIN,unit=4),
            Pin(num='F9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='G13',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='G7',name='GNDADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G8',name='VCCADC_0',func=pin_types.PWRIN,unit=4),
            Pin(num='G9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='H9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='J6',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K11',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K6',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='L1',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L10',name='VCCAUX',func=pin_types.PWRIN,unit=4),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='L8',name='VCCINT',func=pin_types.PWRIN,unit=4),
            Pin(num='M8',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N15',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='N5',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='P2',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='R9',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T16',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='T6',name='GND',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['K12', 'K13', 'D14', 'R10', 'D15', 'K15', 'R11', 'D16', 'K16', 'A13', 'R12', 'D8', 'L12', 'R13', 'D9', 'L13', 'R14', 'E11', 'L14', 'R15', 'A14', 'E12', 'L15', 'A12', 'R16', 'E13', 'L16', 'R5', 'E14', 'M12', 'R6', 'E15', 'M13', 'R7', 'E16', 'M14', 'R8', 'F12', 'M15', 'A15', 'T10', 'F13', 'M16', 'A16', 'T11', 'A8', 'F14', 'M6', 'T12', 'A9', 'F15', 'N10', 'T13', 'B10', 'B11', 'G11', 'N11', 'T14', 'B12', 'G12', 'N12', 'T15', 'B13', 'G14', 'N13', 'B14', 'T5', 'B15', 'G15', 'N14', 'T7', 'B16', 'G16', 'N16', 'T8', 'B9', 'H11', 'N6', 'T9', 'C10', 'A10', 'H12', 'N9', 'C11', 'H13', 'P10', 'C12', 'H14', 'P11', 'C13', 'H15', 'P13', 'C14', 'H16', 'P14', 'C16', 'J12', 'P15', 'C8', 'J13', 'P16', 'C9', 'J14', 'P6', 'D10', 'J15', 'P7', 'P9', 'D11', 'J16', 'P8', 'D13']},{'label': 'uB', 'num': 2, 'pin_nums': ['B5', 'R4', 'H3', 'B4', 'B6', 'T1', 'H4', 'B7', 'H5', 'T2', 'C1', 'T3', 'J1', 'C2', 'J2', 'T4', 'C3', 'J3', 'C4', 'J4', 'C6', 'J5', 'C7', 'K1', 'D1', 'K2', 'D3', 'K3', 'D4', 'K5', 'D5', 'L2', 'D6', 'L3', 'D7', 'L4', 'E1', 'L5', 'E2', 'M1', 'E3', 'M2', 'E4', 'M3', 'E5', 'M4', 'E6', 'M5', 'F1', 'N1', 'A2', 'F2', 'N2', 'A3', 'F3', 'N3', 'A4', 'F4', 'N4', 'A5', 'F5', 'P1', 'A6', 'G1', 'P3', 'A7', 'G2', 'P4', 'B1', 'G4', 'P5', 'B2', 'G5', 'R1', 'B3', 'H1', 'R2', 'H2', 'R3']},{'label': 'uC', 'num': 3, 'pin_nums': ['H10', 'N8', 'L6', 'L7', 'H7', 'H8', 'L9', 'J7', 'M10', 'J8', 'M11', 'K10', 'M7', 'E7', 'K7', 'M9', 'E8', 'K8', 'N7']},{'label': 'uD', 'num': 4, 'pin_nums': ['E10', 'F9', 'K4', 'H6', 'N15', 'A1', 'H9', 'K6', 'N5', 'G10', 'E9', 'F8', 'A11', 'G9', 'F10', 'G13', 'J10', 'K9', 'M8', 'P12', 'B8', 'G3', 'F11', 'J11', 'L1', 'P2', 'C15', 'F16', 'G6', 'J6', 'L10', 'R9', 'C5', 'F6', 'G7', 'J9', 'L11', 'T16', 'D12', 'F7', 'G8', 'K11', 'L8', 'T6', 'D2', 'K14']}] })])