from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Analog_ADC = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AD40xxBCPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD40xxBCPZ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-WD-10-1EP_3x3mm_P0.5mm_EP1.64x2.38mm'], 'footprint':'Package_CSP:LFCSP-WD-10-1EP_3x3mm_P0.5mm_EP1.64x2.38mm', 'keywords':'ADC 18-bit AD4003BCPZ AD4007BCPZ AD4011BCPZ', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad4003-4007-4011.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD40xxBCPZ\n\nADC 18-bit AD4003BCPZ AD4007BCPZ AD4011BCPZ', 'pins':[
            Pin(num='1',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CNV',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SDI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD40xxBRMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD40xxBRMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'ADC 18-bit AD4003BRMZ AD4007BRMZ AD4011BRMZ', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad4003-4007-4011.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD40xxBRMZ\n\nADC 18-bit AD4003BRMZ AD4007BRMZ AD4011BRMZ', 'pins':[
            Pin(num='1',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CNV',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SDI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD6644', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD6644'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-52-1EP_10x10mm_P0.65mm_EP6.5x6.5mm'], 'footprint':'Package_QFP:TQFP-52-1EP_10x10mm_P0.65mm_EP6.5x6.5mm', 'keywords':'ADC differential analog digital converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD6644.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD6644\n\nADC differential analog digital converter', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='AIN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{AIN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='OVR',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='DMID',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='D9',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='D10',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='D11',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='ENCODE',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='D12',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='D13',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DRY',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{ENCODE}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AVCC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7171', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7171'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.55x2.48mm'], 'footprint':'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.55x2.48mm', 'keywords':'sigma delta adc spi 1ch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7171.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7171\n\nsigma delta adc spi 1ch', 'pins':[
            Pin(num='1',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DOUT/~{RDY}',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='AIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='REFIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='REFIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{PDRST}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7298', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7298'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias'], 'footprint':'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias', 'keywords':'ADC, 3.3V, SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7298.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7298\n\nADC, 3.3V, SPI', 'pins':[
            Pin(num='1',name='VIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TSENSE_BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDRIVE',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='~{PD}/~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VIN0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VIN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VIN4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VIN2',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VIN5',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VIN7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND1',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7321', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7321'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'Analog-Devices ADC bipolar 12-Bit SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7321.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7321\n\nAnalog-Devices ADC bipolar 12-Bit SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='V_{DRIVE}',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF_{IN/OUT}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V_{IN}0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{IN}1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{DD}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7323'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Analog-Devices ADC bipolar 12-Bit SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7323.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7323\n\nAnalog-Devices ADC bipolar 12-Bit SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{IN}2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V_{DRIVE}',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF_{IN/OUT}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V_{IN}0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{IN}1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{IN}3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7327', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7327'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Analog-Devices ADC bipolar 12-Bit SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad7327.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7327\n\nAnalog-Devices ADC bipolar 12-Bit SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{IN}5',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_{IN}7',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V_{IN}6',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V_{IN}3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='V_{IN}2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='V_{DRIVE}',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF_{IN/OUT}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V_{IN}0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{IN}1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{IN}4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7329', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7329'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'Analog-Devices ADC bipolar 12-Bit SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7329.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7329\n\nAnalog-Devices ADC bipolar 12-Bit SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{IN}1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_{IN}4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V_{IN}5',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V_{IN}7',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='V_{IN}6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='V_{IN}3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='V_{IN}2',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='MUX_{OUT}-',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='ADC_{IN}-',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='V_{DRIVE}',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF_{IN/OUT}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='ADC_{IN}+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='MUX_{OUT}+',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='V_{IN}0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7606', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7606'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'16bit DAS ADC 8channel 200KSPS', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad7606_7606-6_7606-4.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7606\n\n16bit DAS ADC 8channel 200KSPS', 'pins':[
            Pin(num='1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='CONVST_B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RD}/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='FRSTDATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='Vdrive',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DB7/DOUT_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='DB8/DOUT_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OS0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB12',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='DB13',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='DB14/HBEN',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='DB15/BYTE_SEL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='REF_SELECT',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='REGCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='REGCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OS1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='REFIN/REFOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='REFCAPA',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='REFCAPB',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='REFGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='V1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OS2',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='V1GND',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='V2',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='V2GND',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='V3',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='V3GND',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='V4',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='V4GND',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='V5',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='V5GND',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='V6',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{PAR}/SER/BYTE_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='V6GND',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='V7',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='V7GND',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='V8',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='V8GND',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{STBY}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RANGE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CONVST_A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7606-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7606-4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'16bit DAS ADC 4channel 200KSPS', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad7606_7606-6_7606-4.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7606-4\n\n16bit DAS ADC 4channel 200KSPS', 'pins':[
            Pin(num='1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='CONVST_B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RD}/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='FRSTDATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='Vdrive',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DB7/DOUT_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='DB8/DOUT_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OS0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB12',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='DB13',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='DB14/HBEN',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='DB15/BYTE_SEL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='REF_SELECT',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='REGCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='REGCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OS1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='REFIN/REFOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='REFCAPA',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='REFCAPB',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='REFGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='V1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OS2',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='V1GND',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='V2',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='V2GND',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='V3',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='V3GND',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='V4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{PAR}/SER/BYTE_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='V4GND',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~{STBY}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RANGE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CONVST_A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7606-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7606-6'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'16bit DAS ADC 6channel 200KSPS', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad7606_7606-6_7606-4.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7606-6\n\n16bit DAS ADC 6channel 200KSPS', 'pins':[
            Pin(num='1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='CONVST_B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RD}/SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='FRSTDATA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='Vdrive',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DB7/DOUT_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='DB8/DOUT_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OS0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB12',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='DB13',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='DB14/HBEN',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='DB15/BYTE_SEL',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='REF_SELECT',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='REGCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='REGCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OS1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='REFIN/REFOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='REFCAPA',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='REFCAPB',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='REFGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='V1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OS2',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='V1GND',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='V2',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='V2GND',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='V3',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='V3GND',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='V4',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='V4GND',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='V5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{PAR}/SER/BYTE_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='V5GND',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='V6',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='V6GND',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~{STBY}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RANGE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CONVST_A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7616', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7616'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'16bit DAS ADC 16channel 1MSPS', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7616.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7616\n\n16bit DAS ADC 16channel 1MSPS', 'pins':[
            Pin(num='1',name='V4BGND',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V7BGND',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V7AGND',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V7A',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V6AGND',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='V6A',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V5A',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='V5AGND',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='V4A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V4B',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='V4AGND',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='V3AGND',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='V3A',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='V2AGND',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='V2A',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='V1AGND',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='V1A',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='V0AGND',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='V0A',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='V5BGND',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='REFCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='REFINOUT',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='REFINOUTGND',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='REFSEL',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='SEQEN',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='HW_RNGSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='HW_RNGSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V5B',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='SER/~{PAR}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='DB0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='DB1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='DB2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='DB3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DB4/~{SER1W}',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='DB5/CRCEN',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='DB6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DB7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDRIVE',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='REGGNDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='REGCAPD',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DB8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='DB9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='DB10/SDI',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='DB11/SDOB',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='DB12/SDOA',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DB13/OS0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='DB14/OS1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='DB15/OS2',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='BURST/~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='SCLK/~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='CHSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='CHSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='CHSEL2',func=pin_types.INPUT,unit=1),
            Pin(num='67',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='68',name='CONVST',func=pin_types.INPUT,unit=1),
            Pin(num='69',name='REGGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V6B',func=pin_types.INPUT,unit=1),
            Pin(num='70',name='REGCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='V0B',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='V0BGND',func=pin_types.INPUT,unit=1),
            Pin(num='75',name='V1B',func=pin_types.INPUT,unit=1),
            Pin(num='76',name='V1BGND',func=pin_types.INPUT,unit=1),
            Pin(num='77',name='V2B',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='V2BGND',func=pin_types.INPUT,unit=1),
            Pin(num='79',name='V3B',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V6BGND',func=pin_types.INPUT,unit=1),
            Pin(num='80',name='V3BGND',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V7B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7682BCP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7682BCP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'16-Bit 4-Channel 250kSPS', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7682_7689.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7682BCP\n\n16-Bit 4-Channel 250kSPS', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CNV',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='EPAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='REFIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='IN3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7722', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7722'}), 'ref_prefix':'U', 'fplist':['Package_QFP:MQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:MQFP-44_10x10mm_P0.8mm', 'keywords':'adc 1ch 16bit parallel serial', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7722.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7722\n\nadc 1ch 16bit parallel serial', 'pins':[
            Pin(num='1',name='DB2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AGND1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='AVDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VIN-',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VIN+',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DB1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='REF1',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='REF2',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='CAL',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DB0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='DB15',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='DB14',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='DB13',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB12',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='FSO/DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='SDO/DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CFMT/~{DRDY}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='SCO/DB7',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='FSI/DB6',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='SFMT/DB5',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='DOE/DB4',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='TSI/DB3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DVAL/~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{UNI}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P/~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7745', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7745'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'adc cdc capacitance', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7745_7746.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7745\n\nadc cdc capacitance', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='VIN+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VIN-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='EXCA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXCB',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='REFIN+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFIN-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CIN1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CIN1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7746', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7746'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'adc cdc capacitance', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7745_7746.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7746\n\nadc cdc capacitance', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CIN2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='VIN+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VIN-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='EXCA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXCB',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='REFIN+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFIN-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CIN1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CIN1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CIN2+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7794', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7794'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'adc 6ch 24bit serial', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7794_7795.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7794\n\nadc 6ch 24bit serial', 'pins':[
            Pin(num='1',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN2-',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN3+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AIN3-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFIN1+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFIN1-',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AIN5+/IOUT2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AIN5-/IOUT1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AIN4+/REFIN2+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AIN4-/REFIN2-',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PSW',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='DOUT/~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='AIN6+/P1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN6-/P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN1+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN1-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN2+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7819', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7819'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'CAD', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7819.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7819\n\nCAD', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DB2',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='DB3',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='DB4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='DB5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='DB6',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='DB7',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vin',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='START',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='EOC',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='DB0',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='DB1',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7949BCP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7949BCP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'ADC, SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7949.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7949BCP\n\nADC, SPI', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CNV',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='REFIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9280ARS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9280ARS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ADC CAN VIDEO', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD9280.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD9280ARS\n\nADC CAN VIDEO', 'pins':[
            Pin(num='1',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DRVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='THREE-STATE',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='STBY',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='REFSENSE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CLAMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DRVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CLAMPIN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='REFTS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='REFTF',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='REFBF',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='REFBS',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AIN',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='D4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9283', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9283'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD9283.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD9283\n\nADC', 'pins':[
            Pin(num='1',name='PWRDWN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DO7',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='DO6',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DO5',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DO4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='DO3',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='DO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='DO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VREFout',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DO0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VREFin',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VaD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Ain-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Ain+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VaD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC0800', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC0800'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'CAD', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/snas562/snas562.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC0800\n\nCAD', 'pins':[
            Pin(num='1',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='Clk',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Vin',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Rtop',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='Rbot',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Start',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='-Vgg',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='EOC',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC08060', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC08060'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ADC CAN VIDEO', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/adc08060.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC08060\n\nADC CAN VIDEO', 'pins':[
            Pin(num='1',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VRB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='PWR_DWN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VRT',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIN_GND',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VRB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC081C021CIMM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC081C021CIMM'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'ADC I2C 8-bit Alert', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/adc081c021.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC081C021CIMM\n\nADC I2C 8-bit Alert', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ALERT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='ADR0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='ADR1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC0832', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC0832'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ADC CAN', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/adc0831-n.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC0832\n\nADC CAN', 'pins':[
            Pin(num='1',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ANALOG0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ANALOG1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC101C021CIMK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC101C021CIMK'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'adc 10-bit i2c', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/adc101c021.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC101C021CIMK\n\nadc 10-bit i2c', 'pins':[
            Pin(num='1',name='V_{A}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='V_{IN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC1173', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC1173'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ADC CAN VIDEO', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/adc1173.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC1173\n\nADC CAN VIDEO', 'pins':[
            Pin(num='1',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VRTS',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='VRT',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VRBS',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VRB',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='D6',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC1283', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC1283'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'ADC 2.7V 3.3V 5.5V SPI 12bit 8-channel', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/adc1283.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC1283\n\nADC 2.7V 3.3V 5.5V SPI 12bit 8-channel', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN5',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC128D818', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC128D818'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'ADC 8 Channels TSSOP I2C', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/adc128d818.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC128D818\n\nADC 8 Channels TSSOP I2C', 'pins':[
            Pin(num='1',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{INT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1013IDGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1013IDGS'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'12 bit single channel I2C ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1015.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1013IDGS\n\n12 bit single channel I2C ADC', 'pins':[
            Pin(num='1',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1014IDGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1014IDGS'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'12 bit single channel I2C ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1015.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1014IDGS\n\n12 bit single channel I2C ADC', 'pins':[
            Pin(num='1',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ALERT/RDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1015IDGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1015IDGS'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'12 bit 4 channel I2C ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1015.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1015IDGS\n\n12 bit 4 channel I2C ADC', 'pins':[
            Pin(num='1',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ALERT/RDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1018IDGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1018IDGS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'12 bit 4 channel SPI ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1018.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1018IDGS\n\n12 bit 4 channel SPI ADC', 'pins':[
            Pin(num='1',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='DOUT/~{DRDY}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1110'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'16 Bit Analog to digital converter ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1110.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1110\n\n16 Bit Analog to digital converter ADC', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VIN-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1120-PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1120-PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'adc spi', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1120.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1120-PW\n\nadc spi', 'pins':[
            Pin(num='1',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN0/REFP1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{DRDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DOUT/~{DRDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AIN3/REFN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='REFN0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='REFP0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1120-RVA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1120-RVA'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'adc spi', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1120.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1120-RVA\n\nadc spi', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='~{DRDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DOUT/~{DRDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN3/REFN1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFN0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='REFP0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN0/REFP1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1232IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1232IPW'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ADC 24bit Sensors Dual Channel', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1232.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1232IPW\n\nADC 24bit Sensors Dual Channel', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='AINP1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AINN1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AINN2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AINP2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='REFN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='REFP',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GAIN0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GAIN1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='SPEED',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{PWDN}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{DRDY}/DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='CLKIN/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='TEMP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CAP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1234IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1234IPW'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ADC 24bit Sensors Quad Channel', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1232.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1234IPW\n\nADC 24bit Sensors Quad Channel', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='CAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='AINP1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AINN1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AINP3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AINN3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINN4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINP4',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AINN2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AINP2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='REFN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='REFP',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='GAIN0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='GAIN1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SPEED',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{PWDN}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='~{DRDY}/DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='CLKIN/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CAP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1243'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'24bit ADC 8 Channels PGA SPI', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1243.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1243\n\n24bit ADC 8 Channels PGA SPI', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='Ain5/D5',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Ain6/D6',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Ain7/D7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Ain2/D2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Ain3/D3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{DRDY}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{PDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Ain0/D0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Ain1/D1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Ain4/D4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1251', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1251'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'delta-sigma adc low-power', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1251.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1251\n\ndelta-sigma adc low-power', 'pins':[
            Pin(num='1',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DOUT/nDRDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS127L01IPBS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS127L01IPBS'}), 'ref_prefix':'U', 'fplist':['Package_QFP:PQFP-32_5x5mm_P0.5mm'], 'footprint':'Package_QFP:PQFP-32_5x5mm_P0.5mm', 'keywords':'Texas Instruments high-speed 24bit', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ads127l01.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS127L01IPBS\n\nTexas Instruments high-speed 24bit', 'pins':[
            Pin(num='1',name='LVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='REFN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CAP2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='FILTER1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='FILTER0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='FSMODE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OSR1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='OSR0',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='START',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DAISYIN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{DRDY}/FSYNC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CAP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='CAP3',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='~{RESET}/~{PWDN}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='HR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AINN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='FORMAT',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='REXT',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{INTLDO}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='REFP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1298xPAG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1298xPAG'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-64_10x10mm_P0.5mm', 'keywords':'24bit ADC 8 Channels PGA SPI Biopotential', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1298.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1298xPAG\n\n24bit ADC 8 Channels PGA SPI Biopotential', 'pins':[
            Pin(num='1',name='IN8N',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN4P',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN3N',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN3P',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IN2N',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN2P',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN1N',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IN1P',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TESTP_PACE_OUT1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TESTP_PACE_OUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN8P',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VREFP',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VREFN',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VCAP4',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='VCAP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='IN7P',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCAP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RESV1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='~{PWDN}',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='START',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN7N',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='DAISY_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='~{DRDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN6N',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='CLKSEL',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='AVDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VCAP3',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN6P',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='RLDREF',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='RLDINV',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='RLDIN',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='RLDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='WCT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='IN5N',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN5P',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN4N',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7040xDCU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7040xDCU'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'8 bit SAR ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7040.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7040xDCU\n\n8 bit SAR ADC', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7828', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7828'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'I2C ADC 12Bits', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7828.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7828\n\nI2C ADC 12Bits', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='REF',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CH5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CH6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7866', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7866'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7866.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7866\n\nADC', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SDO',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='~{CS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS8681RUM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS8681RUM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'ADC SPI analog digital', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads8681.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS8681RUM\n\nADC SPI analog digital', 'pins':[
            Pin(num='1',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SDO-0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='SDO-1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='RVS',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='REFIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='REFCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AIN_P',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN_GND',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CONVST/~{CS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS8684', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS8684'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_4.4x9.7mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-38_4.4x9.7mm_P0.5mm', 'keywords':'adc analog digital spi bipolar input', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads8688.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS8684\n\nadc analog digital spi bipolar input', 'pins':[
            Pin(num='1',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_GND',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='AIN_0P',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AIN_0GND',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AIN_1P',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AIN_1GND',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{RST/PD}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='AIN_2GND',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AIN_2P',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='AIN_3GND',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AIN_3P',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DAISY',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{REFSEL}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='REFIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='REFCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AVDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS8688', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS8688'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_4.4x9.7mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-38_4.4x9.7mm_P0.5mm', 'keywords':'adc analog digital spi bipolar input', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads8688.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS8688\n\nadc analog digital spi bipolar input', 'pins':[
            Pin(num='1',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AUX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AUX_GND',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AIN_6P',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AIN_6GND',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AIN_7P',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AIN_7GND',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AIN_0P',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AIN_0GND',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AIN_1P',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='AIN_1GND',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{RST/PD}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='AIN_2GND',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AIN_2P',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='AIN_3GND',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AIN_3P',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='AIN_4GND',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AIN_4P',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='AIN_5GND',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN_5P',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DAISY',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{REFSEL}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='REFIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='REFCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AVDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AMC3336', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AMC3336'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'isolated adc delta sigma integrated power supply', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/amc3336.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAMC3336\n\nisolated adc delta sigma integrated power supply', 'pins':[
            Pin(num='1',name='DCDC_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='LDO_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='DIAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DCDC_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DCDC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DCDC_HGND',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='HLDO_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='HLDO_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='INP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='HGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CA3300', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CA3300'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'ADC CAN', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nCA3300\n\nADC CAN', 'pins':[
            Pin(num='1',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='-REF',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='CREF',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='OVF',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='ZEN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CE2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CE1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PHAS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='+REF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HX711', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HX711'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'adc load cell 24-bits analog weight', 'description':'', 'datasheet':'https://web.archive.org/web/20220615044707/https://akizukidenshi.com/download/ds/avia/hx711.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nHX711\n\nadc load cell 24-bits analog weight', 'pins':[
            Pin(num='1',name='VSUP',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='INB+',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PD_SCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XO',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='XI',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='RATE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='BASE',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VFB',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBG',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='INA-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='INA+',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='INB-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ICL7106CPL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ICL7106CPL'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'LCD ADC', 'description':'', 'datasheet':'https://www.renesas.com/eu/en/www/doc/datasheet/icl7106-07-07s.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nICL7106CPL\n\nLCD ADC', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='C2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='B2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='F2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='E2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='B3',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='F3',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='E3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='AB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='POL',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='BP/GND',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='G3',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='C3',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='G2',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='INT',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='BUFF',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='A-Z',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C1',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='IN_LO',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='IN_HI',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='COMMON',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='CREF-',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='CREF+',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='REF_LO',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='REF_HI',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='TEST',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OSC3',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='OSC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='B1',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='F1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='G1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='E1',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='D2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'INA234AxYBJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'INA234AxYBJ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-8_0.705x1.468mm_Layout2x4_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-8_0.705x1.468mm_Layout2x4_P0.4mm', 'keywords':'ADC I2C 12-Bit Current Voltage Power Shunt', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ina234.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nINA234AxYBJ\n\nADC I2C 12-Bit Current Voltage Power Shunt', 'pins':[
            Pin(num='A1',name='~{ALERT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='A2',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='B1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='B2',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='C1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='VS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1406CGN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1406CGN'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Low Power ADC 8bit 20Msps', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1406f.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1406CGN\n\nLow Power ADC 8bit 20Msps', 'pins':[
            Pin(num='1',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OF/UF',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VBIAS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AIN+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AVDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1594CS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1594CS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'12bit ADC 4 Channel', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/15948fb.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1594CS\n\n12bit ADC 4 Channel', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CSMUX}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ADCIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{CSADC}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1598CG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1598CG'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'12bit ADC 4 Channel', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/15948fb.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1598CG\n\n12bit ADC 4 Channel', 'pins':[
            Pin(num='1',name='CH5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CSADC}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='ADCIN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CH4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH7',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{CSMUX}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1742', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1742'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'ADC analog digital converter pipeline', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1742f.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1742\n\nADC analog digital converter pipeline', 'pins':[
            Pin(num='1',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='REFLB',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='REFHA',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='REFLA',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='REFHB',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCM',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~{MSBINV}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='ENC',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{ENC}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AIN+',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='D9',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='D10',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='OVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='D11',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='D12',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='D13',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='OF',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='AIN-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1864L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1864L'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'adc spi 1ch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/18645lfs.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1864L\n\nadc spi 1ch', 'pins':[
            Pin(num='1',name='V_{REF}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN^{+}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN^{-}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CONV',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1865L-MS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1865L-MS'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'adc 2ch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/18645lfs.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1865L-MS\n\nadc 2ch', 'pins':[
            Pin(num='1',name='CONV',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{REF}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1865L-S8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1865L-S8'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'adc 2ch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/18645lfs.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1865L-S8\n\nadc 2ch', 'pins':[
            Pin(num='1',name='CONV',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2282xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2282xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2282fb.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2282xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2309xF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2309xF'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'LT ADC 12bit I2C SAR TSSOP', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2309fd.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2309xF\n\nLT ADC 12bit I2C SAR TSSOP', 'pins':[
            Pin(num='16',name='CH5',func=pin_types.INPUT),
            Pin(num='1',name='REFCOMP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='CH4',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='CH6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='CH7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AD0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AD1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2309xUF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2309xUF'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'LT ADC 12bit I2C SAR QFN', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2309fd.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2309xUF\n\nLT ADC 12bit I2C SAR QFN', 'pins':[
            Pin(num='3',name='CH5',func=pin_types.INPUT),
            Pin(num='1',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='AD0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AD1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CH4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CH6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='REFCOMP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2311-16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2311-16'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-16-1EP_3x4.039mm_P0.5mm_EP1.651x2.845mm'], 'footprint':'Package_SO:MSOP-16-1EP_3x4.039mm_P0.5mm_EP1.651x2.845mm', 'keywords':'16-bit adc differential input 5 msps lvds cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/231116fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2311-16\n\n16-bit adc differential input 5 msps lvds cmos', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{CMOS}/LVDS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='OV_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SDO^{-}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='SDO^{+}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='SCK^{-}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCK^{+}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='REFIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='REFOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A_{IN+}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A_{IN-}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~{CNV}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2325-16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2325-16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-52-1EP_7x8mm_P0.5mm_EP5.41x6.45mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-52-1EP_7x8mm_P0.5mm_EP5.41x6.45mm_ThermalVias', 'keywords':'16-Bit 5msps 4 channel adc lvds cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/232516fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2325-16\n\n16-Bit 5msps 4 channel adc lvds cmos', 'pins':[
            Pin(num='1',name='A_{IN4-}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A_{IN2-}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A_{IN2+}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='A_{IN1-}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A_{IN1+}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='A_{IN4+}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='V_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='REFOUT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='~{SDR}/DDR',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{CNV}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{CMOS}/LVDS',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='SDOA^{+}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='SDOA^{-}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='SDOB^{+}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='SDOB^{-}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OV_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='CLKOUT^{+}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='CLKOUT^{-}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='SDOC^{+}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='SDOC^{-}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='OV_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='SDOD^{+}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='A_{IN3-}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='SDOD^{-}',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='SCK^{+}',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='SCK^{-}',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='REFBUFEN',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='V_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='REFOUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A_{IN3+}',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='51',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='52',name='V_{DD}',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='REFOUT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='REFOUT2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2358-16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2358-16'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'16bit Simultaneous Sampling ADC 8 Channels SPI buffered', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/235816f.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2358-16\n\n16bit Simultaneous Sampling ADC 8 Channels SPI buffered', 'pins':[
            Pin(num='1',name='IN6-',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2+',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN1-',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN1+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IN0-',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN0+',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='REFIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN6+',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='REFBUF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='LVDS/~{CMOS}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CNV',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SDO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='SDI+/SDO1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SDI-/SDO2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SCKI+/SDO3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SCKI-/SCKI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN5-',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='SCKO+/SCKO',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='SCKO-/SDO4',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='SDO+/SDO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='SDO-/SDO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='SDO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='37',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN5+',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDLBYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VEE',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='IN7-',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='IN7+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN4-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN4+',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN3-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN3+',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN2-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2451xDDB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2451xDDB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x3mm_P0.5mm_EP0.61x2.2mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x3mm_P0.5mm_EP0.61x2.2mm', 'keywords':'analog to digital converter adc i2c twi single channel delta sigma 16 bit', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2451fg.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2451xDDB\n\nanalog to digital converter adc i2c twi single channel delta sigma 16 bit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='REF-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='REF+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2451xTS8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2451xTS8'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-8'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-8', 'keywords':'analog to digital converter adc i2c twi single channel delta sigma 16 bit', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2451fg.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2451xTS8\n\nanalog to digital converter adc i2c twi single channel delta sigma 16 bit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='REF-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='REF+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2508CDKD-32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2508CDKD-32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-24-1EP_4x7mm_P0.5mm_EP2.64x6.44mm'], 'footprint':'Package_DFN_QFN:DFN-24-1EP_4x7mm_P0.5mm_EP2.64x6.44mm', 'keywords':'LT ADC 32bit', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/250832fc.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2508CDKD-32\n\nLT ADC 32bit', 'pins':[
            Pin(num='1',name='~{RDLA}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{DRL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='SDOA',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='SCKA',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCKB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{RDLB}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SDOB',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OV_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='REF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX1112', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX1112'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'MAXIM ADC 5V 8-Bit SPI QSPI MICROWIRE', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX1112-MAX1113.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX1112\n\nMAXIM ADC 5V 8-Bit SPI QSPI MICROWIRE', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='REFIN',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='REFOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SSTRB',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CH5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CH6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11120xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11120xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 8-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11120xTI\n\nMAXIM ADC 3.3V 8-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{CNVST}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11123xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11123xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 8-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11123xTI\n\nMAXIM ADC 3.3V 8-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{CNVST}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11126xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11126xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 8-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11126xTI\n\nMAXIM ADC 3.3V 8-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN12',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN13',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CNVST}/AIN14',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-/AIN15',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN8',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN9',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN10',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN11',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX1113', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX1113'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:QSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'MAXIM ADC 5V 8-Bit SPI QSPI MICROWIRE', 'description':'', 'datasheet':'http://datasheets.maximintegrated.com/en/ds/MAX1112-MAX1113.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX1113\n\nMAXIM ADC 5V 8-Bit SPI QSPI MICROWIRE', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SSTRB',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='REFIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='REFOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11612', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11612'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'adc i2c 4ch', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11612-MAX11617.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11612\n\nadc i2c 4ch', 'pins':[
            Pin(num='1',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN3/REF',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Vdd',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11614', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11614'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:QSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'adc i2c 8ch', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11612-MAX11617.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11614\n\nadc i2c 8ch', 'pins':[
            Pin(num='1',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11616', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11616'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:QSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'adc i2c 12ch', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11612-MAX11617.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11616\n\nadc i2c 12ch', 'pins':[
            Pin(num='1',name='AIN11',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AIN10',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AIN9',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX1248', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX1248'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'10-Bit ADC Internal Reference Serial 4-Channel Maxim', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX1248-MAX1249.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX1248\n\n10-Bit ADC Internal Reference Serial 4-Channel Maxim', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SSTRB',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{SHDN}',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='VREF',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='REFADJ',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX1274', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX1274'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'12bit ADC 1CH diff differential', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX1274-MAX1275.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX1274\n\n12bit ADC 1CH diff differential', 'pins':[
            Pin(num='1',name='AIN-',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='AIN+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='RGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='CNVST',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3002', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3002'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Channel 10-Bit ADC SPI 2CH', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21294E.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3002\n\nDual Channel 10-Bit ADC SPI 2CH', 'pins':[
            Pin(num='1',name='~{CS}/SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH0',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD/VREF',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3004', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3004'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'10-Bit ADC SPI 4CH', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21295C.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3004\n\n10-Bit ADC SPI 4CH', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Dout',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{CS}/SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Din',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3201'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'12-Bit Differential ADC SPI 1ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21290D.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3201\n\n12-Bit Differential ADC SPI 1ch', 'pins':[
            Pin(num='1',name='Vref',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{CS}/SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Dout',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vdd',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3204', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3204'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'12bit ADC Reference Single Supply SPI 4ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21298c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3204\n\n12bit ADC Reference Single Supply SPI 4ch', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Dout',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='Vref',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{CS}/SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Din',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3208'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'12bit ADC Reference Single Supply SPI 8ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21298c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3208\n\n12bit ADC Reference Single Supply SPI 8ch', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CS}/SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Din',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Dout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='Vref',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CH5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CH6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3301'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'13-Bit Differential ADC SPI  1ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21700D.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3301\n\n13-Bit Differential ADC SPI  1ch', 'pins':[
            Pin(num='1',name='Vref',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{CS}/SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Dout',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vdd',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3422Axx-xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3422Axx-xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'18-Bit ADC I2C Delta-Sigma-ADC Delta-Sigma-ADC Reference 2ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22088c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3422Axx-xSN\n\n18-Bit ADC I2C Delta-Sigma-ADC Delta-Sigma-ADC Reference 2ch', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH2-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3423x-xUN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3423x-xUN'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'18-Bit ADC I2C Delta-Sigma-ADC Delta-Sigma-ADC Reference 2ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22088c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3423x-xUN\n\n18-Bit ADC I2C Delta-Sigma-ADC Delta-Sigma-ADC Reference 2ch', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH2-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3424x-xSL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3424x-xSL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'18-Bit ADC I2C IIC IÂ²C Delta-Sigma-ADC Reference 4ch quadruple', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22088c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3424x-xSL\n\n18-Bit ADC I2C IIC IÂ²C Delta-Sigma-ADC Reference 4ch quadruple', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CH3+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CH3-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CH4+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CH4-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH2-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3425Axx-xCH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3425Axx-xCH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Sigma-Delta ADC Converter 16bit I2C  1ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22072b.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3425Axx-xCH\n\nSigma-Delta ADC Converter 16bit I2C  1ch', 'pins':[
            Pin(num='1',name='Vin+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vin-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3426Axx-xMC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3426Axx-xMC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_3x2mm_P0.5mm_EP1.75x1.45mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_3x2mm_P0.5mm_EP1.75x1.45mm', 'keywords':'adc 2ch 16bit i2c', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22226a.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3426Axx-xMC\n\nadc 2ch 16bit i2c', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH2-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{SS}',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3426Axx-xMS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3426Axx-xMS'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'adc 2ch 16bit i2c', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22226a.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3426Axx-xMS\n\nadc 2ch 16bit i2c', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH2-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3427x-xMF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3427x-xMF'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_3x3mm_P0.5mm_EP1.66x2.38mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_3x3mm_P0.5mm_EP1.66x2.38mm', 'keywords':'adc 2ch 16bit i2c', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22226a.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3427x-xMF\n\nadc 2ch 16bit i2c', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Adr1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH2-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Adr0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3427x-xUN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3427x-xUN'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'adc 2ch 16bit i2c', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22226a.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3427x-xUN\n\nadc 2ch 16bit i2c', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Adr1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH2-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Adr0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3428x-xSL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3428x-xSL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'adc 4ch 16bit i2c', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22226a.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3428x-xSL\n\nadc 4ch 16bit i2c', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Adr1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CH3+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CH3-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CH4+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CH4-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH2-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Adr0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3550-50-EMS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3550-50-EMS'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Sigma-Delta ADC Converter 22bit SPI 1ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/21950c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3550-50-EMS\n\nSigma-Delta ADC Converter 22bit SPI 1ch', 'pins':[
            Pin(num='1',name='Vref',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Vin+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Vin-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDO/~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vdd',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3550-60-ESN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3550-60-ESN'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Sigma-Delta ADC Converter 22bit SPI 1ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/21950c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3550-60-ESN\n\nSigma-Delta ADC Converter 22bit SPI 1ch', 'pins':[
            Pin(num='1',name='Vref',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Vin+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Vin-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDO/~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD6645', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD6645'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-52-1EP_10x10mm_P0.65mm_EP6.5x6.5mm', 'Package_QFP:TQFP-52-1EP_10x10mm_P0.65mm_EP6.5x6.5mm'], 'footprint':'Package_QFP:TQFP-52-1EP_10x10mm_P0.65mm_EP6.5x6.5mm', 'keywords':'ADC differential analog digital converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD6645.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD6645\n\nADC differential analog digital converter', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='AIN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{AIN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='OVR',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='DMID',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='D9',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='D10',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='D11',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='ENCODE',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='D12',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='D13',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DRY',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{ENCODE}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AVCC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7322', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7322'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'Analog-Devices ADC bipolar 12-Bit SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7322.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7322\n\nAnalog-Devices ADC bipolar 12-Bit SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='V_{DRIVE}',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF_{IN/OUT}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V_{IN}0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{IN}1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{DD}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7324'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Analog-Devices ADC bipolar 12-Bit SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7324.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7324\n\nAnalog-Devices ADC bipolar 12-Bit SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{IN}2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V_{DRIVE}',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF_{IN/OUT}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V_{IN}0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{IN}1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{IN}3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7328', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7328'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Analog-Devices ADC bipolar 12-Bit SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7328.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7328\n\nAnalog-Devices ADC bipolar 12-Bit SPI', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{IN}5',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_{IN}7',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V_{IN}6',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V_{IN}3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='V_{IN}2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='V_{DRIVE}',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF_{IN/OUT}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V_{IN}0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{IN}1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{IN}4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7689xCP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7689xCP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'ADC, SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7682_7689.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7689xCP\n\nADC, SPI', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CNV',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='REFIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7699BCP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7699BCP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'ADC, SPI', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7699.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7699BCP\n\nADC, SPI', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CNV',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='REFIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7795', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7795'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'adc 6ch 16bit serial', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7794_7795.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nAD7795\n\nadc 6ch 16bit serial', 'pins':[
            Pin(num='1',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN2-',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN3+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AIN3-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFIN1+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFIN1-',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AIN5+/IOUT2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AIN5-/IOUT1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='AIN4+/REFIN2+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AIN4-/REFIN2-',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PSW',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='DOUT/~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='AIN6+/P1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN6-/P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN1+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN1-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN2+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC101C021CIMM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC101C021CIMM'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'ADC I2C 10-bit Alert', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/adc101c021.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC101C021CIMM\n\nADC I2C 10-bit Alert', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ALERT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='ADR0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='ADR1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADC121C021CIMM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADC121C021CIMM'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'ADC I2C 12-bit Alert', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/adc121c021.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADC121C021CIMM\n\nADC I2C 12-bit Alert', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ALERT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='ADR0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='ADR1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1113IDGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1113IDGS'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm', 'Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'16 bit single channel I2C ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1113.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1113IDGS\n\n16 bit single channel I2C ADC', 'pins':[
            Pin(num='1',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1114IDGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1114IDGS'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm', 'Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'16 bit single channel I2C ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1113.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1114IDGS\n\n16 bit single channel I2C ADC', 'pins':[
            Pin(num='1',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ALERT/RDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1115IDGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1115IDGS'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm', 'Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'16 bit 4 channel I2C ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1113.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1115IDGS\n\n16 bit 4 channel I2C ADC', 'pins':[
            Pin(num='1',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ALERT/RDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1118IDGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1118IDGS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'16 bit 4 channel SPI ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1118.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1118IDGS\n\n16 bit 4 channel SPI ADC', 'pins':[
            Pin(num='1',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='DOUT/~{DRDY}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS1220xPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS1220xPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'adc spi', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads1220.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS1220xPW\n\nadc spi', 'pins':[
            Pin(num='1',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN0/REFP1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{DRDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DOUT/~{DRDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AIN3/REFN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='REFN0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='REFP0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7029', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7029'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'8 bit SAR ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7029-q1.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7029\n\n8 bit SAR ADC', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7039', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7039'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'10 bit SAR ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7039-q1.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7039\n\n10 bit SAR ADC', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7041xDCU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7041xDCU'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'10 bit SAR ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7041.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7041xDCU\n\n10 bit SAR ADC', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7042xDCU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7042xDCU'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'12 bit SAR ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7042.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7042xDCU\n\n12 bit SAR ADC', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7043xDCU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7043xDCU'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'12 bit SAR ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7043.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7043xDCU\n\n12 bit SAR ADC', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7044xDCU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7044xDCU'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'12 bit SAR ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7044.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7044xDCU\n\n12 bit SAR ADC', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7049', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7049'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'keywords':'12 bit SAR ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7049-q1.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7049\n\n12 bit SAR ADC', 'pins':[
            Pin(num='1',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AINM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AINP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7867', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7867'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7866.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7867\n\nADC', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SDO',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='~{CS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7868', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7868'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6', 'Package_TO_SOT_SMD:TSOT-23-6'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-6', 'keywords':'ADC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7866.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS7868\n\nADC', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SDO',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='~{CS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS8685RUM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS8685RUM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'ADC SPI analog digital', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads8681.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS8685RUM\n\nADC SPI analog digital', 'pins':[
            Pin(num='1',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SDO-0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='SDO-1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='RVS',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='REFIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='REFCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AIN_P',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN_GND',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CONVST/~{CS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS8689RUM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS8689RUM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'ADC SPI analog digital', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads8681.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nADS8689RUM\n\nADC SPI analog digital', 'pins':[
            Pin(num='1',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SDO-0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='SDO-1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='RVS',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='REFIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='REFGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='REFCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AIN_P',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN_GND',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CONVST/~{CS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ICL7107CPL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ICL7107CPL'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'LED ADC', 'description':'', 'datasheet':'https://www.renesas.com/eu/en/www/doc/datasheet/icl7106-07-07s.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nICL7107CPL\n\nLED ADC', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='C2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='B2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='F2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='E2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='B3',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='F3',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='E3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='AB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='POL',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='BP/GND',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='G3',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='A3',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='C3',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='G2',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='INT',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='BUFF',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='A-Z',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C1',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='IN_LO',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='IN_HI',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='COMMON',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='CREF-',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='CREF+',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='REF_LO',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='REF_HI',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='TEST',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OSC3',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='OSC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='B1',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='OSC1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='F1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='G1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='E1',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='D2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1406IGN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1406IGN'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Low Power ADC 8bit 20Msps', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1406f.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1406IGN\n\nLow Power ADC 8bit 20Msps', 'pins':[
            Pin(num='1',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OF/UF',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VBIAS',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AIN+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AVDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1594IS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1594IS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'12bit ADC 4 Channel', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/15948fb.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1594IS\n\n12bit ADC 4 Channel', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CSMUX}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ADCIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{CSADC}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1598IG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1598IG'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'12bit ADC 4 Channel', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/15948fb.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1598IG\n\n12bit ADC 4 Channel', 'pins':[
            Pin(num='1',name='CH5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CSADC}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='ADCIN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CH4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH7',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{CSMUX}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='COM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1744', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1744'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'ADC analog digital converter pipeline', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1744f.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1744\n\nADC analog digital converter pipeline', 'pins':[
            Pin(num='1',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='REFLB',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='REFHA',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='REFLA',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='REFHB',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCM',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~{MSBINV}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='ENC',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{ENC}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AIN+',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='D9',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='D10',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='OVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='D11',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='D12',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='D13',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='OF',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='AIN-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1746', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1746'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'ADC analog digital converter pipeline', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1746f.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1746\n\nADC analog digital converter pipeline', 'pins':[
            Pin(num='1',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='REFLB',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='REFHA',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='REFLA',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='REFHB',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCM',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~{MSBINV}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='ENC',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{ENC}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AIN+',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='D9',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='D10',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='OVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='D11',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='D12',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='D13',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='OF',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='AIN-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1748', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1748'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-48_6.1x12.5mm_P0.5mm', 'keywords':'ADC analog digital converter pipeline', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1748fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1748\n\nADC analog digital converter pipeline', 'pins':[
            Pin(num='1',name='SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='REFLB',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='REFHA',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='REFLA',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='REFHB',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCM',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~{MSBINV}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='ENC',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{ENC}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='D4',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='D6',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AIN+',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='D9',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='D10',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='OVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='D11',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='D12',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='D13',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='OF',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='AIN-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1864', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1864'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'adc spi 1ch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/18645fb.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1864\n\nadc spi 1ch', 'pins':[
            Pin(num='1',name='V_{REF}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN^{+}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN^{-}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CONV',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1865-MS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1865-MS'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm', 'Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'adc 2ch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/18645fb.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1865-MS\n\nadc 2ch', 'pins':[
            Pin(num='1',name='CONV',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{REF}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1865-S8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1865-S8'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'adc 2ch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/18645fb.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC1865-S8\n\nadc 2ch', 'pins':[
            Pin(num='1',name='CONV',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2284xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2284xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2284fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2284xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2290xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2290xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2290fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2290xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2291xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2291xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/229321fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2291xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2292xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2292xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/229321fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2292xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2293xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2293xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/229321fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2293xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2294xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2294xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2294fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2294xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2295xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2295xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2295fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2295xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2296xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2296xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/229876fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2296xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2297xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2297xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/229876fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2297xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2298xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2298xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/229876fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2298xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2299xUP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2299xUP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.15x7.15mm', 'keywords':'ADC', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/2299fa.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2299xUP\n\nADC', 'pins':[
            Pin(num='1',name='AINA+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='REFLB',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='REFHB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='AINB-',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AINB+',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='SENSEB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AINA-',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCMB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MUX',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SHDNB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{OEB}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DB0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DB3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DB4',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='DB5',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DB6',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='DB7',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='DB8',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DB9',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DB10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='DB11',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='REFHA',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='OFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='DA0',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='DA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='DA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='DA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='DA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='OGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='DA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='DA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='DA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='DA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='DA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='OFA',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='~{OEA}',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='SHDNA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='REFLA',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='VCMA',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SENSEA',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CLKA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2358-18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2358-18'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'18bit Simultaneous Sampling ADC 8 Channels SPI buffered', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/235818f.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2358-18\n\n18bit Simultaneous Sampling ADC 8 Channels SPI buffered', 'pins':[
            Pin(num='1',name='IN6-',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2+',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN1-',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN1+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IN0-',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN0+',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='REFIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN6+',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='REFBUF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PD',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='LVDS/~{CMOS}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CNV',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SDO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='SDI+/SDO1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SDI-/SDO2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SCKI+/SDO3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SCKI-/SCKI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN5-',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='SCKO+/SCKO',func=pin_types.TRISTATE,unit=1),
            Pin(num='33',name='SCKO-/SDO4',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='SDO+/SDO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='SDO-/SDO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='SDO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='37',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN5+',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDLBYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VEE',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='IN7-',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='IN7+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN4-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN4+',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN3-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN3+',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN2-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC2508IDKD-32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC2508IDKD-32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-24-1EP_4x7mm_P0.5mm_EP2.64x6.44mm', 'Package_DFN_QFN:DFN-24-1EP_4x7mm_P0.5mm_EP2.64x6.44mm'], 'footprint':'Package_DFN_QFN:DFN-24-1EP_4x7mm_P0.5mm_EP2.64x6.44mm', 'keywords':'LT ADC 32bit', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/250832fc.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nLTC2508IDKD-32\n\nLT ADC 32bit', 'pins':[
            Pin(num='1',name='~{RDLA}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{DRL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='SDOA',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='SCKA',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SCKB',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{RDLB}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SDOB',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OV_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='REF',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='REF',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11121xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11121xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 10-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11121xTI\n\nMAXIM ADC 3.3V 10-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{CNVST}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11122xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11122xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 12-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11122xTI\n\nMAXIM ADC 3.3V 12-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{CNVST}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11124xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11124xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 10-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11124xTI\n\nMAXIM ADC 3.3V 10-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{CNVST}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11125xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11125xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 12-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11125xTI\n\nMAXIM ADC 3.3V 12-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{CNVST}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11127xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11127xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 10-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11127xTI\n\nMAXIM ADC 3.3V 10-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN12',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN13',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CNVST}/AIN14',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-/AIN15',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN8',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN9',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN10',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN11',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11128xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11128xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'MAXIM ADC 3.3V 12-Bit SPI', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11120-MAX11128.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11128xTI\n\nMAXIM ADC 3.3V 12-Bit SPI', 'pins':[
            Pin(num='1',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN12',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN13',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CNVST}/AIN14',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='REF-/AIN15',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='REF+',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN4',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='~{EOC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN8',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN9',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN10',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN11',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11613', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11613'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'adc i2c 4ch', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11612-MAX11617.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11613\n\nadc i2c 4ch', 'pins':[
            Pin(num='1',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN3/REF',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Vdd',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11615', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11615'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:QSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:QSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'adc i2c 8ch', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11612-MAX11617.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11615\n\nadc i2c 8ch', 'pins':[
            Pin(num='1',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX11617', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX11617'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:QSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:QSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'adc i2c 12ch', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX11612-MAX11617.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX11617\n\nadc i2c 12ch', 'pins':[
            Pin(num='1',name='AIN11',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AIN5',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AIN6',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='AIN7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AIN10',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AIN9',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AIN8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AIN0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AIN3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AIN4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX1249', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX1249'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'10-Bit ADC Serial 4-Channel Maxim', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX1248-MAX1249.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX1249\n\n10-Bit ADC Serial 4-Channel Maxim', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SSTRB',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{SHDN}',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='VREF',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='REFADJ',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX1275', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX1275'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'12bit ADC 1CH diff differential', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX1274-MAX1275.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMAX1275\n\n12bit ADC 1CH diff differential', 'pins':[
            Pin(num='1',name='AIN-',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='AIN+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='RGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='CNVST',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3008', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3008'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'12bit ADC Reference Single Supply SPI 8CH', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21295d.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3008\n\n12bit ADC Reference Single Supply SPI 8CH', 'pins':[
            Pin(num='1',name='CH0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CS}/SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Din',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Dout',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='Vref',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CH4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CH5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CH6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3202'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'12bit ADC Reference Single Supply SPI 2ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21034D.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3202\n\n12bit ADC Reference Single Supply SPI 2ch', 'pins':[
            Pin(num='1',name='~{CS}/SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH0',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD/VREF',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3421A0T-ECH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3421A0T-ECH'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', ''], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'Sigma-Delta ADC Converter 18bit I2C 1ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22003e.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3421A0T-ECH\n\nSigma-Delta ADC Converter 18bit I2C 1ch', 'pins':[
            Pin(num='1',name='Vin+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vin-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3422Axx-xMS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3422Axx-xMS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'18-Bit ADC I2C Delta-Sigma-ADC Delta-Sigma-ADC Reference 2ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22088c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3422Axx-xMS\n\n18-Bit ADC I2C Delta-Sigma-ADC Delta-Sigma-ADC Reference 2ch', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH2-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3424x-xST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3424x-xST'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'18-Bit ADC I2C Delta-Sigma-ADC Reference 4ch quadruple', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22088c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3424x-xST\n\n18-Bit ADC I2C Delta-Sigma-ADC Reference 4ch quadruple', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CH3+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CH3-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CH4+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CH4-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH2-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3426Axx-xSN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3426Axx-xSN'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'adc 2ch 16bit i2c', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22226a.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3426Axx-xSN\n\nadc 2ch 16bit i2c', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CH2-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3428x-xST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3428x-xST'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'adc 4ch 16bit i2c', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22226a.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3428x-xST\n\nadc 4ch 16bit i2c', 'pins':[
            Pin(num='1',name='CH1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Adr1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CH3+',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CH3-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CH4+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CH4-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CH1-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CH2+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CH2-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Adr0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3551-EMS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3551-EMS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Sigma-Delta ADC Converter 22bit SPI 1ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/21950c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3551-EMS\n\nSigma-Delta ADC Converter 22bit SPI 1ch', 'pins':[
            Pin(num='1',name='Vref',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Vin+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Vin-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDO/~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vdd',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP3553-ESN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP3553-ESN'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Sigma-Delta ADC Converter 22bit SPI 1ch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/21950c.pdf', 'search_text':'/usr/share/kicad/symbols/Analog_ADC.kicad_sym\nMCP3553-ESN\n\nSigma-Delta ADC Converter 22bit SPI 1ch', 'pins':[
            Pin(num='1',name='Vref',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Vin+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Vin-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDO/~{RDY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])