from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

FPGA_Xilinx = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'XC2018-PC68', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2018-PC68'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2018-PC68\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P11-GCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='M2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='HDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='LDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='P31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43-XI',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='D/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P46-XO',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='P53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='P54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='P55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='P64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2018-PC84', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2018-PC84'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2018-PC84\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11/GCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='P26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='P27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='P28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='P30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='M2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='P52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='XTL2(I)/P53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='DONE/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='XTL1(O)/P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='CS0/P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='CS1/P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='CS2/P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='WRT/P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='P71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='DOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='P76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='P77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='P78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='P79',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2C256-TQ144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2C256-TQ144'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-144_20x20mm_P0.5mm', 'keywords':'CPLD', 'description':'', 'datasheet':'https://www.xilinx.com/support/documentation/data_sheets/ds094.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2C256-TQ144\n\nCPLD', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='P100',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='P101',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='P102',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='P103',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='P104',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='P105',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='P106',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='P107',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='P110',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='P111',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='P112',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='P113',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='P114',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='P115',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='P116',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='P117',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='P118',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='P119',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='P120',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='P121',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='124',name='P124',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='P125',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='P126',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='P128',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='P129',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='P130',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='P131',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='P132',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='P133',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='P134',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='P135',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='P136',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='P137',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='P138',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='P139',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='P140',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='142',name='P142',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='GSR',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P18',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P19',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GTS2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P20',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P22',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P23',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P25',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P26',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='P28',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GTS3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GCK0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P31',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='CDRST',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='GCK2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DGE',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P40',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P43',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P44',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P45',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P46',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GTS0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P50',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P51',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P52',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P53',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P54',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='P56',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P59',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GTS1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P60',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P61',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P64',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P66',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P69',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='P71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='P74',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P75',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P76',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P77',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P78',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P79',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='P80',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P82',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='P83',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='P85',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P88',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='P91',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P92',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='P94',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='P96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='P97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='P98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2C256-VQ100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2C256-VQ100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:VQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:VQFP-100_14x14mm_P0.5mm', 'keywords':'CPLD', 'description':'', 'datasheet':'https://www.xilinx.com/support/documentation/data_sheets/ds094.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2C256-VQ100\n\nCPLD', 'pins':[
            Pin(num='1',name='P1/GTS2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P10',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P12',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P18',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P19',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2/GTS3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='P22/GCK0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P23/GCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P24/CDRST',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='P27/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P28/DGE',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P3/GTS0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P35',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P37',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='P39',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P4/GTS1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P40',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='P42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='P43',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P44',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='P46',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='P49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='P50',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='P52',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P53',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P54',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P55',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P56',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='P58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P59',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P60',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P61',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P64',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P65',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P66',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P67',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='P71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='P72',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='P73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P74',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='P76',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P77',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P78',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P79',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P8',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='P80',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P82',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='P85',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='P89',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P9',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='P90',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P91',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P92',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='P93',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='P94',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='P96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='P97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='99',name='P99/GSA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2S100TQ144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2S100TQ144'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'xilinx/spartan2e/spartan2e.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2S100TQ144\n\nFPGA', 'pins':[
            Pin(num='1',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO7P10',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='107',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='108',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='112',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='IO/TRDY',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='IO/IRDY',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='139/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='I/GCK3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='I/GCK2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO/REF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='/WR',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='/CS',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='BUSY/DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='D0/DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO/D1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='IO/D2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO/D3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='IO/IRDY',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='IO/TRDY',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='IO/D4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='IO/D5',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='IO/D6',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='IO/D7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='~{INIT/IO}',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='~{PROG}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='DONE',func=pin_types.OPENCOLL,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='I/CCK0',func=pin_types.INPUT,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='I/GCK1',func=pin_types.INPUT,unit=1),
            Pin(num='93',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='IO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2S150PQ208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2S150PQ208'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'xilinx/spartan2e/spartan2e.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2S150PQ208\n\nFPGA', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO7P10',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='IO4P100',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='IO4P101',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO4P102',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='104',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='/PROG',func=pin_types.INPUT,unit=1),
            Pin(num='107',name='/INIT',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='IO3/D7P108',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='IO3P109',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='110',name='IO3P110',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO3VRP111',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO3P112',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='IO3P113',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO3P114',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO3/D6P115',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='117',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='118',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='IO3/D5P119',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='IO3P120',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO3P121',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='IO3P122',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='IO3P123',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='125',name='IO3VRP125',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='IO3/D4P126',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='IO3P127',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='129',name='TRDY3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='132',name='IRDY2',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO2P133',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO2P134',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='IO2/D3P135',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='IO2VRP136',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='IO2P138',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO2P139',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO7P14',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='IO2P140',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO2P141',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='IO2/D2P142',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='145',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='146',name='IO2/D1P46',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='IO2P147',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='IO2P148',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='IO2P149',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO7P15',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='IO2VRP150',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='IO2P151',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='IO2P152',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='D0/DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='BUSY/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='157',name='TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO7P16',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='/CS',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='/WR',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='IO1P162',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='IO1P163',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='IO1VRP164',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='IO1P165',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='IO1P166',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='IO1P167',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='IO1P168',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='IO7P17',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='171',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='IO1P172',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='IO1P173',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='IO1P174',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='IO1P175',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='IO1P176',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='178',name='IO1VRP178',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='IO1P179',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO7P18',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='IO1P180',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='IO1P181',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='GCK2',func=pin_types.INPUT,unit=1),
            Pin(num='183',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='184',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='185',name='GCK3',func=pin_types.INPUT,unit=1),
            Pin(num='186',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='187',name='IO0P187',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='IO0P188',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='IO0VRP189',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='190',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='191',name='IO0P191',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='IO0P192',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='IO0P193',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='IO0P194',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='IO0P195',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='197',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='198',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='199',name='IO0P199',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO7VRP20',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='IO0P200',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='IO0P201',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='IO0P202',func=pin_types.BIDIR,unit=1),
            Pin(num='203',name='IO0VRP203',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='IO0P204',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='IO0P205',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='IO0P206',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='IO7P21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO7P22',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO7P23',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IRDY7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='TRDY6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='IO6P29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO7P3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO6P30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO6VRP31',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='IO6P33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO6P34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO6P35',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO6P36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO6P37',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='IO7P4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IO6P41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO6P42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO6P43',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO6P44',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='IO6VRP45',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='IO6P46',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='IO6P47',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO6P48',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO6P49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO7P5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='IO5P57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO5P58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='IO5VRP59',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO7VRP6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='IO5P60',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='IO5P61',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO5P62',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO5P63',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='IO5P67',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO5P68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IO5P69',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO7P7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IO5P70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IO5P71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='IO5VRP73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO5P74',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='GCK1',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IO7P8',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='GCK0',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='IO4P81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='IO4P82',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO4P83',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO4VRP84',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='IO4P86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO4P87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO4P88',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='IO4P89',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO7P9',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='IO4P90',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='IO4P94',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO4P95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO4P96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO4P97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO4VRP98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO4P99',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2S200PQ208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2S200PQ208'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'xilinx/spartan2e/spartan2e.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2S200PQ208\n\nFPGA', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IO7P10',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='IO4VRP100',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='IO4P101',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO4P102',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='104',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='106',name='/PROG',func=pin_types.INPUT,unit=1),
            Pin(num='107',name='/INIT',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='IO3/D7P108',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='IO3VRP109',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='110',name='IO3P110',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO3VRP111',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO3P112',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='IO3P113',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO3VRP114',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO3/D6P115',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='117',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='IO3/D5P119',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='IO3P120',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO3P121',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='IO3P122',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='IO3P123',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='125',name='IO3VRP125',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='IO3/D4P126',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='IO3P127',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='TRDY3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='130',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='132',name='IRDY2',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO2P133',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO2P134',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='IO2/D3P135',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='IO2VRP136',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='IO2P138',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO2P139',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO7P14',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='IO2P140',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO2P141',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='IO2/D2P142',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='145',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='146',name='IO2/D1P46',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='IO2VRP147',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='IO2P148',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='IO2P149',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO7P15',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='IO2VRP150',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='IO2P151',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='IO2VRP152',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='D0/DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='BUSY/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='157',name='TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO7P16',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='/CS',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='/WR',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='IO1VRP162',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='IO1P163',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='IO1VRP164',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='IO1P165',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='IO1P166',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='IO1VRP167',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='IO1P168',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='IO7P17',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='172',name='IO1P172',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='IO1P173',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='IO1P174',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='IO1P175',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='IO1P176',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='178',name='IO1VRP178',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='IO1P179',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO7P18',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='IO1P180',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='IO1P181',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='GCK2',func=pin_types.INPUT,unit=1),
            Pin(num='183',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='184',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='GCK3',func=pin_types.INPUT,unit=1),
            Pin(num='186',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='IO0P187',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='IO0P188',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='IO0VRP189',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='190',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='191',name='IO0P191',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='IO0P192',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='IO0P193',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='IO0P194',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='IO0P195',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='197',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='198',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='199',name='IO0P199',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO7VRP20',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='IO0VRP200',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='IO0P201',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='IO0P202',func=pin_types.BIDIR,unit=1),
            Pin(num='203',name='IO0VRP203',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='IO0P204',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='IO0VRP205',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='IO0P206',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='IO7P21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO7P22',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO7P23',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IRDY7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='TRDY6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='IO6P29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO7P3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO6P30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO6VRP31',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='IO6P33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO6P34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO6P35',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO6P36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO6P37',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IO7VRP4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IO6P41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO6VRP42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO6P43',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO6P44',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='IO6VRP45',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='IO6P46',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='IO6VRP47',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO6P48',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO6P49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO7P5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='IO5VRP57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO5P58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='IO5VRP59',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO7VRP6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='IO5P60',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='IO5P61',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO5VRP62',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO5P63',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='IO5P67',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO5P68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IO5P69',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO7P7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IO5P70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IO5P71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='IO5VRP73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO5P74',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO5P75',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GCK1',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IO7P8',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='GCK0',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='IO4P81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='IO4P82',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO4P83',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO4VRP84',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='IO4P86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO4P87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO4P88',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='IO4P89',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO7VRP9',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='IO4P90',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='IO4P94',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO4VRP95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO4P96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO4P97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO4VRP98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO4P99',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2S300PQ208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2S300PQ208'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'xilinx/spartan2e/spartan2e.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2S300PQ208\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO7VRP10',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='IO4VRP100',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='IO4P101',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO4P102',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='104',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='/PROG',func=pin_types.INPUT,unit=1),
            Pin(num='107',name='/INIT',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='IO3/D7P108',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='IO3VRP109',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO7P11',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='IO3P110',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO3VRP111',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO3P112',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='IO3P113',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO3P114',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO3VRP115',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='IO3/D6P116',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='IO3/D5P120',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO3P121',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='IO3P122',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='IO3P123',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='125',name='IO3VRP125',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='IO3/D4P126',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='IO3P127',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='129',name='TRDY3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='132',name='IRDY2',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO2P133',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO2P134',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='IO2/D3P135',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='IO2VRP136',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='IO2P138',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO2P139',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='IO2P140',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO2/D2P141',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='143',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='145',name='IO2/D1P145',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='IO2VRP146',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='IO2P147',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='IO2P148',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='IO2P149',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO7P15',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='IO2VRP150',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='IO2P151',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='IO2VRP152',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='D0/DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='BUSY/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='157',name='TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO7P16',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='/CS',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='/WR',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='IO1VRP162',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='IO1P163',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='IO1VRP164',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='IO1P165',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='IO1P166',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='IO1P167',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='IO1VRP168',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='IO1P169',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO7P17',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='172',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='IO1P173',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='IO1P174',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='IO1P175',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='IO1P176',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='178',name='IO1VRP178',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='IO1P179',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO7P18',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='IO1P180',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='IO1P181',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='GCK2',func=pin_types.INPUT,unit=1),
            Pin(num='183',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='184',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='185',name='GCK3',func=pin_types.INPUT,unit=1),
            Pin(num='186',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='187',name='IO0P187',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='IO0P188',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='IO0VRP189',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='190',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='191',name='IO0P191',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='IO0P192',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='IO0P193',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='IO0P194',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='196',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='197',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='198',name='IO0P198',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='IO0VRP199',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO7VRP20',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='IO0P200',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='IO0P201',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='IO0P202',func=pin_types.BIDIR,unit=1),
            Pin(num='203',name='IO0VRP203',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='IO0P204',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='IO0VRP205',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='IO0P206',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='IO7P21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO7P22',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO7P23',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IRDY7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='TRDY6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='IO6P29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO7P3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO6P30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO6VRP31',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='IO6P33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO6P34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO6P35',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO6P36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IO7VRP4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO6P40',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IO6VRP41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO6P42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO6P43',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO6P44',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='IO6VRP45',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='IO6P46',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='IO6VRP47',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO6P48',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO6P49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO7P5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='IO5P55',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='IO5P56',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='IO5VRP57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO5P58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='IO5VRP59',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO7VRP6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='IO5P60',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='IO5P61',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO5P62',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO5VRP63',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='IO5P64',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='68',name='IO5P68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IO5P69',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO7P7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IO5P70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IO5P71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='IO5VRP73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO5P74',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO5P75',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='GCK1',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IO7P8',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='GCK0',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='IO4P81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='IO4P82',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO4P83',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO4VRP84',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='IO4P86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO4P87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO4P88',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='IO4P89',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO7VRP9',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='IO4P93',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='IO4VRP94',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO4P95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO4P96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO4P97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO4VRP98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO4P99',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2S400FT256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2S400FT256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2S400FT256\n\n', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO1A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO1A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO1A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='/WR',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='/CS',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO0VRA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO0A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO0A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO0A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO0VRA7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO1DLLA8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO1VRA9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO1B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO1VRB11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO1B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO1VRB13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B16',name='D0/DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='IO0B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO0B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO0VRB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO0B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO0B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='GCK2',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='IO1B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO7VRC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO1C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO1C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO1C12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='BUSY/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO2VRC16',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO7C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='IO0C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO0VRC5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO0C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO0C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='GCK3',func=pin_types.INPUT,unit=1),
            Pin(num='C9',name='IO1C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO7D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO1D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO1D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO1VRD12',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='IO2VRD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO2D15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO2VRD16',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO7D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO7D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='IO0D5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO0D6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO0VRD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO0DLLD8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO1VRD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO7E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO1E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO1E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='IO2E13',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO2E14',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO2D1E15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO2E16',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO7E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO7VRE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO7E4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='IO0E6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO0E7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='IO7F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='IO2F12',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO2F13',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO2D2F14',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO2F15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO2VRF16',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO7F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO7F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='IO7VRF4',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='IO7F5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='IO7G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='IO2G12',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO2G13',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO2G14',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO2D3G15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO2G16',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO7VRG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO7G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO7G4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='IO7G5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCCO7',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='IRDY7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='IO2H13',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO2VRH14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO2H15',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IRDY2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO7H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO7VRH3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='IO7H4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VCCO7',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCCO7',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='IO6J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='TRDY3',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO3D4J14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO3J15',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO3VRJ16',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO6VRJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='IO6J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='TRDY6',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VCCO6',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VCCO6',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='IO6VRK1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='IO3K12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO3VRK13',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO3K14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO3K15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO3K16',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='IO6K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO6K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO6K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO6K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCCO6',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='IO6L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VCCO4',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='IO3L12',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO3D5L13',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO3L14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO3VRL15',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO3D6L16',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO6L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO6L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO6L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO6VRL5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VCCO5',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VCCO5',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VCCO4',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='IO6M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='IO4M10',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='IO4VRM11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='IO3M13',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO3M14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO3VRM15',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO3M16',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='IO6VRM2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='IO6M3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO6M4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='IO5M6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='IO5VRM7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VCCO5',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VCCO4',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='IO6N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='IO4N10',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='IO4N11',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO4N12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='IO3N14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO3N15',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO3VRN16',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO6N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='IO6VRN3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='IO5N5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='IO5N6',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='IO5N7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='IO5N8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='IO4N9',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='IO6P1',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='IO4P10',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='IO4P11',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='IO4P12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO4P13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='P15',name='/INIT',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO3D7P16',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='IO6P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='P4',name='IO5P4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='IO5P5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='IO5P6',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='IO5P7',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='IO5VRP8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='IO4VRP9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='IO4VRR10',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO4R11',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO4VRR12',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO4VRR13',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO4R14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R16',name='/PROG',func=pin_types.INPUT,unit=1),
            Pin(num='R2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='R4',name='IO5R4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='IO5VRR5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IO5VRR6',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='IO5R7',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='IO5DLLR8',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='IO4DLLR9',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='IO4T10',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='IO4T11',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO4T12',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO4T13',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO4T14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='T3',name='IO5VRT3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='IO5T4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO5T5',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='IO5T6',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='IO5T7',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='GCK1',func=pin_types.INPUT,unit=1),
            Pin(num='T9',name='GCK0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2S50-PQ208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2S50-PQ208'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2S50-PQ208\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='IO7P10',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='IO4P100',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='IO4P101',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO4P102',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='104',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='106',name='/PROG',func=pin_types.INPUT,unit=1),
            Pin(num='107',name='/INIT',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='IO3/D7P108',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='IO3P109',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='110',name='IO3P110',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO3VRP111',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO3P112',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='IO3P113',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO3P114',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO3/D6P115',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='117',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='IO3/D5P119',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='IO3P120',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO3P121',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='IO3P122',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='IO3P123',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='125',name='IO3VRP125',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='IO3/D4P126',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='IO3P127',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='TRDY3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='130',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='132',name='IRDY2',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO2P133',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO2P134',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='IO2/D3P135',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='IO2VRP136',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='IO2P138',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO2P139',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO7P14',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='IO2P140',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO2P141',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='IO2/D2P142',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='145',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='146',name='IO2/D1P46',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='IO2P147',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='IO2P148',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='IO2P149',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO7P15',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='IO2VRP150',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='IO2P151',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='IO2P152',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='D0/DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='BUSY/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='157',name='TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO7P16',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='/CS',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='/WR',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='IO1P162',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='IO1P163',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='IO1VRP164',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='IO1P165',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='IO1P166',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='IO1P167',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='IO1P168',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='IO7P17',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='172',name='IO1P172',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='IO1P173',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='IO1P174',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='IO1P175',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='IO1P176',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='178',name='IO1VRP178',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='IO1P179',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO7P18',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='IO1P180',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='IO1P181',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='GCK2',func=pin_types.INPUT,unit=1),
            Pin(num='183',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='184',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='GCK3',func=pin_types.INPUT,unit=1),
            Pin(num='186',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='IO0P187',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='IO0P188',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='IO0VRP189',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='190',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='191',name='IO0P191',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='IO0P192',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='IO0P193',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='IO0P194',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='IO0P195',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='197',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='198',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='199',name='IO0P199',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO7VRP20',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='IO0P200',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='IO0P201',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='IO0P202',func=pin_types.BIDIR,unit=1),
            Pin(num='203',name='IO0VRP203',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='IO0P204',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='IO0P205',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='IO0P206',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='IO7P21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO7P22',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO7P23',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IRDY7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='TRDY6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='IO6P29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO7P3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO6P30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO6VRP31',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='IO6P33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO6P34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO6P35',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO6P36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO6P37',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IO7P4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IO6P41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO6P42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO6P43',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO6P44',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='IO6VRP45',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='IO6P46',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='IO6P47',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO6P48',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO6P49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO7P5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='IO5P57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO5P58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='IO5VRP59',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO7VRP6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='IO5P60',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='IO5P61',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO5P62',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO5P63',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='IO5P67',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO5P68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IO5P69',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO7P7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IO5P70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IO5P71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='IO5VRP73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO5P74',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='CGK1',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='IO7P8',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='CGK0',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='IO4P81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='IO4P82',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO4P83',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO4VRP84',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='IO4P86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO4P87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO4P88',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='IO4P89',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO7P9',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='IO4P90',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='VCCO',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='IO4P94',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO4P95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO4P96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO4P97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO4VRP98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO4P99',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2S64A-xQFG48', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2S64A-xQFG48'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'xilinx/xc2c64.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2S64A-xQFG48\n\n', 'pins':[
            Pin(num='1',name='GTS0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GCK0',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GCK2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='B12',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='B13',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VCCio1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GTS1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='D10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VCCint',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCCjtag',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D16',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='C15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='C14',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='C12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='C11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='C10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='C9',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='C6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='C5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VCCio2',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='C3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='C2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='C1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GSR',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GTS2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='GTS3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='B4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3020-PC68', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3020-PC68'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3020-PC68\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22/INIT',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='M2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='HDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='LDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='P31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43-XI',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='D/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47-XO',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='P53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='P54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='P55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='P64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3030-PC44', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3030-PC44'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3030-PC44\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='M2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='HDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='LDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='INIT-P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='XIN-P26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='D/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='XOUT-P30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='P31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P8-GCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3030-PC84', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3030-PC84'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3030-PC84\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='P26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='P27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='P28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='P30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='M2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='INIT/P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='P52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='XTL2(I)/P53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='DONE/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='XTL1(O)/P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='CS0/P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='CS1/P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='P71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='DOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='WS/P75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='CS2/P76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='P77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='P78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='P79',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3030-VQ100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3030-VQ100'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3030-VQ100\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/TCLKIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='P30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='P31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='M1/RD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='M0/RT',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='M2',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='P/HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='P55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P/LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P/INIT',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='P64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='P71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='P72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='P/XI',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='76',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='DONE/PG',func=pin_types.OPENCOLL,unit=1),
            Pin(num='78',name='P78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='P/XO',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='P85',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='P86',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='P87',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='P98',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1),
            Pin(num='90',name='P90',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='P91',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='P92',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='P93',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='P94',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='P91',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='P/RDY',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='P/DIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='98',name='P/DOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='CLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3042-VQ100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3042-VQ100'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3042-VQ100\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='P/TCLKIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='P28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='P30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='P31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='M2',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='P/HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='P55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P/LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P/INIT',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='P64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='P71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='P72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='P/XI',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='76',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='DONE/PG',func=pin_types.OPENCOLL,unit=1),
            Pin(num='78',name='P78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='P/XO',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='P85',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='P86',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='P87',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='P98',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1),
            Pin(num='90',name='P90',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='P91',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='P92',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='P93',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='P94',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='P95',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='P/RDY',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='P/DIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='98',name='P/DOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='CLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3S1400A-FG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3S1400A-FG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3S1400A-FG484\n\n', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO_L21P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L18N_0/GCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L18P_0/GCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO_L12N_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO_L12P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L05N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L06N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L36N_0/PUDC_B',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L03N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='A22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L31P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L28N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L26N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L26P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L22N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L22P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L45P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA2',name='IO_L45N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='IO_L02P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='IO_L19P_0/GCLK8',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='B15',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B17',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='B19',name='IO_L06P_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO_L36P_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO_L03P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L31N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L28P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='IO_L25P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO_L24P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO_L01P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L21N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L19N_0/GCLK9',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L17P_0/GCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO_L09P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L08N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO_L07N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L05P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L02N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO_L02N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='PROG_B',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L29P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L27N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L25N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L24N_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO_L06P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L23P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L20P_0/GCLK10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D15',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L08P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO_L07P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L01N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L02P_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO_L01N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO_L03P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO_L29N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO_L27P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L30N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='IO_L06N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L23N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO_L20N_0/GCLK11',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO_L17N_0/GCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO_L14N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L09N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO_L04P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='E17',name='IO_L01P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='E19',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='E2',name='VCCO3',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='IO_L07N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO_L03N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='IO_L35N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO_L34P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='IO_L30P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO_L12N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='F11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='F13',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='F15',name='IO_L04N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='F17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='IO_L12P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO_L08P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='IO_L07P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='IO_L35P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO-L34N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='IO_L13N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G11',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G12',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G13',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G14',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G15',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G16',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='IO_L13P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO_L08N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='IO_L05N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='IO_L05P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G8',name='IP_0/VREF_0',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='IO_L16N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='H11',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='IP_0/VREF_0',func=pin_types.INPUT,unit=1),
            Pin(num='H13',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='H14',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='H2',name='IO_L16P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO_L14N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='IO_L14P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO_L09P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='IO_L09N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IP_L04N_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='H8',name='IP_L04P_3',func=pin_types.INPUT,unit=1),
            Pin(num='H9',name='IP_0/VREF_0',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='IO_L17N_3/VREF_3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='IO_L17P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J5',name='IO_L10N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='IP_L11P_3',func=pin_types.INPUT,unit=1),
            Pin(num='J8',name='IP_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='IO_L22P_3/LHCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='IO_L20N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO_L20P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO_L18N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO_L18P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO_L10P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='IP_L15P_3',func=pin_types.INPUT,unit=1),
            Pin(num='K8',name='IP_L11N_3',func=pin_types.INPUT,unit=1),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='IO_L22N_3/IRDY2/LHCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='IO_L21N_3/LHCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='IO_L21P_3/LHCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='IP_L19P_3',func=pin_types.INPUT,unit=1),
            Pin(num='L8',name='IP_L15N_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='L9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='IO_L24P_3/LHCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='VCCINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M19',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='IO_L24N_3/LHCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='IO_L25P_3/TRDY2/LHCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO_L25N_3/LHCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='IO_L30P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='IP_L23N_3',func=pin_types.INPUT,unit=1),
            Pin(num='M7',name='IP_L23P_3',func=pin_types.INPUT,unit=1),
            Pin(num='M8',name='IP_L19N_3',func=pin_types.INPUT,unit=1),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='IO_L26P_3/VREF_3',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N2',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='N3',name='IO_L26N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='IO_L30N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='IP_L31N_3',func=pin_types.INPUT,unit=1),
            Pin(num='N6',name='IP_L31P_3',func=pin_types.INPUT,unit=1),
            Pin(num='N7',name='IP_L35P_3',func=pin_types.INPUT,unit=1),
            Pin(num='N8',name='IP_L27P_3',func=pin_types.INPUT,unit=1),
            Pin(num='N9',name='IP_L27N_3',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='IO_L28P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='P14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P2',name='IO_L28N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='IO_L29P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P5',name='IO_L29N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='P7',name='IP_L39P_3',func=pin_types.INPUT,unit=1),
            Pin(num='P8',name='IP_L35N_3',func=pin_types.INPUT,unit=1),
            Pin(num='P9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='IO_L32P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='IO_L32N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='IO_L33P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='IO_L33N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='IO_L34P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IP_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='R7',name='IP_L46P_3',func=pin_types.INPUT,unit=1),
            Pin(num='R8',name='IP_L39N_3',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='IO_L36P_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='T12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='IO_L36N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='IO_L34N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO_L40P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='IP_L46N_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='U1',name='IO_L37P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='IO_L37N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='IO_L41P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='IO_L41N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='IO_L40N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V1',name='IO_L38P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='V2',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='V3',name='IO_L38N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='IO_L43P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='W1',name='IO_L42P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W11',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='W14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='IO_L42N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='IO_L43N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='IO_L44P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='IO_L44N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA10',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='IO_L19P_2/GCLK0',func=pin_types.BIDIR,unit=2),
            Pin(num='AA13',name='VCCO2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA14',name='IO_L22P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='IO_L24N_2/DOUT',func=pin_types.BIDIR,unit=2),
            Pin(num='AA17',name='IO_L28P_2/D2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='VCCO2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA19',name='IO_L32N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L36N_2/CCLK',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L35N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='IO_L01P_1/HDC',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='IO_L03N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L04N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='VCCO2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA6',name='IO_L08P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA8',name='IO_L12P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA9',name='VCCO2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB10',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L16N_2/D4',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L19N_2/GCLK1',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L22N_2/MOSI/CSI_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L24P_2/AWAKE',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L27P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L29P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L29N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L32P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='IO_L03P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB20',name='IO_L36P_2/D0/DIN/MISO',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='IO_L35P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='IO_L04P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB4',name='IO_L06P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L06N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L08N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L10N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L12N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L14N_2/D6',func=pin_types.BIDIR,unit=2),
            Pin(num='B21',name='IO_L45N_1/A23',func=pin_types.BIDIR,unit=2),
            Pin(num='B22',name='IO_L45P_1/A22',func=pin_types.BIDIR,unit=2),
            Pin(num='C21',name='IO_L44N_1/A21',func=pin_types.BIDIR,unit=2),
            Pin(num='C22',name='IO_L44P_1/A20',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO_L42N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='D21',name='IO_L42P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='D22',name='IO_L41N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='E20',name='IO_L38P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='E21',name='VCCO1',func=pin_types.PWRIN,unit=2),
            Pin(num='E22',name='IO_L41P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO_L40N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO_L40P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO_L38N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='F21',name='IO_L34N_1/A19',func=pin_types.BIDIR,unit=2),
            Pin(num='F22',name='IO_L34P_1/A18',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO_L46N_1/A25',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO_L46P_1/A24',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='IO_L36P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='G20',name='IO_L36N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='G22',name='IO_L30N_1/A15',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IP_L47N_1',func=pin_types.INPUT,unit=2),
            Pin(num='H16',name='IP_L47P_1/VREF_1',func=pin_types.INPUT,unit=2),
            Pin(num='H17',name='IP_L39P_1',func=pin_types.INPUT,unit=2),
            Pin(num='H18',name='IP_L39N_1',func=pin_types.INPUT,unit=2),
            Pin(num='H19',name='IO_L37N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO_L33N_1/A17',func=pin_types.BIDIR,unit=2),
            Pin(num='H21',name='IO_L33P_1/A16',func=pin_types.BIDIR,unit=2),
            Pin(num='H22',name='IO_L30P_1/A14',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IP_L43N_1/VREF_1',func=pin_types.INPUT,unit=2),
            Pin(num='J16',name='IP_L43P_1',func=pin_types.INPUT,unit=2),
            Pin(num='J17',name='VCCO1',func=pin_types.PWRIN,unit=2),
            Pin(num='J18',name='IO_L37P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO_L29N_1/A13',func=pin_types.BIDIR,unit=2),
            Pin(num='J21',name='IO_L29P_1/A12',func=pin_types.BIDIR,unit=2),
            Pin(num='J22',name='IO_L26N_1/A11',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IP_L35P_1/VREF_1',func=pin_types.INPUT,unit=2),
            Pin(num='K15',name='IP_L35N_1',func=pin_types.INPUT,unit=2),
            Pin(num='K16',name='IP_L31N_1',func=pin_types.INPUT,unit=2),
            Pin(num='K17',name='IO_L32P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO_L32N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='K19',name='IO_L25N_1/RHCLK7',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='IO_L25P_1/IRDY1/RHCLK6',func=pin_types.BIDIR,unit=2),
            Pin(num='K21',name='VCCO1',func=pin_types.PWRIN,unit=2),
            Pin(num='K22',name='IO_L26P_1/A10',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IP_L31P_1',func=pin_types.INPUT,unit=2),
            Pin(num='L16',name='IP_L27N_1',func=pin_types.INPUT,unit=2),
            Pin(num='L18',name='IO_L28P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='L19',name='IO_L28N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO_L22N_1/TRDY1/RHCLK3',func=pin_types.BIDIR,unit=2),
            Pin(num='L21',name='IO_L22P_1/RHCLK2',func=pin_types.BIDIR,unit=2),
            Pin(num='L22',name='IO_L21N_1/RHCLK1',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IP_L27P_1/VREF_1',func=pin_types.INPUT,unit=2),
            Pin(num='M16',name='IP_L23N_1',func=pin_types.INPUT,unit=2),
            Pin(num='M17',name='IP_L23P_1',func=pin_types.INPUT,unit=2),
            Pin(num='M18',name='IO_L24P_1/RHCLK4',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO_L24N_1/RHCLK5',func=pin_types.BIDIR,unit=2),
            Pin(num='M22',name='IO_L21P_1/RHCLK0',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='IP_L16P_1',func=pin_types.INPUT,unit=2),
            Pin(num='N16',name='IP_L16N_1/VREF_1',func=pin_types.INPUT,unit=2),
            Pin(num='N17',name='IO_L20N_1/A9',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO_L20P_1/A8',func=pin_types.BIDIR,unit=2),
            Pin(num='N19',name='IO_L19N_1/A7',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO_L19P_1/A6',func=pin_types.BIDIR,unit=2),
            Pin(num='N21',name='IO_L18N_1/A5',func=pin_types.BIDIR,unit=2),
            Pin(num='N22',name='IO_L18P_1/A4',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='P15',name='IP_L08P_1',func=pin_types.INPUT,unit=2),
            Pin(num='P16',name='IP_L08N_1',func=pin_types.INPUT,unit=2),
            Pin(num='P17',name='VCCO1',func=pin_types.PWRIN,unit=2),
            Pin(num='P18',name='IO_L17N_1/A3',func=pin_types.BIDIR,unit=2),
            Pin(num='P20',name='IO_L15P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='P21',name='VCCO1',func=pin_types.PWRIN,unit=2),
            Pin(num='P22',name='IO_L15N_1/VREF_1',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='R11',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='R12',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='R13',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='R14',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='R15',name='IP_L04P_1',func=pin_types.INPUT,unit=2),
            Pin(num='R16',name='IP_L04N_1/VREF_1',func=pin_types.INPUT,unit=2),
            Pin(num='R17',name='IP_L12P_1',func=pin_types.INPUT,unit=2),
            Pin(num='R18',name='IP_L12N_1/VREF_1',func=pin_types.INPUT,unit=2),
            Pin(num='R19',name='IO_L17P_1/A2',func=pin_types.BIDIR,unit=2),
            Pin(num='R20',name='IO_L13P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='R21',name='IO_L14P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='R22',name='IO_L14N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='T10',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='T11',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='T13',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='T14',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='T15',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='T16',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='T17',name='IO_L03P_1/A0',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='IO_L03N_1/A1',func=pin_types.BIDIR,unit=2),
            Pin(num='T19',name='IO_L13N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='T20',name='IO_L11P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='T22',name='IO_L11N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='T8',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='T9',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='U10',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='U11',name='IO_L17P_2/GCLK12',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L20N_2/GCLK3',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L26N_2/D3',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='VCCO2',func=pin_types.PASSIVE,unit=2),
            Pin(num='U15',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='U16',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='U18',name='SUSPEND',func=pin_types.INPUT,unit=2),
            Pin(num='U19',name='IO_L10N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='U20',name='IO_L10P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='U21',name='IO_L09N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='U22',name='IO_L09P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='U8',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='U9',name='VCCO2',func=pin_types.PWRIN,unit=2),
            Pin(num='V10',name='IO_L13P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L17N_2/GCLK13',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO_L20P_2/GCLK2',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO_L26P_2/INIT_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO_L30P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO_L30N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO_L31N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V17',name='IO_L33N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V19',name='IO_L06P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='V20',name='IO_L06N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='V21',name='VCCO1',func=pin_types.PWRIN,unit=2),
            Pin(num='V22',name='IO_L07N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO_L01P_2/M1',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IP_2',func=pin_types.INPUT,unit=2),
            Pin(num='V8',name='IP_2/VREF_2',func=pin_types.INPUT,unit=2),
            Pin(num='V9',name='IO_L09P_2/RDWR_B',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L18P_2/GCLK14',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L23P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L25P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='IO_L31P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L34N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L33P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W19',name='IO_L02P_1/LDC1',func=pin_types.BIDIR,unit=2),
            Pin(num='W20',name='IO_L02N_1/LDC0',func=pin_types.BIDIR,unit=2),
            Pin(num='W21',name='IO_L05N_1',func=pin_types.BIDIR,unit=2),
            Pin(num='W22',name='IO_L07P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L02P_2/M2',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO_L01N_2/M0',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO_L05P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO_L07P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L11P_2/VS1',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L09N_2/VS2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L13N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L16P_2/D5',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L18N_2/GCLK15',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L23N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L25N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L27N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L28N_2/D1',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L34P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y21',name='IO_L01N_1/LDC2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y22',name='IO_L05P_1',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L02N_2/CSO_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L05N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L07N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L10P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L11N_2/VS0',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L14P_2/D7',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['E18', 'L6', 'A4', 'N7', 'L5', 'T6', 'N6', 'C7', 'E19', 'U17', 'A5', 'G15', 'J2', 'J4', 'N8', 'G2', 'U1', 'C8', 'E2', 'A6', 'G16', 'J3', 'L7', 'N9', 'L9', 'P10', 'C9', 'E3', 'A7', 'G21', 'L8', 'P1', 'U2', 'D1', 'E4', 'A8', 'J5', 'M10', 'U3', 'D10', 'E5', 'A9', 'G3', 'J6', 'AA11', 'M1', 'P11', 'P14', 'U4', 'D11', 'E6', 'U6', 'AA1', 'G4', 'J7', 'J9', 'P13', 'M12', 'U5', 'D12', 'E7', 'AA16', 'D14', 'G5', 'J8', 'M11', 'P19', 'C10', 'D13', 'E8', 'G6', 'AA7', 'K10', 'C16', 'M14', 'V1', 'E9', 'AA2', 'G7', 'K1', 'M13', 'P2', 'P4', 'V18', 'D15', 'F1', 'AB1', 'F11', 'G8', 'K12', 'P3', 'V2', 'D16', 'F10', 'AB22', 'G9', 'K11', 'M19', 'M21', 'V3', 'D17', 'C11', 'H1', 'B20', 'M2', 'P5', 'V4', 'D18', 'F12', 'B1', 'C12', 'H10', 'K13', 'P6', 'V5', 'D19', 'F13', 'W10', 'B10', 'C13', 'H11', 'K2', 'B12', 'C19', 'M3', 'P7', 'P9', 'W1', 'C14', 'D2', 'F14', 'B11', 'H12', 'K3', 'M4', 'P8', 'C15', 'D3', 'F15', 'W14', 'F17', 'H13', 'K4', 'M5', 'W11', 'D4', 'F16', 'B13', 'C18', 'H14', 'K5', 'A12', 'M6', 'R1', 'B4', 'D5', 'B14', 'H2', 'K6', 'B16', 'B5', 'M7', 'R2', 'W2', 'A1', 'B3', 'D6', 'F2', 'A11', 'B15', 'B6', 'H3', 'A10', 'K7', 'M8', 'R3', 'W3', 'D7', 'F3', 'D9', 'H4', 'K8', 'M9', 'R4', 'A13', 'B7', 'Y1', 'D8', 'F4', 'B17', 'B8', 'F6', 'H5', 'K9', 'N1', 'R5', 'A14', 'N11', 'Y19', 'B9', 'F5', 'Y20', 'B18', 'H6', 'L1', 'A15', 'L11', 'N10', 'R6', 'Y2', 'E1', 'B19', 'H7', 'L10', 'A16', 'R7', 'N13', 'Y3', 'E10', 'F7', 'B2', 'H8', 'A17', 'L13', 'N12', 'R8', 'A18', 'T12', 'C17', 'E11', 'F8', 'H9', 'L12', 'T1', 'C20', 'E12', 'F9', 'A19', 'J1', 'J11', 'L17', 'N14', 'T2', 'C2', 'E13', 'G1', 'A2', 'J10', 'L14', 'N2', 'T21', 'C3', 'E14', 'G10', 'A20', 'L2', 'A22', 'J13', 'N3', 'C1', 'E15', 'G11', 'A21', 'J12', 'N4', 'T3', 'C4', 'E16', 'G12', 'G14', 'J14', 'L3', 'N5', 'T4', 'C5', 'E17', 'G13', 'A3', 'J19', 'L4', 'T5', 'C6']},{'label': 'uB', 'num': 2, 'pin_nums': ['J21', 'T22', 'Y6', 'V7', 'AA19', 'C21', 'J22', 'P15', 'T7', 'Y7', 'V8', 'AA20', 'C22', 'K14', 'P16', 'T8', 'V9', 'Y8', 'AA21', 'D20', 'K15', 'P17', 'T9', 'W12', 'Y9', 'AA22', 'D21', 'K16', 'P18', 'U10', 'W13', 'AA3', 'D22', 'K17', 'P20', 'U11', 'W15', 'AA4', 'E20', 'K18', 'P21', 'U12', 'W16', 'AA5', 'E21', 'K19', 'P22', 'U13', 'W17', 'AA6', 'E22', 'K20', 'R10', 'U14', 'W18', 'AA8', 'F18', 'K21', 'B22', 'R11', 'U15', 'W19', 'AA9', 'F19', 'K22', 'R12', 'U16', 'W20', 'AB10', 'F20', 'L15', 'R13', 'U18', 'W21', 'AB11', 'F21', 'L16', 'R14', 'U19', 'W22', 'AB12', 'F22', 'L18', 'R15', 'U20', 'W4', 'AB13', 'G17', 'L19', 'R16', 'U21', 'W5', 'AB14', 'G18', 'L20', 'R17', 'U22', 'W6', 'AB15', 'G19', 'L21', 'R18', 'U7', 'W7', 'AB16', 'G20', 'L22', 'R19', 'U8', 'W8', 'AB17', 'G22', 'M15', 'R20', 'U9', 'W9', 'AB18', 'H15', 'M16', 'R21', 'V10', 'Y10', 'AB19', 'H16', 'M17', 'R22', 'V11', 'Y11', 'AB2', 'H17', 'M18', 'R9', 'V12', 'Y12', 'AB20', 'H18', 'M20', 'T10', 'V13', 'Y13', 'AB21', 'H19', 'M22', 'T11', 'V14', 'Y14', 'AB3', 'H20', 'N15', 'T13', 'V15', 'Y15', 'AB4', 'H21', 'N16', 'T14', 'V16', 'Y16', 'AA10', 'AB5', 'H22', 'N17', 'T15', 'V17', 'Y17', 'AA12', 'AB6', 'J15', 'N18', 'T16', 'V19', 'Y18', 'AA13', 'AB7', 'J16', 'N19', 'T17', 'V20', 'Y21', 'AA14', 'AB8', 'J17', 'N20', 'T18', 'V21', 'Y22', 'AA15', 'AB9', 'J18', 'N21', 'P12', 'T19', 'V22', 'Y4', 'AA17', 'B21', 'J20', 'N22', 'T20', 'V6', 'Y5', 'AA18']}] }),
        Part(**{ 'name':'XC3S200AN-FT256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3S200AN-FT256'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3S200AN-FT256\n\n', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO_L08N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO_L07N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO_L05N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO_L04N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO_L04P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='A16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO_L19P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L18P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L17P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO_L15P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO_L13P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO_L12P_0/GCLK10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO_L10N_0/GCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='B10',name='IO_L08P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='IO_L05P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='IO_L02N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO_L02P_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='B2',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='IO_L19N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO_L18N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='IO_L15N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='IO_L12N_0/GCLK11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='IO_L01N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO_L09P_0/GCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO_L07P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO_L03P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO_L01N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='IO_L24N_1/A25',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO_L24P_1/A24',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO_L01P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='IO_L20P_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L17N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO_L16N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO_L13N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO_L11P_0/GCLK8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO_L10P_0/GCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO_L03P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO_L06P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO_L03N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='D13',name='IO_L01P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO_L23N_1/A23',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO_L22N_1/A21',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO_L22P_1/A20',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VCCO3',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='IO_L02N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L02P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L20N_0/PUDC_B',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='IO_L16P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO_L11N_0/GCLK9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO_L09N_0/GCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO_L03N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO_L06N_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E13',name='IO_L23P_1/A22',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO_L20P_1/A18',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='E16',name='IO_L18P_1/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO_L05N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO_L05P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IP_L04P_3',func=pin_types.INPUT,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='IO_L14N_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='IP_0/VREF_0',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='IO_L08P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='F11',name='IP_L25N_1',func=pin_types.INPUT,unit=1),
            Pin(num='F12',name='IP_L25P_1/VREF_1',func=pin_types.INPUT,unit=1),
            Pin(num='F13',name='IO_L20N_1/A19',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L19N_1/A17',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L18N_1/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L16N_1/A11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='IO_L07P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='IP_L04N_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='F5',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='IO_L14P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='IO_L08N_3/VREF_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='IP_L21N_1',func=pin_types.INPUT,unit=1),
            Pin(num='G12',name='IP_L21P_1/VREF_1',func=pin_types.INPUT,unit=1),
            Pin(num='G13',name='IO_L19P_1/A16',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='IO_L17N_1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='IO_L16P_1/A10',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO_L11P_3/LHCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO_L09P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO_L07N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='IP_L06N_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='IP_L06P_3',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO_L11N_3/LHCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IP_L13P_1',func=pin_types.INPUT,unit=1),
            Pin(num='H11',name='IP_L13N_1',func=pin_types.INPUT,unit=1),
            Pin(num='H12',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='IO_L17P_1/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L14N_1/RHCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO_L15P_1/IRDY1/RHCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO_L15N_1/RHCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='IO_L12P_3/LHCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='IO_L09N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO_L10N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='IO_L10P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IP_L13P_3',func=pin_types.INPUT,unit=1),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='IO_L14N_3/LHCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='IP_L09P_1/VREF_1',func=pin_types.INPUT,unit=1),
            Pin(num='J11',name='IP_L09N_1',func=pin_types.INPUT,unit=1),
            Pin(num='J12',name='IO_L10P_1/A8',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO_L10N_1/A9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO_L14P_1/RHCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J16',name='IO_L12N_1/TRDY1/RHCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO_L14P_3/LHCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='IO_L12N_3/IRDY2/LHCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO_L17P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='IO_L17N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='IP_L13N_3',func=pin_types.INPUT,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='IO_L15N_3/LHCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='IP_L04P_1',func=pin_types.INPUT,unit=1),
            Pin(num='K12',name='IP_L04N_1/VREF_1',func=pin_types.INPUT,unit=1),
            Pin(num='K13',name='IO_L06N_1/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO_L11N_1/RHCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO_L11P_1/RHCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO_L12P_1/RHCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='IO_L15P_3/TRDY2/LHCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO_L18P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IP_L21P_3',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='IP_L21N_3',func=pin_types.INPUT,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='IO_L16P_3/VREF_3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IP_2/VREF_2',func=pin_types.INPUT,unit=1),
            Pin(num='L11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='IO_L06P_1/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO_L08P_1/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='IO_L08N_1/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO_L16N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO_L18N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO_L19N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IP_L25P_3',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='IP_L25N_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='L7',name='IP_2',func=pin_types.INPUT,unit=1),
            Pin(num='L8',name='IP_2',func=pin_types.INPUT,unit=1),
            Pin(num='L9',name='IP_2/VREF_2',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='IO_L20P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='IO_L13N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='IP_2/VREF_2',func=pin_types.INPUT,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='IO_L05P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO_L05N_1/VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO_L07P_1/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO_L07N_1/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='M3',name='IO_L19P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO_L24N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='IP_2/VREF_2',func=pin_types.INPUT,unit=1),
            Pin(num='M8',name='IP_2/VREF_2',func=pin_types.INPUT,unit=1),
            Pin(num='M9',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='IO_L20N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='IO_L13P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='IO_L16N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO_L19P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO_L01P_1/HDC',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO_L01N_1/LDC2',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='N16',name='IO_L03N_1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO_L22P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='IO_L24P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='IO_L01P_2/M1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='IP_2/VREF_2',func=pin_types.INPUT,unit=1),
            Pin(num='N6',name='IO_L04P_2/VS1',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='IO_L07P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='IO_L08N_2/D4',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='IO_L11P_2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='IO_L22N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='IO_L14N_2/MOSI/CSI_B',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='IO_L16P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='IO_L17N_2/D3',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO_L19N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='IO_L02N_1/LDC0',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L03P_1/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='IO_L23N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='IO_L01N_2/M0',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='IO_L04N_2/VS0',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='IO_L07N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='IO_L08P_2/D5',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='IO_L10P_2/GCLK14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='IO_L11N_2/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='IO_L23P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='IO_L15N_2/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='R13',name='IO_L18N_2/D1',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO_L20N_2/CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='IO_L02P_1/LDC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='SUSPEND',func=pin_types.INPUT,unit=1),
            Pin(num='R2',name='IO_L02P_2/M2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='IO_L03P_2/RDWR_B',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='R5',name='IO_L05N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='IO_L09P_2/GCLK12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='R9',name='IO_L12P_2/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T10',name='IO_L14P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='IO_L15P_2/AWAKE',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO_L17P_2/INIT_B',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO_L18P_2/D2',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='IO_L20P_2/D0/DIN/MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='IO_L02N_2/CSO_B',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='IO_L03N_2/VS2',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='IO_L05P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO_L06P_2/D7',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='IO_L06N_2/D6',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='IO_L09N_2/GCLK13',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='IO_L10N_2/GCLK15',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO_L12N_2/GCLK3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3S400-FG320', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3S400-FG320'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3S400-FG320\n\n', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO1VREF/A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO1/A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO1VREF/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A14',name='IO1/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO1VREF/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO1VRP/A16',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO1VRN/A17',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='IO0VRP/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO0VRN/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO0/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO0/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='IO0/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO0/A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO0VREF/A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO7VREF/B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO1/B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='IO1/B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO1/B14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO1/B15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='B17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B18',name='IO2/B18',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='IO0VREF/B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO0/B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO0/B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO0/B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='IO0/B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO7/C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='IO1/C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO1/C12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='IO1/C14',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO1/C15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO2VRP/C16',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO2VRN/C17',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO2/C18',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO7VRN/C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO7VRP/C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO0/C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO0/C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='IO0/C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO0/C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='IO7/D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO1/D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO1/D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO1/D12',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO1/D13',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO1/D14',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='D16',name='IO2/D16',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO2/D17',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO2VREF/D18',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO7/D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO7/D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='IO0/D5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO0VREF/D6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO0/D7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO0/D8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO0/D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO7/E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='GCLK5/E10',func=pin_types.INPUT,unit=1),
            Pin(num='E11',name='IO1/E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO1/E12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO1/E13',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='E15',name='IO2/E15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO2/E16',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO2/E17',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO2/E18',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO7/E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO7VREF/E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO7/E4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PROG/B',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='HSWAP/EN',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='IO0/E7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO0/E8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='GCLK7/E9',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='GCLK4/F10',func=pin_types.INPUT,unit=1),
            Pin(num='F11',name='IO1/F11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='IO2/F14',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO2/F15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F17',name='IO2/F17',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='IO7/F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VCCO7',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='IO7/F4',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='IO7/F5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='IO0/F8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='GCLK6/F9',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='IO7/G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='IO2/G14',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO2/G15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO2/G16',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='G18',name='IO2VREF/G18',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='IO7/G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO7/G4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='IO7/G5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO7/H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='IO2/H13',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO2/H14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO2/H15',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO2VREF/H16',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='IO2/H17',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO2/H18',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO7/H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO7/H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='IO7/H4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO7/H5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='IO7VREF/H6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VCCO7',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='IO7/J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='IO2/J13',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO2VREF/J14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO2/J15',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='IO2/J17',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='IO2/J18',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO7/J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='IO7/J4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='IO7VREF/J5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='IO7/J6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VCCO7',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='IO6/K1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='K13',name='IO3/K13',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='IO3/K14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO3/K15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K17',name='IO3VREF/K17',func=pin_types.BIDIR,unit=1),
            Pin(num='K18',name='IO3/K18',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='IO6VREF/K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='IO6/K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO6/K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO6/K6',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VCCO6',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='IO6/L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='IO3/L13',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO3/L14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO3/L15',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO3VREF/L16',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='IO3/L17',func=pin_types.BIDIR,unit=1),
            Pin(num='L18',name='IO3/L18',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO6/L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO6VREF/L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO6/L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO6/L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='IO6/L6',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='VCCO6',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='IO6/M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VCCO4',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VCCO4',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='IO3/M14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO3/M15',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO3VREF/M16',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='IO3/M18',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='M3',name='IO6/M3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO6/M4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='IO6/M5',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VCCO5',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='VCCO5',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='GCLK1/N10',func=pin_types.INPUT,unit=1),
            Pin(num='N11',name='IO4D2/N11',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N14',name='IO3/N14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO3/N15',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='N17',name='IO3/N17',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N2',name='IO6VREF/N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VCCO6',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='IO6/N4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='IO6/N5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='IO5/N8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='GCLK3/N9',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='IO6/P1',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='GCLK0/P10',func=pin_types.INPUT,unit=1),
            Pin(num='P11',name='IO4D3/P11',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='IO4/P12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO4/P13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO4VREF/P14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO3/P15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO3/P16',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='IO3/P17',func=pin_types.BIDIR,unit=1),
            Pin(num='P18',name='IO3/P18',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='IO6/P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='IO6/P3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='IO6/P4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='P6',name='IO5VREF/P6',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='IO5/P7',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='IO5/P8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='GCLK2/P9',func=pin_types.INPUT,unit=1),
            Pin(num='R1',name='IO6VREF/R1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO4VREF/R10',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO4/R11',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO4D1/R12',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO4/R13',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO4/R14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='DONE',func=pin_types.OUTPUT,unit=1),
            Pin(num='R16',name='IO3VREF/R16',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='IO3/R17',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO3/R18',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='IO6/R2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='IO6/R3',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='R5',name='IO5/R5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IO5/R6',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='IO5D6/R7',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='IO5/R8',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='IO5VREF/R9',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='IO6/T1',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='IO4/T11',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='DIN/D0',func=pin_types.INPUT,unit=1),
            Pin(num='T13',name='VCCO4',func=pin_types.PWRIN,unit=1),
            Pin(num='T14',name='IO4/T14',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='T16',name='IO3VRN/T16',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='IO3VRP/T17',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO3/T18',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='IO6VRN/T2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='IO6VRP/T3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='IO5/T4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO5/T5',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='VCCO5',func=pin_types.PWRIN,unit=1),
            Pin(num='T7',name='IO5D7/T7',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='IO5/T8',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U1',name='IO6/U1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='INIT',func=pin_types.INPUT,unit=1),
            Pin(num='U11',name='VCCO4',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='IO4VREF/U13',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='IO4/U14',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='IO4/U15',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='IO4VRP/U16',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U18',name='IO3/U18',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='U3',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='U4',name='IO5VRN/U4',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='IO5/U5',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='IO5/U6',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='U8',name='VCCO5',func=pin_types.PWRIN,unit=1),
            Pin(num='U9',name='IO5D4/U9',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V10',name='DOUT/BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='V11',name='IO4/V11',func=pin_types.BIDIR,unit=1),
            Pin(num='V12',name='IO4/V12',func=pin_types.BIDIR,unit=1),
            Pin(num='V13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V14',name='IO4/V14',func=pin_types.BIDIR,unit=1),
            Pin(num='V15',name='IO4/V15',func=pin_types.BIDIR,unit=1),
            Pin(num='V16',name='IO4VRN/V16',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO4VREF/V17',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V2',name='CS',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='RDWR',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='IO5VRP/V4',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='IO5/V5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='V7',name='IO5VREF/V7',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='IO5/V8',func=pin_types.BIDIR,unit=1),
            Pin(num='V9',name='IO5D5/V9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3S400-PQ208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3S400-PQ208'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3S400-PQ208\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IO_L20P_7',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='IO_L01P_4/VRN_4',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='IO_L01N_4/VRP_4',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO/VREF_4',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='106',name='IO_L01P_3/VRN_3',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='IO_L01N_3/VRP_3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='IO_L17P_3/VREF_3',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='IO_L17N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO_L20N_7',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VCCO_3',func=pin_types.PWRIN,unit=1),
            Pin(num='111',name='IO_L19P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='IO_L19N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO_L20P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO_L20N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='IO_L21P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='IO_L21N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='IO_L22P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO_L21P_7',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='IO_L22N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='IO_L23P_3/VREF_3',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='IO_L23N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='IO_L24P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='IO_L24N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='IO_L39P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VCCO_3',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='IO_L39N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='IO_L21N_7',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='IO_L40P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='IO_L40N_3/VREF_3',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='IO_L40P_2/VREF_2',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO_L40N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='IO_L39P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VCCO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='IO_L39N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='IO_L24P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO_L24N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='140',name='IO_L23P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO_L23N_2/VREF_2',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='143',name='IO_L22P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='IO_L22N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='146',name='IO_L21P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='IO-L21N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='IO_L20P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='IO_L20N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO_L22P_7',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='IO_L19P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='IO_L19N_2',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='VCCO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='154',name='IO/VREF_2',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='IO_L01P_2/VRN_2',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='IO_L01N_2/VRP_2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='158',name='TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO_L22N_7',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='IO_L01P_1/VRN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='IO_L01N_1/VRP_1',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='164',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='165',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='IO_L10N_1/VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='IO_L27P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='IO_L27N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='170',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='IO_L28P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='IO_L28N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='174',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='175',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='IO_L31P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='178',name='IO_L31N_1/VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='IO_L23P_7',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='IO_L32P_1/GCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='IO_L32N_1GCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='IO_L32P_0/GCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='IO_L32N_0/GCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='185',name='IO_L31P_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='186',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='IO_L31N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='189',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO_L23N_7',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='IO_L30P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='IO_L30N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='193',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='194',name='IO_L27P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='196',name='IO_L27N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='198',name='IO_L25P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='IO_L25N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IO_L01P_7/VRN_7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO_L24P_7',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='IO/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='202',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='IO_L01P_0/VRN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='IO_L01N_0/VRP_0',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='IO/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='HSWAP_EN',func=pin_types.INPUT,unit=1),
            Pin(num='207',name='PROG_B',func=pin_types.INPUT,unit=1),
            Pin(num='208',name='TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO_L24N_7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO_L39P_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VCCO_7',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='IO_L39N_7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='IO_L40P_7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO_L40N_7/VREF_7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO_L40P_6/VREF_6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO_L40N_6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO_L01N_7/VRP_7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='IO_L39P_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VCCO_6',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='IO_L39N_6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO_L24P_6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO_L24N_6/VREF_6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO_L23P_6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO_L23N_6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='IO_L22P_6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO_L16P_7/VREF_7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO_L22N_6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='IO_L21P_6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO_L21N_6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO_L20P_6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='IO_L20N_6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='IO_L19P_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='IO_L19N_6',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCCO_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO_L16N_7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='IO/VREF_6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='IO_L01P_6/VRN_6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='IO_L01N_6/VRP_6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='IO_L01P_5/CS_B',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO_L01N_5/RDWR_B',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCCO_7',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VCCO_5',func=pin_types.PWRIN,unit=1),
            Pin(num='61',name='IO_L10P_5/VRN_5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO_L10N_5/VRP_5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='IO_L27P_5',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='IO_L27N_5/VREF_5',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='IO_L28P_5/D7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO_L28N_5/D6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IO_L19P_7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='IO_L31P_5/D5',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCCO_5',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='IO_L31N_5/D4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='IO_L32P_5/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='IO_L32N_5/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='IO/VREF_5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IO_L32P_4/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='IO_L32N_4/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='IO_L31P_4/DOUT/BUSY',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='IO_L31N_4/INIT_B',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='VCCO_4',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='IO/VREF_4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='IO_L30P_4/D3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO_L30N_4/D2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='IO_L19N_7/VREF_7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='IO_L27P_4/D1',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='IO_L27N_4/DIN/D0',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='IO_L25P_4',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO_L25N_4',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO/VREF_4',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VCCO_4',func=pin_types.PWRIN,unit=1),
            Pin(num='99',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3S50-VQ100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3S50-VQ100'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FPGA', 'description':'', 'datasheet':'xilinx/spartan2e/spartan2e.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3S50-VQ100\n\nFPGA', 'pins':[
            Pin(num='1',name='IO-VRN',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO-VREF',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCCINT(1.2V)',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VCCO_6',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IO-VRP',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO-VRN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO-VRP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='IO/CS',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO/RDWR',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='IO/D7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCCO_5',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='IO/D6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VCCAUX(2.5V)',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='IO/D5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO/D4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO/GCK2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO/GCK3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO/GCK0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='IO/GCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO/DOUT/BUSY',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='IO/INIT',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO/D3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO/D2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VCCINT(1.2V)',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VCCO_4',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IO/D1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO/D0/DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DONE',func=pin_types.OPENCOLL,unit=1),
            Pin(num='52',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='IO-VRN',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='IO-VRP',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='VCCO_3',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='VCCAUX(2.5V)',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCCO_7',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='VCCINT(1.2V)',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCCAUX(2.5V)',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VCCO_2',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='IO-VRN',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO-VRP',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='77',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='79',name='IO-VRN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IO-VRP',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VCCO_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VCCAUX(2.5V)',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO/GCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO/GCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='IO/GCK6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='IO/GCK7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='IO/VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='IO',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='VCCINT(1.2V)',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='VCCO_0',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='IO-VRN',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO-VRP',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='HSWAP_EN',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='~{PROG}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3S50AN-TQG144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3S50AN-TQG144'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3S50AN-TQG144\n\n', 'pins':[
            Pin(num='1',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IO_L04P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='IO_L09N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO_L10P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='IO_L11P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='IO_L10N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='IO_L11N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='108',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IO_L04N_3/VREF_3',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='IO_L01P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO_L01N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO_L02P_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='IO_L02N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO_L04P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='IO_L03P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='IO_L04N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='IO_L03N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='IO_L05P_3/LHCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='IO_L05P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO_L05N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='IP_0/VREF_0',func=pin_types.INPUT,unit=1),
            Pin(num='124',name='IO_L06P_0/GCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='IO_L07P_0/GCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='IO_L06N_0/GCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='IO_L07N_0/GCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='IO_L08P_0/GCLK8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO_L05N_3/LHCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='IO_L09P_0/GCLK10',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='IO_L08N_0/GCLK9',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='IO_L09N_0/GCLK11',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='IO_L10P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='IO_L10N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VCCO0',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='IO_L11P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO_L11N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCCO3',func=pin_types.PASSIVE,unit=1),
            Pin(num='140',name='IP_0',func=pin_types.INPUT,unit=1),
            Pin(num='141',name='IO_L12P_0/VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='IO_0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='IO_L12N_0/PUDC_B',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PROG_B',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO_L06P_3/LHCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO_L06N_3/IRDY2/LHCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='IO_L07P_3/LHCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO_L08P_3/TRDY2/LHCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IO_L07N_3/LHCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO_L08N_3/LHCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCCO3',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='IO_L09P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='IO_L09N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='IO_L10P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO_L11P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO_L10N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO_L02P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO_L11N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO_L12P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='IO_L12N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='IN_L13P_3',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='IN_L13N_3/VREF_3',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='IO_L01P_2/M1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO_L01N_2/M0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='IO_L02P_2/M2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO_L01P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='IO_L02N_2/CSO_B',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO_L03P_2/RDWR_B',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO_L04P_2/VS2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO_L03N_2/VS1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='IO_L04N_2/VS0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='IO_L05P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='IO_L06P_2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO_L05N_2/D7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO_L06N_2/D6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO_L02N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='IO_L07P_2/D5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='IO_L07N_2/D4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='IP_2/VREF_2',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='IO_L08P_2/GCLK14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='IO_L08N_2/GCLK15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='IO_L09P_2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO_L10P_2/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='IO_L09N_2/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO_L01N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='IO_L10N_2/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VCCO2',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='IO_2/MOSI/CSI_B',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO_L11P_2/AWAKE',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='IO_L11N_2/DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='VCCAUX',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='IO_L12P_2/INIT_B',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO_L12N_2/D3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IO_L13P_2/D2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO_L03P_3',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IO_L14P_2/D1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IO_L13N_2/D0/DIN/MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='IO_L14N_2/CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='SUSPEND',func=pin_types.INPUT,unit=1),
            Pin(num='75',name='IO_L02P_1/LDC1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='IO_L01P_1/HDC',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='IO_L02N_1/LDC0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='IO_L01N_1/LDC2',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IO_1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO_L03N_3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IP_1/VREF_1',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='IO_L03P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO_L04P_1/RHCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO_L03N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='IO_L04N_1/RHCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='IO_L05P_1/RHCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO_L05N_1/TRDY1/RHCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='90',name='IO_L06P_1/RHCLK4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='IO_L07P_1/IRDY1/RHCLK6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='IO_L06N_1/RHCLK5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='IO_L07N_1/RHCLK7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='VCCO1',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='IO_L08P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IP_1/VREF_1',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='IO_L08N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO_L09P_1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC4003-PC84', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC4003-PC84'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC4003-PC84\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10-SGI4',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13-PGI1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='TDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='P26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='P27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='P28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='P29-SGI1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='INIT-P41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='SGI2-P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='~{PROG}',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='PGI3-P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='RCLK-RDY-P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='DIN/P71',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='DOUT-SGI3',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='CCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='TD0',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='P77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='PGI4-P78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='P79',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC4003-VQ100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC4003-VQ100'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'xilinx/xc400x-pinout.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC4003-VQ100\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P/A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P13',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PGCK1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='SGCK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='M1/RD',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='M0/RT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='M2',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='PGCK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='P/HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P/A17',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='P/LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='P31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36/INIT',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P/TDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='SGCK3',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P/TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='DONE',func=pin_types.OPENCOLL,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='~{PROG}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='P53',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PGCK3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P56',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P/A3',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='P71/RDY',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='DIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='DOUT/SGCK4',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='75',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='P78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='PGCK4',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='P85',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='P86',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='P87',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P/A15',func=pin_types.PASSIVE,unit=1),
            Pin(num='90',name='P90',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P91',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='P92',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='P93',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='P94',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='P91',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='P96',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='P97',func=pin_types.PASSIVE,unit=1),
            Pin(num='98',name='P98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='SGCK1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC4004-PQ160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC4004-PQ160'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC4004-PQ160\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='102',name='P102',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='P103',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='P104',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='P105',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='P106',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='P107',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='P113',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='P114/BUSY',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='P115',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='P116',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='DIN/D0',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='DOUT/SGCK4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='120',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='122',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='P123',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PGCK4',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='P125',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='P126',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='P127',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='P128',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P13/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='134',name='P134',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='P135',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='P137',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='P138',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='P139',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P14',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='P140',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='143',name='P143',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='P144',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='P145',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='P146',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='P147',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='P148',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P15',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='154',name='P154',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='P155',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='P156',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='P157',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='P158',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='SGCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P16',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P18',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PGCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='P21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P22',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P23',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P25',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P26',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P32',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P35',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SGCK2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='PGCK2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P44/HDC',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P45',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P46',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P47',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P48/LDC',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='P54',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P55',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P56',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P59/INIT',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P6/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P63',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P64',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P65',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P66',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P67',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P7/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='P73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P74',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P75',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P76',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P77',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='SGCK3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='DONE',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='~{PROG}',func=pin_types.INPUT,unit=1),
            Pin(num='83',name='P83',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PGCK3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='P85',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P88',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='P94',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='P96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='P97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='P98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P99',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC4005-PG156', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC4005-PG156'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC4005-PG156\n\n', 'pins':[
            Pin(num='A1',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='P26',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='A14',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='A15',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='A16',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='P9',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='P27',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='P28',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='P29-SGCK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='B16',name='P-PGCK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='P10-SGCK1',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='P13-PGCK1',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='TDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='C16',name='LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C7',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D15',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='E14',name='P36',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='F14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F15',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='F16',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G14',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='G15',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='G16',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='H14',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='H15',name='P41-INIT',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='H2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='J14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='J16',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='K14',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='K15',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='L14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='L15',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='M14',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='N14',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='N15',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='N2',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='N3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P79',func=pin_types.PASSIVE,unit=1),
            Pin(num='P10',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P12',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P13',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='P14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P15',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P16',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='P2',name='P78-PGCK4',func=pin_types.PASSIVE,unit=1),
            Pin(num='P3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='P4',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='P5',name='RCLK-RDY-P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='P6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P7',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='P8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P9',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='P77',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='R11',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='R13',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='R14',name='~{PROG}',func=pin_types.INPUT,unit=1),
            Pin(num='R15',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='P51-SGCK3',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='CCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='R4',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='TD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='T10',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='T11',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='T14',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='T15',name='P57-PGCK3',func=pin_types.PASSIVE,unit=1),
            Pin(num='T16',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='DOUT-SGCK4',func=pin_types.PASSIVE,unit=1),
            Pin(num='T3',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='T4',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='T5',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='T6',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='T7',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='T8',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='T9',name='P',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC4005-PQ100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC4005-PQ100'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC4005-PQ100\n\n', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='P100',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SGCK1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='SGCK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='M1',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PGCK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='P31/HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33/LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39/INIT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PGCK1',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='SGCK3',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DONE',func=pin_types.OPENCOLL,unit=1),
            Pin(num='54',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='~{PROG}',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='PGCK3',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='P64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7/TDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='P71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='P72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='P73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='P74/BUSY',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='DIN/D0',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='DOUT/SGCK4',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='CCLK',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='P8/TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PGCK4',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='P85',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='P86',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='P87',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='P88',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='P89',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9/TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='90',name='P90',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='P93',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='P94',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='P95',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='P96',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='P97',func=pin_types.PASSIVE,unit=1),
            Pin(num='98',name='P98',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='P99',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC4005-PQ160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC4005-PQ160'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC4005-PQ160\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='102',name='P102',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='P103',func=pin_types.PASSIVE,unit=1),
            Pin(num='104',name='P104',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='P105',func=pin_types.PASSIVE,unit=1),
            Pin(num='106',name='P106',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='P107',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='P108',func=pin_types.PASSIVE,unit=1),
            Pin(num='109',name='P109',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='110',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='P113',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='P114-RDY',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='P115',func=pin_types.PASSIVE,unit=1),
            Pin(num='116',name='P116',func=pin_types.PASSIVE,unit=1),
            Pin(num='117',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='118',name='DOUT-SGI4',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='CCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='122',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='123',name='P123',func=pin_types.PASSIVE,unit=1),
            Pin(num='124',name='P124',func=pin_types.PASSIVE,unit=1),
            Pin(num='125',name='P125',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='P126',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='P127',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='P128',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='132',name='P132',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='P133',func=pin_types.PASSIVE,unit=1),
            Pin(num='134',name='P134',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='P135',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='P137',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='P138',func=pin_types.PASSIVE,unit=1),
            Pin(num='139',name='P139',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='140',name='P140',func=pin_types.PASSIVE,unit=1),
            Pin(num='141',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='143',name='P143',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='P144',func=pin_types.PASSIVE,unit=1),
            Pin(num='145',name='P145',func=pin_types.PASSIVE,unit=1),
            Pin(num='146',name='P146',func=pin_types.PASSIVE,unit=1),
            Pin(num='147',name='P147',func=pin_types.PASSIVE,unit=1),
            Pin(num='148',name='P148',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='P149',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='150',name='P150',func=pin_types.PASSIVE,unit=1),
            Pin(num='151',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='154',name='P154',func=pin_types.PASSIVE,unit=1),
            Pin(num='155',name='P155',func=pin_types.PASSIVE,unit=1),
            Pin(num='156',name='P156',func=pin_types.PASSIVE,unit=1),
            Pin(num='157',name='P157',func=pin_types.PASSIVE,unit=1),
            Pin(num='158',name='P158',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='SGCK1',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='160',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PGCK1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='P26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='P27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='P28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='SGCK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='PGCK2',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='P52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='P53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='P54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='P55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59-INIT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='TDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='P64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='P73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='P74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='P75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='P76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='P77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='SGCK3',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='~{PROG}',func=pin_types.INPUT,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='PGCK3',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='P85',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='P86',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='P87',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='P88',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='P92',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='P93',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='P93',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='P95',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='P96',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='P97',func=pin_types.PASSIVE,unit=1),
            Pin(num='98',name='P98',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='P90',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC6SLX25T-BG484', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC6SLX25T-BG484'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC6SLX25T-BG484\n\n', 'pins':[
            Pin(num='A10',name='MGTREFCLK0P_101',func=pin_types.INPUT,unit=1),
            Pin(num='A17',name='IO_L50N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO_L63N_SCP6_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO_L46N_SCP4_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO_L3N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO_L65N_SCP2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='IO_L5N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO_L6N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO_L8N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='MGTTXN0_101',func=pin_types.OUTPUT,unit=1),
            Pin(num='A7',name='MGTAVTTTX_101',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='MGTTXN1_101',func=pin_types.OUTPUT,unit=1),
            Pin(num='B10',name='MGTREFCLK0N_101',func=pin_types.INPUT,unit=1),
            Pin(num='B18',name='IO_L63P_SCP7_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='IO_L3P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO_L65P_SCP3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO_L5P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='MGTTXP0_101',func=pin_types.OUTPUT,unit=1),
            Pin(num='B8',name='MGTTXP1_101',func=pin_types.OUTPUT,unit=1),
            Pin(num='B9',name='MGTAVCCPLL0_101',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='MGTAVCC_101',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='MGTREFCLK1P_101',func=pin_types.INPUT,unit=1),
            Pin(num='C17',name='IO_L50P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO_L66N_SCP0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO_L64P_SCP5_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO_L20P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='C22',name='IO_L20N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO_L1P_HSWAPEN_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO_L6P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO_L8P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='MGTRXN0_101',func=pin_types.INPUT,unit=1),
            Pin(num='C9',name='MGTRXN1_101',func=pin_types.INPUT,unit=1),
            Pin(num='D11',name='MGTREFCLK1N_101',func=pin_types.INPUT,unit=1),
            Pin(num='D12',name='MGTAVCCPLL1_101',func=pin_types.PASSIVE,unit=1),
            Pin(num='D17',name='IO_L66P_SCP1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO_L62P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO_L62N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='IO_L1N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO_L2P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO_L2N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='MGTRXP0_101',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='MGTAVTTRX_101',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='MGTRXP1_101',func=pin_types.INPUT,unit=1),
            Pin(num='E16',name='IO_L37P_GCLK13_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='E18',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='E19',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='E20',name='IO_L32P_A17_M1A8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E22',name='IO_L32N_A16_M1A9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO_L4P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO_L4N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='MGTAVTTRCAL_101',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='MGTRREF_101',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='IO_L34N_GCLK18_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO_L36P_GCLK15_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO_L36N_GCLK14_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO_L37N_GCLK12_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='IO_L51N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F18',name='IO_L1P_A25_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO_L1N_A24_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO_L29N_A22_M1A14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F21',name='IO_L31P_A19_M1CKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F22',name='IO_L31N_A18_M1A12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='IO_L7P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO_L7N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO_L32N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='IO_L35N_GCLK16_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO_L38N_VREF_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='VCCO_0',func=pin_types.PWRIN,unit=1),
            Pin(num='G15',name='IO_L49N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO_L51P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G17',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='G19',name='IO_L29P_A23_M1A13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO_L35P_A11_M1A7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='G22',name='IO_L35N_A10_M1A2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO_L32P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO_L34P_GCLK19_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO_L33P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO_L33N_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='IO_L35P_GCLK17_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO_L38P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO_L49P_0',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='IO_L30P_A21_M1RESET_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H19',name='IO_L30N_A20_M1A11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO_L33N_A14_M1A4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H21',name='IO_L37P_A7_M1A0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='H22',name='IO_L37N_A6_M1A1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO_L19P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='IO_L19N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO_L33P_A15_M1A10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO_L39P_M1A3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='J22',name='IO_L39N_M1ODT_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='IO_L36P_A9_M1BA0_1',func=pin_types.INPUT,unit=1),
            Pin(num='K18',name='IO_L34N_A12_M1BA2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K19',name='IO_L34P_A13_M1WE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K20',name='IO_L38P_A5_M1CLK_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K21',name='IO_L41P_GCLK9_IRDY1_M1RASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='K22',name='IO_L41N_GCLK8_M1CASN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L17',name='IO_L36N_A8_M1BA1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L19',name='IO_L38N_A4_M1CLKN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L20',name='IO_L43P_GCLK5_M1DQ4_1',func=pin_types.BIDIR,unit=1),
            Pin(num='L21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='L22',name='IO_L43N_CLK4_M1DQ5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='IO_L61P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M18',name='IO_L61N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M19',name='IO_L40N_GCLK10_M1A6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO_L40P_GCLK11_M1A5_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M21',name='IO_L44P_A3_M1DQ6_1',func=pin_types.BIDIR,unit=1),
            Pin(num='M22',name='IO_L44N_A2_M1DQ7_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO_L60P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO_L42N_GCLK6_TRDY1_M1LDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO_L45P_A1_M1LDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='N22',name='IO_L45N_A0_M1LDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='IO_L60N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO_L53P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO_L42P_GCLK7_M1UDM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P21',name='IO_L46P_FCS_B_M1DQ2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='P22',name='IO_L46N_FOE_B_M1DQ3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO_L53N_VREF_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO_L47P_FWE_B_M1DQ0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='R21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='R22',name='IO_L47N_LDC_M1DQ1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO_L59N_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T21',name='IO_L48P_HDC_M1DQ8_1',func=pin_types.BIDIR,unit=1),
            Pin(num='T22',name='IO_L48N_M1DQ9_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='U19',name='IO_L59P_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U20',name='IO_L49P_M1DQ10_1',func=pin_types.BIDIR,unit=1),
            Pin(num='U22',name='IO_L49N_M1DQ11_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO_L74P_AWAKE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V20',name='IO_L74N_DOUT_BUSY_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V21',name='IO_L50P_M1UDQS_1',func=pin_types.BIDIR,unit=1),
            Pin(num='V22',name='IO_L50N_M1UDQSN_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W20',name='IO_L51P_M1DQ12_1',func=pin_types.BIDIR,unit=1),
            Pin(num='W21',name='VCCO_1',func=pin_types.PWRIN,unit=1),
            Pin(num='W22',name='IO_L51N_M1DQ13_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y21',name='IO_L52P_M1DQ14_1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y22',name='IO_L52N_M1DQ15_1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO_L10N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA10',name='IO_L41P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA11',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA12',name='IO_L31P_GCLK31_D14_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA14',name='IO_L6P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA15',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA16',name='IO_L19P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA18',name='IO_L14P_D11_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA19',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA2',name='IO_L10P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='AA20',name='IO_L3P_D0_DIN_MISO_MISO1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA21',name='IO_L1N_M0_CMPMISO_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA22',name='SUSPEND',func=pin_types.INPUT,unit=2),
            Pin(num='AA3',name='IO_L65N_CSO_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA4',name='IO_L63P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA6',name='IO_L49P_D3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AA7',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AA8',name='IO_L45P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB10',name='IO_L41N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB11',name='IO_L32N_GCLK28_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB12',name='IO_L31N_GCLK30_D15_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB13',name='IO_L30N_GCLK0_USERCCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB14',name='IO_L6N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB15',name='IO_L21N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB16',name='IO_L19N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB17',name='IO_L15N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB18',name='IO_L14N_D12_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB19',name='IO_L13N_D10_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB2',name='PROGRAM_B_2',func=pin_types.INPUT,unit=2),
            Pin(num='AB20',name='IO_L3N_MOSI_CSI_B_MISO0_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB21',name='DONE_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB3',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB4',name='IO_L63N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB5',name='IO_L62N_D6_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB6',name='IO_L49N_D4_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB7',name='IO_L47N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB8',name='IO_L45N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='AB9',name='IO_L43N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='B1',name='IO_L83N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C1',name='IO_L83P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='C2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='D1',name='IO_L59N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='D2',name='IO_L59P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E1',name='IO_L54N_M3A11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E3',name='IO_L54P_M3RESET_3',func=pin_types.BIDIR,unit=2),
            Pin(num='E4',name='IO_L60N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F1',name='IO_L53N_M3A12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F2',name='IO_L53P_M3CKE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F3',name='IO_L60P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='F4',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G1',name='IO_L52N_M3A9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='G2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='G3',name='IO_L52P_M3A8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H1',name='IO_L50N_M3BA2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H2',name='IO_L50P_M3WE_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H3',name='IO_L51N_M3A4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='H5',name='IO_L55N_M3A14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J1',name='IO_L48N_M3BA1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J3',name='IO_L48P_M3BA0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J4',name='IO_L51P_M3A10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='J5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='J6',name='IO_L55P_M3A13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K1',name='IO_L47N_M3A1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K2',name='IO_L47P_M3A0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K3',name='IO_L46N_M3CLKN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K4',name='IO_L46P_M3CLK_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K5',name='IO_L49N_M3A2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='K6',name='IO_L49P_M3A7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L1',name='IO_L41N_GCLK26_M3DQ5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='L3',name='IO_L41P_GCLK27_M3DQ4_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L4',name='IO_L44N_GCLK207_M3A6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L6',name='IO_L45N_M3ODT_3',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='M1',name='IO_L40N_M3DQ7_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M2',name='IO_L40P_M3DQ6_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M3',name='IO_L44P_GCLK21_M3A5_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M4',name='IO_L43N_GCLK22_TRDY2_M3CASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M5',name='IO_L43P_GCLK23_M3RASN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO_L45P_M3A3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO_L31P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO_L31N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N1',name='IO_L39N_M3LDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N3',name='IO_L39P_M3LDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N4',name='IO_L42N_GCLK24_M3LDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='P1',name='IO_L38N_M3DQ3_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P2',name='IO_L38P_M3DQ2_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P3',name='IO_L42P_GCLK25_TRDY2_M3UDM_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P4',name='IO_L9N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO_L9P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO_L1N_VREF_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO_L37N_M3DQ1_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO_L12P_D1_MISO2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO_L37P_M3DQ0_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO_L1P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO_L59N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO_L59P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='IO_L36N_M3DQ9_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO_L46P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO_L29P_GCLK3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='T14',name='IO_L12N_D2_MISO3_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T2',name='IO_L36P_M3DQ8_3',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO_L64P_D8_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO_L57P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='U1',name='IO_L35N_M3DQ11_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO_L46N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO_L29N_GCLK2_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO_L16N_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO_L16P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='IO_L35P_M3DQ10_3',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='U6',name='IO_L64N_D9_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO_L57N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO_L50P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='IO_L34N_M3UDQSN_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO_L42P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='IO_L18P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO_L2P_CMPCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='CMPCS_B_2',func=pin_types.INPUT,unit=2),
            Pin(num='V2',name='IO_L34P_M3UDQS_3',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO_L58P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='V9',name='IO_L50N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='IO_L33N_M3DQ13_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W10',name='IO_L44P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO_L42N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO_L40P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO_L18N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO_L20P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO_L17N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO_L5P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO_L2N_CMPMOSI_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W2',name='VCCO_3',func=pin_types.PWRIN,unit=2),
            Pin(num='W3',name='IO_L33P_M3DQ12_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO_L2P_3',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='VCCO_2',func=pin_types.PWRIN,unit=2),
            Pin(num='W6',name='IO_L60P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO_L58N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO_L48P_D7_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO_L32N_M3DQ15_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO_L44N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO_L32P_GCLK29_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO_L40N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO_L30P_GCLK1_D13_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO_L20N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO_L21P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO_L17P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO_L15P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO_L5N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO_L13P_M1_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO_L32P_M3DQ14_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO_L1P_CCLK_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO_L2N_3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO_L65P_INIT_B_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO_L62P_D5_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO_L60N_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO_L47P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO_L48N_RDWR_B_VREF_2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO_L43P_2',func=pin_types.BIDIR,unit=2),
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='A11',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='A22',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='A9',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='AA13',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='AA17',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='AA5',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='AA9',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='AB1',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='AB22',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='B11',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='B5',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='B7',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='C14',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='C16',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='D10',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='D16',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='E11',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='E14',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='E15',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='E2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='E21',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='F11',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='F13',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='G12',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='G18',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='H15',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='H9',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='J10',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='J11',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='J12',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='J13',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='J14',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='J15',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='J2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='J21',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='J8',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='J9',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='K10',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='K11',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='K12',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='K13',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='K14',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='K15',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='K9',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='L10',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='L11',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='L12',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='L13',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='L14',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='L18',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='L5',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='L8',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='L9',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='M10',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='M11',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='M12',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='M13',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='M14',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='M15',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='M9',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='N10',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='N11',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='N12',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='N13',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='N14',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='N17',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='N2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='N21',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='N8',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='N9',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='P10',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='P11',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='P12',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='P13',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='P14',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='P9',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='R10',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='R12',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='R14',name='VCCINT',func=pin_types.PWRIN,unit=3),
            Pin(num='R18',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='R5',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='R6',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='U11',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='U2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='U21',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='U7',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='V10',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='V14',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='V4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='V6',name='VCCAUX',func=pin_types.PWRIN,unit=3),
            Pin(num='W16',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='W19',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='W7',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G21', 'W21', 'B3', 'G22', 'E18', 'M18', 'W22', 'B4', 'E19', 'G8', 'M19', 'Y21', 'B6', 'E20', 'G9', 'M20', 'B8', 'E22', 'H10', 'M21', 'B9', 'E5', 'H11', 'M22', 'C10', 'E6', 'H12', 'N16', 'C11', 'E8', 'H13', 'N18', 'C17', 'E9', 'H14', 'N19', 'C18', 'F10', 'H18', 'N20', 'C19', 'F14', 'H19', 'N22', 'C20', 'F15', 'H20', 'P16', 'C21', 'F16', 'H21', 'P19', 'C22', 'F17', 'H22', 'P20', 'C3', 'F18', 'J16', 'P21', 'A18', 'C4', 'F19', 'J17', 'P22', 'A10', 'C5', 'F20', 'J18', 'R19', 'C7', 'F21', 'J19', 'R20', 'C9', 'A19', 'F22', 'J20', 'A17', 'R21', 'D11', 'F6', 'J22', 'A2', 'R22', 'D12', 'F7', 'K17', 'A20', 'T20', 'D17', 'A21', 'F8', 'K18', 'T21', 'D18', 'A3', 'F9', 'K19', 'T22', 'D19', 'A4', 'G10', 'K20', 'A5', 'U18', 'D20', 'G11', 'K21', 'U19', 'A6', 'D3', 'G13', 'K22', 'U20', 'A7', 'D4', 'G14', 'L16', 'U22', 'A8', 'D5', 'G15', 'L17', 'V19', 'B10', 'D7', 'G16', 'L19', 'V20', 'B18', 'D8', 'G17', 'L20', 'E17', 'V21', 'B19', 'D9', 'Y22', 'G19', 'L21', 'M17', 'V22', 'B2', 'E16', 'G20', 'L22', 'W20', 'B20']},{'label': 'uB', 'num': 2, 'pin_nums': ['AB8', 'L1', 'W12', 'T10', 'Y9', 'L2', 'AB9', 'W13', 'T12', 'B1', 'L3', 'T13', 'W14', 'AA18', 'L4', 'C1', 'W15', 'T14', 'AA19', 'C2', 'L6', 'T2', 'W17', 'AA2', 'D1', 'L7', 'T7', 'W18', 'AA20', 'D2', 'M1', 'T8', 'W2', 'AA21', 'M2', 'E1', 'W3', 'T9', 'AA22', 'E3', 'M3', 'U1', 'W4', 'AA3', 'E4', 'M4', 'U10', 'W5', 'AA4', 'F1', 'M5', 'AA1', 'U12', 'W6', 'AA6', 'F2', 'M6', 'U13', 'W8', 'AA7', 'F3', 'M7', 'U14', 'W9', 'K6', 'AA8', 'F4', 'M8', 'U3', 'Y1', 'AB10', 'G1', 'N1', 'U5', 'Y10', 'AA10', 'AB11', 'G2', 'N3', 'U6', 'Y11', 'AA11', 'AB12', 'G3', 'N4', 'U8', 'Y12', 'AA12', 'AB13', 'H1', 'N5', 'U9', 'Y13', 'AA14', 'AA16', 'AB14', 'H2', 'P1', 'V1', 'Y14', 'AB15', 'H3', 'P2', 'AA15', 'V11', 'Y15', 'W11', 'AB16', 'H5', 'P3', 'V12', 'Y16', 'AB17', 'J1', 'P4', 'V13', 'Y17', 'AB18', 'J3', 'P5', 'V16', 'Y18', 'AB19', 'J4', 'P8', 'V17', 'Y19', 'AB2', 'J5', 'R1', 'V18', 'Y2', 'AB20', 'J6', 'R13', 'V2', 'Y20', 'AB21', 'K1', 'R2', 'V7', 'Y3', 'AB3', 'K2', 'R3', 'V8', 'Y4', 'AB4', 'K3', 'R7', 'V9', 'Y5', 'AB5', 'K4', 'R8', 'W1', 'Y6', 'AB6', 'K5', 'R9', 'W10', 'Y7', 'AB7', 'T1', 'Y8']},{'label': 'uC', 'num': 3, 'pin_nums': ['F11', 'L8', 'U2', 'F13', 'U21', 'L9', 'A1', 'G12', 'M10', 'U7', 'A11', 'G18', 'V10', 'M11', 'A13', 'G5', 'M12', 'V14', 'A22', 'H15', 'M13', 'V4', 'A9', 'H7', 'M14', 'V6', 'AA13', 'H9', 'W16', 'M15', 'AA17', 'J10', 'M9', 'W19', 'AA5', 'J11', 'N10', 'W7', 'AA9', 'J12', 'N11', 'AB1', 'J13', 'N12', 'AB22', 'J14', 'N13', 'B11', 'J15', 'N14', 'B15', 'J2', 'N17', 'B17', 'J21', 'N2', 'B5', 'J8', 'N21', 'B7', 'J9', 'N8', 'C12', 'K10', 'N9', 'C14', 'K11', 'P10', 'C16', 'K12', 'P11', 'C6', 'K13', 'P12', 'C8', 'K14', 'P13', 'D10', 'K15', 'P14', 'D16', 'K9', 'P9', 'D6', 'L10', 'R10', 'E11', 'L11', 'R12', 'E14', 'L12', 'R14', 'E15', 'L13', 'R18', 'E2', 'L14', 'R5', 'E21', 'L18', 'R6', 'E7', 'L5', 'U11']}] }),
        Part(**{ 'name':'XCV150_BG352', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XCV150_BG352'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'field programmable gate array', 'description':'', 'datasheet':'https://www.xilinx.com/support/documentation/data_sheets/ds003.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXCV150_BG352\n\nfield programmable gate array', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='IO1A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO1A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO1A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A15',name='IO0A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IOR0A16',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='A18',name='IO0A18',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A20',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='A21',name='IO0A21',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A23',name='IO0A23',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='IO0A24',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='IO1A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO1A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='IO1A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO1A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='IO1A9',func=pin_types.BIDIR,unit=1),
            Pin(num='AA1',name='IO3AA1',func=pin_types.BIDIR,unit=1),
            Pin(num='AA2',name='IO3AA2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA23',name='IO6AA23',func=pin_types.BIDIR,unit=1),
            Pin(num='AA24',name='IO6AA24',func=pin_types.BIDIR,unit=1),
            Pin(num='AA25',name='IOR6AA25',func=pin_types.BIDIR,unit=1),
            Pin(num='AA26',name='IO6AA26',func=pin_types.BIDIR,unit=1),
            Pin(num='AA3',name='IO3AA3',func=pin_types.BIDIR,unit=1),
            Pin(num='AA4',name='IO3AA4',func=pin_types.BIDIR,unit=1),
            Pin(num='AB1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB2',name='IO3AB2',func=pin_types.BIDIR,unit=1),
            Pin(num='AB23',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='AB24',name='IO6AB24',func=pin_types.BIDIR,unit=1),
            Pin(num='AB25',name='IO6AB25',func=pin_types.BIDIR,unit=1),
            Pin(num='AB26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AB3',name='IO3AB3',func=pin_types.BIDIR,unit=1),
            Pin(num='AB4',name='IO3AB4',func=pin_types.BIDIR,unit=1),
            Pin(num='AC1',name='IO3AC1',func=pin_types.BIDIR,unit=1),
            Pin(num='AC10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='AC11',name='IO4AC11',func=pin_types.BIDIR,unit=1),
            Pin(num='AC12',name='IOR4AC12',func=pin_types.BIDIR,unit=1),
            Pin(num='AC13',name='IO4AC13',func=pin_types.BIDIR,unit=1),
            Pin(num='AC14',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='AC15',name='IOR5AC15',func=pin_types.BIDIR,unit=1),
            Pin(num='AC16',name='IO5AC16',func=pin_types.BIDIR,unit=1),
            Pin(num='AC17',name='IO5AC17',func=pin_types.BIDIR,unit=1),
            Pin(num='AC18',name='IOR5AC18',func=pin_types.BIDIR,unit=1),
            Pin(num='AC19',name='IO5AC19',func=pin_types.BIDIR,unit=1),
            Pin(num='AC2',name='IO3AC2',func=pin_types.BIDIR,unit=1),
            Pin(num='AC20',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='AC21',name='IO5AC21',func=pin_types.BIDIR,unit=1),
            Pin(num='AC22',name='IO5AC22',func=pin_types.BIDIR,unit=1),
            Pin(num='AC23',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='AC24',name='IO6AC24',func=pin_types.BIDIR,unit=1),
            Pin(num='AC25',name='IO6AC25',func=pin_types.BIDIR,unit=1),
            Pin(num='AC26',name='IO6AC26',func=pin_types.BIDIR,unit=1),
            Pin(num='AC3',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC4',name='~{PROGRAM}',func=pin_types.INPUT,unit=1),
            Pin(num='AC5',name='IO4AC5',func=pin_types.BIDIR,unit=1),
            Pin(num='AC6',name='IO4AC6',func=pin_types.BIDIR,unit=1),
            Pin(num='AC7',name='IO4AC7',func=pin_types.BIDIR,unit=1),
            Pin(num='AC8',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='AC9',name='IO4AC9',func=pin_types.BIDIR,unit=1),
            Pin(num='AD1',name='IO3AD1',func=pin_types.BIDIR,unit=1),
            Pin(num='AD10',name='IO4AD10',func=pin_types.BIDIR,unit=1),
            Pin(num='AD11',name='IO4AD11',func=pin_types.BIDIR,unit=1),
            Pin(num='AD12',name='IO4AD12',func=pin_types.BIDIR,unit=1),
            Pin(num='AD13',name='IO4AD13',func=pin_types.BIDIR,unit=1),
            Pin(num='AD14',name='IO5AD14',func=pin_types.BIDIR,unit=1),
            Pin(num='AD15',name='IO5AD15',func=pin_types.BIDIR,unit=1),
            Pin(num='AD16',name='IO5AD16',func=pin_types.BIDIR,unit=1),
            Pin(num='AD17',name='IO5AD17',func=pin_types.BIDIR,unit=1),
            Pin(num='AD18',name='IO5AD18',func=pin_types.BIDIR,unit=1),
            Pin(num='AD19',name='IO5AD19',func=pin_types.BIDIR,unit=1),
            Pin(num='AD2',name='~{INIT}',func=pin_types.BIDIR,unit=1),
            Pin(num='AD20',name='IOR5AD20',func=pin_types.BIDIR,unit=1),
            Pin(num='AD21',name='IO5AD21',func=pin_types.BIDIR,unit=1),
            Pin(num='AD22',name='IO5AD22',func=pin_types.BIDIR,unit=1),
            Pin(num='AD23',name='DXN',func=pin_types.PASSIVE,unit=1),
            Pin(num='AD24',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='AD25',name='IO6AD25',func=pin_types.BIDIR,unit=1),
            Pin(num='AD26',name='IO6AD26',func=pin_types.BIDIR,unit=1),
            Pin(num='AD3',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='AD4',name='IO4AD4',func=pin_types.BIDIR,unit=1),
            Pin(num='AD5',name='IO4AD5',func=pin_types.BIDIR,unit=1),
            Pin(num='AD6',name='IO4AD6',func=pin_types.BIDIR,unit=1),
            Pin(num='AD7',name='IO4AD7',func=pin_types.BIDIR,unit=1),
            Pin(num='AD8',name='IO4AD8',func=pin_types.BIDIR,unit=1),
            Pin(num='AD9',name='IO4AD9',func=pin_types.BIDIR,unit=1),
            Pin(num='AE1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE10',name='IO4AE10',func=pin_types.BIDIR,unit=1),
            Pin(num='AE11',name='IO4AE11',func=pin_types.BIDIR,unit=1),
            Pin(num='AE12',name='IO4AE12',func=pin_types.BIDIR,unit=1),
            Pin(num='AE13',name='GCK0',func=pin_types.INPUT,unit=1),
            Pin(num='AE14',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='AE15',name='IO5AE15',func=pin_types.BIDIR,unit=1),
            Pin(num='AE16',name='IO5AE16',func=pin_types.BIDIR,unit=1),
            Pin(num='AE17',name='IO5AE17',func=pin_types.BIDIR,unit=1),
            Pin(num='AE18',name='IO5AE18',func=pin_types.BIDIR,unit=1),
            Pin(num='AE19',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='AE2',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='AE20',name='IO5AE20',func=pin_types.BIDIR,unit=1),
            Pin(num='AE21',name='IO5AE21',func=pin_types.BIDIR,unit=1),
            Pin(num='AE22',name='IO5AE22',func=pin_types.BIDIR,unit=1),
            Pin(num='AE23',name='IO5AE23',func=pin_types.BIDIR,unit=1),
            Pin(num='AE24',name='DXP',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE25',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='AE26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AE3',name='IO4AE3',func=pin_types.BIDIR,unit=1),
            Pin(num='AE4',name='IO4AE4',func=pin_types.BIDIR,unit=1),
            Pin(num='AE5',name='IOR4AE5',func=pin_types.BIDIR,unit=1),
            Pin(num='AE6',name='IO4AE6',func=pin_types.BIDIR,unit=1),
            Pin(num='AE7',name='IO4AE7',func=pin_types.BIDIR,unit=1),
            Pin(num='AE8',name='IOR4AE8',func=pin_types.BIDIR,unit=1),
            Pin(num='AE9',name='IO4AE9',func=pin_types.BIDIR,unit=1),
            Pin(num='AF1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF10',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='AF11',name='v',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF12',name='IO4AF12',func=pin_types.BIDIR,unit=1),
            Pin(num='AF13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF14',name='GCK1',func=pin_types.INPUT,unit=1),
            Pin(num='AF15',name='IO5AF15',func=pin_types.BIDIR,unit=1),
            Pin(num='AF16',name='v',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF17',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='AF18',name='IO5AF18',func=pin_types.BIDIR,unit=1),
            Pin(num='AF19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF20',name='IO5AF20',func=pin_types.BIDIR,unit=1),
            Pin(num='AF21',name='IO5AF21',func=pin_types.BIDIR,unit=1),
            Pin(num='AF22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF23',name='IO5AF23',func=pin_types.BIDIR,unit=1),
            Pin(num='AF24',name='IO5AF24',func=pin_types.BIDIR,unit=1),
            Pin(num='AF25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF3',name='IO4AF3',func=pin_types.BIDIR,unit=1),
            Pin(num='AF4',name='IO4AF4',func=pin_types.BIDIR,unit=1),
            Pin(num='AF5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF6',name='IO4AF6',func=pin_types.BIDIR,unit=1),
            Pin(num='AF7',name='IO4AF7',func=pin_types.BIDIR,unit=1),
            Pin(num='AF8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='AF9',name='IO4AF9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='IO1B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO1B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO1B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO1B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='GCK2',func=pin_types.INPUT,unit=1),
            Pin(num='B15',name='IO0B15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='v',func=pin_types.PASSIVE,unit=1),
            Pin(num='B17',name='IO0B17',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO0B18',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='IO0B19',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='B20',name='IO0B20',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='IO0B21',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='IO0B22',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='IO0B23',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='IO0B24',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='B26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='TDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='IO1B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO1B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IOR1B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO1B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO1B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO1B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO2C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO1C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO1C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IOR1C12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO1C13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='IO0C15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO0C16',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO0C17',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO0C18',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IOR0C19',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO2C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO0C20',func=pin_types.BIDIR,unit=1),
            Pin(num='C21',name='IOR0C21',func=pin_types.BIDIR,unit=1),
            Pin(num='C22',name='IO0C22',func=pin_types.BIDIR,unit=1),
            Pin(num='C23',name='IO0C23',func=pin_types.BIDIR,unit=1),
            Pin(num='C24',name='TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='C25',name='IO7C25',func=pin_types.BIDIR,unit=1),
            Pin(num='C26',name='IO7C26',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='CCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='IO1C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO1C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO1C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO1C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IOR1C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO2D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='IO1D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='v',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='D14',name='GCK3',func=pin_types.INPUT,unit=1),
            Pin(num='D15',name='IO0D15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO0D16',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='IO0D17',func=pin_types.BIDIR,unit=1),
            Pin(num='D18',name='IO0D18',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='IO2D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO0D20',func=pin_types.BIDIR,unit=1),
            Pin(num='D21',name='IO0D21',func=pin_types.BIDIR,unit=1),
            Pin(num='D22',name='IO0D22',func=pin_types.BIDIR,unit=1),
            Pin(num='D23',name='TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D24',name='IO7D24',func=pin_types.BIDIR,unit=1),
            Pin(num='D25',name='IO7D25',func=pin_types.BIDIR,unit=1),
            Pin(num='D26',name='IOR7D26',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='D0/DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='TDO',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='~{WRITE}',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='IO1D6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO1D8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO1D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='IOR2E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E23',name='IO7E23',func=pin_types.BIDIR,unit=1),
            Pin(num='E24',name='IO7E24',func=pin_types.BIDIR,unit=1),
            Pin(num='E25',name='IO7E25',func=pin_types.BIDIR,unit=1),
            Pin(num='E26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='IO2E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='BUSY/DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='F1',name='IO2F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO2F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F23',name='IO7F23',func=pin_types.BIDIR,unit=1),
            Pin(num='F24',name='IO7F24',func=pin_types.BIDIR,unit=1),
            Pin(num='F25',name='IO7F25',func=pin_types.BIDIR,unit=1),
            Pin(num='F26',name='IO7F26',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO2F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='IO2F4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO2G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G23',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='G24',name='IO7G24',func=pin_types.BIDIR,unit=1),
            Pin(num='G25',name='IO7G25',func=pin_types.BIDIR,unit=1),
            Pin(num='G26',name='IOR7G26',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO2G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO2G4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H2',name='IOR2H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H23',name='IO7H23',func=pin_types.BIDIR,unit=1),
            Pin(num='H24',name='IO7H24',func=pin_types.BIDIR,unit=1),
            Pin(num='H25',name='IO7H25',func=pin_types.BIDIR,unit=1),
            Pin(num='H26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='IO2H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='IO2J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO2J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J23',name='IO7J23',func=pin_types.BIDIR,unit=1),
            Pin(num='J24',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J25',name='IO7J25',func=pin_types.BIDIR,unit=1),
            Pin(num='J26',name='IO7J26',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO2J4',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='IO2K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K23',name='IO7K23',func=pin_types.BIDIR,unit=1),
            Pin(num='K24',name='IO7K24',func=pin_types.BIDIR,unit=1),
            Pin(num='K25',name='IO7K25',func=pin_types.BIDIR,unit=1),
            Pin(num='K26',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='IO2K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='v',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='IO2L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L23',name='IO7L23',func=pin_types.BIDIR,unit=1),
            Pin(num='L24',name='IO7L24',func=pin_types.BIDIR,unit=1),
            Pin(num='L25',name='v',func=pin_types.PASSIVE,unit=1),
            Pin(num='L26',name='IOR7L26',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO2L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO2L4',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='IO2M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='IO2M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M23',name='IO7M23',func=pin_types.BIDIR,unit=1),
            Pin(num='M24',name='IO7M24',func=pin_types.BIDIR,unit=1),
            Pin(num='M25',name='IO7M25',func=pin_types.BIDIR,unit=1),
            Pin(num='M26',name='IO7M26',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IOR2M4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='N2',name='IO2N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N23',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='N24',name='IO7N24',func=pin_types.BIDIR,unit=1),
            Pin(num='N25',name='IO7N25',func=pin_types.BIDIR,unit=1),
            Pin(num='N26',name='IO6N26',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='IO2N3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='IO2N4',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='IO3P1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='P23',name='IO6P23',func=pin_types.BIDIR,unit=1),
            Pin(num='P24',name='IO6P24',func=pin_types.BIDIR,unit=1),
            Pin(num='P25',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='P26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='P3',name='IO3P3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='R1',name='IO3R1',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='IO3R2',func=pin_types.BIDIR,unit=1),
            Pin(num='R23',name='v',func=pin_types.PASSIVE,unit=1),
            Pin(num='R24',name='IOR6R24',func=pin_types.BIDIR,unit=1),
            Pin(num='R25',name='IO6R25',func=pin_types.BIDIR,unit=1),
            Pin(num='R26',name='IO6R26',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='IOR3R4',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='v',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='IO3T2',func=pin_types.BIDIR,unit=1),
            Pin(num='T23',name='IO6T23',func=pin_types.BIDIR,unit=1),
            Pin(num='T24',name='IO6T24',func=pin_types.BIDIR,unit=1),
            Pin(num='T25',name='IO6T25',func=pin_types.BIDIR,unit=1),
            Pin(num='T26',name='IO6T26',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='IO3T3',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='IO3T4',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='U2',name='IO3U2',func=pin_types.BIDIR,unit=1),
            Pin(num='U23',name='IO6U23',func=pin_types.BIDIR,unit=1),
            Pin(num='U24',name='IO6U24',func=pin_types.BIDIR,unit=1),
            Pin(num='U25',name='IO6U25',func=pin_types.BIDIR,unit=1),
            Pin(num='U26',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='U3',name='IO3U3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='IO3V1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='IO3V2',func=pin_types.BIDIR,unit=1),
            Pin(num='V23',name='IO6V23',func=pin_types.BIDIR,unit=1),
            Pin(num='V24',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='V25',name='IO6V25',func=pin_types.BIDIR,unit=1),
            Pin(num='V26',name='IO6V26',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='IOR3V4',func=pin_types.BIDIR,unit=1),
            Pin(num='W1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W2',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='W23',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='W24',name='IO6W24',func=pin_types.BIDIR,unit=1),
            Pin(num='W25',name='IO6W25',func=pin_types.BIDIR,unit=1),
            Pin(num='W26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='W3',name='IO3W3',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='IO3W4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='IO3Y1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='IO3Y2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y23',name='IO6Y23',func=pin_types.BIDIR,unit=1),
            Pin(num='Y24',name='IO6Y24',func=pin_types.BIDIR,unit=1),
            Pin(num='Y25',name='IO6Y25',func=pin_types.BIDIR,unit=1),
            Pin(num='Y26',name='IOR6Y26',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='IOR3Y3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='VCCO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC2064-PC68', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC2064-PC68'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC2064-PC68\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P11-GCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='M2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='HDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='LDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='P31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43-XI',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='D/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P46-XO',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='P53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='P54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='P55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='P64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3030-PC68', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3030-PC68'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3030-PC68\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22/INIT',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='M2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='HDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='LDC',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='P31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='P32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='P33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='P34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='P43-XI',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='D/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47-XO',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='P53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='P54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='P55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='DIN',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='DOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='P64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC3042-PC84', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC3042-PC84'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC3042-PC84\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{PWRDWN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='P26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='P27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='P28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='P29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='P30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='M2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='P35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='P37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='P41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='INIT/P42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='P52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='XTL2(I)/P53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='DONE/PROG',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='XTL1(O)/P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='CS0/P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='P63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='CS1/P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='P71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='DOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='WS/P75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='CS2/P76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='P77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='P78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='P79',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XC4005-PC84', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC4005-PC84'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/FPGA_Xilinx.kicad_sym\nXC4005-PC84\n\n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P10-SGI4',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13-PGI1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='TDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='P26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='P27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='P28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='P29-SGI1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='HDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='P36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='LDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='P38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='P39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='P40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='INIT-P41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='P44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='P45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='P46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='P47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='P48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='P49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='P50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='SGI2-P51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DONE',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='~{PROG}',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='P56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='PGI3-P57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='P58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='P59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='P60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='P61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='P62',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='P65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='P66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='P67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='P68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='P69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='RCLK-RDY-P70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='DIN/P71',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='DOUT-SGI3',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='CCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='TD0',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='P77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='PGI4-P78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='P79',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='P80',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='P81',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='P82',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='P83',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='P84',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])