from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32L5 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32L552CETxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552CETxP'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552CETxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552CEUxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552CEUxP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552CEUxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552C_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552C_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552C_C-E_Tx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552C_C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552C_C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552C_C-E_Ux\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552MEYxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552MEYxP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_4.36x4.07mm_Layout9x9_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-81_4.36x4.07mm_Layout9x9_P0.4mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552MEYxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552MEYxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552MEYxQ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_4.36x4.07mm_Layout9x9_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-81_4.36x4.07mm_Layout9x9_P0.4mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552MEYxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552QEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552QEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552QEIx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='OPAMP1_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='OPAMP2_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PG14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552QEIxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552QEIxP'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552QEIxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='OPAMP1_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='OPAMP2_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PG14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552Q_C-E_IxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552Q_C-E_IxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552qc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552Q_C-E_IxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='OPAMP1_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='OPAMP2_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDSMPS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552RETxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552RETxP'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552RETxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552RETxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552RETxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552RETxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552R_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552R_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552R_C-E_Tx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552VETx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552V_C-E_TxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552V_C-E_TxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552V_C-E_TxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='V15SMPS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552ZETx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552Z_C-E_TxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552Z_C-E_TxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552Z_C-E_TxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='143',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562CETx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562CETxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562CETxP'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562CETxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562CEUx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562CEUxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562CEUxP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562CEUxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562MEYxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562MEYxP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_4.36x4.07mm_Layout9x9_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-81_4.36x4.07mm_Layout9x9_P0.4mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562MEYxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562MEYxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562MEYxQ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_4.36x4.07mm_Layout9x9_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-81_4.36x4.07mm_Layout9x9_P0.4mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562MEYxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='J3',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562QEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562QEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562QEIx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='OPAMP1_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='OPAMP2_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PG14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562QEIxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562QEIxP'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562QEIxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='OPAMP1_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='OPAMP2_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PG14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562QEIxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562QEIxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562QEIxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='OPAMP1_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='OPAMP2_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDSMPS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562RETx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562RETxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562RETxP'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562RETxP\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562RETxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562RETxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562RETxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562VETx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562VETxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562VETxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562VETxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='V15SMPS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562ZETx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L562ZETxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L562ZETxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l562ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L562ZETxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='143',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552CCTx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552CCUx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552CETx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552CEUx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552QCIxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552QCIxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552qc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552QCIxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='OPAMP1_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='OPAMP2_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDSMPS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552QEIxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552QEIxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-132_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552QEIxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='A1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='OPAMP1_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='OPAMP2_VINM',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDDSMPS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552RCTx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552RETx\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552VCTxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552VCTxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552VCTxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='V15SMPS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552VETxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552VETxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552VETxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='V15SMPS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552ZCTxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552ZCTxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552ZCTxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='143',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32L552ZETxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32L552ZETxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M33 STM32L5 STM32L5x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32l552ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32L5.kicad_sym\nSTM32L552ZETxQ\n\nArm Cortex-M33 STM32L5 STM32L5x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='131',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='143',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='V15SMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])