from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32G4 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32G431CBYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431CBYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_3.15x3.13mm_Layout7x7_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-49_3.15x3.13mm_Layout7x7_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431CBYx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431C_6-8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431C_6-8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431C_6-8-B_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431C_6-8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431C_6-8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431C_6-8-B_Ux\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431K_6-8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431K_6-8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431K_6-8-B_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431K_6-8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431K_6-8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431K_6-8-B_Ux\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431M_6-8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431M_6-8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431m6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431M_6-8-B_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431R_6-8-B_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431R_6-8-B_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431R_6-8-B_Ix\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431R_6-8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431R_6-8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431R_6-8-B_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431V_6-8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431V_6-8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431v6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431V_6-8-B_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441CBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441CBUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441CBYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441CBYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-49_3.15x3.13mm_Layout7x7_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-49_3.15x3.13mm_Layout7x7_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441CBYx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441KBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441KBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441KBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441KBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441KBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441KBUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441MBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441MBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441MBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441RBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441RBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441RBIx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441RBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G441VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G441VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g441vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G441VBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473C_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473C_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473C_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473C_B-C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473C_B-C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473C_B-C-E_Ux\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473MEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473MEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_4.02x4.27mm_Layout9x9_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-81_4.02x4.27mm_Layout9x9_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473MEYx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473M_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473M_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473M_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473P_B-C-E_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473P_B-C-E_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473pb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473P_B-C-E_Ix\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473Q_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473Q_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473qb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473Q_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473R_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473R_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473R_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473V_B-C-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473V_B-C-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473V_B-C-E_Hx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473V_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473V_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473V_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474C_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474C_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474C_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474C_B-C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474C_B-C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474C_B-C-E_Ux\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474MEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474MEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_4.02x4.27mm_Layout9x9_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-81_4.02x4.27mm_Layout9x9_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474MEYx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474M_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474M_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474M_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474P_B-C-E_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474P_B-C-E_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474pb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474P_B-C-E_Ix\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474Q_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474Q_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474qb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474Q_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474R_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474R_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474R_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474V_B-C-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474V_B-C-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474V_B-C-E_Hx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474V_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474V_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474V_B-C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483CETx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483CEUx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483METx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483METx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483METx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483MEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483MEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_4.02x4.27mm_Layout9x9_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-81_4.02x4.27mm_Layout9x9_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483MEYx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483PEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483PEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483pe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483PEIx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483QETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483QETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483QETx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483RETx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483VEHx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G483VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G483VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g483ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G483VETx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484CETx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484CEUx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484METx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484METx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484METx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484MEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484MEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-81_4.02x4.27mm_Layout9x9_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-81_4.02x4.27mm_Layout9x9_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484MEYx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484PEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484PEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484pe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484PEIx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484QETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484QETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484QETx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484RETx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484VEHx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G484VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G484VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g484ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G484VETx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491C_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491C_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491C_C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491C_C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491C_C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491C_C-E_Ux\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491K_C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491K_C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491K_C-E_Ux\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491M_C-E_Sx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491M_C-E_Sx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491M_C-E_Sx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491M_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491M_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491M_C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491REYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491REYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_3.56x3.52mm_Layout8x8_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-64_3.56x3.52mm_Layout8x8_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491REYx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491R_C-E_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491R_C-E_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491R_C-E_Ix\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491R_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491R_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491R_C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491V_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491V_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491V_C-E_Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1CETx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1CEUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1KEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1KEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1KEUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1MESx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1MESx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1MESx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1METx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1METx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1METx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1REIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1REIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1REIx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1RETx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1REYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1REYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_3.56x3.52mm_Layout8x8_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-64_3.56x3.52mm_Layout8x8_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1REYx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G4A1VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G4A1VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g4a1ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G4A1VETx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431C6Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431C6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431C6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431C6Ux\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431C8Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431C8Ux\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431CBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431CBUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431K6Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431K6Ux\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431K8Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431K8Ux\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431KBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431KBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431KBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431KBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431KBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431KBUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431M6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431M6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431m6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431M6Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431M8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431M8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431m8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431M8Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431MBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431MBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431MBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431R6Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431R6Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431R6Ix\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431R6Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431R8Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431R8Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431R8Ix\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431R8Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431RBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431RBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431RBIx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431RBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431V6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431V6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431v6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431V6Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431V8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431V8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431V8Tx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G431VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G431VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g431vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G431VBTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473CBTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473CBUx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473CCTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473CCUx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473CETx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473CEUx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473MBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473MBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473MBTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473MCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473MCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473MCTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473METx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473METx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473METx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473PBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473PBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473pb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473PBIx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473PCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473PCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473pc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473PCIx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473PEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473PEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473pe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473PEIx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473QBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473QBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473qb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473QBTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473QCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473QCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473qc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473QCTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473QETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473QETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473QETx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473RBTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473RCTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473RETx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473VBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473VBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473VBHx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473VBTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473VCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473VCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473VCHx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473VCTx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473VEHx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G473VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G473VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g473ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G473VETx\n\nArm Cortex-M4 STM32G4 STM32G4x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474CBTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474CBUx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474CCTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474CCUx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474CETx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474CEUx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474MBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474MBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474MBTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474MCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474MCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474MCTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474METx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474METx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474METx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474PBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474PBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474pb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474PBIx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474PCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474PCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474pc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474PCIx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474PEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474PEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-121_6x6mm_Layout11x11_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474pe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474PEIx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474QBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474QBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474qb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474QBTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474QCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474QCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474qc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474QCTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474QETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474QETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'Package_QFP:LQFP-128_14x14mm_P0.4mm'], 'footprint':'Package_QFP:LQFP-128_14x14mm_P0.4mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474qe.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474QETx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='112',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='120',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='128',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VREF_+',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474RBTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474RCTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474RETx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474VBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474VBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474VBHx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474VBTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474VCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474VCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474VCHx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474VCTx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474VEHx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G474VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G474VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x4', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g474ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G474VETx\n\nArm Cortex-M4 STM32G4 STM32G4x4', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491CCTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491CCUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491CETx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491CEUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491KCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491KCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491KCUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491KEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491KEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491KEUx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491MCSx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491MCSx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm', 'Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491MCSx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491MCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491MCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491MCTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491MESx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491MESx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_14x14mm_P0.65mm', 'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'Package_QFP:LQFP-80_14x14mm_P0.65mm'], 'footprint':'Package_QFP:LQFP-80_14x14mm_P0.65mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491MESx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491METx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491METx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491METx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491RCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491RCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491RCIx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491RCTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491REIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491REIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491REIx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G6',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491RETx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491VCTx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G491VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G491VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M4 STM32G4 STM32G4x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g491ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G4.kicad_sym\nSTM32G491VETx\n\nArm Cortex-M4 STM32G4 STM32G4x1', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])