from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32F7 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32F722I_C-E_Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722I_C-E_Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722ic.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722I_C-E_Kx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722I_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722I_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722ic.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722I_C-E_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722R_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722R_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722R_C-E_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722V_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722V_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722V_C-E_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722Z_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722Z_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722Z_C-E_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723I_C-E_Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723I_C-E_Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ic.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723I_C-E_Kx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723I_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723I_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ic.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723I_C-E_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723V_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723V_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723V_C-E_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDDPHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723V_C-E_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723V_C-E_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_Die452'], 'footprint':'Package_CSP:ST_WLCSP-100_Die452', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723V_C-E_Yx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='J4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='VDDPHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723Z_C-E_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723Z_C-E_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723Z_C-E_Ix\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723Z_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723Z_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723Z_C-E_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F730I8Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F730I8Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f730i8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F730I8Kx\n\nArm Cortex-M7 STM32F7 STM32F7x0 Value line', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F730R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F730R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f730r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F730R8Tx\n\nArm Cortex-M7 STM32F7 STM32F7x0 Value line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F730V8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F730V8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f730v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F730V8Tx\n\nArm Cortex-M7 STM32F7 STM32F7x0 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F730Z8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F730Z8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f730z8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F730Z8Tx\n\nArm Cortex-M7 STM32F7 STM32F7x0 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F732IEKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F732IEKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f732ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F732IEKx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F732IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F732IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f732ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F732IETx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F732RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F732RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f732re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F732RETx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F732VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F732VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f732ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F732VETx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F732ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F732ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f732ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F732ZETx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F733IEKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F733IEKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f733ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F733IEKx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F733IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F733IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f733ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F733IETx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F733VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F733VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f733ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F733VETx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDDPHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F733VEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F733VEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_Die452'], 'footprint':'Package_CSP:ST_WLCSP-100_Die452', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f733ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F733VEYx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='J4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='VDDPHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F733ZEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F733ZEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f733ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F733ZEIx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F733ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F733ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f733ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F733ZETx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745I_E-G_Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745I_E-G_Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745I_E-G_Kx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745I_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745I_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745I_E-G_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745V_E-G_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745V_E-G_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745V_E-G_Hx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745V_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745V_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745V_E-G_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745Z_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745Z_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745Z_E-G_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746B_E-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746B_E-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746be.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746B_E-G_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746IETx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746IGTx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746I_E-G_Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746I_E-G_Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746I_E-G_Kx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746NEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746NEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ne.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746NEHx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746NGHx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746VETx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746VGTx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746V_E-G_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746V_E-G_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746V_E-G_Hx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746ZETx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746ZGTx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746Z_E-G_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746Z_E-G_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die449'], 'footprint':'Package_CSP:ST_WLCSP-143_Die449', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746Z_E-G_Yx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F750N8Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F750N8Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f750n8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F750N8Hx\n\nArm Cortex-M7 STM32F7 STM32F7x0 Value line', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F750V8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F750V8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f750v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F750V8Tx\n\nArm Cortex-M7 STM32F7 STM32F7x0 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F750Z8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F750Z8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f750z8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F750Z8Tx\n\nArm Cortex-M7 STM32F7 STM32F7x0 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F756BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F756BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f756bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F756BGTx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F756IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F756IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f756ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F756IGKx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F756IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F756IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f756ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F756IGTx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F756NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F756NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f756ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F756NGHx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F756VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F756VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f756vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F756VGHx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F756VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F756VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f756vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F756VGTx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F756ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F756ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f756zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F756ZGTx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F756ZGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F756ZGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die449'], 'footprint':'Package_CSP:ST_WLCSP-143_Die449', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f756zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F756ZGYx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765B_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765B_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765B_G-I_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765I_G-I_Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765I_G-I_Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765I_G-I_Kx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765I_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765I_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765I_G-I_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765N_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765N_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765N_G-I_Hx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765V_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765V_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765V_G-I_Hx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765V_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765V_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765V_G-I_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765Z_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765Z_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765Z_G-I_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767B_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767B_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767B_G-I_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767I_G-I_Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767I_G-I_Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767I_G-I_Kx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767I_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767I_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767I_G-I_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767N_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767N_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767N_G-I_Hx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767VGHx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767VGTx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767VIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767VIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767VIHx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767VITx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767ZGTx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767ZITx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F768AIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F768AIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-180_Die451'], 'footprint':'Package_CSP:ST_WLCSP-180_Die451', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x8', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F768AIYx\n\nArm Cortex-M7 STM32F7 STM32F7x8', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C10',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P5',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='P6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769A_G-I_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769A_G-I_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-180_Die451'], 'footprint':'Package_CSP:ST_WLCSP-180_Die451', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769A_G-I_Yx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C10',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P5',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='P6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769B_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769B_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769B_G-I_Tx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769IGTx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769IITx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769NGHx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769NIHx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F777BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F777BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f777bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F777BITx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F777IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F777IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f777ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F777IIKx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F777IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F777IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f777ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F777IITx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F777NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F777NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f777ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F777NIHx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F777VIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F777VIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f777vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F777VIHx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F777VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F777VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f777vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F777VITx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F777ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F777ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f777zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F777ZITx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F778AIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F778AIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-180_Die451'], 'footprint':'Package_CSP:ST_WLCSP-180_Die451', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f778ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F778AIYx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C10',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P5',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='P6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F779AIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F779AIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-180_Die451'], 'footprint':'Package_CSP:ST_WLCSP-180_Die451', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f779ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F779AIYx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C10',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P5',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='P6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F779BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F779BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f779bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F779BITx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F779IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F779IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f779ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F779IITx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='101',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='118',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDDDSI',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F779NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F779NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f779ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F779NIHx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722ICKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722ICKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722ic.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722ICKx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722ICTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722ICTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722ic.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722ICTx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722IEKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722IEKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722IEKx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722IETx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722RCTx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722RETx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722VCTx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722VETx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722ZCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722ZCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722ZCTx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F722ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F722ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x2', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f722ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F722ZETx\n\nArm Cortex-M7 STM32F7 STM32F7x2', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723ICKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723ICKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ic.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723ICKx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723ICTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723ICTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ic.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723ICTx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723IEKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723IEKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723IEKx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='J15',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723IETx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723VCTx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDDPHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723VCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723VCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_Die452', 'Package_CSP:ST_WLCSP-100_Die452'], 'footprint':'Package_CSP:ST_WLCSP-100_Die452', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723VCYx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='J4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='VDDPHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723VETx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDDPHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723VEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723VEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-100_Die452', 'Package_CSP:ST_WLCSP-100_Die452', 'Package_CSP:ST_WLCSP-100_Die452'], 'footprint':'Package_CSP:ST_WLCSP-100_Die452', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723VEYx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='B4',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='J4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='VDDPHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723ZCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723ZCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723ZCIx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723ZCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723ZCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723ZCTx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723ZEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723ZEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723ZEIx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F723ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F723ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f723ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F723ZETx\n\nArm Cortex-M7 STM32F7 STM32F7x3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='REXTPHYHS',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='V12PHYHS',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745IEKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745IEKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745IEKx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745IETx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745IGKx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745IGTx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745VEHx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745VETx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745VGHx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745VGTx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745ZETx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F745ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F745ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f745zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F745ZGTx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746BETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746BETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746be.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746BETx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746BGTx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746IEKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746IEKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746IEKx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746IGKx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746VEHx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746VGHx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746ZEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746ZEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die449', 'Package_CSP:ST_WLCSP-143_Die449'], 'footprint':'Package_CSP:ST_WLCSP-143_Die449', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746ZEYx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F746ZGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F746ZGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-143_Die449', 'Package_CSP:ST_WLCSP-143_Die449', 'Package_CSP:ST_WLCSP-143_Die449'], 'footprint':'Package_CSP:ST_WLCSP-143_Die449', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x6', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f746zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F746ZGYx\n\nArm Cortex-M7 STM32F7 STM32F7x6', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='D10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='N2',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='N3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PC5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765BGTx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765BITx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765IGKx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765IGTx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765IIKx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765IITx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765NGHx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765NIHx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765VGHx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765VGTx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765VIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765VIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765VIHx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765VITx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765ZGTx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F765ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F765ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x5', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f765zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F765ZITx\n\nArm Cortex-M7 STM32F7 STM32F7x5', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767BGTx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767BITx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767IGKx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767IGTx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767IIKx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767IITx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767NGHx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F767NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F767NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x7', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f767ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F767NIHx\n\nArm Cortex-M7 STM32F7 STM32F7x7', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='BYPASS_REG',func=pin_types.INPUT,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769AGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769AGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-180_Die451', 'Package_CSP:ST_WLCSP-180_Die451'], 'footprint':'Package_CSP:ST_WLCSP-180_Die451', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769AGYx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C10',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P5',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='P6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769AIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769AIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-180_Die451', 'Package_CSP:ST_WLCSP-180_Die451', 'Package_CSP:ST_WLCSP-180_Die451'], 'footprint':'Package_CSP:ST_WLCSP-180_Die451', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769AIYx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='A1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A3',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='C10',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C11',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M12',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='P3',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P5',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='P6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769BGTx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F769BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F769BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32F7 STM32F7x9', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f769bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F7.kicad_sym\nSTM32F769BITx\n\nArm Cortex-M7 STM32F7 STM32F7x9', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='DSIHOST_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='DSIHOST_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='DSIHOST_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='DSIHOST_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='DSIHOST_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='DSIHOST_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDDUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP_2',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDDSDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP_1',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])